#[repr(C)]pub struct AnEmptyStructInStruct {
pub v: EmptyStruct,
}Fields
v: EmptyStructTrait Implementations
Sourceimpl Clone for AnEmptyStructInStruct
impl Clone for AnEmptyStructInStruct
Sourcefn clone(&self) -> AnEmptyStructInStruct
fn clone(&self) -> AnEmptyStructInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<AnEmptyStructInStruct> for AnEmptyStructInStruct
impl CompatFrom<AnEmptyStructInStruct> for AnEmptyStructInStruct
Sourcefn compat_from(value: AnEmptyStructInStruct) -> AnEmptyStructInStruct
fn compat_from(value: AnEmptyStructInStruct) -> AnEmptyStructInStruct
Converts
value into a value of this type.Sourceimpl Debug for AnEmptyStructInStruct
impl Debug for AnEmptyStructInStruct
Sourceimpl<'a, ___E> Encode<AnEmptyStructInStruct, ___E> for &'a AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AnEmptyStructInStruct, ___E> for &'a AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnEmptyStructInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnEmptyStructInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, AnEmptyStructInStruct>
const COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, AnEmptyStructInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnEmptyStructInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnEmptyStructInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AnEmptyStructInStruct>, ___E> for &'a AnEmptyStructInStruct
impl<'a, ___E> EncodeOption<Box<'static, AnEmptyStructInStruct>, ___E> for &'a AnEmptyStructInStruct
Sourcefn encode_option(
this: Option<&'a AnEmptyStructInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AnEmptyStructInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a AnEmptyStructInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AnEmptyStructInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, AnEmptyStructInStruct>, ___E> for AnEmptyStructInStruct
impl<___E> EncodeOption<Box<'static, AnEmptyStructInStruct>, ___E> for AnEmptyStructInStruct
Sourcefn encode_option(
this: Option<AnEmptyStructInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AnEmptyStructInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<AnEmptyStructInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AnEmptyStructInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<AnEmptyStructInStruct> for AnEmptyStructInStruct
impl FromWire<AnEmptyStructInStruct> for AnEmptyStructInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, AnEmptyStructInStruct>
const COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, AnEmptyStructInStruct>
Sourcefn from_wire(wire: AnEmptyStructInStruct) -> AnEmptyStructInStruct
fn from_wire(wire: AnEmptyStructInStruct) -> AnEmptyStructInStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<AnEmptyStructInStruct> for AnEmptyStructInStruct
impl FromWireRef<AnEmptyStructInStruct> for AnEmptyStructInStruct
Sourcefn from_wire_ref(wire: &AnEmptyStructInStruct) -> AnEmptyStructInStruct
fn from_wire_ref(wire: &AnEmptyStructInStruct) -> AnEmptyStructInStruct
Converts the given reference to this type.
Sourceimpl Hash for AnEmptyStructInStruct
impl Hash for AnEmptyStructInStruct
Sourceimpl Ord for AnEmptyStructInStruct
impl Ord for AnEmptyStructInStruct
Sourcefn cmp(&self, other: &AnEmptyStructInStruct) -> Ordering
fn cmp(&self, other: &AnEmptyStructInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AnEmptyStructInStruct
impl PartialEq for AnEmptyStructInStruct
Sourceimpl PartialOrd for AnEmptyStructInStruct
impl PartialOrd for AnEmptyStructInStruct
impl Copy for AnEmptyStructInStruct
impl Eq for AnEmptyStructInStruct
impl StructuralPartialEq for AnEmptyStructInStruct