pub struct ArrayOfVectorOfEventInStructWithDefaultRights {
pub h: [Vec<Event>; 1],
}Fields
h: [Vec<Event>; 1]Trait Implementations
Sourceimpl CompatFrom<ArrayOfVectorOfEventInStructWithDefaultRights> for ArrayOfVectorOfEventInStructWithDefaultRights
impl CompatFrom<ArrayOfVectorOfEventInStructWithDefaultRights> for ArrayOfVectorOfEventInStructWithDefaultRights
Sourcefn compat_from(value: ArrayOfVectorOfEventInStructWithDefaultRights) -> Self
fn compat_from(value: ArrayOfVectorOfEventInStructWithDefaultRights) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayOfVectorOfEventInStructWithDefaultRights> for ArrayOfVectorOfEventInStructWithDefaultRights
impl CompatFrom<ArrayOfVectorOfEventInStructWithDefaultRights> for ArrayOfVectorOfEventInStructWithDefaultRights
Sourcefn compat_from(value: ArrayOfVectorOfEventInStructWithDefaultRights) -> Self
fn compat_from(value: ArrayOfVectorOfEventInStructWithDefaultRights) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<ArrayOfVectorOfEventInStructWithDefaultRights<'static>, ___E> for ArrayOfVectorOfEventInStructWithDefaultRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ArrayOfVectorOfEventInStructWithDefaultRights<'static>, ___E> for ArrayOfVectorOfEventInStructWithDefaultRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfVectorOfEventInStructWithDefaultRights<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfVectorOfEventInStructWithDefaultRights<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInStructWithDefaultRights<'static>>, ___E> for ArrayOfVectorOfEventInStructWithDefaultRightswhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInStructWithDefaultRights: Encode<ArrayOfVectorOfEventInStructWithDefaultRights<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInStructWithDefaultRights<'static>>, ___E> for ArrayOfVectorOfEventInStructWithDefaultRightswhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInStructWithDefaultRights: Encode<ArrayOfVectorOfEventInStructWithDefaultRights<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInStructWithDefaultRights<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInStructWithDefaultRights<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ArrayOfVectorOfEventInStructWithDefaultRights<'de>> for ArrayOfVectorOfEventInStructWithDefaultRights
impl<'de> FromWire<ArrayOfVectorOfEventInStructWithDefaultRights<'de>> for ArrayOfVectorOfEventInStructWithDefaultRights
Sourcefn from_wire(wire: ArrayOfVectorOfEventInStructWithDefaultRights<'de>) -> Self
fn from_wire(wire: ArrayOfVectorOfEventInStructWithDefaultRights<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ArrayOfVectorOfEventInStructWithDefaultRights
impl PartialEq for ArrayOfVectorOfEventInStructWithDefaultRights
Sourcefn eq(&self, other: &ArrayOfVectorOfEventInStructWithDefaultRights) -> bool
fn eq(&self, other: &ArrayOfVectorOfEventInStructWithDefaultRights) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ArrayOfVectorOfEventInStructWithDefaultRights