pub struct ArrayOfVectorOfEventInStructWithReducedRights {
pub h: [Vec<Event>; 1],
}Fields
h: [Vec<Event>; 1]Trait Implementations
Sourceimpl CompatFrom<ArrayOfVectorOfEventInStructWithReducedRights> for ArrayOfVectorOfEventInStructWithReducedRights
impl CompatFrom<ArrayOfVectorOfEventInStructWithReducedRights> for ArrayOfVectorOfEventInStructWithReducedRights
Sourcefn compat_from(value: ArrayOfVectorOfEventInStructWithReducedRights) -> Self
fn compat_from(value: ArrayOfVectorOfEventInStructWithReducedRights) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayOfVectorOfEventInStructWithReducedRights> for ArrayOfVectorOfEventInStructWithReducedRights
impl CompatFrom<ArrayOfVectorOfEventInStructWithReducedRights> for ArrayOfVectorOfEventInStructWithReducedRights
Sourcefn compat_from(value: ArrayOfVectorOfEventInStructWithReducedRights) -> Self
fn compat_from(value: ArrayOfVectorOfEventInStructWithReducedRights) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<ArrayOfVectorOfEventInStructWithReducedRights<'static>, ___E> for ArrayOfVectorOfEventInStructWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ArrayOfVectorOfEventInStructWithReducedRights<'static>, ___E> for ArrayOfVectorOfEventInStructWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfVectorOfEventInStructWithReducedRights<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfVectorOfEventInStructWithReducedRights<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInStructWithReducedRights<'static>>, ___E> for ArrayOfVectorOfEventInStructWithReducedRightswhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInStructWithReducedRights: Encode<ArrayOfVectorOfEventInStructWithReducedRights<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInStructWithReducedRights<'static>>, ___E> for ArrayOfVectorOfEventInStructWithReducedRightswhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInStructWithReducedRights: Encode<ArrayOfVectorOfEventInStructWithReducedRights<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInStructWithReducedRights<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInStructWithReducedRights<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ArrayOfVectorOfEventInStructWithReducedRights<'de>> for ArrayOfVectorOfEventInStructWithReducedRights
impl<'de> FromWire<ArrayOfVectorOfEventInStructWithReducedRights<'de>> for ArrayOfVectorOfEventInStructWithReducedRights
Sourcefn from_wire(wire: ArrayOfVectorOfEventInStructWithReducedRights<'de>) -> Self
fn from_wire(wire: ArrayOfVectorOfEventInStructWithReducedRights<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ArrayOfVectorOfEventInStructWithReducedRights
impl PartialEq for ArrayOfVectorOfEventInStructWithReducedRights
Sourcefn eq(&self, other: &ArrayOfVectorOfEventInStructWithReducedRights) -> bool
fn eq(&self, other: &ArrayOfVectorOfEventInStructWithReducedRights) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ArrayOfVectorOfEventInStructWithReducedRights