pub struct ArrayOfVectorOfEventInTableWithDefaultRightsStruct {
pub t: ArrayOfVectorOfEventInTableWithDefaultRights,
}Fields
t: ArrayOfVectorOfEventInTableWithDefaultRightsTrait Implementations
Sourceimpl CompatFrom<ArrayOfVectorOfEventInTableWithDefaultRightsStruct> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
impl CompatFrom<ArrayOfVectorOfEventInTableWithDefaultRightsStruct> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
Sourcefn compat_from(
value: ArrayOfVectorOfEventInTableWithDefaultRightsStruct,
) -> Self
fn compat_from( value: ArrayOfVectorOfEventInTableWithDefaultRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayOfVectorOfEventInTableWithDefaultRightsStruct> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
impl CompatFrom<ArrayOfVectorOfEventInTableWithDefaultRightsStruct> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
Sourcefn compat_from(
value: ArrayOfVectorOfEventInTableWithDefaultRightsStruct,
) -> Self
fn compat_from( value: ArrayOfVectorOfEventInTableWithDefaultRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>, ___E> for ArrayOfVectorOfEventInTableWithDefaultRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>, ___E> for ArrayOfVectorOfEventInTableWithDefaultRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>, ___E> for ArrayOfVectorOfEventInTableWithDefaultRightsStructwhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInTableWithDefaultRightsStruct: Encode<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>, ___E> for ArrayOfVectorOfEventInTableWithDefaultRightsStructwhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInTableWithDefaultRightsStruct: Encode<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'de>> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
impl<'de> FromWire<ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'de>> for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
Sourcefn from_wire(
wire: ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'de>,
) -> Self
fn from_wire( wire: ArrayOfVectorOfEventInTableWithDefaultRightsStruct<'de>, ) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
impl PartialEq for ArrayOfVectorOfEventInTableWithDefaultRightsStruct
Sourcefn eq(&self, other: &ArrayOfVectorOfEventInTableWithDefaultRightsStruct) -> bool
fn eq(&self, other: &ArrayOfVectorOfEventInTableWithDefaultRightsStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ArrayOfVectorOfEventInTableWithDefaultRightsStruct