pub struct ArrayOfVectorOfEventInUnionWithReducedRightsStruct {
pub u: ArrayOfVectorOfEventInUnionWithReducedRights,
}Fields
u: ArrayOfVectorOfEventInUnionWithReducedRightsTrait Implementations
Sourceimpl CompatFrom<ArrayOfVectorOfEventInUnionWithReducedRightsStruct> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
impl CompatFrom<ArrayOfVectorOfEventInUnionWithReducedRightsStruct> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
Sourcefn compat_from(
value: ArrayOfVectorOfEventInUnionWithReducedRightsStruct,
) -> Self
fn compat_from( value: ArrayOfVectorOfEventInUnionWithReducedRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayOfVectorOfEventInUnionWithReducedRightsStruct> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
impl CompatFrom<ArrayOfVectorOfEventInUnionWithReducedRightsStruct> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
Sourcefn compat_from(
value: ArrayOfVectorOfEventInUnionWithReducedRightsStruct,
) -> Self
fn compat_from( value: ArrayOfVectorOfEventInUnionWithReducedRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>, ___E> for ArrayOfVectorOfEventInUnionWithReducedRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>, ___E> for ArrayOfVectorOfEventInUnionWithReducedRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>, ___E> for ArrayOfVectorOfEventInUnionWithReducedRightsStructwhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInUnionWithReducedRightsStruct: Encode<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>, ___E> for ArrayOfVectorOfEventInUnionWithReducedRightsStructwhere
___E: Encoder + ?Sized,
ArrayOfVectorOfEventInUnionWithReducedRightsStruct: Encode<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'de>> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
impl<'de> FromWire<ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'de>> for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
Sourcefn from_wire(
wire: ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'de>,
) -> Self
fn from_wire( wire: ArrayOfVectorOfEventInUnionWithReducedRightsStruct<'de>, ) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
impl PartialEq for ArrayOfVectorOfEventInUnionWithReducedRightsStruct
Sourcefn eq(&self, other: &ArrayOfVectorOfEventInUnionWithReducedRightsStruct) -> bool
fn eq(&self, other: &ArrayOfVectorOfEventInUnionWithReducedRightsStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ArrayOfVectorOfEventInUnionWithReducedRightsStruct