pub struct Bounded32NonnullableString {
pub s0: String,
}Fields
s0: StringTrait Implementations
Sourceimpl Clone for Bounded32NonnullableString
impl Clone for Bounded32NonnullableString
Sourcefn clone(&self) -> Bounded32NonnullableString
fn clone(&self) -> Bounded32NonnullableString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Bounded32NonnullableString> for Bounded32NonnullableString
impl CompatFrom<Bounded32NonnullableString> for Bounded32NonnullableString
Sourcefn compat_from(value: Bounded32NonnullableString) -> Bounded32NonnullableString
fn compat_from(value: Bounded32NonnullableString) -> Bounded32NonnullableString
Converts
value into a value of this type.Sourceimpl Debug for Bounded32NonnullableString
impl Debug for Bounded32NonnullableString
Sourceimpl<'a, ___E> Encode<Bounded32NonnullableString<'static>, ___E> for &'a Bounded32NonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Bounded32NonnullableString<'static>, ___E> for &'a Bounded32NonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NonnullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NonnullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Bounded32NonnullableString<'static>, ___E> for Bounded32NonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Bounded32NonnullableString<'static>, ___E> for Bounded32NonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NonnullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NonnullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Bounded32NonnullableString<'static>>, ___E> for &'a Bounded32NonnullableStringwhere
___E: Encoder + ?Sized,
&'a Bounded32NonnullableString: Encode<Bounded32NonnullableString<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, Bounded32NonnullableString<'static>>, ___E> for &'a Bounded32NonnullableStringwhere
___E: Encoder + ?Sized,
&'a Bounded32NonnullableString: Encode<Bounded32NonnullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a Bounded32NonnullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NonnullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Bounded32NonnullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NonnullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Bounded32NonnullableString<'static>>, ___E> for Bounded32NonnullableStringwhere
___E: Encoder + ?Sized,
Bounded32NonnullableString: Encode<Bounded32NonnullableString<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, Bounded32NonnullableString<'static>>, ___E> for Bounded32NonnullableStringwhere
___E: Encoder + ?Sized,
Bounded32NonnullableString: Encode<Bounded32NonnullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<Bounded32NonnullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NonnullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Bounded32NonnullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NonnullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Bounded32NonnullableString<'de>> for Bounded32NonnullableString
impl<'de> FromWire<Bounded32NonnullableString<'de>> for Bounded32NonnullableString
Sourcefn from_wire(
wire: Bounded32NonnullableString<'de>,
) -> Bounded32NonnullableString
fn from_wire( wire: Bounded32NonnullableString<'de>, ) -> Bounded32NonnullableString
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Bounded32NonnullableString<'de>> for Bounded32NonnullableString
impl<'de> FromWireRef<Bounded32NonnullableString<'de>> for Bounded32NonnullableString
Sourcefn from_wire_ref(
wire: &Bounded32NonnullableString<'de>,
) -> Bounded32NonnullableString
fn from_wire_ref( wire: &Bounded32NonnullableString<'de>, ) -> Bounded32NonnullableString
Converts the given reference to this type.
Sourceimpl Hash for Bounded32NonnullableString
impl Hash for Bounded32NonnullableString
Sourceimpl Ord for Bounded32NonnullableString
impl Ord for Bounded32NonnullableString
Sourcefn cmp(&self, other: &Bounded32NonnullableString) -> Ordering
fn cmp(&self, other: &Bounded32NonnullableString) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Bounded32NonnullableString
impl PartialOrd for Bounded32NonnullableString
impl Eq for Bounded32NonnullableString
impl StructuralPartialEq for Bounded32NonnullableString