pub struct Bounded32NullableString {
pub s0: Option<String>,
}Fields
s0: Option<String>Trait Implementations
Sourceimpl Clone for Bounded32NullableString
impl Clone for Bounded32NullableString
Sourcefn clone(&self) -> Bounded32NullableString
fn clone(&self) -> Bounded32NullableString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Bounded32NullableString> for Bounded32NullableString
impl CompatFrom<Bounded32NullableString> for Bounded32NullableString
Sourcefn compat_from(value: Bounded32NullableString) -> Bounded32NullableString
fn compat_from(value: Bounded32NullableString) -> Bounded32NullableString
Converts
value into a value of this type.Sourceimpl Debug for Bounded32NullableString
impl Debug for Bounded32NullableString
Sourceimpl<'a, ___E> Encode<Bounded32NullableString<'static>, ___E> for &'a Bounded32NullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Bounded32NullableString<'static>, ___E> for &'a Bounded32NullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Bounded32NullableString<'static>>, ___E> for &'a Bounded32NullableStringwhere
___E: Encoder + ?Sized,
&'a Bounded32NullableString: Encode<Bounded32NullableString<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, Bounded32NullableString<'static>>, ___E> for &'a Bounded32NullableStringwhere
___E: Encoder + ?Sized,
&'a Bounded32NullableString: Encode<Bounded32NullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a Bounded32NullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Bounded32NullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Bounded32NullableString<'static>>, ___E> for Bounded32NullableStringwhere
___E: Encoder + ?Sized,
Bounded32NullableString: Encode<Bounded32NullableString<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, Bounded32NullableString<'static>>, ___E> for Bounded32NullableStringwhere
___E: Encoder + ?Sized,
Bounded32NullableString: Encode<Bounded32NullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<Bounded32NullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Bounded32NullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Bounded32NullableString<'de>> for Bounded32NullableString
impl<'de> FromWire<Bounded32NullableString<'de>> for Bounded32NullableString
Sourcefn from_wire(wire: Bounded32NullableString<'de>) -> Bounded32NullableString
fn from_wire(wire: Bounded32NullableString<'de>) -> Bounded32NullableString
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Bounded32NullableString<'de>> for Bounded32NullableString
impl<'de> FromWireRef<Bounded32NullableString<'de>> for Bounded32NullableString
Sourcefn from_wire_ref(wire: &Bounded32NullableString<'de>) -> Bounded32NullableString
fn from_wire_ref(wire: &Bounded32NullableString<'de>) -> Bounded32NullableString
Converts the given reference to this type.
Sourceimpl Hash for Bounded32NullableString
impl Hash for Bounded32NullableString
Sourceimpl Ord for Bounded32NullableString
impl Ord for Bounded32NullableString
Sourcefn cmp(&self, other: &Bounded32NullableString) -> Ordering
fn cmp(&self, other: &Bounded32NullableString) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Bounded32NullableString
impl PartialEq for Bounded32NullableString
Sourceimpl PartialOrd for Bounded32NullableString
impl PartialOrd for Bounded32NullableString
impl Eq for Bounded32NullableString
impl StructuralPartialEq for Bounded32NullableString