pub struct Bounded32NullableVectorOfHandles {
pub vh0: Option<Vec<NullableHandle>>,
}Fields
vh0: Option<Vec<NullableHandle>>Trait Implementations
Sourceimpl<___E> Encode<Bounded32NullableVectorOfHandles<'static>, ___E> for Bounded32NullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<Bounded32NullableVectorOfHandles<'static>, ___E> for Bounded32NullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableVectorOfHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableVectorOfHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, Bounded32NullableVectorOfHandles<'static>>, ___E> for Bounded32NullableVectorOfHandleswhere
___E: Encoder + ?Sized,
Bounded32NullableVectorOfHandles: Encode<Bounded32NullableVectorOfHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, Bounded32NullableVectorOfHandles<'static>>, ___E> for Bounded32NullableVectorOfHandleswhere
___E: Encoder + ?Sized,
Bounded32NullableVectorOfHandles: Encode<Bounded32NullableVectorOfHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Bounded32NullableVectorOfHandles<'de>> for Bounded32NullableVectorOfHandles
impl<'de> FromWire<Bounded32NullableVectorOfHandles<'de>> for Bounded32NullableVectorOfHandles
Sourcefn from_wire(wire: Bounded32NullableVectorOfHandles<'de>) -> Self
fn from_wire(wire: Bounded32NullableVectorOfHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for Bounded32NullableVectorOfHandles
impl PartialEq for Bounded32NullableVectorOfHandles
Sourcefn eq(&self, other: &Bounded32NullableVectorOfHandles) -> bool
fn eq(&self, other: &Bounded32NullableVectorOfHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Bounded32NullableVectorOfHandles