#[repr(C)]pub struct EmptyStructsInArrayInStruct {
pub v: [EmptyStruct; 4],
}Fields
v: [EmptyStruct; 4]Trait Implementations
Sourceimpl Clone for EmptyStructsInArrayInStruct
impl Clone for EmptyStructsInArrayInStruct
Sourcefn clone(&self) -> EmptyStructsInArrayInStruct
fn clone(&self) -> EmptyStructsInArrayInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
impl CompatFrom<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
Sourcefn compat_from(
value: EmptyStructsInArrayInStruct,
) -> EmptyStructsInArrayInStruct
fn compat_from( value: EmptyStructsInArrayInStruct, ) -> EmptyStructsInArrayInStruct
Converts
value into a value of this type.Sourceimpl Debug for EmptyStructsInArrayInStruct
impl Debug for EmptyStructsInArrayInStruct
Sourceimpl<'a, ___E> Encode<EmptyStructsInArrayInStruct, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmptyStructsInArrayInStruct, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EmptyStructsInArrayInStruct>, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: Encoder + ?Sized,
&'a EmptyStructsInArrayInStruct: Encode<EmptyStructsInArrayInStruct, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EmptyStructsInArrayInStruct>, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: Encoder + ?Sized,
&'a EmptyStructsInArrayInStruct: Encode<EmptyStructsInArrayInStruct, ___E>,
Sourcefn encode_option(
this: Option<&'a EmptyStructsInArrayInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructsInArrayInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a EmptyStructsInArrayInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructsInArrayInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EmptyStructsInArrayInStruct>, ___E> for EmptyStructsInArrayInStructwhere
___E: Encoder + ?Sized,
EmptyStructsInArrayInStruct: Encode<EmptyStructsInArrayInStruct, ___E>,
impl<___E> EncodeOption<Box<'static, EmptyStructsInArrayInStruct>, ___E> for EmptyStructsInArrayInStructwhere
___E: Encoder + ?Sized,
EmptyStructsInArrayInStruct: Encode<EmptyStructsInArrayInStruct, ___E>,
Sourcefn encode_option(
this: Option<EmptyStructsInArrayInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructsInArrayInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<EmptyStructsInArrayInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructsInArrayInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
impl FromWire<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
Sourcefn from_wire(wire: EmptyStructsInArrayInStruct) -> EmptyStructsInArrayInStruct
fn from_wire(wire: EmptyStructsInArrayInStruct) -> EmptyStructsInArrayInStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
impl FromWireRef<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
Sourcefn from_wire_ref(
wire: &EmptyStructsInArrayInStruct,
) -> EmptyStructsInArrayInStruct
fn from_wire_ref( wire: &EmptyStructsInArrayInStruct, ) -> EmptyStructsInArrayInStruct
Converts the given reference to this type.
Sourceimpl Hash for EmptyStructsInArrayInStruct
impl Hash for EmptyStructsInArrayInStruct
Sourceimpl Ord for EmptyStructsInArrayInStruct
impl Ord for EmptyStructsInArrayInStruct
Sourcefn cmp(&self, other: &EmptyStructsInArrayInStruct) -> Ordering
fn cmp(&self, other: &EmptyStructsInArrayInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for EmptyStructsInArrayInStruct
impl PartialOrd for EmptyStructsInArrayInStruct
impl Copy for EmptyStructsInArrayInStruct
impl Eq for EmptyStructsInArrayInStruct
impl StructuralPartialEq for EmptyStructsInArrayInStruct