pub struct EnvelopeInliningTestUnionStruct {
pub u: EnvelopeInliningTestUnion,
}Fields
u: EnvelopeInliningTestUnionTrait Implementations
Sourceimpl CompatFrom<EnvelopeInliningTestUnionStruct> for EnvelopeInliningTestUnionStruct
impl CompatFrom<EnvelopeInliningTestUnionStruct> for EnvelopeInliningTestUnionStruct
Sourcefn compat_from(value: EnvelopeInliningTestUnionStruct) -> Self
fn compat_from(value: EnvelopeInliningTestUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EnvelopeInliningTestUnionStruct> for EnvelopeInliningTestUnionStruct
impl CompatFrom<EnvelopeInliningTestUnionStruct> for EnvelopeInliningTestUnionStruct
Sourcefn compat_from(value: EnvelopeInliningTestUnionStruct) -> Self
fn compat_from(value: EnvelopeInliningTestUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<EnvelopeInliningTestUnionStruct<'static>, ___E> for EnvelopeInliningTestUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<EnvelopeInliningTestUnionStruct<'static>, ___E> for EnvelopeInliningTestUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EnvelopeInliningTestUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EnvelopeInliningTestUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, EnvelopeInliningTestUnionStruct<'static>>, ___E> for EnvelopeInliningTestUnionStructwhere
___E: Encoder + ?Sized,
EnvelopeInliningTestUnionStruct: Encode<EnvelopeInliningTestUnionStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, EnvelopeInliningTestUnionStruct<'static>>, ___E> for EnvelopeInliningTestUnionStructwhere
___E: Encoder + ?Sized,
EnvelopeInliningTestUnionStruct: Encode<EnvelopeInliningTestUnionStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EnvelopeInliningTestUnionStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EnvelopeInliningTestUnionStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EnvelopeInliningTestUnionStruct<'de>> for EnvelopeInliningTestUnionStruct
impl<'de> FromWire<EnvelopeInliningTestUnionStruct<'de>> for EnvelopeInliningTestUnionStruct
Sourcefn from_wire(wire: EnvelopeInliningTestUnionStruct<'de>) -> Self
fn from_wire(wire: EnvelopeInliningTestUnionStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for EnvelopeInliningTestUnionStruct
impl PartialEq for EnvelopeInliningTestUnionStruct
Sourcefn eq(&self, other: &EnvelopeInliningTestUnionStruct) -> bool
fn eq(&self, other: &EnvelopeInliningTestUnionStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EnvelopeInliningTestUnionStruct