pub struct FiveByteInArray {
pub elems: [FiveByte; 3],
}Fields
elems: [FiveByte; 3]Trait Implementations
Sourceimpl Clone for FiveByteInArray
impl Clone for FiveByteInArray
Sourcefn clone(&self) -> FiveByteInArray
fn clone(&self) -> FiveByteInArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<FiveByteInArray> for FiveByteInArray
impl CompatFrom<FiveByteInArray> for FiveByteInArray
Sourcefn compat_from(value: FiveByteInArray) -> FiveByteInArray
fn compat_from(value: FiveByteInArray) -> FiveByteInArray
Converts
value into a value of this type.Sourceimpl Debug for FiveByteInArray
impl Debug for FiveByteInArray
Sourceimpl<'a, ___E> Encode<FiveByteInArray, ___E> for &'a FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FiveByteInArray, ___E> for &'a FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FiveByteInArray, ___E> for FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FiveByteInArray, ___E> for FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FiveByteInArray>, ___E> for &'a FiveByteInArray
impl<'a, ___E> EncodeOption<Box<'static, FiveByteInArray>, ___E> for &'a FiveByteInArray
Sourcefn encode_option(
this: Option<&'a FiveByteInArray>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByteInArray>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a FiveByteInArray>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByteInArray>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, FiveByteInArray>, ___E> for FiveByteInArray
impl<___E> EncodeOption<Box<'static, FiveByteInArray>, ___E> for FiveByteInArray
Sourcefn encode_option(
this: Option<FiveByteInArray>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByteInArray>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<FiveByteInArray>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByteInArray>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<FiveByteInArray> for FiveByteInArray
impl FromWire<FiveByteInArray> for FiveByteInArray
Sourcefn from_wire(wire: FiveByteInArray) -> FiveByteInArray
fn from_wire(wire: FiveByteInArray) -> FiveByteInArray
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FiveByteInArray> for FiveByteInArray
impl FromWireRef<FiveByteInArray> for FiveByteInArray
Sourcefn from_wire_ref(wire: &FiveByteInArray) -> FiveByteInArray
fn from_wire_ref(wire: &FiveByteInArray) -> FiveByteInArray
Converts the given reference to this type.
Sourceimpl Hash for FiveByteInArray
impl Hash for FiveByteInArray
Sourceimpl Ord for FiveByteInArray
impl Ord for FiveByteInArray
Sourcefn cmp(&self, other: &FiveByteInArray) -> Ordering
fn cmp(&self, other: &FiveByteInArray) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FiveByteInArray
impl PartialEq for FiveByteInArray
Sourceimpl PartialOrd for FiveByteInArray
impl PartialOrd for FiveByteInArray
impl Copy for FiveByteInArray
impl Eq for FiveByteInArray
impl StructuralPartialEq for FiveByteInArray