pub struct FiveByteInStruct {
pub elem1: FiveByte,
pub elem2: FiveByte,
pub elem3: FiveByte,
}Fields
elem1: FiveByteelem2: FiveByteelem3: FiveByteTrait Implementations
Sourceimpl Clone for FiveByteInStruct
impl Clone for FiveByteInStruct
Sourcefn clone(&self) -> FiveByteInStruct
fn clone(&self) -> FiveByteInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<FiveByteInStruct> for FiveByteInStruct
impl CompatFrom<FiveByteInStruct> for FiveByteInStruct
Sourcefn compat_from(value: FiveByteInStruct) -> FiveByteInStruct
fn compat_from(value: FiveByteInStruct) -> FiveByteInStruct
Converts
value into a value of this type.Sourceimpl Debug for FiveByteInStruct
impl Debug for FiveByteInStruct
Sourceimpl<'a, ___E> Encode<FiveByteInStruct, ___E> for &'a FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FiveByteInStruct, ___E> for &'a FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FiveByteInStruct, ___E> for FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FiveByteInStruct, ___E> for FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FiveByteInStruct>, ___E> for &'a FiveByteInStruct
impl<'a, ___E> EncodeOption<Box<'static, FiveByteInStruct>, ___E> for &'a FiveByteInStruct
Sourcefn encode_option(
this: Option<&'a FiveByteInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByteInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a FiveByteInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByteInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, FiveByteInStruct>, ___E> for FiveByteInStruct
impl<___E> EncodeOption<Box<'static, FiveByteInStruct>, ___E> for FiveByteInStruct
Sourcefn encode_option(
this: Option<FiveByteInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByteInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<FiveByteInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByteInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<FiveByteInStruct> for FiveByteInStruct
impl FromWire<FiveByteInStruct> for FiveByteInStruct
Sourcefn from_wire(wire: FiveByteInStruct) -> FiveByteInStruct
fn from_wire(wire: FiveByteInStruct) -> FiveByteInStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FiveByteInStruct> for FiveByteInStruct
impl FromWireRef<FiveByteInStruct> for FiveByteInStruct
Sourcefn from_wire_ref(wire: &FiveByteInStruct) -> FiveByteInStruct
fn from_wire_ref(wire: &FiveByteInStruct) -> FiveByteInStruct
Converts the given reference to this type.
Sourceimpl Hash for FiveByteInStruct
impl Hash for FiveByteInStruct
Sourceimpl Ord for FiveByteInStruct
impl Ord for FiveByteInStruct
Sourcefn cmp(&self, other: &FiveByteInStruct) -> Ordering
fn cmp(&self, other: &FiveByteInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FiveByteInStruct
impl PartialEq for FiveByteInStruct
Sourceimpl PartialOrd for FiveByteInStruct
impl PartialOrd for FiveByteInStruct
impl Copy for FiveByteInStruct
impl Eq for FiveByteInStruct
impl StructuralPartialEq for FiveByteInStruct