pub struct FlexibleBitsUint64(/* private fields */);Implementations
Sourceimpl FlexibleBitsUint64
impl FlexibleBitsUint64
pub const A: FlexibleBitsUint64
pub const B: FlexibleBitsUint64
Sourceimpl FlexibleBitsUint64
impl FlexibleBitsUint64
Sourcepub const fn empty() -> FlexibleBitsUint64
pub const fn empty() -> FlexibleBitsUint64
Get a flags value with all bits unset.
Sourcepub const fn all() -> FlexibleBitsUint64
pub const fn all() -> FlexibleBitsUint64
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<FlexibleBitsUint64>
pub const fn from_bits(bits: u64) -> Option<FlexibleBitsUint64>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> FlexibleBitsUint64
pub const fn from_bits_truncate(bits: u64) -> FlexibleBitsUint64
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> FlexibleBitsUint64
pub const fn from_bits_retain(bits: u64) -> FlexibleBitsUint64
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FlexibleBitsUint64>
pub fn from_name(name: &str) -> Option<FlexibleBitsUint64>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FlexibleBitsUint64) -> bool
pub const fn intersects(&self, other: FlexibleBitsUint64) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: FlexibleBitsUint64) -> bool
pub const fn contains(&self, other: FlexibleBitsUint64) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: FlexibleBitsUint64)
pub fn insert(&mut self, other: FlexibleBitsUint64)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: FlexibleBitsUint64)
pub fn remove(&mut self, other: FlexibleBitsUint64)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FlexibleBitsUint64)
pub fn toggle(&mut self, other: FlexibleBitsUint64)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: FlexibleBitsUint64, value: bool)
pub fn set(&mut self, other: FlexibleBitsUint64, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
pub const fn intersection(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
pub const fn union(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
pub const fn difference(self, other: FlexibleBitsUint64) -> FlexibleBitsUint64
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: FlexibleBitsUint64,
) -> FlexibleBitsUint64
pub const fn symmetric_difference( self, other: FlexibleBitsUint64, ) -> FlexibleBitsUint64
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> FlexibleBitsUint64
pub const fn complement(self) -> FlexibleBitsUint64
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FlexibleBitsUint64
impl FlexibleBitsUint64
Sourcepub const fn iter(&self) -> Iter<FlexibleBitsUint64>
pub const fn iter(&self) -> Iter<FlexibleBitsUint64>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FlexibleBitsUint64>
pub const fn iter_names(&self) -> IterNames<FlexibleBitsUint64>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.