#[repr(C)]pub struct GoldenBitsStruct {
pub v: GoldenBits,
}Fields
v: GoldenBitsTrait Implementations
Sourceimpl Clone for GoldenBitsStruct
impl Clone for GoldenBitsStruct
Sourcefn clone(&self) -> GoldenBitsStruct
fn clone(&self) -> GoldenBitsStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenBitsStruct> for GoldenBitsStruct
impl CompatFrom<GoldenBitsStruct> for GoldenBitsStruct
Sourcefn compat_from(value: GoldenBitsStruct) -> GoldenBitsStruct
fn compat_from(value: GoldenBitsStruct) -> GoldenBitsStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenBitsStruct
impl Debug for GoldenBitsStruct
Sourceimpl<'a, ___E> Encode<GoldenBitsStruct, ___E> for &'a GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenBitsStruct, ___E> for &'a GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenBitsStruct, ___E> for GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenBitsStruct, ___E> for GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, GoldenBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, GoldenBitsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenBitsStruct>, ___E> for &'a GoldenBitsStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenBitsStruct>, ___E> for &'a GoldenBitsStruct
Sourcefn encode_option(
this: Option<&'a GoldenBitsStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenBitsStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenBitsStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenBitsStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenBitsStruct>, ___E> for GoldenBitsStruct
impl<___E> EncodeOption<Box<'static, GoldenBitsStruct>, ___E> for GoldenBitsStruct
Sourcefn encode_option(
this: Option<GoldenBitsStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenBitsStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenBitsStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenBitsStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenBitsStruct> for GoldenBitsStruct
impl FromWire<GoldenBitsStruct> for GoldenBitsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, GoldenBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, GoldenBitsStruct>
Sourcefn from_wire(wire: GoldenBitsStruct) -> GoldenBitsStruct
fn from_wire(wire: GoldenBitsStruct) -> GoldenBitsStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenBitsStruct> for GoldenBitsStruct
impl FromWireRef<GoldenBitsStruct> for GoldenBitsStruct
Sourcefn from_wire_ref(wire: &GoldenBitsStruct) -> GoldenBitsStruct
fn from_wire_ref(wire: &GoldenBitsStruct) -> GoldenBitsStruct
Converts the given reference to this type.
Sourceimpl Hash for GoldenBitsStruct
impl Hash for GoldenBitsStruct
Sourceimpl Ord for GoldenBitsStruct
impl Ord for GoldenBitsStruct
Sourcefn cmp(&self, other: &GoldenBitsStruct) -> Ordering
fn cmp(&self, other: &GoldenBitsStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenBitsStruct
impl PartialEq for GoldenBitsStruct
Sourceimpl PartialOrd for GoldenBitsStruct
impl PartialOrd for GoldenBitsStruct
impl Copy for GoldenBitsStruct
impl Eq for GoldenBitsStruct
impl StructuralPartialEq for GoldenBitsStruct