#[repr(C)]pub struct GoldenDoubleStruct {
pub v: f64,
}Fields
v: f64Trait Implementations
Sourceimpl Clone for GoldenDoubleStruct
impl Clone for GoldenDoubleStruct
Sourcefn clone(&self) -> GoldenDoubleStruct
fn clone(&self) -> GoldenDoubleStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenDoubleStruct> for GoldenDoubleStruct
impl CompatFrom<GoldenDoubleStruct> for GoldenDoubleStruct
Sourcefn compat_from(value: GoldenDoubleStruct) -> GoldenDoubleStruct
fn compat_from(value: GoldenDoubleStruct) -> GoldenDoubleStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenDoubleStruct
impl Debug for GoldenDoubleStruct
Sourceimpl<'a, ___E> Encode<GoldenDoubleStruct, ___E> for &'a GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenDoubleStruct, ___E> for &'a GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenDoubleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenDoubleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, GoldenDoubleStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, GoldenDoubleStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenDoubleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenDoubleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenDoubleStruct>, ___E> for &'a GoldenDoubleStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenDoubleStruct>, ___E> for &'a GoldenDoubleStruct
Sourcefn encode_option(
this: Option<&'a GoldenDoubleStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenDoubleStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenDoubleStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenDoubleStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenDoubleStruct>, ___E> for GoldenDoubleStruct
impl<___E> EncodeOption<Box<'static, GoldenDoubleStruct>, ___E> for GoldenDoubleStruct
Sourcefn encode_option(
this: Option<GoldenDoubleStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenDoubleStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenDoubleStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenDoubleStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenDoubleStruct> for GoldenDoubleStruct
impl FromWire<GoldenDoubleStruct> for GoldenDoubleStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, GoldenDoubleStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, GoldenDoubleStruct>
Sourcefn from_wire(wire: GoldenDoubleStruct) -> GoldenDoubleStruct
fn from_wire(wire: GoldenDoubleStruct) -> GoldenDoubleStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenDoubleStruct> for GoldenDoubleStruct
impl FromWireRef<GoldenDoubleStruct> for GoldenDoubleStruct
Sourcefn from_wire_ref(wire: &GoldenDoubleStruct) -> GoldenDoubleStruct
fn from_wire_ref(wire: &GoldenDoubleStruct) -> GoldenDoubleStruct
Converts the given reference to this type.
Sourceimpl PartialEq for GoldenDoubleStruct
impl PartialEq for GoldenDoubleStruct
Sourceimpl PartialOrd for GoldenDoubleStruct
impl PartialOrd for GoldenDoubleStruct
impl Copy for GoldenDoubleStruct
impl StructuralPartialEq for GoldenDoubleStruct