pub struct GoldenTableStruct {
pub v: GoldenTable,
}Fields
v: GoldenTableTrait Implementations
Sourceimpl Clone for GoldenTableStruct
impl Clone for GoldenTableStruct
Sourcefn clone(&self) -> GoldenTableStruct
fn clone(&self) -> GoldenTableStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenTableStruct> for GoldenTableStruct
impl CompatFrom<GoldenTableStruct> for GoldenTableStruct
Sourcefn compat_from(value: GoldenTableStruct) -> GoldenTableStruct
fn compat_from(value: GoldenTableStruct) -> GoldenTableStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenTableStruct
impl Debug for GoldenTableStruct
Sourceimpl<'a, ___E> Encode<GoldenTableStruct<'static>, ___E> for &'a GoldenTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<GoldenTableStruct<'static>, ___E> for &'a GoldenTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenTableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenTableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenTableStruct<'static>, ___E> for GoldenTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<GoldenTableStruct<'static>, ___E> for GoldenTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenTableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenTableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenTableStruct<'static>>, ___E> for &'a GoldenTableStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenTableStruct<'static>>, ___E> for &'a GoldenTableStruct
Sourcefn encode_option(
this: Option<&'a GoldenTableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenTableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenTableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenTableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenTableStruct<'static>>, ___E> for GoldenTableStruct
impl<___E> EncodeOption<Box<'static, GoldenTableStruct<'static>>, ___E> for GoldenTableStruct
Sourcefn encode_option(
this: Option<GoldenTableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenTableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenTableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenTableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenTableStruct<'de>> for GoldenTableStruct
impl<'de> FromWire<GoldenTableStruct<'de>> for GoldenTableStruct
Sourcefn from_wire(wire: GoldenTableStruct<'de>) -> GoldenTableStruct
fn from_wire(wire: GoldenTableStruct<'de>) -> GoldenTableStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenTableStruct<'de>> for GoldenTableStruct
impl<'de> FromWireRef<GoldenTableStruct<'de>> for GoldenTableStruct
Sourcefn from_wire_ref(wire: &GoldenTableStruct<'de>) -> GoldenTableStruct
fn from_wire_ref(wire: &GoldenTableStruct<'de>) -> GoldenTableStruct
Converts the given reference to this type.
Sourceimpl Hash for GoldenTableStruct
impl Hash for GoldenTableStruct
Sourceimpl Ord for GoldenTableStruct
impl Ord for GoldenTableStruct
Sourcefn cmp(&self, other: &GoldenTableStruct) -> Ordering
fn cmp(&self, other: &GoldenTableStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenTableStruct
impl PartialEq for GoldenTableStruct
Sourceimpl PartialOrd for GoldenTableStruct
impl PartialOrd for GoldenTableStruct
impl Copy for GoldenTableStruct
impl Eq for GoldenTableStruct
impl StructuralPartialEq for GoldenTableStruct