pub struct LargeArrays {
pub a33: [Option<String>; 33],
pub a100: [u8; 100],
pub nested: Vec<[[String; 100]; 200]>,
}Fields
a33: [Option<String>; 33]a100: [u8; 100]nested: Vec<[[String; 100]; 200]>Trait Implementations
Sourceimpl Clone for LargeArrays
impl Clone for LargeArrays
Sourcefn clone(&self) -> LargeArrays
fn clone(&self) -> LargeArrays
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<LargeArrays> for LargeArrays
impl CompatFrom<LargeArrays> for LargeArrays
Sourcefn compat_from(value: LargeArrays) -> LargeArrays
fn compat_from(value: LargeArrays) -> LargeArrays
Converts
value into a value of this type.Sourceimpl Debug for LargeArrays
impl Debug for LargeArrays
Sourceimpl<'a, ___E> Encode<LargeArrays<'static>, ___E> for &'a LargeArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<LargeArrays<'static>, ___E> for &'a LargeArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LargeArrays<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LargeArrays<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LargeArrays<'static>, ___E> for LargeArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<LargeArrays<'static>, ___E> for LargeArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LargeArrays<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LargeArrays<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, LargeArrays<'static>>, ___E> for &'a LargeArrays
impl<'a, ___E> EncodeOption<Box<'static, LargeArrays<'static>>, ___E> for &'a LargeArrays
Sourcefn encode_option(
this: Option<&'a LargeArrays>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LargeArrays<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a LargeArrays>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LargeArrays<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, LargeArrays<'static>>, ___E> for LargeArrays
impl<___E> EncodeOption<Box<'static, LargeArrays<'static>>, ___E> for LargeArrays
Sourcefn encode_option(
this: Option<LargeArrays>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LargeArrays<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<LargeArrays>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LargeArrays<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<LargeArrays<'de>> for LargeArrays
impl<'de> FromWire<LargeArrays<'de>> for LargeArrays
Sourcefn from_wire(wire: LargeArrays<'de>) -> LargeArrays
fn from_wire(wire: LargeArrays<'de>) -> LargeArrays
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<LargeArrays<'de>> for LargeArrays
impl<'de> FromWireRef<LargeArrays<'de>> for LargeArrays
Sourcefn from_wire_ref(wire: &LargeArrays<'de>) -> LargeArrays
fn from_wire_ref(wire: &LargeArrays<'de>) -> LargeArrays
Converts the given reference to this type.
Sourceimpl Hash for LargeArrays
impl Hash for LargeArrays
Sourceimpl Ord for LargeArrays
impl Ord for LargeArrays
Sourcefn cmp(&self, other: &LargeArrays) -> Ordering
fn cmp(&self, other: &LargeArrays) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LargeArrays
impl PartialEq for LargeArrays
Sourceimpl PartialOrd for LargeArrays
impl PartialOrd for LargeArrays
impl Eq for LargeArrays
impl StructuralPartialEq for LargeArrays