pub struct MultipleBoundedNonnullableVectorsOfHandles {
pub vh0: Vec<NullableHandle>,
pub vh1: Vec<NullableHandle>,
}Fields
vh0: Vec<NullableHandle>vh1: Vec<NullableHandle>Trait Implementations
Sourceimpl CompatFrom<MultipleBoundedNonnullableVectorsOfHandles> for MultipleBoundedNonnullableVectorsOfHandles
impl CompatFrom<MultipleBoundedNonnullableVectorsOfHandles> for MultipleBoundedNonnullableVectorsOfHandles
Sourcefn compat_from(value: MultipleBoundedNonnullableVectorsOfHandles) -> Self
fn compat_from(value: MultipleBoundedNonnullableVectorsOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MultipleBoundedNonnullableVectorsOfHandles> for MultipleBoundedNonnullableVectorsOfHandles
impl CompatFrom<MultipleBoundedNonnullableVectorsOfHandles> for MultipleBoundedNonnullableVectorsOfHandles
Sourcefn compat_from(value: MultipleBoundedNonnullableVectorsOfHandles) -> Self
fn compat_from(value: MultipleBoundedNonnullableVectorsOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<MultipleBoundedNonnullableVectorsOfHandles<'static>, ___E> for MultipleBoundedNonnullableVectorsOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<MultipleBoundedNonnullableVectorsOfHandles<'static>, ___E> for MultipleBoundedNonnullableVectorsOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfHandles<'static>>, ___E> for MultipleBoundedNonnullableVectorsOfHandleswhere
___E: Encoder + ?Sized,
MultipleBoundedNonnullableVectorsOfHandles: Encode<MultipleBoundedNonnullableVectorsOfHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfHandles<'static>>, ___E> for MultipleBoundedNonnullableVectorsOfHandleswhere
___E: Encoder + ?Sized,
MultipleBoundedNonnullableVectorsOfHandles: Encode<MultipleBoundedNonnullableVectorsOfHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MultipleBoundedNonnullableVectorsOfHandles<'de>> for MultipleBoundedNonnullableVectorsOfHandles
impl<'de> FromWire<MultipleBoundedNonnullableVectorsOfHandles<'de>> for MultipleBoundedNonnullableVectorsOfHandles
Sourcefn from_wire(wire: MultipleBoundedNonnullableVectorsOfHandles<'de>) -> Self
fn from_wire(wire: MultipleBoundedNonnullableVectorsOfHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for MultipleBoundedNonnullableVectorsOfHandles
impl PartialEq for MultipleBoundedNonnullableVectorsOfHandles
Sourcefn eq(&self, other: &MultipleBoundedNonnullableVectorsOfHandles) -> bool
fn eq(&self, other: &MultipleBoundedNonnullableVectorsOfHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MultipleBoundedNonnullableVectorsOfHandles