pub struct MultipleBoundedNullableVectorsOfHandles {
pub vh0: Option<Vec<NullableHandle>>,
pub vh1: Option<Vec<NullableHandle>>,
}Fields
vh0: Option<Vec<NullableHandle>>vh1: Option<Vec<NullableHandle>>Trait Implementations
Sourceimpl CompatFrom<MultipleBoundedNullableVectorsOfHandles> for MultipleBoundedNullableVectorsOfHandles
impl CompatFrom<MultipleBoundedNullableVectorsOfHandles> for MultipleBoundedNullableVectorsOfHandles
Sourcefn compat_from(value: MultipleBoundedNullableVectorsOfHandles) -> Self
fn compat_from(value: MultipleBoundedNullableVectorsOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MultipleBoundedNullableVectorsOfHandles> for MultipleBoundedNullableVectorsOfHandles
impl CompatFrom<MultipleBoundedNullableVectorsOfHandles> for MultipleBoundedNullableVectorsOfHandles
Sourcefn compat_from(value: MultipleBoundedNullableVectorsOfHandles) -> Self
fn compat_from(value: MultipleBoundedNullableVectorsOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<MultipleBoundedNullableVectorsOfHandles<'static>, ___E> for MultipleBoundedNullableVectorsOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<MultipleBoundedNullableVectorsOfHandles<'static>, ___E> for MultipleBoundedNullableVectorsOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfHandles<'static>>, ___E> for MultipleBoundedNullableVectorsOfHandleswhere
___E: Encoder + ?Sized,
MultipleBoundedNullableVectorsOfHandles: Encode<MultipleBoundedNullableVectorsOfHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfHandles<'static>>, ___E> for MultipleBoundedNullableVectorsOfHandleswhere
___E: Encoder + ?Sized,
MultipleBoundedNullableVectorsOfHandles: Encode<MultipleBoundedNullableVectorsOfHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MultipleBoundedNullableVectorsOfHandles<'de>> for MultipleBoundedNullableVectorsOfHandles
impl<'de> FromWire<MultipleBoundedNullableVectorsOfHandles<'de>> for MultipleBoundedNullableVectorsOfHandles
Sourcefn from_wire(wire: MultipleBoundedNullableVectorsOfHandles<'de>) -> Self
fn from_wire(wire: MultipleBoundedNullableVectorsOfHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for MultipleBoundedNullableVectorsOfHandles
impl PartialEq for MultipleBoundedNullableVectorsOfHandles
Sourcefn eq(&self, other: &MultipleBoundedNullableVectorsOfHandles) -> bool
fn eq(&self, other: &MultipleBoundedNullableVectorsOfHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MultipleBoundedNullableVectorsOfHandles