pub struct MultipleNonnullableVectorsOfUint32s {
pub vu0: Vec<u32>,
pub vu1: Vec<u32>,
}Fields
vu0: Vec<u32>vu1: Vec<u32>Trait Implementations
Sourceimpl Clone for MultipleNonnullableVectorsOfUint32s
impl Clone for MultipleNonnullableVectorsOfUint32s
Sourcefn clone(&self) -> MultipleNonnullableVectorsOfUint32s
fn clone(&self) -> MultipleNonnullableVectorsOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<MultipleNonnullableVectorsOfUint32s> for MultipleNonnullableVectorsOfUint32s
impl CompatFrom<MultipleNonnullableVectorsOfUint32s> for MultipleNonnullableVectorsOfUint32s
Sourcefn compat_from(
value: MultipleNonnullableVectorsOfUint32s,
) -> MultipleNonnullableVectorsOfUint32s
fn compat_from( value: MultipleNonnullableVectorsOfUint32s, ) -> MultipleNonnullableVectorsOfUint32s
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E> for &'a MultipleNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E> for &'a MultipleNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleNonnullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleNonnullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E> for MultipleNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E> for MultipleNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleNonnullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleNonnullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleNonnullableVectorsOfUint32s: Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleNonnullableVectorsOfUint32s: Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a MultipleNonnullableVectorsOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a MultipleNonnullableVectorsOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>, ___E> for MultipleNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleNonnullableVectorsOfUint32s: Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>, ___E> for MultipleNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleNonnullableVectorsOfUint32s: Encode<MultipleNonnullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<MultipleNonnullableVectorsOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<MultipleNonnullableVectorsOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleNonnullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MultipleNonnullableVectorsOfUint32s<'de>> for MultipleNonnullableVectorsOfUint32s
impl<'de> FromWire<MultipleNonnullableVectorsOfUint32s<'de>> for MultipleNonnullableVectorsOfUint32s
Sourcefn from_wire(
wire: MultipleNonnullableVectorsOfUint32s<'de>,
) -> MultipleNonnullableVectorsOfUint32s
fn from_wire( wire: MultipleNonnullableVectorsOfUint32s<'de>, ) -> MultipleNonnullableVectorsOfUint32s
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MultipleNonnullableVectorsOfUint32s<'de>> for MultipleNonnullableVectorsOfUint32s
impl<'de> FromWireRef<MultipleNonnullableVectorsOfUint32s<'de>> for MultipleNonnullableVectorsOfUint32s
Sourcefn from_wire_ref(
wire: &MultipleNonnullableVectorsOfUint32s<'de>,
) -> MultipleNonnullableVectorsOfUint32s
fn from_wire_ref( wire: &MultipleNonnullableVectorsOfUint32s<'de>, ) -> MultipleNonnullableVectorsOfUint32s
Converts the given reference to this type.
Sourceimpl Ord for MultipleNonnullableVectorsOfUint32s
impl Ord for MultipleNonnullableVectorsOfUint32s
Sourcefn cmp(&self, other: &MultipleNonnullableVectorsOfUint32s) -> Ordering
fn cmp(&self, other: &MultipleNonnullableVectorsOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MultipleNonnullableVectorsOfUint32s
impl PartialEq for MultipleNonnullableVectorsOfUint32s
Sourcefn eq(&self, other: &MultipleNonnullableVectorsOfUint32s) -> bool
fn eq(&self, other: &MultipleNonnullableVectorsOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MultipleNonnullableVectorsOfUint32s
impl PartialOrd for MultipleNonnullableVectorsOfUint32s
impl Eq for MultipleNonnullableVectorsOfUint32s
impl StructuralPartialEq for MultipleNonnullableVectorsOfUint32s