#[repr(C)]pub struct OneLayerStructNoPaddingAlign4 {
pub a: u16,
pub b: u8,
pub c: u8,
pub d: u32,
}Fields
a: u16b: u8c: u8d: u32Trait Implementations
Sourceimpl Clone for OneLayerStructNoPaddingAlign4
impl Clone for OneLayerStructNoPaddingAlign4
Sourcefn clone(&self) -> OneLayerStructNoPaddingAlign4
fn clone(&self) -> OneLayerStructNoPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
impl CompatFrom<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
Sourcefn compat_from(
value: OneLayerStructNoPaddingAlign4,
) -> OneLayerStructNoPaddingAlign4
fn compat_from( value: OneLayerStructNoPaddingAlign4, ) -> OneLayerStructNoPaddingAlign4
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign4>, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
&'a OneLayerStructNoPaddingAlign4: Encode<OneLayerStructNoPaddingAlign4, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign4>, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
&'a OneLayerStructNoPaddingAlign4: Encode<OneLayerStructNoPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<&'a OneLayerStructNoPaddingAlign4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a OneLayerStructNoPaddingAlign4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign4>, ___E> for OneLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
OneLayerStructNoPaddingAlign4: Encode<OneLayerStructNoPaddingAlign4, ___E>,
impl<___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign4>, ___E> for OneLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
OneLayerStructNoPaddingAlign4: Encode<OneLayerStructNoPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<OneLayerStructNoPaddingAlign4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<OneLayerStructNoPaddingAlign4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
impl FromWire<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
Sourcefn from_wire(
wire: OneLayerStructNoPaddingAlign4,
) -> OneLayerStructNoPaddingAlign4
fn from_wire( wire: OneLayerStructNoPaddingAlign4, ) -> OneLayerStructNoPaddingAlign4
Converts the given owned value to this type.
Sourceimpl FromWireRef<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
impl FromWireRef<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
Sourcefn from_wire_ref(
wire: &OneLayerStructNoPaddingAlign4,
) -> OneLayerStructNoPaddingAlign4
fn from_wire_ref( wire: &OneLayerStructNoPaddingAlign4, ) -> OneLayerStructNoPaddingAlign4
Converts the given reference to this type.
Sourceimpl Hash for OneLayerStructNoPaddingAlign4
impl Hash for OneLayerStructNoPaddingAlign4
Sourceimpl Ord for OneLayerStructNoPaddingAlign4
impl Ord for OneLayerStructNoPaddingAlign4
Sourcefn cmp(&self, other: &OneLayerStructNoPaddingAlign4) -> Ordering
fn cmp(&self, other: &OneLayerStructNoPaddingAlign4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneLayerStructNoPaddingAlign4
impl PartialEq for OneLayerStructNoPaddingAlign4
Sourcefn eq(&self, other: &OneLayerStructNoPaddingAlign4) -> bool
fn eq(&self, other: &OneLayerStructNoPaddingAlign4) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OneLayerStructNoPaddingAlign4
impl PartialOrd for OneLayerStructNoPaddingAlign4
impl Copy for OneLayerStructNoPaddingAlign4
impl Eq for OneLayerStructNoPaddingAlign4
impl StructuralPartialEq for OneLayerStructNoPaddingAlign4