#[repr(C)]pub struct OneLayerStructWithBool {
pub a: bool,
pub b: u8,
pub c: u16,
pub d: u32,
}Fields
a: boolb: u8c: u16d: u32Trait Implementations
Sourceimpl Clone for OneLayerStructWithBool
impl Clone for OneLayerStructWithBool
Sourcefn clone(&self) -> OneLayerStructWithBool
fn clone(&self) -> OneLayerStructWithBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OneLayerStructWithBool> for OneLayerStructWithBool
impl CompatFrom<OneLayerStructWithBool> for OneLayerStructWithBool
Sourcefn compat_from(value: OneLayerStructWithBool) -> OneLayerStructWithBool
fn compat_from(value: OneLayerStructWithBool) -> OneLayerStructWithBool
Converts
value into a value of this type.Sourceimpl Debug for OneLayerStructWithBool
impl Debug for OneLayerStructWithBool
Sourceimpl<'a, ___E> Encode<OneLayerStructWithBool, ___E> for &'a OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithBool, ___E> for &'a OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithBool>, ___E> for &'a OneLayerStructWithBool
impl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithBool>, ___E> for &'a OneLayerStructWithBool
Sourcefn encode_option(
this: Option<&'a OneLayerStructWithBool>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithBool>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a OneLayerStructWithBool>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithBool>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OneLayerStructWithBool>, ___E> for OneLayerStructWithBool
impl<___E> EncodeOption<Box<'static, OneLayerStructWithBool>, ___E> for OneLayerStructWithBool
Sourcefn encode_option(
this: Option<OneLayerStructWithBool>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithBool>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<OneLayerStructWithBool>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithBool>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<OneLayerStructWithBool> for OneLayerStructWithBool
impl FromWire<OneLayerStructWithBool> for OneLayerStructWithBool
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
Sourcefn from_wire(wire: OneLayerStructWithBool) -> OneLayerStructWithBool
fn from_wire(wire: OneLayerStructWithBool) -> OneLayerStructWithBool
Converts the given owned value to this type.
Sourceimpl FromWireRef<OneLayerStructWithBool> for OneLayerStructWithBool
impl FromWireRef<OneLayerStructWithBool> for OneLayerStructWithBool
Sourcefn from_wire_ref(wire: &OneLayerStructWithBool) -> OneLayerStructWithBool
fn from_wire_ref(wire: &OneLayerStructWithBool) -> OneLayerStructWithBool
Converts the given reference to this type.
Sourceimpl Hash for OneLayerStructWithBool
impl Hash for OneLayerStructWithBool
Sourceimpl Ord for OneLayerStructWithBool
impl Ord for OneLayerStructWithBool
Sourcefn cmp(&self, other: &OneLayerStructWithBool) -> Ordering
fn cmp(&self, other: &OneLayerStructWithBool) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneLayerStructWithBool
impl PartialEq for OneLayerStructWithBool
Sourceimpl PartialOrd for OneLayerStructWithBool
impl PartialOrd for OneLayerStructWithBool
impl Copy for OneLayerStructWithBool
impl Eq for OneLayerStructWithBool
impl StructuralPartialEq for OneLayerStructWithBool