pub struct OutOfLineArrayOfNonnullableHandles {
pub handles: Option<Box<NonnullableHandleArray>>,
}Fields
handles: Option<Box<NonnullableHandleArray>>Trait Implementations
Sourceimpl CompatFrom<OutOfLineArrayOfNonnullableHandles> for OutOfLineArrayOfNonnullableHandles
impl CompatFrom<OutOfLineArrayOfNonnullableHandles> for OutOfLineArrayOfNonnullableHandles
Sourcefn compat_from(value: OutOfLineArrayOfNonnullableHandles) -> Self
fn compat_from(value: OutOfLineArrayOfNonnullableHandles) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<OutOfLineArrayOfNonnullableHandles> for OutOfLineArrayOfNonnullableHandles
impl CompatFrom<OutOfLineArrayOfNonnullableHandles> for OutOfLineArrayOfNonnullableHandles
Sourcefn compat_from(value: OutOfLineArrayOfNonnullableHandles) -> Self
fn compat_from(value: OutOfLineArrayOfNonnullableHandles) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<OutOfLineArrayOfNonnullableHandles<'static>, ___E> for OutOfLineArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<OutOfLineArrayOfNonnullableHandles<'static>, ___E> for OutOfLineArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineArrayOfNonnullableHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineArrayOfNonnullableHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, OutOfLineArrayOfNonnullableHandles<'static>>, ___E> for OutOfLineArrayOfNonnullableHandleswhere
___E: Encoder + ?Sized,
OutOfLineArrayOfNonnullableHandles: Encode<OutOfLineArrayOfNonnullableHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, OutOfLineArrayOfNonnullableHandles<'static>>, ___E> for OutOfLineArrayOfNonnullableHandleswhere
___E: Encoder + ?Sized,
OutOfLineArrayOfNonnullableHandles: Encode<OutOfLineArrayOfNonnullableHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OutOfLineArrayOfNonnullableHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OutOfLineArrayOfNonnullableHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<OutOfLineArrayOfNonnullableHandles<'de>> for OutOfLineArrayOfNonnullableHandles
impl<'de> FromWire<OutOfLineArrayOfNonnullableHandles<'de>> for OutOfLineArrayOfNonnullableHandles
Sourcefn from_wire(wire: OutOfLineArrayOfNonnullableHandles<'de>) -> Self
fn from_wire(wire: OutOfLineArrayOfNonnullableHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for OutOfLineArrayOfNonnullableHandles
impl PartialEq for OutOfLineArrayOfNonnullableHandles
Sourcefn eq(&self, other: &OutOfLineArrayOfNonnullableHandles) -> bool
fn eq(&self, other: &OutOfLineArrayOfNonnullableHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OutOfLineArrayOfNonnullableHandles