pub struct PaddingAlignment4MaskMayBe8Bytes {
pub a: u8,
pub b: u32,
pub c: u32,
}Fields
a: u8b: u32c: u32Trait Implementations
Sourceimpl Clone for PaddingAlignment4MaskMayBe8Bytes
impl Clone for PaddingAlignment4MaskMayBe8Bytes
Sourcefn clone(&self) -> PaddingAlignment4MaskMayBe8Bytes
fn clone(&self) -> PaddingAlignment4MaskMayBe8Bytes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
impl CompatFrom<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
Sourcefn compat_from(
value: PaddingAlignment4MaskMayBe8Bytes,
) -> PaddingAlignment4MaskMayBe8Bytes
fn compat_from( value: PaddingAlignment4MaskMayBe8Bytes, ) -> PaddingAlignment4MaskMayBe8Bytes
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8Bytes>, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: Encoder + ?Sized,
&'a PaddingAlignment4MaskMayBe8Bytes: Encode<PaddingAlignment4MaskMayBe8Bytes, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8Bytes>, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: Encoder + ?Sized,
&'a PaddingAlignment4MaskMayBe8Bytes: Encode<PaddingAlignment4MaskMayBe8Bytes, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingAlignment4MaskMayBe8Bytes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8Bytes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingAlignment4MaskMayBe8Bytes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8Bytes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8Bytes>, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: Encoder + ?Sized,
PaddingAlignment4MaskMayBe8Bytes: Encode<PaddingAlignment4MaskMayBe8Bytes, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8Bytes>, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: Encoder + ?Sized,
PaddingAlignment4MaskMayBe8Bytes: Encode<PaddingAlignment4MaskMayBe8Bytes, ___E>,
Sourcefn encode_option(
this: Option<PaddingAlignment4MaskMayBe8Bytes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8Bytes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingAlignment4MaskMayBe8Bytes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8Bytes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
impl FromWire<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
Sourcefn from_wire(
wire: PaddingAlignment4MaskMayBe8Bytes,
) -> PaddingAlignment4MaskMayBe8Bytes
fn from_wire( wire: PaddingAlignment4MaskMayBe8Bytes, ) -> PaddingAlignment4MaskMayBe8Bytes
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
impl FromWireRef<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
Sourcefn from_wire_ref(
wire: &PaddingAlignment4MaskMayBe8Bytes,
) -> PaddingAlignment4MaskMayBe8Bytes
fn from_wire_ref( wire: &PaddingAlignment4MaskMayBe8Bytes, ) -> PaddingAlignment4MaskMayBe8Bytes
Converts the given reference to this type.
Sourceimpl Ord for PaddingAlignment4MaskMayBe8Bytes
impl Ord for PaddingAlignment4MaskMayBe8Bytes
Sourcefn cmp(&self, other: &PaddingAlignment4MaskMayBe8Bytes) -> Ordering
fn cmp(&self, other: &PaddingAlignment4MaskMayBe8Bytes) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingAlignment4MaskMayBe8Bytes
impl PartialEq for PaddingAlignment4MaskMayBe8Bytes
Sourcefn eq(&self, other: &PaddingAlignment4MaskMayBe8Bytes) -> bool
fn eq(&self, other: &PaddingAlignment4MaskMayBe8Bytes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingAlignment4MaskMayBe8Bytes
impl PartialOrd for PaddingAlignment4MaskMayBe8Bytes
impl Copy for PaddingAlignment4MaskMayBe8Bytes
impl Eq for PaddingAlignment4MaskMayBe8Bytes
impl StructuralPartialEq for PaddingAlignment4MaskMayBe8Bytes