pub struct PaddingBetweenFieldsInt16Int32 {
pub a: i16,
pub b: i32,
}Fields
a: i16b: i32Trait Implementations
Sourceimpl Clone for PaddingBetweenFieldsInt16Int32
impl Clone for PaddingBetweenFieldsInt16Int32
Sourcefn clone(&self) -> PaddingBetweenFieldsInt16Int32
fn clone(&self) -> PaddingBetweenFieldsInt16Int32
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
impl CompatFrom<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
Sourcefn compat_from(
value: PaddingBetweenFieldsInt16Int32,
) -> PaddingBetweenFieldsInt16Int32
fn compat_from( value: PaddingBetweenFieldsInt16Int32, ) -> PaddingBetweenFieldsInt16Int32
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingBetweenFieldsInt16Int32, ___E> for &'a PaddingBetweenFieldsInt16Int32where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingBetweenFieldsInt16Int32, ___E> for &'a PaddingBetweenFieldsInt16Int32where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt16Int32>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt16Int32>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingBetweenFieldsInt16Int32, ___E> for PaddingBetweenFieldsInt16Int32where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingBetweenFieldsInt16Int32, ___E> for PaddingBetweenFieldsInt16Int32where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt16Int32>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt16Int32>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt16Int32>, ___E> for &'a PaddingBetweenFieldsInt16Int32where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt16Int32: Encode<PaddingBetweenFieldsInt16Int32, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt16Int32>, ___E> for &'a PaddingBetweenFieldsInt16Int32where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt16Int32: Encode<PaddingBetweenFieldsInt16Int32, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingBetweenFieldsInt16Int32>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt16Int32>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingBetweenFieldsInt16Int32>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt16Int32>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt16Int32>, ___E> for PaddingBetweenFieldsInt16Int32where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt16Int32: Encode<PaddingBetweenFieldsInt16Int32, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt16Int32>, ___E> for PaddingBetweenFieldsInt16Int32where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt16Int32: Encode<PaddingBetweenFieldsInt16Int32, ___E>,
Sourcefn encode_option(
this: Option<PaddingBetweenFieldsInt16Int32>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt16Int32>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingBetweenFieldsInt16Int32>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt16Int32>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
impl FromWire<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
Sourcefn from_wire(
wire: PaddingBetweenFieldsInt16Int32,
) -> PaddingBetweenFieldsInt16Int32
fn from_wire( wire: PaddingBetweenFieldsInt16Int32, ) -> PaddingBetweenFieldsInt16Int32
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
impl FromWireRef<PaddingBetweenFieldsInt16Int32> for PaddingBetweenFieldsInt16Int32
Sourcefn from_wire_ref(
wire: &PaddingBetweenFieldsInt16Int32,
) -> PaddingBetweenFieldsInt16Int32
fn from_wire_ref( wire: &PaddingBetweenFieldsInt16Int32, ) -> PaddingBetweenFieldsInt16Int32
Converts the given reference to this type.
Sourceimpl Ord for PaddingBetweenFieldsInt16Int32
impl Ord for PaddingBetweenFieldsInt16Int32
Sourcefn cmp(&self, other: &PaddingBetweenFieldsInt16Int32) -> Ordering
fn cmp(&self, other: &PaddingBetweenFieldsInt16Int32) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingBetweenFieldsInt16Int32
impl PartialEq for PaddingBetweenFieldsInt16Int32
Sourcefn eq(&self, other: &PaddingBetweenFieldsInt16Int32) -> bool
fn eq(&self, other: &PaddingBetweenFieldsInt16Int32) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingBetweenFieldsInt16Int32
impl PartialOrd for PaddingBetweenFieldsInt16Int32
impl Copy for PaddingBetweenFieldsInt16Int32
impl Eq for PaddingBetweenFieldsInt16Int32
impl StructuralPartialEq for PaddingBetweenFieldsInt16Int32