pub struct RecursiveOptionalAndVectorStruct {
pub vec: Vec<RecursiveOptionalStruct>,
}Fields
vec: Vec<RecursiveOptionalStruct>Trait Implementations
Sourceimpl Clone for RecursiveOptionalAndVectorStruct
impl Clone for RecursiveOptionalAndVectorStruct
Sourcefn clone(&self) -> RecursiveOptionalAndVectorStruct
fn clone(&self) -> RecursiveOptionalAndVectorStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<RecursiveOptionalAndVectorStruct> for RecursiveOptionalAndVectorStruct
impl CompatFrom<RecursiveOptionalAndVectorStruct> for RecursiveOptionalAndVectorStruct
Sourcefn compat_from(
value: RecursiveOptionalAndVectorStruct,
) -> RecursiveOptionalAndVectorStruct
fn compat_from( value: RecursiveOptionalAndVectorStruct, ) -> RecursiveOptionalAndVectorStruct
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<RecursiveOptionalAndVectorStruct<'static>, ___E> for &'a RecursiveOptionalAndVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<RecursiveOptionalAndVectorStruct<'static>, ___E> for &'a RecursiveOptionalAndVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalAndVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalAndVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveOptionalAndVectorStruct<'static>, ___E> for RecursiveOptionalAndVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<RecursiveOptionalAndVectorStruct<'static>, ___E> for RecursiveOptionalAndVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalAndVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalAndVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RecursiveOptionalAndVectorStruct<'static>>, ___E> for &'a RecursiveOptionalAndVectorStructwhere
___E: Encoder + ?Sized,
&'a RecursiveOptionalAndVectorStruct: Encode<RecursiveOptionalAndVectorStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RecursiveOptionalAndVectorStruct<'static>>, ___E> for &'a RecursiveOptionalAndVectorStructwhere
___E: Encoder + ?Sized,
&'a RecursiveOptionalAndVectorStruct: Encode<RecursiveOptionalAndVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a RecursiveOptionalAndVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveOptionalAndVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a RecursiveOptionalAndVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveOptionalAndVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RecursiveOptionalAndVectorStruct<'static>>, ___E> for RecursiveOptionalAndVectorStructwhere
___E: Encoder + ?Sized,
RecursiveOptionalAndVectorStruct: Encode<RecursiveOptionalAndVectorStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RecursiveOptionalAndVectorStruct<'static>>, ___E> for RecursiveOptionalAndVectorStructwhere
___E: Encoder + ?Sized,
RecursiveOptionalAndVectorStruct: Encode<RecursiveOptionalAndVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<RecursiveOptionalAndVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveOptionalAndVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<RecursiveOptionalAndVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveOptionalAndVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RecursiveOptionalAndVectorStruct<'de>> for RecursiveOptionalAndVectorStruct
impl<'de> FromWire<RecursiveOptionalAndVectorStruct<'de>> for RecursiveOptionalAndVectorStruct
Sourcefn from_wire(
wire: RecursiveOptionalAndVectorStruct<'de>,
) -> RecursiveOptionalAndVectorStruct
fn from_wire( wire: RecursiveOptionalAndVectorStruct<'de>, ) -> RecursiveOptionalAndVectorStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveOptionalAndVectorStruct<'de>> for RecursiveOptionalAndVectorStruct
impl<'de> FromWireRef<RecursiveOptionalAndVectorStruct<'de>> for RecursiveOptionalAndVectorStruct
Sourcefn from_wire_ref(
wire: &RecursiveOptionalAndVectorStruct<'de>,
) -> RecursiveOptionalAndVectorStruct
fn from_wire_ref( wire: &RecursiveOptionalAndVectorStruct<'de>, ) -> RecursiveOptionalAndVectorStruct
Converts the given reference to this type.
Sourceimpl Ord for RecursiveOptionalAndVectorStruct
impl Ord for RecursiveOptionalAndVectorStruct
Sourcefn cmp(&self, other: &RecursiveOptionalAndVectorStruct) -> Ordering
fn cmp(&self, other: &RecursiveOptionalAndVectorStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecursiveOptionalAndVectorStruct
impl PartialEq for RecursiveOptionalAndVectorStruct
Sourcefn eq(&self, other: &RecursiveOptionalAndVectorStruct) -> bool
fn eq(&self, other: &RecursiveOptionalAndVectorStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecursiveOptionalAndVectorStruct
impl PartialOrd for RecursiveOptionalAndVectorStruct
impl Eq for RecursiveOptionalAndVectorStruct
impl StructuralPartialEq for RecursiveOptionalAndVectorStruct