pub struct Regression1 {
pub f1: u8,
pub f2: u32,
pub f3: u8,
pub f4: u16,
pub f5: u64,
pub f6: u8,
}Fields
f1: u8f2: u32f3: u8f4: u16f5: u64f6: u8Trait Implementations
Sourceimpl Clone for Regression1
impl Clone for Regression1
Sourcefn clone(&self) -> Regression1
fn clone(&self) -> Regression1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression1> for Regression1
impl CompatFrom<Regression1> for Regression1
Sourcefn compat_from(value: Regression1) -> Regression1
fn compat_from(value: Regression1) -> Regression1
Converts
value into a value of this type.Sourceimpl Debug for Regression1
impl Debug for Regression1
Sourceimpl<'a, ___E> Encode<Regression1, ___E> for &'a Regression1where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Regression1, ___E> for &'a Regression1where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression1, ___E> for Regression1where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Regression1, ___E> for Regression1where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression1>, ___E> for &'a Regression1
impl<'a, ___E> EncodeOption<Box<'static, Regression1>, ___E> for &'a Regression1
Sourcefn encode_option(
this: Option<&'a Regression1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression1>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression1>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression1>, ___E> for Regression1
impl<___E> EncodeOption<Box<'static, Regression1>, ___E> for Regression1
Sourcefn encode_option(
this: Option<Regression1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression1>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression1>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Regression1> for Regression1
impl FromWire<Regression1> for Regression1
Sourcefn from_wire(wire: Regression1) -> Regression1
fn from_wire(wire: Regression1) -> Regression1
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Regression1> for Regression1
impl FromWireRef<Regression1> for Regression1
Sourcefn from_wire_ref(wire: &Regression1) -> Regression1
fn from_wire_ref(wire: &Regression1) -> Regression1
Converts the given reference to this type.
Sourceimpl Hash for Regression1
impl Hash for Regression1
Sourceimpl Ord for Regression1
impl Ord for Regression1
Sourcefn cmp(&self, other: &Regression1) -> Ordering
fn cmp(&self, other: &Regression1) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression1
impl PartialEq for Regression1
Sourceimpl PartialOrd for Regression1
impl PartialOrd for Regression1
impl Copy for Regression1
impl Eq for Regression1
impl StructuralPartialEq for Regression1