pub struct Regression10V1 {
pub table: Regression10TableV1,
}Fields
table: Regression10TableV1Trait Implementations
Sourceimpl Clone for Regression10V1
impl Clone for Regression10V1
Sourcefn clone(&self) -> Regression10V1
fn clone(&self) -> Regression10V1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression10V1> for Regression10V1
impl CompatFrom<Regression10V1> for Regression10V1
Sourcefn compat_from(value: Regression10V1) -> Regression10V1
fn compat_from(value: Regression10V1) -> Regression10V1
Converts
value into a value of this type.Sourceimpl Debug for Regression10V1
impl Debug for Regression10V1
Sourceimpl<'a, ___E> Encode<Regression10V1<'static>, ___E> for &'a Regression10V1where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Regression10V1<'static>, ___E> for &'a Regression10V1where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V1<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V1<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression10V1<'static>, ___E> for Regression10V1where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Regression10V1<'static>, ___E> for Regression10V1where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V1<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V1<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression10V1<'static>>, ___E> for &'a Regression10V1
impl<'a, ___E> EncodeOption<Box<'static, Regression10V1<'static>>, ___E> for &'a Regression10V1
Sourcefn encode_option(
this: Option<&'a Regression10V1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V1<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression10V1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V1<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression10V1<'static>>, ___E> for Regression10V1
impl<___E> EncodeOption<Box<'static, Regression10V1<'static>>, ___E> for Regression10V1
Sourcefn encode_option(
this: Option<Regression10V1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V1<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression10V1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V1<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression10V1<'de>> for Regression10V1
impl<'de> FromWire<Regression10V1<'de>> for Regression10V1
Sourcefn from_wire(wire: Regression10V1<'de>) -> Regression10V1
fn from_wire(wire: Regression10V1<'de>) -> Regression10V1
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression10V1<'de>> for Regression10V1
impl<'de> FromWireRef<Regression10V1<'de>> for Regression10V1
Sourcefn from_wire_ref(wire: &Regression10V1<'de>) -> Regression10V1
fn from_wire_ref(wire: &Regression10V1<'de>) -> Regression10V1
Converts the given reference to this type.
Sourceimpl Hash for Regression10V1
impl Hash for Regression10V1
Sourceimpl Ord for Regression10V1
impl Ord for Regression10V1
Sourcefn cmp(&self, other: &Regression10V1) -> Ordering
fn cmp(&self, other: &Regression10V1) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression10V1
impl PartialEq for Regression10V1
Sourceimpl PartialOrd for Regression10V1
impl PartialOrd for Regression10V1
impl Copy for Regression10V1
impl Eq for Regression10V1
impl StructuralPartialEq for Regression10V1