pub struct Regression4 {
pub f1: u8,
pub f2: u32,
pub s1: StructSize3Align1,
pub f3: u8,
pub f4: u16,
pub f5: u64,
pub f6: u8,
}Fields
f1: u8f2: u32s1: StructSize3Align1f3: u8f4: u16f5: u64f6: u8Trait Implementations
Sourceimpl Clone for Regression4
impl Clone for Regression4
Sourcefn clone(&self) -> Regression4
fn clone(&self) -> Regression4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression4> for Regression4
impl CompatFrom<Regression4> for Regression4
Sourcefn compat_from(value: Regression4) -> Regression4
fn compat_from(value: Regression4) -> Regression4
Converts
value into a value of this type.Sourceimpl Debug for Regression4
impl Debug for Regression4
Sourceimpl<'a, ___E> Encode<Regression4, ___E> for &'a Regression4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Regression4, ___E> for &'a Regression4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression4, ___E> for Regression4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Regression4, ___E> for Regression4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression4>, ___E> for &'a Regression4
impl<'a, ___E> EncodeOption<Box<'static, Regression4>, ___E> for &'a Regression4
Sourcefn encode_option(
this: Option<&'a Regression4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression4>, ___E> for Regression4
impl<___E> EncodeOption<Box<'static, Regression4>, ___E> for Regression4
Sourcefn encode_option(
this: Option<Regression4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Regression4> for Regression4
impl FromWire<Regression4> for Regression4
Sourcefn from_wire(wire: Regression4) -> Regression4
fn from_wire(wire: Regression4) -> Regression4
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Regression4> for Regression4
impl FromWireRef<Regression4> for Regression4
Sourcefn from_wire_ref(wire: &Regression4) -> Regression4
fn from_wire_ref(wire: &Regression4) -> Regression4
Converts the given reference to this type.
Sourceimpl Hash for Regression4
impl Hash for Regression4
Sourceimpl Ord for Regression4
impl Ord for Regression4
Sourcefn cmp(&self, other: &Regression4) -> Ordering
fn cmp(&self, other: &Regression4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression4
impl PartialEq for Regression4
Sourceimpl PartialOrd for Regression4
impl PartialOrd for Regression4
impl Copy for Regression4
impl Eq for Regression4
impl StructuralPartialEq for Regression4