pub struct Sandwich1WithOptUnion {
pub before: u32,
pub opt_union: Option<Box<UnionSize8Align4>>,
pub after: u32,
}Fields
before: u32opt_union: Option<Box<UnionSize8Align4>>after: u32Trait Implementations
Sourceimpl Clone for Sandwich1WithOptUnion
impl Clone for Sandwich1WithOptUnion
Sourcefn clone(&self) -> Sandwich1WithOptUnion
fn clone(&self) -> Sandwich1WithOptUnion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
impl CompatFrom<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
Sourcefn compat_from(value: Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
fn compat_from(value: Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
Converts
value into a value of this type.Sourceimpl Debug for Sandwich1WithOptUnion
impl Debug for Sandwich1WithOptUnion
Sourceimpl<'a, ___E> Encode<Sandwich1WithOptUnion, ___E> for &'a Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Sandwich1WithOptUnion, ___E> for &'a Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1WithOptUnion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1WithOptUnion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1WithOptUnion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1WithOptUnion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Sandwich1WithOptUnion>, ___E> for &'a Sandwich1WithOptUnion
impl<'a, ___E> EncodeOption<Box<'static, Sandwich1WithOptUnion>, ___E> for &'a Sandwich1WithOptUnion
Sourcefn encode_option(
this: Option<&'a Sandwich1WithOptUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich1WithOptUnion>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Sandwich1WithOptUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich1WithOptUnion>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Sandwich1WithOptUnion>, ___E> for Sandwich1WithOptUnion
impl<___E> EncodeOption<Box<'static, Sandwich1WithOptUnion>, ___E> for Sandwich1WithOptUnion
Sourcefn encode_option(
this: Option<Sandwich1WithOptUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich1WithOptUnion>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Sandwich1WithOptUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich1WithOptUnion>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
impl FromWire<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
Sourcefn from_wire(wire: Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
fn from_wire(wire: Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
impl FromWireRef<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
Sourcefn from_wire_ref(wire: &Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
fn from_wire_ref(wire: &Sandwich1WithOptUnion) -> Sandwich1WithOptUnion
Converts the given reference to this type.
Sourceimpl Hash for Sandwich1WithOptUnion
impl Hash for Sandwich1WithOptUnion
Sourceimpl Ord for Sandwich1WithOptUnion
impl Ord for Sandwich1WithOptUnion
Sourcefn cmp(&self, other: &Sandwich1WithOptUnion) -> Ordering
fn cmp(&self, other: &Sandwich1WithOptUnion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Sandwich1WithOptUnion
impl PartialEq for Sandwich1WithOptUnion
Sourceimpl PartialOrd for Sandwich1WithOptUnion
impl PartialOrd for Sandwich1WithOptUnion
impl Eq for Sandwich1WithOptUnion
impl StructuralPartialEq for Sandwich1WithOptUnion