#[repr(C)]pub struct Size5Alignment1 {
pub data: [u8; 5],
}Fields
data: [u8; 5]Trait Implementations
Sourceimpl Clone for Size5Alignment1
impl Clone for Size5Alignment1
Sourcefn clone(&self) -> Size5Alignment1
fn clone(&self) -> Size5Alignment1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Size5Alignment1> for Size5Alignment1
impl CompatFrom<Size5Alignment1> for Size5Alignment1
Sourcefn compat_from(value: Size5Alignment1) -> Size5Alignment1
fn compat_from(value: Size5Alignment1) -> Size5Alignment1
Converts
value into a value of this type.Sourceimpl Debug for Size5Alignment1
impl Debug for Size5Alignment1
Sourceimpl<'a, ___E> Encode<Size5Alignment1, ___E> for &'a Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment1, ___E> for &'a Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment1, ___E> for Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment1, ___E> for Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Size5Alignment1>, ___E> for &'a Size5Alignment1
impl<'a, ___E> EncodeOption<Box<'static, Size5Alignment1>, ___E> for &'a Size5Alignment1
Sourcefn encode_option(
this: Option<&'a Size5Alignment1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment1>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Size5Alignment1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment1>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Size5Alignment1>, ___E> for Size5Alignment1
impl<___E> EncodeOption<Box<'static, Size5Alignment1>, ___E> for Size5Alignment1
Sourcefn encode_option(
this: Option<Size5Alignment1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment1>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Size5Alignment1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment1>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Size5Alignment1> for Size5Alignment1
impl FromWire<Size5Alignment1> for Size5Alignment1
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
Sourcefn from_wire(wire: Size5Alignment1) -> Size5Alignment1
fn from_wire(wire: Size5Alignment1) -> Size5Alignment1
Converts the given owned value to this type.
Sourceimpl FromWireRef<Size5Alignment1> for Size5Alignment1
impl FromWireRef<Size5Alignment1> for Size5Alignment1
Sourcefn from_wire_ref(wire: &Size5Alignment1) -> Size5Alignment1
fn from_wire_ref(wire: &Size5Alignment1) -> Size5Alignment1
Converts the given reference to this type.
Sourceimpl Hash for Size5Alignment1
impl Hash for Size5Alignment1
Sourceimpl Ord for Size5Alignment1
impl Ord for Size5Alignment1
Sourcefn cmp(&self, other: &Size5Alignment1) -> Ordering
fn cmp(&self, other: &Size5Alignment1) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Size5Alignment1
impl PartialEq for Size5Alignment1
Sourceimpl PartialOrd for Size5Alignment1
impl PartialOrd for Size5Alignment1
impl Copy for Size5Alignment1
impl Eq for Size5Alignment1
impl StructuralPartialEq for Size5Alignment1