#[repr(C)]pub struct StrictBitsUint8Struct {
pub b: StrictBitsUint8,
}Fields
b: StrictBitsUint8Trait Implementations
Sourceimpl Clone for StrictBitsUint8Struct
impl Clone for StrictBitsUint8Struct
Sourcefn clone(&self) -> StrictBitsUint8Struct
fn clone(&self) -> StrictBitsUint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictBitsUint8Struct> for StrictBitsUint8Struct
impl CompatFrom<StrictBitsUint8Struct> for StrictBitsUint8Struct
Sourcefn compat_from(value: StrictBitsUint8Struct) -> StrictBitsUint8Struct
fn compat_from(value: StrictBitsUint8Struct) -> StrictBitsUint8Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictBitsUint8Struct
impl Debug for StrictBitsUint8Struct
Sourceimpl<'a, ___E> Encode<StrictBitsUint8Struct, ___E> for &'a StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint8Struct, ___E> for &'a StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint8Struct>, ___E> for &'a StrictBitsUint8Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint8Struct>, ___E> for &'a StrictBitsUint8Struct
Sourcefn encode_option(
this: Option<&'a StrictBitsUint8Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictBitsUint8Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictBitsUint8Struct>, ___E> for StrictBitsUint8Struct
impl<___E> EncodeOption<Box<'static, StrictBitsUint8Struct>, ___E> for StrictBitsUint8Struct
Sourcefn encode_option(
this: Option<StrictBitsUint8Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictBitsUint8Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictBitsUint8Struct> for StrictBitsUint8Struct
impl FromWire<StrictBitsUint8Struct> for StrictBitsUint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
Sourcefn from_wire(wire: StrictBitsUint8Struct) -> StrictBitsUint8Struct
fn from_wire(wire: StrictBitsUint8Struct) -> StrictBitsUint8Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint8Struct> for StrictBitsUint8Struct
impl FromWireRef<StrictBitsUint8Struct> for StrictBitsUint8Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint8Struct) -> StrictBitsUint8Struct
fn from_wire_ref(wire: &StrictBitsUint8Struct) -> StrictBitsUint8Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictBitsUint8Struct
impl Hash for StrictBitsUint8Struct
Sourceimpl Ord for StrictBitsUint8Struct
impl Ord for StrictBitsUint8Struct
Sourcefn cmp(&self, other: &StrictBitsUint8Struct) -> Ordering
fn cmp(&self, other: &StrictBitsUint8Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictBitsUint8Struct
impl PartialEq for StrictBitsUint8Struct
Sourceimpl PartialOrd for StrictBitsUint8Struct
impl PartialOrd for StrictBitsUint8Struct
impl Copy for StrictBitsUint8Struct
impl Eq for StrictBitsUint8Struct
impl StructuralPartialEq for StrictBitsUint8Struct