#[repr(C)]pub struct StrictEnumInt16Struct {
pub e: StrictEnumInt16,
}Fields
e: StrictEnumInt16Trait Implementations
Sourceimpl Clone for StrictEnumInt16Struct
impl Clone for StrictEnumInt16Struct
Sourcefn clone(&self) -> StrictEnumInt16Struct
fn clone(&self) -> StrictEnumInt16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumInt16Struct> for StrictEnumInt16Struct
impl CompatFrom<StrictEnumInt16Struct> for StrictEnumInt16Struct
Sourcefn compat_from(value: StrictEnumInt16Struct) -> StrictEnumInt16Struct
fn compat_from(value: StrictEnumInt16Struct) -> StrictEnumInt16Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumInt16Struct
impl Debug for StrictEnumInt16Struct
Sourceimpl<'a, ___E> Encode<StrictEnumInt16Struct, ___E> for &'a StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt16Struct, ___E> for &'a StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, StrictEnumInt16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, StrictEnumInt16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt16Struct>, ___E> for &'a StrictEnumInt16Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt16Struct>, ___E> for &'a StrictEnumInt16Struct
Sourcefn encode_option(
this: Option<&'a StrictEnumInt16Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictEnumInt16Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumInt16Struct>, ___E> for StrictEnumInt16Struct
impl<___E> EncodeOption<Box<'static, StrictEnumInt16Struct>, ___E> for StrictEnumInt16Struct
Sourcefn encode_option(
this: Option<StrictEnumInt16Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictEnumInt16Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumInt16Struct> for StrictEnumInt16Struct
impl FromWire<StrictEnumInt16Struct> for StrictEnumInt16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, StrictEnumInt16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, StrictEnumInt16Struct>
Sourcefn from_wire(wire: StrictEnumInt16Struct) -> StrictEnumInt16Struct
fn from_wire(wire: StrictEnumInt16Struct) -> StrictEnumInt16Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt16Struct> for StrictEnumInt16Struct
impl FromWireRef<StrictEnumInt16Struct> for StrictEnumInt16Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt16Struct) -> StrictEnumInt16Struct
fn from_wire_ref(wire: &StrictEnumInt16Struct) -> StrictEnumInt16Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumInt16Struct
impl Hash for StrictEnumInt16Struct
Sourceimpl Ord for StrictEnumInt16Struct
impl Ord for StrictEnumInt16Struct
Sourcefn cmp(&self, other: &StrictEnumInt16Struct) -> Ordering
fn cmp(&self, other: &StrictEnumInt16Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumInt16Struct
impl PartialEq for StrictEnumInt16Struct
Sourceimpl PartialOrd for StrictEnumInt16Struct
impl PartialOrd for StrictEnumInt16Struct
impl Copy for StrictEnumInt16Struct
impl Eq for StrictEnumInt16Struct
impl StructuralPartialEq for StrictEnumInt16Struct