#[repr(C)]pub struct StrictEnumUint32Struct {
pub e: StrictEnumUint32,
}Fields
e: StrictEnumUint32Trait Implementations
Sourceimpl Clone for StrictEnumUint32Struct
impl Clone for StrictEnumUint32Struct
Sourcefn clone(&self) -> StrictEnumUint32Struct
fn clone(&self) -> StrictEnumUint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumUint32Struct> for StrictEnumUint32Struct
impl CompatFrom<StrictEnumUint32Struct> for StrictEnumUint32Struct
Sourcefn compat_from(value: StrictEnumUint32Struct) -> StrictEnumUint32Struct
fn compat_from(value: StrictEnumUint32Struct) -> StrictEnumUint32Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumUint32Struct
impl Debug for StrictEnumUint32Struct
Sourceimpl<'a, ___E> Encode<StrictEnumUint32Struct, ___E> for &'a StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint32Struct, ___E> for &'a StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, StrictEnumUint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, StrictEnumUint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint32Struct>, ___E> for &'a StrictEnumUint32Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint32Struct>, ___E> for &'a StrictEnumUint32Struct
Sourcefn encode_option(
this: Option<&'a StrictEnumUint32Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictEnumUint32Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumUint32Struct>, ___E> for StrictEnumUint32Struct
impl<___E> EncodeOption<Box<'static, StrictEnumUint32Struct>, ___E> for StrictEnumUint32Struct
Sourcefn encode_option(
this: Option<StrictEnumUint32Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictEnumUint32Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumUint32Struct> for StrictEnumUint32Struct
impl FromWire<StrictEnumUint32Struct> for StrictEnumUint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, StrictEnumUint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, StrictEnumUint32Struct>
Sourcefn from_wire(wire: StrictEnumUint32Struct) -> StrictEnumUint32Struct
fn from_wire(wire: StrictEnumUint32Struct) -> StrictEnumUint32Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint32Struct> for StrictEnumUint32Struct
impl FromWireRef<StrictEnumUint32Struct> for StrictEnumUint32Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint32Struct) -> StrictEnumUint32Struct
fn from_wire_ref(wire: &StrictEnumUint32Struct) -> StrictEnumUint32Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumUint32Struct
impl Hash for StrictEnumUint32Struct
Sourceimpl Ord for StrictEnumUint32Struct
impl Ord for StrictEnumUint32Struct
Sourcefn cmp(&self, other: &StrictEnumUint32Struct) -> Ordering
fn cmp(&self, other: &StrictEnumUint32Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumUint32Struct
impl PartialEq for StrictEnumUint32Struct
Sourceimpl PartialOrd for StrictEnumUint32Struct
impl PartialOrd for StrictEnumUint32Struct
impl Copy for StrictEnumUint32Struct
impl Eq for StrictEnumUint32Struct
impl StructuralPartialEq for StrictEnumUint32Struct