#[repr(C)]pub struct StrictEnumUint64Struct {
pub e: StrictEnumUint64,
}Fields
e: StrictEnumUint64Trait Implementations
Sourceimpl Clone for StrictEnumUint64Struct
impl Clone for StrictEnumUint64Struct
Sourcefn clone(&self) -> StrictEnumUint64Struct
fn clone(&self) -> StrictEnumUint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumUint64Struct> for StrictEnumUint64Struct
impl CompatFrom<StrictEnumUint64Struct> for StrictEnumUint64Struct
Sourcefn compat_from(value: StrictEnumUint64Struct) -> StrictEnumUint64Struct
fn compat_from(value: StrictEnumUint64Struct) -> StrictEnumUint64Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumUint64Struct
impl Debug for StrictEnumUint64Struct
Sourceimpl<'a, ___E> Encode<StrictEnumUint64Struct, ___E> for &'a StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint64Struct, ___E> for &'a StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint64Struct>, ___E> for &'a StrictEnumUint64Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint64Struct>, ___E> for &'a StrictEnumUint64Struct
Sourcefn encode_option(
this: Option<&'a StrictEnumUint64Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictEnumUint64Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumUint64Struct>, ___E> for StrictEnumUint64Struct
impl<___E> EncodeOption<Box<'static, StrictEnumUint64Struct>, ___E> for StrictEnumUint64Struct
Sourcefn encode_option(
this: Option<StrictEnumUint64Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictEnumUint64Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumUint64Struct> for StrictEnumUint64Struct
impl FromWire<StrictEnumUint64Struct> for StrictEnumUint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
Sourcefn from_wire(wire: StrictEnumUint64Struct) -> StrictEnumUint64Struct
fn from_wire(wire: StrictEnumUint64Struct) -> StrictEnumUint64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint64Struct> for StrictEnumUint64Struct
impl FromWireRef<StrictEnumUint64Struct> for StrictEnumUint64Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint64Struct) -> StrictEnumUint64Struct
fn from_wire_ref(wire: &StrictEnumUint64Struct) -> StrictEnumUint64Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumUint64Struct
impl Hash for StrictEnumUint64Struct
Sourceimpl Ord for StrictEnumUint64Struct
impl Ord for StrictEnumUint64Struct
Sourcefn cmp(&self, other: &StrictEnumUint64Struct) -> Ordering
fn cmp(&self, other: &StrictEnumUint64Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumUint64Struct
impl PartialEq for StrictEnumUint64Struct
Sourceimpl PartialOrd for StrictEnumUint64Struct
impl PartialOrd for StrictEnumUint64Struct
impl Copy for StrictEnumUint64Struct
impl Eq for StrictEnumUint64Struct
impl StructuralPartialEq for StrictEnumUint64Struct