pub struct StringWithLimitInUnion {
pub u: UnionWithStringWithLimit,
}Fields
u: UnionWithStringWithLimitTrait Implementations
Sourceimpl Clone for StringWithLimitInUnion
impl Clone for StringWithLimitInUnion
Sourcefn clone(&self) -> StringWithLimitInUnion
fn clone(&self) -> StringWithLimitInUnion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StringWithLimitInUnion> for StringWithLimitInUnion
impl CompatFrom<StringWithLimitInUnion> for StringWithLimitInUnion
Sourcefn compat_from(value: StringWithLimitInUnion) -> StringWithLimitInUnion
fn compat_from(value: StringWithLimitInUnion) -> StringWithLimitInUnion
Converts
value into a value of this type.Sourceimpl Debug for StringWithLimitInUnion
impl Debug for StringWithLimitInUnion
Sourceimpl<'a, ___E> Encode<StringWithLimitInUnion<'static>, ___E> for &'a StringWithLimitInUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StringWithLimitInUnion<'static>, ___E> for &'a StringWithLimitInUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StringWithLimitInUnion<'static>, ___E> for StringWithLimitInUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StringWithLimitInUnion<'static>, ___E> for StringWithLimitInUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInUnion<'static>>, ___E> for &'a StringWithLimitInUnionwhere
___E: Encoder + ?Sized,
&'a StringWithLimitInUnion: Encode<StringWithLimitInUnion<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInUnion<'static>>, ___E> for &'a StringWithLimitInUnionwhere
___E: Encoder + ?Sized,
&'a StringWithLimitInUnion: Encode<StringWithLimitInUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a StringWithLimitInUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StringWithLimitInUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StringWithLimitInUnion<'static>>, ___E> for StringWithLimitInUnionwhere
___E: Encoder + ?Sized,
StringWithLimitInUnion: Encode<StringWithLimitInUnion<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StringWithLimitInUnion<'static>>, ___E> for StringWithLimitInUnionwhere
___E: Encoder + ?Sized,
StringWithLimitInUnion: Encode<StringWithLimitInUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<StringWithLimitInUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StringWithLimitInUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StringWithLimitInUnion<'de>> for StringWithLimitInUnion
impl<'de> FromWire<StringWithLimitInUnion<'de>> for StringWithLimitInUnion
Sourcefn from_wire(wire: StringWithLimitInUnion<'de>) -> StringWithLimitInUnion
fn from_wire(wire: StringWithLimitInUnion<'de>) -> StringWithLimitInUnion
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StringWithLimitInUnion<'de>> for StringWithLimitInUnion
impl<'de> FromWireRef<StringWithLimitInUnion<'de>> for StringWithLimitInUnion
Sourcefn from_wire_ref(wire: &StringWithLimitInUnion<'de>) -> StringWithLimitInUnion
fn from_wire_ref(wire: &StringWithLimitInUnion<'de>) -> StringWithLimitInUnion
Converts the given reference to this type.
Sourceimpl Hash for StringWithLimitInUnion
impl Hash for StringWithLimitInUnion
Sourceimpl Ord for StringWithLimitInUnion
impl Ord for StringWithLimitInUnion
Sourcefn cmp(&self, other: &StringWithLimitInUnion) -> Ordering
fn cmp(&self, other: &StringWithLimitInUnion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringWithLimitInUnion
impl PartialEq for StringWithLimitInUnion
Sourceimpl PartialOrd for StringWithLimitInUnion
impl PartialOrd for StringWithLimitInUnion
impl Eq for StringWithLimitInUnion
impl StructuralPartialEq for StringWithLimitInUnion