pub struct StringWithLimitInVector {
pub v: Vec<Option<String>>,
}Fields
v: Vec<Option<String>>Trait Implementations
Sourceimpl Clone for StringWithLimitInVector
impl Clone for StringWithLimitInVector
Sourcefn clone(&self) -> StringWithLimitInVector
fn clone(&self) -> StringWithLimitInVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StringWithLimitInVector> for StringWithLimitInVector
impl CompatFrom<StringWithLimitInVector> for StringWithLimitInVector
Sourcefn compat_from(value: StringWithLimitInVector) -> StringWithLimitInVector
fn compat_from(value: StringWithLimitInVector) -> StringWithLimitInVector
Converts
value into a value of this type.Sourceimpl Debug for StringWithLimitInVector
impl Debug for StringWithLimitInVector
Sourceimpl<'a, ___E> Encode<StringWithLimitInVector<'static>, ___E> for &'a StringWithLimitInVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StringWithLimitInVector<'static>, ___E> for &'a StringWithLimitInVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StringWithLimitInVector<'static>, ___E> for StringWithLimitInVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StringWithLimitInVector<'static>, ___E> for StringWithLimitInVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInVector<'static>>, ___E> for &'a StringWithLimitInVectorwhere
___E: Encoder + ?Sized,
&'a StringWithLimitInVector: Encode<StringWithLimitInVector<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInVector<'static>>, ___E> for &'a StringWithLimitInVectorwhere
___E: Encoder + ?Sized,
&'a StringWithLimitInVector: Encode<StringWithLimitInVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a StringWithLimitInVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StringWithLimitInVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StringWithLimitInVector<'static>>, ___E> for StringWithLimitInVectorwhere
___E: Encoder + ?Sized,
StringWithLimitInVector: Encode<StringWithLimitInVector<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StringWithLimitInVector<'static>>, ___E> for StringWithLimitInVectorwhere
___E: Encoder + ?Sized,
StringWithLimitInVector: Encode<StringWithLimitInVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<StringWithLimitInVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StringWithLimitInVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StringWithLimitInVector<'de>> for StringWithLimitInVector
impl<'de> FromWire<StringWithLimitInVector<'de>> for StringWithLimitInVector
Sourcefn from_wire(wire: StringWithLimitInVector<'de>) -> StringWithLimitInVector
fn from_wire(wire: StringWithLimitInVector<'de>) -> StringWithLimitInVector
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StringWithLimitInVector<'de>> for StringWithLimitInVector
impl<'de> FromWireRef<StringWithLimitInVector<'de>> for StringWithLimitInVector
Sourcefn from_wire_ref(wire: &StringWithLimitInVector<'de>) -> StringWithLimitInVector
fn from_wire_ref(wire: &StringWithLimitInVector<'de>) -> StringWithLimitInVector
Converts the given reference to this type.
Sourceimpl Hash for StringWithLimitInVector
impl Hash for StringWithLimitInVector
Sourceimpl Ord for StringWithLimitInVector
impl Ord for StringWithLimitInVector
Sourcefn cmp(&self, other: &StringWithLimitInVector) -> Ordering
fn cmp(&self, other: &StringWithLimitInVector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringWithLimitInVector
impl PartialEq for StringWithLimitInVector
Sourceimpl PartialOrd for StringWithLimitInVector
impl PartialOrd for StringWithLimitInVector
impl Eq for StringWithLimitInVector
impl StructuralPartialEq for StringWithLimitInVector