pub struct Struct3Byte {
pub a: i16,
pub b: i8,
}Fields
a: i16b: i8Trait Implementations
Sourceimpl Clone for Struct3Byte
impl Clone for Struct3Byte
Sourcefn clone(&self) -> Struct3Byte
fn clone(&self) -> Struct3Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct3Byte> for Struct3Byte
impl CompatFrom<Struct3Byte> for Struct3Byte
Sourcefn compat_from(value: Struct3Byte) -> Struct3Byte
fn compat_from(value: Struct3Byte) -> Struct3Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct3Byte
impl Debug for Struct3Byte
Sourceimpl<'a, ___E> Encode<Struct3Byte, ___E> for &'a Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct3Byte, ___E> for &'a Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct3Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct3Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct3Byte, ___E> for Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct3Byte, ___E> for Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct3Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct3Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct3Byte>, ___E> for &'a Struct3Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct3Byte>, ___E> for &'a Struct3Byte
Sourcefn encode_option(
this: Option<&'a Struct3Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct3Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct3Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct3Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct3Byte>, ___E> for Struct3Byte
impl<___E> EncodeOption<Box<'static, Struct3Byte>, ___E> for Struct3Byte
Sourcefn encode_option(
this: Option<Struct3Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct3Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct3Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct3Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct3Byte> for Struct3Byte
impl FromWire<Struct3Byte> for Struct3Byte
Sourcefn from_wire(wire: Struct3Byte) -> Struct3Byte
fn from_wire(wire: Struct3Byte) -> Struct3Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct3Byte> for Struct3Byte
impl FromWireRef<Struct3Byte> for Struct3Byte
Sourcefn from_wire_ref(wire: &Struct3Byte) -> Struct3Byte
fn from_wire_ref(wire: &Struct3Byte) -> Struct3Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct3Byte
impl Hash for Struct3Byte
Sourceimpl Ord for Struct3Byte
impl Ord for Struct3Byte
Sourcefn cmp(&self, other: &Struct3Byte) -> Ordering
fn cmp(&self, other: &Struct3Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct3Byte
impl PartialEq for Struct3Byte
Sourceimpl PartialOrd for Struct3Byte
impl PartialOrd for Struct3Byte
impl Copy for Struct3Byte
impl Eq for Struct3Byte
impl StructuralPartialEq for Struct3Byte