#[repr(C)]pub struct Struct4Byte {
pub a: i32,
}Fields
a: i32Trait Implementations
Sourceimpl Clone for Struct4Byte
impl Clone for Struct4Byte
Sourcefn clone(&self) -> Struct4Byte
fn clone(&self) -> Struct4Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct4Byte> for Struct4Byte
impl CompatFrom<Struct4Byte> for Struct4Byte
Sourcefn compat_from(value: Struct4Byte) -> Struct4Byte
fn compat_from(value: Struct4Byte) -> Struct4Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct4Byte
impl Debug for Struct4Byte
Sourceimpl<'a, ___E> Encode<Struct4Byte, ___E> for &'a Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct4Byte, ___E> for &'a Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct4Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct4Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct4Byte, ___E> for Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct4Byte, ___E> for Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct4Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct4Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct4Byte>, ___E> for &'a Struct4Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct4Byte>, ___E> for &'a Struct4Byte
Sourcefn encode_option(
this: Option<&'a Struct4Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct4Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct4Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct4Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct4Byte>, ___E> for Struct4Byte
impl<___E> EncodeOption<Box<'static, Struct4Byte>, ___E> for Struct4Byte
Sourcefn encode_option(
this: Option<Struct4Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct4Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct4Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct4Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct4Byte> for Struct4Byte
impl FromWire<Struct4Byte> for Struct4Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
Sourcefn from_wire(wire: Struct4Byte) -> Struct4Byte
fn from_wire(wire: Struct4Byte) -> Struct4Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct4Byte> for Struct4Byte
impl FromWireRef<Struct4Byte> for Struct4Byte
Sourcefn from_wire_ref(wire: &Struct4Byte) -> Struct4Byte
fn from_wire_ref(wire: &Struct4Byte) -> Struct4Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct4Byte
impl Hash for Struct4Byte
Sourceimpl Ord for Struct4Byte
impl Ord for Struct4Byte
Sourcefn cmp(&self, other: &Struct4Byte) -> Ordering
fn cmp(&self, other: &Struct4Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct4Byte
impl PartialEq for Struct4Byte
Sourceimpl PartialOrd for Struct4Byte
impl PartialOrd for Struct4Byte
impl Copy for Struct4Byte
impl Eq for Struct4Byte
impl StructuralPartialEq for Struct4Byte