pub struct Struct6Byte {
pub a: i32,
pub b: i16,
}Fields
a: i32b: i16Trait Implementations
Sourceimpl Clone for Struct6Byte
impl Clone for Struct6Byte
Sourcefn clone(&self) -> Struct6Byte
fn clone(&self) -> Struct6Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct6Byte> for Struct6Byte
impl CompatFrom<Struct6Byte> for Struct6Byte
Sourcefn compat_from(value: Struct6Byte) -> Struct6Byte
fn compat_from(value: Struct6Byte) -> Struct6Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct6Byte
impl Debug for Struct6Byte
Sourceimpl<'a, ___E> Encode<Struct6Byte, ___E> for &'a Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct6Byte, ___E> for &'a Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct6Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct6Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct6Byte, ___E> for Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct6Byte, ___E> for Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct6Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct6Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct6Byte>, ___E> for &'a Struct6Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct6Byte>, ___E> for &'a Struct6Byte
Sourcefn encode_option(
this: Option<&'a Struct6Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct6Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct6Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct6Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct6Byte>, ___E> for Struct6Byte
impl<___E> EncodeOption<Box<'static, Struct6Byte>, ___E> for Struct6Byte
Sourcefn encode_option(
this: Option<Struct6Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct6Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct6Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct6Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct6Byte> for Struct6Byte
impl FromWire<Struct6Byte> for Struct6Byte
Sourcefn from_wire(wire: Struct6Byte) -> Struct6Byte
fn from_wire(wire: Struct6Byte) -> Struct6Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct6Byte> for Struct6Byte
impl FromWireRef<Struct6Byte> for Struct6Byte
Sourcefn from_wire_ref(wire: &Struct6Byte) -> Struct6Byte
fn from_wire_ref(wire: &Struct6Byte) -> Struct6Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct6Byte
impl Hash for Struct6Byte
Sourceimpl Ord for Struct6Byte
impl Ord for Struct6Byte
Sourcefn cmp(&self, other: &Struct6Byte) -> Ordering
fn cmp(&self, other: &Struct6Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct6Byte
impl PartialEq for Struct6Byte
Sourceimpl PartialOrd for Struct6Byte
impl PartialOrd for Struct6Byte
impl Copy for Struct6Byte
impl Eq for Struct6Byte
impl StructuralPartialEq for Struct6Byte