pub struct Struct7Byte {
pub a: i32,
pub b: i16,
pub c: i8,
}Fields
a: i32b: i16c: i8Trait Implementations
Sourceimpl Clone for Struct7Byte
impl Clone for Struct7Byte
Sourcefn clone(&self) -> Struct7Byte
fn clone(&self) -> Struct7Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct7Byte> for Struct7Byte
impl CompatFrom<Struct7Byte> for Struct7Byte
Sourcefn compat_from(value: Struct7Byte) -> Struct7Byte
fn compat_from(value: Struct7Byte) -> Struct7Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct7Byte
impl Debug for Struct7Byte
Sourceimpl<'a, ___E> Encode<Struct7Byte, ___E> for &'a Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct7Byte, ___E> for &'a Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct7Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct7Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct7Byte, ___E> for Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct7Byte, ___E> for Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct7Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct7Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct7Byte>, ___E> for &'a Struct7Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct7Byte>, ___E> for &'a Struct7Byte
Sourcefn encode_option(
this: Option<&'a Struct7Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct7Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct7Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct7Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct7Byte>, ___E> for Struct7Byte
impl<___E> EncodeOption<Box<'static, Struct7Byte>, ___E> for Struct7Byte
Sourcefn encode_option(
this: Option<Struct7Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct7Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct7Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct7Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct7Byte> for Struct7Byte
impl FromWire<Struct7Byte> for Struct7Byte
Sourcefn from_wire(wire: Struct7Byte) -> Struct7Byte
fn from_wire(wire: Struct7Byte) -> Struct7Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct7Byte> for Struct7Byte
impl FromWireRef<Struct7Byte> for Struct7Byte
Sourcefn from_wire_ref(wire: &Struct7Byte) -> Struct7Byte
fn from_wire_ref(wire: &Struct7Byte) -> Struct7Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct7Byte
impl Hash for Struct7Byte
Sourceimpl Ord for Struct7Byte
impl Ord for Struct7Byte
Sourcefn cmp(&self, other: &Struct7Byte) -> Ordering
fn cmp(&self, other: &Struct7Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct7Byte
impl PartialEq for Struct7Byte
Sourceimpl PartialOrd for Struct7Byte
impl PartialOrd for Struct7Byte
impl Copy for Struct7Byte
impl Eq for Struct7Byte
impl StructuralPartialEq for Struct7Byte