#[repr(C)]pub struct Struct8Byte {
pub a: i64,
}Fields
a: i64Trait Implementations
Sourceimpl Clone for Struct8Byte
impl Clone for Struct8Byte
Sourcefn clone(&self) -> Struct8Byte
fn clone(&self) -> Struct8Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct8Byte> for Struct8Byte
impl CompatFrom<Struct8Byte> for Struct8Byte
Sourcefn compat_from(value: Struct8Byte) -> Struct8Byte
fn compat_from(value: Struct8Byte) -> Struct8Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct8Byte
impl Debug for Struct8Byte
Sourceimpl<'a, ___E> Encode<Struct8Byte, ___E> for &'a Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct8Byte, ___E> for &'a Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct8Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct8Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct8Byte, ___E> for Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct8Byte, ___E> for Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct8Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct8Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct8Byte>, ___E> for &'a Struct8Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct8Byte>, ___E> for &'a Struct8Byte
Sourcefn encode_option(
this: Option<&'a Struct8Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct8Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct8Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct8Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct8Byte>, ___E> for Struct8Byte
impl<___E> EncodeOption<Box<'static, Struct8Byte>, ___E> for Struct8Byte
Sourcefn encode_option(
this: Option<Struct8Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct8Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct8Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct8Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct8Byte> for Struct8Byte
impl FromWire<Struct8Byte> for Struct8Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
Sourcefn from_wire(wire: Struct8Byte) -> Struct8Byte
fn from_wire(wire: Struct8Byte) -> Struct8Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct8Byte> for Struct8Byte
impl FromWireRef<Struct8Byte> for Struct8Byte
Sourcefn from_wire_ref(wire: &Struct8Byte) -> Struct8Byte
fn from_wire_ref(wire: &Struct8Byte) -> Struct8Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct8Byte
impl Hash for Struct8Byte
Sourceimpl Ord for Struct8Byte
impl Ord for Struct8Byte
Sourcefn cmp(&self, other: &Struct8Byte) -> Ordering
fn cmp(&self, other: &Struct8Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct8Byte
impl PartialEq for Struct8Byte
Sourceimpl PartialOrd for Struct8Byte
impl PartialOrd for Struct8Byte
impl Copy for Struct8Byte
impl Eq for Struct8Byte
impl StructuralPartialEq for Struct8Byte