pub struct StructOfSimpleTable {
pub table: SimpleTable,
}Fields
table: SimpleTableTrait Implementations
Sourceimpl Clone for StructOfSimpleTable
impl Clone for StructOfSimpleTable
Sourcefn clone(&self) -> StructOfSimpleTable
fn clone(&self) -> StructOfSimpleTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfSimpleTable> for StructOfSimpleTable
impl CompatFrom<StructOfSimpleTable> for StructOfSimpleTable
Sourcefn compat_from(value: StructOfSimpleTable) -> StructOfSimpleTable
fn compat_from(value: StructOfSimpleTable) -> StructOfSimpleTable
Converts
value into a value of this type.Sourceimpl Debug for StructOfSimpleTable
impl Debug for StructOfSimpleTable
Sourceimpl<'a, ___E> Encode<StructOfSimpleTable<'static>, ___E> for &'a StructOfSimpleTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructOfSimpleTable<'static>, ___E> for &'a StructOfSimpleTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfSimpleTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfSimpleTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfSimpleTable<'static>, ___E> for StructOfSimpleTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructOfSimpleTable<'static>, ___E> for StructOfSimpleTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfSimpleTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfSimpleTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfSimpleTable<'static>>, ___E> for &'a StructOfSimpleTable
impl<'a, ___E> EncodeOption<Box<'static, StructOfSimpleTable<'static>>, ___E> for &'a StructOfSimpleTable
Sourcefn encode_option(
this: Option<&'a StructOfSimpleTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfSimpleTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructOfSimpleTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfSimpleTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfSimpleTable<'static>>, ___E> for StructOfSimpleTable
impl<___E> EncodeOption<Box<'static, StructOfSimpleTable<'static>>, ___E> for StructOfSimpleTable
Sourcefn encode_option(
this: Option<StructOfSimpleTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfSimpleTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructOfSimpleTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfSimpleTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfSimpleTable<'de>> for StructOfSimpleTable
impl<'de> FromWire<StructOfSimpleTable<'de>> for StructOfSimpleTable
Sourcefn from_wire(wire: StructOfSimpleTable<'de>) -> StructOfSimpleTable
fn from_wire(wire: StructOfSimpleTable<'de>) -> StructOfSimpleTable
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfSimpleTable<'de>> for StructOfSimpleTable
impl<'de> FromWireRef<StructOfSimpleTable<'de>> for StructOfSimpleTable
Sourcefn from_wire_ref(wire: &StructOfSimpleTable<'de>) -> StructOfSimpleTable
fn from_wire_ref(wire: &StructOfSimpleTable<'de>) -> StructOfSimpleTable
Converts the given reference to this type.
Sourceimpl Hash for StructOfSimpleTable
impl Hash for StructOfSimpleTable
Sourceimpl Ord for StructOfSimpleTable
impl Ord for StructOfSimpleTable
Sourcefn cmp(&self, other: &StructOfSimpleTable) -> Ordering
fn cmp(&self, other: &StructOfSimpleTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfSimpleTable
impl PartialEq for StructOfSimpleTable
Sourceimpl PartialOrd for StructOfSimpleTable
impl PartialOrd for StructOfSimpleTable
impl Copy for StructOfSimpleTable
impl Eq for StructOfSimpleTable
impl StructuralPartialEq for StructOfSimpleTable