pub struct StructOfTableWithXUnion {
pub value: TableWithXUnion,
}Fields
value: TableWithXUnionTrait Implementations
Sourceimpl Clone for StructOfTableWithXUnion
impl Clone for StructOfTableWithXUnion
Sourcefn clone(&self) -> StructOfTableWithXUnion
fn clone(&self) -> StructOfTableWithXUnion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfTableWithXUnion> for StructOfTableWithXUnion
impl CompatFrom<StructOfTableWithXUnion> for StructOfTableWithXUnion
Sourcefn compat_from(value: StructOfTableWithXUnion) -> StructOfTableWithXUnion
fn compat_from(value: StructOfTableWithXUnion) -> StructOfTableWithXUnion
Converts
value into a value of this type.Sourceimpl Debug for StructOfTableWithXUnion
impl Debug for StructOfTableWithXUnion
Sourceimpl<'a, ___E> Encode<StructOfTableWithXUnion<'static>, ___E> for &'a StructOfTableWithXUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructOfTableWithXUnion<'static>, ___E> for &'a StructOfTableWithXUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithXUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithXUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfTableWithXUnion<'static>, ___E> for StructOfTableWithXUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructOfTableWithXUnion<'static>, ___E> for StructOfTableWithXUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithXUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithXUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithXUnion<'static>>, ___E> for &'a StructOfTableWithXUnionwhere
___E: Encoder + ?Sized,
&'a StructOfTableWithXUnion: Encode<StructOfTableWithXUnion<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithXUnion<'static>>, ___E> for &'a StructOfTableWithXUnionwhere
___E: Encoder + ?Sized,
&'a StructOfTableWithXUnion: Encode<StructOfTableWithXUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a StructOfTableWithXUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithXUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructOfTableWithXUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithXUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfTableWithXUnion<'static>>, ___E> for StructOfTableWithXUnionwhere
___E: Encoder + ?Sized,
StructOfTableWithXUnion: Encode<StructOfTableWithXUnion<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StructOfTableWithXUnion<'static>>, ___E> for StructOfTableWithXUnionwhere
___E: Encoder + ?Sized,
StructOfTableWithXUnion: Encode<StructOfTableWithXUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<StructOfTableWithXUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithXUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructOfTableWithXUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithXUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfTableWithXUnion<'de>> for StructOfTableWithXUnion
impl<'de> FromWire<StructOfTableWithXUnion<'de>> for StructOfTableWithXUnion
Sourcefn from_wire(wire: StructOfTableWithXUnion<'de>) -> StructOfTableWithXUnion
fn from_wire(wire: StructOfTableWithXUnion<'de>) -> StructOfTableWithXUnion
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfTableWithXUnion<'de>> for StructOfTableWithXUnion
impl<'de> FromWireRef<StructOfTableWithXUnion<'de>> for StructOfTableWithXUnion
Sourcefn from_wire_ref(wire: &StructOfTableWithXUnion<'de>) -> StructOfTableWithXUnion
fn from_wire_ref(wire: &StructOfTableWithXUnion<'de>) -> StructOfTableWithXUnion
Converts the given reference to this type.
Sourceimpl Hash for StructOfTableWithXUnion
impl Hash for StructOfTableWithXUnion
Sourceimpl Ord for StructOfTableWithXUnion
impl Ord for StructOfTableWithXUnion
Sourcefn cmp(&self, other: &StructOfTableWithXUnion) -> Ordering
fn cmp(&self, other: &StructOfTableWithXUnion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfTableWithXUnion
impl PartialEq for StructOfTableWithXUnion
Sourceimpl PartialOrd for StructOfTableWithXUnion
impl PartialOrd for StructOfTableWithXUnion
impl Eq for StructOfTableWithXUnion
impl StructuralPartialEq for StructOfTableWithXUnion