#[repr(C)]pub struct StructWithInt {
pub x: i32,
}Fields
x: i32Trait Implementations
Sourceimpl Clone for StructWithInt
impl Clone for StructWithInt
Sourcefn clone(&self) -> StructWithInt
fn clone(&self) -> StructWithInt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructWithInt> for StructWithInt
impl CompatFrom<StructWithInt> for StructWithInt
Sourcefn compat_from(value: StructWithInt) -> StructWithInt
fn compat_from(value: StructWithInt) -> StructWithInt
Converts
value into a value of this type.Sourceimpl Debug for StructWithInt
impl Debug for StructWithInt
Sourceimpl<'a, ___E> Encode<StructWithInt, ___E> for &'a StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StructWithInt, ___E> for &'a StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithInt>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithInt>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithInt, ___E> for StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StructWithInt, ___E> for StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
const COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithInt>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithInt>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructWithInt>, ___E> for &'a StructWithInt
impl<'a, ___E> EncodeOption<Box<'static, StructWithInt>, ___E> for &'a StructWithInt
Sourcefn encode_option(
this: Option<&'a StructWithInt>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithInt>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructWithInt>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithInt>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructWithInt>, ___E> for StructWithInt
impl<___E> EncodeOption<Box<'static, StructWithInt>, ___E> for StructWithInt
Sourcefn encode_option(
this: Option<StructWithInt>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithInt>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructWithInt>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithInt>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StructWithInt> for StructWithInt
impl FromWire<StructWithInt> for StructWithInt
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
const COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
Sourcefn from_wire(wire: StructWithInt) -> StructWithInt
fn from_wire(wire: StructWithInt) -> StructWithInt
Converts the given owned value to this type.
Sourceimpl FromWireRef<StructWithInt> for StructWithInt
impl FromWireRef<StructWithInt> for StructWithInt
Sourcefn from_wire_ref(wire: &StructWithInt) -> StructWithInt
fn from_wire_ref(wire: &StructWithInt) -> StructWithInt
Converts the given reference to this type.
Sourceimpl Hash for StructWithInt
impl Hash for StructWithInt
Sourceimpl Ord for StructWithInt
impl Ord for StructWithInt
Sourcefn cmp(&self, other: &StructWithInt) -> Ordering
fn cmp(&self, other: &StructWithInt) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructWithInt
impl PartialEq for StructWithInt
Sourceimpl PartialOrd for StructWithInt
impl PartialOrd for StructWithInt
impl Copy for StructWithInt
impl Eq for StructWithInt
impl StructuralPartialEq for StructWithInt