pub struct TableFieldInlinedHandleStruct {
pub t: TableFieldInlinedHandle,
}Fields
t: TableFieldInlinedHandleTrait Implementations
Sourceimpl CompatFrom<TableFieldInlinedHandleStruct> for TableFieldInlinedHandleStruct
impl CompatFrom<TableFieldInlinedHandleStruct> for TableFieldInlinedHandleStruct
Sourcefn compat_from(value: TableFieldInlinedHandleStruct) -> Self
fn compat_from(value: TableFieldInlinedHandleStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TableFieldInlinedHandleStruct> for TableFieldInlinedHandleStruct
impl CompatFrom<TableFieldInlinedHandleStruct> for TableFieldInlinedHandleStruct
Sourcefn compat_from(value: TableFieldInlinedHandleStruct) -> Self
fn compat_from(value: TableFieldInlinedHandleStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<TableFieldInlinedHandleStruct<'static>, ___E> for TableFieldInlinedHandleStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<TableFieldInlinedHandleStruct<'static>, ___E> for TableFieldInlinedHandleStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableFieldInlinedHandleStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableFieldInlinedHandleStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TableFieldInlinedHandleStruct<'static>>, ___E> for TableFieldInlinedHandleStructwhere
___E: Encoder + ?Sized,
TableFieldInlinedHandleStruct: Encode<TableFieldInlinedHandleStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableFieldInlinedHandleStruct<'static>>, ___E> for TableFieldInlinedHandleStructwhere
___E: Encoder + ?Sized,
TableFieldInlinedHandleStruct: Encode<TableFieldInlinedHandleStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableFieldInlinedHandleStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableFieldInlinedHandleStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableFieldInlinedHandleStruct<'de>> for TableFieldInlinedHandleStruct
impl<'de> FromWire<TableFieldInlinedHandleStruct<'de>> for TableFieldInlinedHandleStruct
Sourcefn from_wire(wire: TableFieldInlinedHandleStruct<'de>) -> Self
fn from_wire(wire: TableFieldInlinedHandleStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for TableFieldInlinedHandleStruct
impl PartialEq for TableFieldInlinedHandleStruct
Sourcefn eq(&self, other: &TableFieldInlinedHandleStruct) -> bool
fn eq(&self, other: &TableFieldInlinedHandleStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TableFieldInlinedHandleStruct