pub struct TableFieldInlinedStruct {
pub t: TableFieldInlined,
}Fields
t: TableFieldInlinedTrait Implementations
Sourceimpl Clone for TableFieldInlinedStruct
impl Clone for TableFieldInlinedStruct
Sourcefn clone(&self) -> TableFieldInlinedStruct
fn clone(&self) -> TableFieldInlinedStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TableFieldInlinedStruct> for TableFieldInlinedStruct
impl CompatFrom<TableFieldInlinedStruct> for TableFieldInlinedStruct
Sourcefn compat_from(value: TableFieldInlinedStruct) -> TableFieldInlinedStruct
fn compat_from(value: TableFieldInlinedStruct) -> TableFieldInlinedStruct
Converts
value into a value of this type.Sourceimpl Debug for TableFieldInlinedStruct
impl Debug for TableFieldInlinedStruct
Sourceimpl<'a, ___E> Encode<TableFieldInlinedStruct<'static>, ___E> for &'a TableFieldInlinedStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TableFieldInlinedStruct<'static>, ___E> for &'a TableFieldInlinedStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableFieldInlinedStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableFieldInlinedStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableFieldInlinedStruct<'static>, ___E> for TableFieldInlinedStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TableFieldInlinedStruct<'static>, ___E> for TableFieldInlinedStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableFieldInlinedStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableFieldInlinedStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TableFieldInlinedStruct<'static>>, ___E> for &'a TableFieldInlinedStructwhere
___E: Encoder + ?Sized,
&'a TableFieldInlinedStruct: Encode<TableFieldInlinedStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TableFieldInlinedStruct<'static>>, ___E> for &'a TableFieldInlinedStructwhere
___E: Encoder + ?Sized,
&'a TableFieldInlinedStruct: Encode<TableFieldInlinedStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TableFieldInlinedStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableFieldInlinedStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TableFieldInlinedStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableFieldInlinedStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TableFieldInlinedStruct<'static>>, ___E> for TableFieldInlinedStructwhere
___E: Encoder + ?Sized,
TableFieldInlinedStruct: Encode<TableFieldInlinedStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableFieldInlinedStruct<'static>>, ___E> for TableFieldInlinedStructwhere
___E: Encoder + ?Sized,
TableFieldInlinedStruct: Encode<TableFieldInlinedStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<TableFieldInlinedStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableFieldInlinedStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TableFieldInlinedStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableFieldInlinedStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableFieldInlinedStruct<'de>> for TableFieldInlinedStruct
impl<'de> FromWire<TableFieldInlinedStruct<'de>> for TableFieldInlinedStruct
Sourcefn from_wire(wire: TableFieldInlinedStruct<'de>) -> TableFieldInlinedStruct
fn from_wire(wire: TableFieldInlinedStruct<'de>) -> TableFieldInlinedStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableFieldInlinedStruct<'de>> for TableFieldInlinedStruct
impl<'de> FromWireRef<TableFieldInlinedStruct<'de>> for TableFieldInlinedStruct
Sourcefn from_wire_ref(wire: &TableFieldInlinedStruct<'de>) -> TableFieldInlinedStruct
fn from_wire_ref(wire: &TableFieldInlinedStruct<'de>) -> TableFieldInlinedStruct
Converts the given reference to this type.
Sourceimpl Hash for TableFieldInlinedStruct
impl Hash for TableFieldInlinedStruct
Sourceimpl Ord for TableFieldInlinedStruct
impl Ord for TableFieldInlinedStruct
Sourcefn cmp(&self, other: &TableFieldInlinedStruct) -> Ordering
fn cmp(&self, other: &TableFieldInlinedStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TableFieldInlinedStruct
impl PartialEq for TableFieldInlinedStruct
Sourceimpl PartialOrd for TableFieldInlinedStruct
impl PartialOrd for TableFieldInlinedStruct
impl Copy for TableFieldInlinedStruct
impl Eq for TableFieldInlinedStruct
impl StructuralPartialEq for TableFieldInlinedStruct