pub struct TableStructWithUint32SandwichStruct {
pub table: TableStructWithUint32Sandwich,
}Fields
table: TableStructWithUint32SandwichTrait Implementations
Sourceimpl Clone for TableStructWithUint32SandwichStruct
impl Clone for TableStructWithUint32SandwichStruct
Sourcefn clone(&self) -> TableStructWithUint32SandwichStruct
fn clone(&self) -> TableStructWithUint32SandwichStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TableStructWithUint32SandwichStruct> for TableStructWithUint32SandwichStruct
impl CompatFrom<TableStructWithUint32SandwichStruct> for TableStructWithUint32SandwichStruct
Sourcefn compat_from(
value: TableStructWithUint32SandwichStruct,
) -> TableStructWithUint32SandwichStruct
fn compat_from( value: TableStructWithUint32SandwichStruct, ) -> TableStructWithUint32SandwichStruct
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TableStructWithUint32SandwichStruct<'static>>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: Encoder + ?Sized,
&'a TableStructWithUint32SandwichStruct: Encode<TableStructWithUint32SandwichStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TableStructWithUint32SandwichStruct<'static>>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: Encoder + ?Sized,
&'a TableStructWithUint32SandwichStruct: Encode<TableStructWithUint32SandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TableStructWithUint32SandwichStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableStructWithUint32SandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TableStructWithUint32SandwichStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableStructWithUint32SandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TableStructWithUint32SandwichStruct<'static>>, ___E> for TableStructWithUint32SandwichStructwhere
___E: Encoder + ?Sized,
TableStructWithUint32SandwichStruct: Encode<TableStructWithUint32SandwichStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableStructWithUint32SandwichStruct<'static>>, ___E> for TableStructWithUint32SandwichStructwhere
___E: Encoder + ?Sized,
TableStructWithUint32SandwichStruct: Encode<TableStructWithUint32SandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<TableStructWithUint32SandwichStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableStructWithUint32SandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TableStructWithUint32SandwichStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableStructWithUint32SandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
impl<'de> FromWire<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
Sourcefn from_wire(
wire: TableStructWithUint32SandwichStruct<'de>,
) -> TableStructWithUint32SandwichStruct
fn from_wire( wire: TableStructWithUint32SandwichStruct<'de>, ) -> TableStructWithUint32SandwichStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
impl<'de> FromWireRef<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
Sourcefn from_wire_ref(
wire: &TableStructWithUint32SandwichStruct<'de>,
) -> TableStructWithUint32SandwichStruct
fn from_wire_ref( wire: &TableStructWithUint32SandwichStruct<'de>, ) -> TableStructWithUint32SandwichStruct
Converts the given reference to this type.
Sourceimpl Ord for TableStructWithUint32SandwichStruct
impl Ord for TableStructWithUint32SandwichStruct
Sourcefn cmp(&self, other: &TableStructWithUint32SandwichStruct) -> Ordering
fn cmp(&self, other: &TableStructWithUint32SandwichStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TableStructWithUint32SandwichStruct
impl PartialEq for TableStructWithUint32SandwichStruct
Sourcefn eq(&self, other: &TableStructWithUint32SandwichStruct) -> bool
fn eq(&self, other: &TableStructWithUint32SandwichStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TableStructWithUint32SandwichStruct
impl PartialOrd for TableStructWithUint32SandwichStruct
impl Copy for TableStructWithUint32SandwichStruct
impl Eq for TableStructWithUint32SandwichStruct
impl StructuralPartialEq for TableStructWithUint32SandwichStruct