pub struct TableUnionWithVectorReservedSandwichStruct {
pub table: TableUnionWithVectorReservedSandwich,
}Fields
table: TableUnionWithVectorReservedSandwichTrait Implementations
Sourceimpl CompatFrom<TableUnionWithVectorReservedSandwichStruct> for TableUnionWithVectorReservedSandwichStruct
impl CompatFrom<TableUnionWithVectorReservedSandwichStruct> for TableUnionWithVectorReservedSandwichStruct
Sourcefn compat_from(value: TableUnionWithVectorReservedSandwichStruct) -> Self
fn compat_from(value: TableUnionWithVectorReservedSandwichStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TableUnionWithVectorReservedSandwichStruct> for TableUnionWithVectorReservedSandwichStruct
impl CompatFrom<TableUnionWithVectorReservedSandwichStruct> for TableUnionWithVectorReservedSandwichStruct
Sourcefn compat_from(value: TableUnionWithVectorReservedSandwichStruct) -> Self
fn compat_from(value: TableUnionWithVectorReservedSandwichStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<TableUnionWithVectorReservedSandwichStruct<'static>, ___E> for TableUnionWithVectorReservedSandwichStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<TableUnionWithVectorReservedSandwichStruct<'static>, ___E> for TableUnionWithVectorReservedSandwichStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableUnionWithVectorReservedSandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableUnionWithVectorReservedSandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TableUnionWithVectorReservedSandwichStruct<'static>>, ___E> for TableUnionWithVectorReservedSandwichStructwhere
___E: Encoder + ?Sized,
TableUnionWithVectorReservedSandwichStruct: Encode<TableUnionWithVectorReservedSandwichStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableUnionWithVectorReservedSandwichStruct<'static>>, ___E> for TableUnionWithVectorReservedSandwichStructwhere
___E: Encoder + ?Sized,
TableUnionWithVectorReservedSandwichStruct: Encode<TableUnionWithVectorReservedSandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableUnionWithVectorReservedSandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableUnionWithVectorReservedSandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableUnionWithVectorReservedSandwichStruct<'de>> for TableUnionWithVectorReservedSandwichStruct
impl<'de> FromWire<TableUnionWithVectorReservedSandwichStruct<'de>> for TableUnionWithVectorReservedSandwichStruct
Sourcefn from_wire(wire: TableUnionWithVectorReservedSandwichStruct<'de>) -> Self
fn from_wire(wire: TableUnionWithVectorReservedSandwichStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for TableUnionWithVectorReservedSandwichStruct
impl PartialEq for TableUnionWithVectorReservedSandwichStruct
Sourcefn eq(&self, other: &TableUnionWithVectorReservedSandwichStruct) -> bool
fn eq(&self, other: &TableUnionWithVectorReservedSandwichStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TableUnionWithVectorReservedSandwichStruct