pub struct TableUnionWithVectorStructSandwichStruct {
pub table: TableUnionWithVectorStructSandwich,
}Fields
table: TableUnionWithVectorStructSandwichTrait Implementations
Sourceimpl CompatFrom<TableUnionWithVectorStructSandwichStruct> for TableUnionWithVectorStructSandwichStruct
impl CompatFrom<TableUnionWithVectorStructSandwichStruct> for TableUnionWithVectorStructSandwichStruct
Sourcefn compat_from(value: TableUnionWithVectorStructSandwichStruct) -> Self
fn compat_from(value: TableUnionWithVectorStructSandwichStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TableUnionWithVectorStructSandwichStruct> for TableUnionWithVectorStructSandwichStruct
impl CompatFrom<TableUnionWithVectorStructSandwichStruct> for TableUnionWithVectorStructSandwichStruct
Sourcefn compat_from(value: TableUnionWithVectorStructSandwichStruct) -> Self
fn compat_from(value: TableUnionWithVectorStructSandwichStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<TableUnionWithVectorStructSandwichStruct<'static>, ___E> for TableUnionWithVectorStructSandwichStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<TableUnionWithVectorStructSandwichStruct<'static>, ___E> for TableUnionWithVectorStructSandwichStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableUnionWithVectorStructSandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableUnionWithVectorStructSandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TableUnionWithVectorStructSandwichStruct<'static>>, ___E> for TableUnionWithVectorStructSandwichStructwhere
___E: Encoder + ?Sized,
TableUnionWithVectorStructSandwichStruct: Encode<TableUnionWithVectorStructSandwichStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableUnionWithVectorStructSandwichStruct<'static>>, ___E> for TableUnionWithVectorStructSandwichStructwhere
___E: Encoder + ?Sized,
TableUnionWithVectorStructSandwichStruct: Encode<TableUnionWithVectorStructSandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableUnionWithVectorStructSandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableUnionWithVectorStructSandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableUnionWithVectorStructSandwichStruct<'de>> for TableUnionWithVectorStructSandwichStruct
impl<'de> FromWire<TableUnionWithVectorStructSandwichStruct<'de>> for TableUnionWithVectorStructSandwichStruct
Sourcefn from_wire(wire: TableUnionWithVectorStructSandwichStruct<'de>) -> Self
fn from_wire(wire: TableUnionWithVectorStructSandwichStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for TableUnionWithVectorStructSandwichStruct
impl PartialEq for TableUnionWithVectorStructSandwichStruct
Sourcefn eq(&self, other: &TableUnionWithVectorStructSandwichStruct) -> bool
fn eq(&self, other: &TableUnionWithVectorStructSandwichStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TableUnionWithVectorStructSandwichStruct