pub struct TestStrictResourceXUnionInStruct {
pub xu: SampleStrictResourceXUnion,
}Fields
xu: SampleStrictResourceXUnionTrait Implementations
Sourceimpl Clone for TestStrictResourceXUnionInStruct
impl Clone for TestStrictResourceXUnionInStruct
Sourcefn clone(&self) -> TestStrictResourceXUnionInStruct
fn clone(&self) -> TestStrictResourceXUnionInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestStrictResourceXUnionInStruct> for TestStrictResourceXUnionInStruct
impl CompatFrom<TestStrictResourceXUnionInStruct> for TestStrictResourceXUnionInStruct
Sourcefn compat_from(value: TestStrictResourceXUnionInStruct) -> Self
fn compat_from(value: TestStrictResourceXUnionInStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TestStrictResourceXUnionInStruct> for TestStrictResourceXUnionInStruct
impl CompatFrom<TestStrictResourceXUnionInStruct> for TestStrictResourceXUnionInStruct
Sourcefn compat_from(value: TestStrictResourceXUnionInStruct) -> Self
fn compat_from(value: TestStrictResourceXUnionInStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<TestStrictResourceXUnionInStruct<'static>, ___E> for TestStrictResourceXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<TestStrictResourceXUnionInStruct<'static>, ___E> for TestStrictResourceXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestStrictResourceXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestStrictResourceXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TestStrictResourceXUnionInStruct<'static>>, ___E> for TestStrictResourceXUnionInStructwhere
___E: Encoder + ?Sized,
TestStrictResourceXUnionInStruct: Encode<TestStrictResourceXUnionInStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TestStrictResourceXUnionInStruct<'static>>, ___E> for TestStrictResourceXUnionInStructwhere
___E: Encoder + ?Sized,
TestStrictResourceXUnionInStruct: Encode<TestStrictResourceXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestStrictResourceXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestStrictResourceXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestStrictResourceXUnionInStruct<'de>> for TestStrictResourceXUnionInStruct
impl<'de> FromWire<TestStrictResourceXUnionInStruct<'de>> for TestStrictResourceXUnionInStruct
Sourcefn from_wire(wire: TestStrictResourceXUnionInStruct<'de>) -> Self
fn from_wire(wire: TestStrictResourceXUnionInStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl Ord for TestStrictResourceXUnionInStruct
impl Ord for TestStrictResourceXUnionInStruct
Sourcefn cmp(&self, other: &TestStrictResourceXUnionInStruct) -> Ordering
fn cmp(&self, other: &TestStrictResourceXUnionInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestStrictResourceXUnionInStruct
impl PartialEq for TestStrictResourceXUnionInStruct
Sourcefn eq(&self, other: &TestStrictResourceXUnionInStruct) -> bool
fn eq(&self, other: &TestStrictResourceXUnionInStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TestStrictResourceXUnionInStruct
impl PartialOrd for TestStrictResourceXUnionInStruct
impl Eq for TestStrictResourceXUnionInStruct
impl StructuralPartialEq for TestStrictResourceXUnionInStruct