pub struct TestStrictXUnionInStruct {
pub xu: SampleStrictXUnion,
}Fields
xu: SampleStrictXUnionTrait Implementations
Sourceimpl Clone for TestStrictXUnionInStruct
impl Clone for TestStrictXUnionInStruct
Sourcefn clone(&self) -> TestStrictXUnionInStruct
fn clone(&self) -> TestStrictXUnionInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestStrictXUnionInStruct> for TestStrictXUnionInStruct
impl CompatFrom<TestStrictXUnionInStruct> for TestStrictXUnionInStruct
Sourcefn compat_from(value: TestStrictXUnionInStruct) -> TestStrictXUnionInStruct
fn compat_from(value: TestStrictXUnionInStruct) -> TestStrictXUnionInStruct
Converts
value into a value of this type.Sourceimpl Debug for TestStrictXUnionInStruct
impl Debug for TestStrictXUnionInStruct
Sourceimpl<'a, ___E> Encode<TestStrictXUnionInStruct<'static>, ___E> for &'a TestStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TestStrictXUnionInStruct<'static>, ___E> for &'a TestStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestStrictXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestStrictXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestStrictXUnionInStruct<'static>, ___E> for TestStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TestStrictXUnionInStruct<'static>, ___E> for TestStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestStrictXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestStrictXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TestStrictXUnionInStruct<'static>>, ___E> for &'a TestStrictXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestStrictXUnionInStruct: Encode<TestStrictXUnionInStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TestStrictXUnionInStruct<'static>>, ___E> for &'a TestStrictXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestStrictXUnionInStruct: Encode<TestStrictXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TestStrictXUnionInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestStrictXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TestStrictXUnionInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestStrictXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TestStrictXUnionInStruct<'static>>, ___E> for TestStrictXUnionInStructwhere
___E: Encoder + ?Sized,
TestStrictXUnionInStruct: Encode<TestStrictXUnionInStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TestStrictXUnionInStruct<'static>>, ___E> for TestStrictXUnionInStructwhere
___E: Encoder + ?Sized,
TestStrictXUnionInStruct: Encode<TestStrictXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<TestStrictXUnionInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestStrictXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TestStrictXUnionInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestStrictXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestStrictXUnionInStruct<'de>> for TestStrictXUnionInStruct
impl<'de> FromWire<TestStrictXUnionInStruct<'de>> for TestStrictXUnionInStruct
Sourcefn from_wire(wire: TestStrictXUnionInStruct<'de>) -> TestStrictXUnionInStruct
fn from_wire(wire: TestStrictXUnionInStruct<'de>) -> TestStrictXUnionInStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestStrictXUnionInStruct<'de>> for TestStrictXUnionInStruct
impl<'de> FromWireRef<TestStrictXUnionInStruct<'de>> for TestStrictXUnionInStruct
Sourcefn from_wire_ref(
wire: &TestStrictXUnionInStruct<'de>,
) -> TestStrictXUnionInStruct
fn from_wire_ref( wire: &TestStrictXUnionInStruct<'de>, ) -> TestStrictXUnionInStruct
Converts the given reference to this type.
Sourceimpl Hash for TestStrictXUnionInStruct
impl Hash for TestStrictXUnionInStruct
Sourceimpl Ord for TestStrictXUnionInStruct
impl Ord for TestStrictXUnionInStruct
Sourcefn cmp(&self, other: &TestStrictXUnionInStruct) -> Ordering
fn cmp(&self, other: &TestStrictXUnionInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestStrictXUnionInStruct
impl PartialEq for TestStrictXUnionInStruct
Sourceimpl PartialOrd for TestStrictXUnionInStruct
impl PartialOrd for TestStrictXUnionInStruct
impl Eq for TestStrictXUnionInStruct
impl StructuralPartialEq for TestStrictXUnionInStruct