pub struct Uint8UnionStruct {
pub u: Uint8Union,
}Fields
u: Uint8UnionTrait Implementations
Sourceimpl Clone for Uint8UnionStruct
impl Clone for Uint8UnionStruct
Sourcefn clone(&self) -> Uint8UnionStruct
fn clone(&self) -> Uint8UnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint8UnionStruct> for Uint8UnionStruct
impl CompatFrom<Uint8UnionStruct> for Uint8UnionStruct
Sourcefn compat_from(value: Uint8UnionStruct) -> Uint8UnionStruct
fn compat_from(value: Uint8UnionStruct) -> Uint8UnionStruct
Converts
value into a value of this type.Sourceimpl Debug for Uint8UnionStruct
impl Debug for Uint8UnionStruct
Sourceimpl<'a, ___E> Encode<Uint8UnionStruct, ___E> for &'a Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8UnionStruct, ___E> for &'a Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8UnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8UnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8UnionStruct, ___E> for Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8UnionStruct, ___E> for Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8UnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8UnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint8UnionStruct>, ___E> for &'a Uint8UnionStruct
impl<'a, ___E> EncodeOption<Box<'static, Uint8UnionStruct>, ___E> for &'a Uint8UnionStruct
Sourcefn encode_option(
this: Option<&'a Uint8UnionStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8UnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Uint8UnionStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8UnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint8UnionStruct>, ___E> for Uint8UnionStruct
impl<___E> EncodeOption<Box<'static, Uint8UnionStruct>, ___E> for Uint8UnionStruct
Sourcefn encode_option(
this: Option<Uint8UnionStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8UnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Uint8UnionStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8UnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint8UnionStruct> for Uint8UnionStruct
impl FromWire<Uint8UnionStruct> for Uint8UnionStruct
Sourcefn from_wire(wire: Uint8UnionStruct) -> Uint8UnionStruct
fn from_wire(wire: Uint8UnionStruct) -> Uint8UnionStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint8UnionStruct> for Uint8UnionStruct
impl FromWireRef<Uint8UnionStruct> for Uint8UnionStruct
Sourcefn from_wire_ref(wire: &Uint8UnionStruct) -> Uint8UnionStruct
fn from_wire_ref(wire: &Uint8UnionStruct) -> Uint8UnionStruct
Converts the given reference to this type.
Sourceimpl Hash for Uint8UnionStruct
impl Hash for Uint8UnionStruct
Sourceimpl Ord for Uint8UnionStruct
impl Ord for Uint8UnionStruct
Sourcefn cmp(&self, other: &Uint8UnionStruct) -> Ordering
fn cmp(&self, other: &Uint8UnionStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint8UnionStruct
impl PartialEq for Uint8UnionStruct
Sourceimpl PartialOrd for Uint8UnionStruct
impl PartialOrd for Uint8UnionStruct
impl Copy for Uint8UnionStruct
impl Eq for Uint8UnionStruct
impl StructuralPartialEq for Uint8UnionStruct