pub struct UnboundedNonnullableString {
pub s0: String,
}Fields
s0: StringTrait Implementations
Sourceimpl Clone for UnboundedNonnullableString
impl Clone for UnboundedNonnullableString
Sourcefn clone(&self) -> UnboundedNonnullableString
fn clone(&self) -> UnboundedNonnullableString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<UnboundedNonnullableString> for UnboundedNonnullableString
impl CompatFrom<UnboundedNonnullableString> for UnboundedNonnullableString
Sourcefn compat_from(value: UnboundedNonnullableString) -> UnboundedNonnullableString
fn compat_from(value: UnboundedNonnullableString) -> UnboundedNonnullableString
Converts
value into a value of this type.Sourceimpl Debug for UnboundedNonnullableString
impl Debug for UnboundedNonnullableString
Sourceimpl<'a, ___E> Encode<UnboundedNonnullableString<'static>, ___E> for &'a UnboundedNonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<UnboundedNonnullableString<'static>, ___E> for &'a UnboundedNonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNonnullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNonnullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UnboundedNonnullableString<'static>, ___E> for UnboundedNonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<UnboundedNonnullableString<'static>, ___E> for UnboundedNonnullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNonnullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNonnullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UnboundedNonnullableString<'static>>, ___E> for &'a UnboundedNonnullableStringwhere
___E: Encoder + ?Sized,
&'a UnboundedNonnullableString: Encode<UnboundedNonnullableString<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, UnboundedNonnullableString<'static>>, ___E> for &'a UnboundedNonnullableStringwhere
___E: Encoder + ?Sized,
&'a UnboundedNonnullableString: Encode<UnboundedNonnullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a UnboundedNonnullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNonnullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a UnboundedNonnullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNonnullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNonnullableString<'static>>, ___E> for UnboundedNonnullableStringwhere
___E: Encoder + ?Sized,
UnboundedNonnullableString: Encode<UnboundedNonnullableString<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNonnullableString<'static>>, ___E> for UnboundedNonnullableStringwhere
___E: Encoder + ?Sized,
UnboundedNonnullableString: Encode<UnboundedNonnullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<UnboundedNonnullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNonnullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<UnboundedNonnullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNonnullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNonnullableString<'de>> for UnboundedNonnullableString
impl<'de> FromWire<UnboundedNonnullableString<'de>> for UnboundedNonnullableString
Sourcefn from_wire(
wire: UnboundedNonnullableString<'de>,
) -> UnboundedNonnullableString
fn from_wire( wire: UnboundedNonnullableString<'de>, ) -> UnboundedNonnullableString
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<UnboundedNonnullableString<'de>> for UnboundedNonnullableString
impl<'de> FromWireRef<UnboundedNonnullableString<'de>> for UnboundedNonnullableString
Sourcefn from_wire_ref(
wire: &UnboundedNonnullableString<'de>,
) -> UnboundedNonnullableString
fn from_wire_ref( wire: &UnboundedNonnullableString<'de>, ) -> UnboundedNonnullableString
Converts the given reference to this type.
Sourceimpl Hash for UnboundedNonnullableString
impl Hash for UnboundedNonnullableString
Sourceimpl Ord for UnboundedNonnullableString
impl Ord for UnboundedNonnullableString
Sourcefn cmp(&self, other: &UnboundedNonnullableString) -> Ordering
fn cmp(&self, other: &UnboundedNonnullableString) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for UnboundedNonnullableString
impl PartialOrd for UnboundedNonnullableString
impl Eq for UnboundedNonnullableString
impl StructuralPartialEq for UnboundedNonnullableString