pub struct UnboundedNonnullableVectorOfHandles {
pub vh0: Vec<NullableHandle>,
}Fields
vh0: Vec<NullableHandle>Trait Implementations
Sourceimpl CompatFrom<UnboundedNonnullableVectorOfHandles> for UnboundedNonnullableVectorOfHandles
impl CompatFrom<UnboundedNonnullableVectorOfHandles> for UnboundedNonnullableVectorOfHandles
Sourcefn compat_from(value: UnboundedNonnullableVectorOfHandles) -> Self
fn compat_from(value: UnboundedNonnullableVectorOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<UnboundedNonnullableVectorOfHandles> for UnboundedNonnullableVectorOfHandles
impl CompatFrom<UnboundedNonnullableVectorOfHandles> for UnboundedNonnullableVectorOfHandles
Sourcefn compat_from(value: UnboundedNonnullableVectorOfHandles) -> Self
fn compat_from(value: UnboundedNonnullableVectorOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<UnboundedNonnullableVectorOfHandles<'static>, ___E> for UnboundedNonnullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<UnboundedNonnullableVectorOfHandles<'static>, ___E> for UnboundedNonnullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNonnullableVectorOfHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNonnullableVectorOfHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfHandles<'static>>, ___E> for UnboundedNonnullableVectorOfHandleswhere
___E: Encoder + ?Sized,
UnboundedNonnullableVectorOfHandles: Encode<UnboundedNonnullableVectorOfHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfHandles<'static>>, ___E> for UnboundedNonnullableVectorOfHandleswhere
___E: Encoder + ?Sized,
UnboundedNonnullableVectorOfHandles: Encode<UnboundedNonnullableVectorOfHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNonnullableVectorOfHandles<'de>> for UnboundedNonnullableVectorOfHandles
impl<'de> FromWire<UnboundedNonnullableVectorOfHandles<'de>> for UnboundedNonnullableVectorOfHandles
Sourcefn from_wire(wire: UnboundedNonnullableVectorOfHandles<'de>) -> Self
fn from_wire(wire: UnboundedNonnullableVectorOfHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for UnboundedNonnullableVectorOfHandles
impl PartialEq for UnboundedNonnullableVectorOfHandles
Sourcefn eq(&self, other: &UnboundedNonnullableVectorOfHandles) -> bool
fn eq(&self, other: &UnboundedNonnullableVectorOfHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnboundedNonnullableVectorOfHandles