pub struct UnboundedNonnullableVectorOfUint32s {
pub vu0: Vec<u32>,
}Fields
vu0: Vec<u32>Trait Implementations
Sourceimpl Clone for UnboundedNonnullableVectorOfUint32s
impl Clone for UnboundedNonnullableVectorOfUint32s
Sourcefn clone(&self) -> UnboundedNonnullableVectorOfUint32s
fn clone(&self) -> UnboundedNonnullableVectorOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<UnboundedNonnullableVectorOfUint32s> for UnboundedNonnullableVectorOfUint32s
impl CompatFrom<UnboundedNonnullableVectorOfUint32s> for UnboundedNonnullableVectorOfUint32s
Sourcefn compat_from(
value: UnboundedNonnullableVectorOfUint32s,
) -> UnboundedNonnullableVectorOfUint32s
fn compat_from( value: UnboundedNonnullableVectorOfUint32s, ) -> UnboundedNonnullableVectorOfUint32s
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E> for &'a UnboundedNonnullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E> for &'a UnboundedNonnullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNonnullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNonnullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E> for UnboundedNonnullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E> for UnboundedNonnullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNonnullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNonnullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>, ___E> for &'a UnboundedNonnullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a UnboundedNonnullableVectorOfUint32s: Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>, ___E> for &'a UnboundedNonnullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a UnboundedNonnullableVectorOfUint32s: Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a UnboundedNonnullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a UnboundedNonnullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>, ___E> for UnboundedNonnullableVectorOfUint32swhere
___E: Encoder + ?Sized,
UnboundedNonnullableVectorOfUint32s: Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>, ___E> for UnboundedNonnullableVectorOfUint32swhere
___E: Encoder + ?Sized,
UnboundedNonnullableVectorOfUint32s: Encode<UnboundedNonnullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<UnboundedNonnullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<UnboundedNonnullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNonnullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNonnullableVectorOfUint32s<'de>> for UnboundedNonnullableVectorOfUint32s
impl<'de> FromWire<UnboundedNonnullableVectorOfUint32s<'de>> for UnboundedNonnullableVectorOfUint32s
Sourcefn from_wire(
wire: UnboundedNonnullableVectorOfUint32s<'de>,
) -> UnboundedNonnullableVectorOfUint32s
fn from_wire( wire: UnboundedNonnullableVectorOfUint32s<'de>, ) -> UnboundedNonnullableVectorOfUint32s
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<UnboundedNonnullableVectorOfUint32s<'de>> for UnboundedNonnullableVectorOfUint32s
impl<'de> FromWireRef<UnboundedNonnullableVectorOfUint32s<'de>> for UnboundedNonnullableVectorOfUint32s
Sourcefn from_wire_ref(
wire: &UnboundedNonnullableVectorOfUint32s<'de>,
) -> UnboundedNonnullableVectorOfUint32s
fn from_wire_ref( wire: &UnboundedNonnullableVectorOfUint32s<'de>, ) -> UnboundedNonnullableVectorOfUint32s
Converts the given reference to this type.
Sourceimpl Ord for UnboundedNonnullableVectorOfUint32s
impl Ord for UnboundedNonnullableVectorOfUint32s
Sourcefn cmp(&self, other: &UnboundedNonnullableVectorOfUint32s) -> Ordering
fn cmp(&self, other: &UnboundedNonnullableVectorOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UnboundedNonnullableVectorOfUint32s
impl PartialEq for UnboundedNonnullableVectorOfUint32s
Sourcefn eq(&self, other: &UnboundedNonnullableVectorOfUint32s) -> bool
fn eq(&self, other: &UnboundedNonnullableVectorOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UnboundedNonnullableVectorOfUint32s
impl PartialOrd for UnboundedNonnullableVectorOfUint32s
impl Eq for UnboundedNonnullableVectorOfUint32s
impl StructuralPartialEq for UnboundedNonnullableVectorOfUint32s