pub struct UnboundedNullableString {
pub s0: Option<String>,
}Fields
s0: Option<String>Trait Implementations
Sourceimpl Clone for UnboundedNullableString
impl Clone for UnboundedNullableString
Sourcefn clone(&self) -> UnboundedNullableString
fn clone(&self) -> UnboundedNullableString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<UnboundedNullableString> for UnboundedNullableString
impl CompatFrom<UnboundedNullableString> for UnboundedNullableString
Sourcefn compat_from(value: UnboundedNullableString) -> UnboundedNullableString
fn compat_from(value: UnboundedNullableString) -> UnboundedNullableString
Converts
value into a value of this type.Sourceimpl Debug for UnboundedNullableString
impl Debug for UnboundedNullableString
Sourceimpl<'a, ___E> Encode<UnboundedNullableString<'static>, ___E> for &'a UnboundedNullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<UnboundedNullableString<'static>, ___E> for &'a UnboundedNullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UnboundedNullableString<'static>, ___E> for UnboundedNullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<UnboundedNullableString<'static>, ___E> for UnboundedNullableStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UnboundedNullableString<'static>>, ___E> for &'a UnboundedNullableStringwhere
___E: Encoder + ?Sized,
&'a UnboundedNullableString: Encode<UnboundedNullableString<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, UnboundedNullableString<'static>>, ___E> for &'a UnboundedNullableStringwhere
___E: Encoder + ?Sized,
&'a UnboundedNullableString: Encode<UnboundedNullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a UnboundedNullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a UnboundedNullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNullableString<'static>>, ___E> for UnboundedNullableStringwhere
___E: Encoder + ?Sized,
UnboundedNullableString: Encode<UnboundedNullableString<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNullableString<'static>>, ___E> for UnboundedNullableStringwhere
___E: Encoder + ?Sized,
UnboundedNullableString: Encode<UnboundedNullableString<'static>, ___E>,
Sourcefn encode_option(
this: Option<UnboundedNullableString>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNullableString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<UnboundedNullableString>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNullableString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNullableString<'de>> for UnboundedNullableString
impl<'de> FromWire<UnboundedNullableString<'de>> for UnboundedNullableString
Sourcefn from_wire(wire: UnboundedNullableString<'de>) -> UnboundedNullableString
fn from_wire(wire: UnboundedNullableString<'de>) -> UnboundedNullableString
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<UnboundedNullableString<'de>> for UnboundedNullableString
impl<'de> FromWireRef<UnboundedNullableString<'de>> for UnboundedNullableString
Sourcefn from_wire_ref(wire: &UnboundedNullableString<'de>) -> UnboundedNullableString
fn from_wire_ref(wire: &UnboundedNullableString<'de>) -> UnboundedNullableString
Converts the given reference to this type.
Sourceimpl Hash for UnboundedNullableString
impl Hash for UnboundedNullableString
Sourceimpl Ord for UnboundedNullableString
impl Ord for UnboundedNullableString
Sourcefn cmp(&self, other: &UnboundedNullableString) -> Ordering
fn cmp(&self, other: &UnboundedNullableString) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UnboundedNullableString
impl PartialEq for UnboundedNullableString
Sourceimpl PartialOrd for UnboundedNullableString
impl PartialOrd for UnboundedNullableString
impl Eq for UnboundedNullableString
impl StructuralPartialEq for UnboundedNullableString