pub struct UnboundedNullableVectorOfHandles {
pub vh0: Option<Vec<NullableHandle>>,
}Fields
vh0: Option<Vec<NullableHandle>>Trait Implementations
Sourceimpl CompatFrom<UnboundedNullableVectorOfHandles> for UnboundedNullableVectorOfHandles
impl CompatFrom<UnboundedNullableVectorOfHandles> for UnboundedNullableVectorOfHandles
Sourcefn compat_from(value: UnboundedNullableVectorOfHandles) -> Self
fn compat_from(value: UnboundedNullableVectorOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<UnboundedNullableVectorOfHandles> for UnboundedNullableVectorOfHandles
impl CompatFrom<UnboundedNullableVectorOfHandles> for UnboundedNullableVectorOfHandles
Sourcefn compat_from(value: UnboundedNullableVectorOfHandles) -> Self
fn compat_from(value: UnboundedNullableVectorOfHandles) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<UnboundedNullableVectorOfHandles<'static>, ___E> for UnboundedNullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<UnboundedNullableVectorOfHandles<'static>, ___E> for UnboundedNullableVectorOfHandleswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNullableVectorOfHandles<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNullableVectorOfHandles<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNullableVectorOfHandles<'static>>, ___E> for UnboundedNullableVectorOfHandleswhere
___E: Encoder + ?Sized,
UnboundedNullableVectorOfHandles: Encode<UnboundedNullableVectorOfHandles<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNullableVectorOfHandles<'static>>, ___E> for UnboundedNullableVectorOfHandleswhere
___E: Encoder + ?Sized,
UnboundedNullableVectorOfHandles: Encode<UnboundedNullableVectorOfHandles<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfHandles<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfHandles<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNullableVectorOfHandles<'de>> for UnboundedNullableVectorOfHandles
impl<'de> FromWire<UnboundedNullableVectorOfHandles<'de>> for UnboundedNullableVectorOfHandles
Sourcefn from_wire(wire: UnboundedNullableVectorOfHandles<'de>) -> Self
fn from_wire(wire: UnboundedNullableVectorOfHandles<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for UnboundedNullableVectorOfHandles
impl PartialEq for UnboundedNullableVectorOfHandles
Sourcefn eq(&self, other: &UnboundedNullableVectorOfHandles) -> bool
fn eq(&self, other: &UnboundedNullableVectorOfHandles) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnboundedNullableVectorOfHandles