pub struct VectorOfArrayOfEventInStructWithReducedRights {
pub h: Vec<[Event; 1]>,
}Fields
h: Vec<[Event; 1]>Trait Implementations
Sourceimpl CompatFrom<VectorOfArrayOfEventInStructWithReducedRights> for VectorOfArrayOfEventInStructWithReducedRights
impl CompatFrom<VectorOfArrayOfEventInStructWithReducedRights> for VectorOfArrayOfEventInStructWithReducedRights
Sourcefn compat_from(value: VectorOfArrayOfEventInStructWithReducedRights) -> Self
fn compat_from(value: VectorOfArrayOfEventInStructWithReducedRights) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<VectorOfArrayOfEventInStructWithReducedRights> for VectorOfArrayOfEventInStructWithReducedRights
impl CompatFrom<VectorOfArrayOfEventInStructWithReducedRights> for VectorOfArrayOfEventInStructWithReducedRights
Sourcefn compat_from(value: VectorOfArrayOfEventInStructWithReducedRights) -> Self
fn compat_from(value: VectorOfArrayOfEventInStructWithReducedRights) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<VectorOfArrayOfEventInStructWithReducedRights<'static>, ___E> for VectorOfArrayOfEventInStructWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<VectorOfArrayOfEventInStructWithReducedRights<'static>, ___E> for VectorOfArrayOfEventInStructWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorOfArrayOfEventInStructWithReducedRights<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorOfArrayOfEventInStructWithReducedRights<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, VectorOfArrayOfEventInStructWithReducedRights<'static>>, ___E> for VectorOfArrayOfEventInStructWithReducedRightswhere
___E: Encoder + ?Sized,
VectorOfArrayOfEventInStructWithReducedRights: Encode<VectorOfArrayOfEventInStructWithReducedRights<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, VectorOfArrayOfEventInStructWithReducedRights<'static>>, ___E> for VectorOfArrayOfEventInStructWithReducedRightswhere
___E: Encoder + ?Sized,
VectorOfArrayOfEventInStructWithReducedRights: Encode<VectorOfArrayOfEventInStructWithReducedRights<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorOfArrayOfEventInStructWithReducedRights<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorOfArrayOfEventInStructWithReducedRights<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<VectorOfArrayOfEventInStructWithReducedRights<'de>> for VectorOfArrayOfEventInStructWithReducedRights
impl<'de> FromWire<VectorOfArrayOfEventInStructWithReducedRights<'de>> for VectorOfArrayOfEventInStructWithReducedRights
Sourcefn from_wire(wire: VectorOfArrayOfEventInStructWithReducedRights<'de>) -> Self
fn from_wire(wire: VectorOfArrayOfEventInStructWithReducedRights<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for VectorOfArrayOfEventInStructWithReducedRights
impl PartialEq for VectorOfArrayOfEventInStructWithReducedRights
Sourcefn eq(&self, other: &VectorOfArrayOfEventInStructWithReducedRights) -> bool
fn eq(&self, other: &VectorOfArrayOfEventInStructWithReducedRights) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VectorOfArrayOfEventInStructWithReducedRights