pub struct VectorOfArrayOfEventInUnionWithReducedRightsStruct {
pub u: VectorOfArrayOfEventInUnionWithReducedRights,
}Fields
u: VectorOfArrayOfEventInUnionWithReducedRightsTrait Implementations
Sourceimpl CompatFrom<VectorOfArrayOfEventInUnionWithReducedRightsStruct> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
impl CompatFrom<VectorOfArrayOfEventInUnionWithReducedRightsStruct> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
Sourcefn compat_from(
value: VectorOfArrayOfEventInUnionWithReducedRightsStruct,
) -> Self
fn compat_from( value: VectorOfArrayOfEventInUnionWithReducedRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<VectorOfArrayOfEventInUnionWithReducedRightsStruct> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
impl CompatFrom<VectorOfArrayOfEventInUnionWithReducedRightsStruct> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
Sourcefn compat_from(
value: VectorOfArrayOfEventInUnionWithReducedRightsStruct,
) -> Self
fn compat_from( value: VectorOfArrayOfEventInUnionWithReducedRightsStruct, ) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>, ___E> for VectorOfArrayOfEventInUnionWithReducedRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>, ___E> for VectorOfArrayOfEventInUnionWithReducedRightsStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>, ___E> for VectorOfArrayOfEventInUnionWithReducedRightsStructwhere
___E: Encoder + ?Sized,
VectorOfArrayOfEventInUnionWithReducedRightsStruct: Encode<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>, ___E> for VectorOfArrayOfEventInUnionWithReducedRightsStructwhere
___E: Encoder + ?Sized,
VectorOfArrayOfEventInUnionWithReducedRightsStruct: Encode<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorOfArrayOfEventInUnionWithReducedRightsStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'de>> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
impl<'de> FromWire<VectorOfArrayOfEventInUnionWithReducedRightsStruct<'de>> for VectorOfArrayOfEventInUnionWithReducedRightsStruct
Sourcefn from_wire(
wire: VectorOfArrayOfEventInUnionWithReducedRightsStruct<'de>,
) -> Self
fn from_wire( wire: VectorOfArrayOfEventInUnionWithReducedRightsStruct<'de>, ) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for VectorOfArrayOfEventInUnionWithReducedRightsStruct
impl PartialEq for VectorOfArrayOfEventInUnionWithReducedRightsStruct
Sourcefn eq(&self, other: &VectorOfArrayOfEventInUnionWithReducedRightsStruct) -> bool
fn eq(&self, other: &VectorOfArrayOfEventInUnionWithReducedRightsStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VectorOfArrayOfEventInUnionWithReducedRightsStruct