#[repr(C)]pub struct AliasedBool {
pub value: bool,
}Fields
value: boolTrait Implementations
Sourceimpl Clone for AliasedBool
impl Clone for AliasedBool
Sourcefn clone(&self) -> AliasedBool
fn clone(&self) -> AliasedBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<AliasedBool> for AliasedBool
impl CompatFrom<AliasedBool> for AliasedBool
Sourcefn compat_from(value: AliasedBool) -> AliasedBool
fn compat_from(value: AliasedBool) -> AliasedBool
Converts
value into a value of this type.Sourceimpl Debug for AliasedBool
impl Debug for AliasedBool
Sourceimpl<'a, ___E> Encode<AliasedBool, ___E> for &'a AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedBool, ___E> for &'a AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedBool, ___E> for AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedBool, ___E> for AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
const COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AliasedBool>, ___E> for &'a AliasedBool
impl<'a, ___E> EncodeOption<Box<'static, AliasedBool>, ___E> for &'a AliasedBool
Sourcefn encode_option(
this: Option<&'a AliasedBool>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedBool>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a AliasedBool>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedBool>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, AliasedBool>, ___E> for AliasedBool
impl<___E> EncodeOption<Box<'static, AliasedBool>, ___E> for AliasedBool
Sourcefn encode_option(
this: Option<AliasedBool>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedBool>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<AliasedBool>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedBool>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<AliasedBool> for AliasedBool
impl FromWire<AliasedBool> for AliasedBool
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
const COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
Sourcefn from_wire(wire: AliasedBool) -> AliasedBool
fn from_wire(wire: AliasedBool) -> AliasedBool
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedBool> for AliasedBool
impl FromWireRef<AliasedBool> for AliasedBool
Sourcefn from_wire_ref(wire: &AliasedBool) -> AliasedBool
fn from_wire_ref(wire: &AliasedBool) -> AliasedBool
Converts the given reference to this type.
Sourceimpl Hash for AliasedBool
impl Hash for AliasedBool
Sourceimpl Ord for AliasedBool
impl Ord for AliasedBool
Sourcefn cmp(&self, other: &AliasedBool) -> Ordering
fn cmp(&self, other: &AliasedBool) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AliasedBool
impl PartialEq for AliasedBool
Sourceimpl PartialOrd for AliasedBool
impl PartialOrd for AliasedBool
impl Copy for AliasedBool
impl Eq for AliasedBool
impl StructuralPartialEq for AliasedBool