#[repr(C)]pub struct AnotherEmptyStruct {}Trait Implementations
Sourceimpl Clone for AnotherEmptyStruct
impl Clone for AnotherEmptyStruct
Sourcefn clone(&self) -> AnotherEmptyStruct
fn clone(&self) -> AnotherEmptyStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<AnotherEmptyStruct> for AnotherEmptyStruct
impl CompatFrom<AnotherEmptyStruct> for AnotherEmptyStruct
Sourcefn compat_from(value: AnotherEmptyStruct) -> AnotherEmptyStruct
fn compat_from(value: AnotherEmptyStruct) -> AnotherEmptyStruct
Converts
value into a value of this type.Sourceimpl Debug for AnotherEmptyStruct
impl Debug for AnotherEmptyStruct
Sourceimpl<'a, ___E> Encode<AnotherEmptyStruct, ___E> for &'a AnotherEmptyStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AnotherEmptyStruct, ___E> for &'a AnotherEmptyStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnotherEmptyStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnotherEmptyStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AnotherEmptyStruct, ___E> for AnotherEmptyStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AnotherEmptyStruct, ___E> for AnotherEmptyStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnotherEmptyStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnotherEmptyStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AnotherEmptyStruct>, ___E> for &'a AnotherEmptyStruct
impl<'a, ___E> EncodeOption<Box<'static, AnotherEmptyStruct>, ___E> for &'a AnotherEmptyStruct
Sourcefn encode_option(
this: Option<&'a AnotherEmptyStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AnotherEmptyStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a AnotherEmptyStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AnotherEmptyStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, AnotherEmptyStruct>, ___E> for AnotherEmptyStruct
impl<___E> EncodeOption<Box<'static, AnotherEmptyStruct>, ___E> for AnotherEmptyStruct
Sourcefn encode_option(
this: Option<AnotherEmptyStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AnotherEmptyStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<AnotherEmptyStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AnotherEmptyStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<AnotherEmptyStruct> for AnotherEmptyStruct
impl FromWire<AnotherEmptyStruct> for AnotherEmptyStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AnotherEmptyStruct, AnotherEmptyStruct>
const COPY_OPTIMIZATION: CopyOptimization<AnotherEmptyStruct, AnotherEmptyStruct>
Sourcefn from_wire(wire: AnotherEmptyStruct) -> AnotherEmptyStruct
fn from_wire(wire: AnotherEmptyStruct) -> AnotherEmptyStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<AnotherEmptyStruct> for AnotherEmptyStruct
impl FromWireRef<AnotherEmptyStruct> for AnotherEmptyStruct
Sourcefn from_wire_ref(wire: &AnotherEmptyStruct) -> AnotherEmptyStruct
fn from_wire_ref(wire: &AnotherEmptyStruct) -> AnotherEmptyStruct
Converts the given reference to this type.
Sourceimpl Hash for AnotherEmptyStruct
impl Hash for AnotherEmptyStruct
Sourceimpl Ord for AnotherEmptyStruct
impl Ord for AnotherEmptyStruct
Sourcefn cmp(&self, other: &AnotherEmptyStruct) -> Ordering
fn cmp(&self, other: &AnotherEmptyStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AnotherEmptyStruct
impl PartialEq for AnotherEmptyStruct
Sourceimpl PartialOrd for AnotherEmptyStruct
impl PartialOrd for AnotherEmptyStruct
impl Copy for AnotherEmptyStruct
impl Eq for AnotherEmptyStruct
impl StructuralPartialEq for AnotherEmptyStruct