pub struct Bounded32NullableVectorOfUint32s {
pub vu0: Option<Vec<u32>>,
}Fields
vu0: Option<Vec<u32>>Trait Implementations
Sourceimpl Clone for Bounded32NullableVectorOfUint32s
impl Clone for Bounded32NullableVectorOfUint32s
Sourcefn clone(&self) -> Bounded32NullableVectorOfUint32s
fn clone(&self) -> Bounded32NullableVectorOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Bounded32NullableVectorOfUint32s> for Bounded32NullableVectorOfUint32s
impl CompatFrom<Bounded32NullableVectorOfUint32s> for Bounded32NullableVectorOfUint32s
Sourcefn compat_from(
value: Bounded32NullableVectorOfUint32s,
) -> Bounded32NullableVectorOfUint32s
fn compat_from( value: Bounded32NullableVectorOfUint32s, ) -> Bounded32NullableVectorOfUint32s
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Bounded32NullableVectorOfUint32s<'static>, ___E> for &'a Bounded32NullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Bounded32NullableVectorOfUint32s<'static>, ___E> for &'a Bounded32NullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Bounded32NullableVectorOfUint32s<'static>, ___E> for Bounded32NullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Bounded32NullableVectorOfUint32s<'static>, ___E> for Bounded32NullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Bounded32NullableVectorOfUint32s<'static>>, ___E> for &'a Bounded32NullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a Bounded32NullableVectorOfUint32s: Encode<Bounded32NullableVectorOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, Bounded32NullableVectorOfUint32s<'static>>, ___E> for &'a Bounded32NullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a Bounded32NullableVectorOfUint32s: Encode<Bounded32NullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a Bounded32NullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Bounded32NullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Bounded32NullableVectorOfUint32s<'static>>, ___E> for Bounded32NullableVectorOfUint32swhere
___E: Encoder + ?Sized,
Bounded32NullableVectorOfUint32s: Encode<Bounded32NullableVectorOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, Bounded32NullableVectorOfUint32s<'static>>, ___E> for Bounded32NullableVectorOfUint32swhere
___E: Encoder + ?Sized,
Bounded32NullableVectorOfUint32s: Encode<Bounded32NullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<Bounded32NullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Bounded32NullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bounded32NullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Bounded32NullableVectorOfUint32s<'de>> for Bounded32NullableVectorOfUint32s
impl<'de> FromWire<Bounded32NullableVectorOfUint32s<'de>> for Bounded32NullableVectorOfUint32s
Sourcefn from_wire(
wire: Bounded32NullableVectorOfUint32s<'de>,
) -> Bounded32NullableVectorOfUint32s
fn from_wire( wire: Bounded32NullableVectorOfUint32s<'de>, ) -> Bounded32NullableVectorOfUint32s
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Bounded32NullableVectorOfUint32s<'de>> for Bounded32NullableVectorOfUint32s
impl<'de> FromWireRef<Bounded32NullableVectorOfUint32s<'de>> for Bounded32NullableVectorOfUint32s
Sourcefn from_wire_ref(
wire: &Bounded32NullableVectorOfUint32s<'de>,
) -> Bounded32NullableVectorOfUint32s
fn from_wire_ref( wire: &Bounded32NullableVectorOfUint32s<'de>, ) -> Bounded32NullableVectorOfUint32s
Converts the given reference to this type.
Sourceimpl Ord for Bounded32NullableVectorOfUint32s
impl Ord for Bounded32NullableVectorOfUint32s
Sourcefn cmp(&self, other: &Bounded32NullableVectorOfUint32s) -> Ordering
fn cmp(&self, other: &Bounded32NullableVectorOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Bounded32NullableVectorOfUint32s
impl PartialEq for Bounded32NullableVectorOfUint32s
Sourcefn eq(&self, other: &Bounded32NullableVectorOfUint32s) -> bool
fn eq(&self, other: &Bounded32NullableVectorOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for Bounded32NullableVectorOfUint32s
impl PartialOrd for Bounded32NullableVectorOfUint32s
impl Eq for Bounded32NullableVectorOfUint32s
impl StructuralPartialEq for Bounded32NullableVectorOfUint32s