pub struct CompatTable {
pub value: CompatTableValue,
pub empty: String,
}Fields
value: CompatTableValueempty: StringTrait Implementations
Sourceimpl Clone for CompatTable
impl Clone for CompatTable
Sourcefn clone(&self) -> CompatTable
fn clone(&self) -> CompatTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<CompatTable> for CompatTable
impl CompatFrom<CompatTable> for CompatTable
Sourcefn compat_from(value: CompatTable) -> CompatTable
fn compat_from(value: CompatTable) -> CompatTable
Converts
value into a value of this type.Sourceimpl Debug for CompatTable
impl Debug for CompatTable
Sourceimpl<'a, ___E> Encode<CompatTable<'static>, ___E> for &'a CompatTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<CompatTable<'static>, ___E> for &'a CompatTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CompatTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CompatTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<CompatTable<'static>, ___E> for CompatTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<CompatTable<'static>, ___E> for CompatTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CompatTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CompatTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, CompatTable<'static>>, ___E> for &'a CompatTable
impl<'a, ___E> EncodeOption<Box<'static, CompatTable<'static>>, ___E> for &'a CompatTable
Sourcefn encode_option(
this: Option<&'a CompatTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, CompatTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a CompatTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, CompatTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, CompatTable<'static>>, ___E> for CompatTable
impl<___E> EncodeOption<Box<'static, CompatTable<'static>>, ___E> for CompatTable
Sourcefn encode_option(
this: Option<CompatTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, CompatTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<CompatTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, CompatTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<CompatTable<'de>> for CompatTable
impl<'de> FromWire<CompatTable<'de>> for CompatTable
Sourcefn from_wire(wire: CompatTable<'de>) -> CompatTable
fn from_wire(wire: CompatTable<'de>) -> CompatTable
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<CompatTable<'de>> for CompatTable
impl<'de> FromWireRef<CompatTable<'de>> for CompatTable
Sourcefn from_wire_ref(wire: &CompatTable<'de>) -> CompatTable
fn from_wire_ref(wire: &CompatTable<'de>) -> CompatTable
Converts the given reference to this type.
Sourceimpl Hash for CompatTable
impl Hash for CompatTable
Sourceimpl Ord for CompatTable
impl Ord for CompatTable
Sourcefn cmp(&self, other: &CompatTable) -> Ordering
fn cmp(&self, other: &CompatTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CompatTable
impl PartialEq for CompatTable
Sourceimpl PartialOrd for CompatTable
impl PartialOrd for CompatTable
impl Eq for CompatTable
impl StructuralPartialEq for CompatTable