#[repr(C)]pub struct GoldenIntStruct {
pub v: i16,
}Fields
v: i16Trait Implementations
Sourceimpl Clone for GoldenIntStruct
impl Clone for GoldenIntStruct
Sourcefn clone(&self) -> GoldenIntStruct
fn clone(&self) -> GoldenIntStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenIntStruct> for GoldenIntStruct
impl CompatFrom<GoldenIntStruct> for GoldenIntStruct
Sourcefn compat_from(value: GoldenIntStruct) -> GoldenIntStruct
fn compat_from(value: GoldenIntStruct) -> GoldenIntStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenIntStruct
impl Debug for GoldenIntStruct
Sourceimpl<'a, ___E> Encode<GoldenIntStruct, ___E> for &'a GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenIntStruct, ___E> for &'a GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenIntStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenIntStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenIntStruct, ___E> for GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenIntStruct, ___E> for GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, GoldenIntStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, GoldenIntStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenIntStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenIntStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenIntStruct>, ___E> for &'a GoldenIntStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenIntStruct>, ___E> for &'a GoldenIntStruct
Sourcefn encode_option(
this: Option<&'a GoldenIntStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenIntStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenIntStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenIntStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenIntStruct>, ___E> for GoldenIntStruct
impl<___E> EncodeOption<Box<'static, GoldenIntStruct>, ___E> for GoldenIntStruct
Sourcefn encode_option(
this: Option<GoldenIntStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenIntStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenIntStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenIntStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenIntStruct> for GoldenIntStruct
impl FromWire<GoldenIntStruct> for GoldenIntStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, GoldenIntStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, GoldenIntStruct>
Sourcefn from_wire(wire: GoldenIntStruct) -> GoldenIntStruct
fn from_wire(wire: GoldenIntStruct) -> GoldenIntStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenIntStruct> for GoldenIntStruct
impl FromWireRef<GoldenIntStruct> for GoldenIntStruct
Sourcefn from_wire_ref(wire: &GoldenIntStruct) -> GoldenIntStruct
fn from_wire_ref(wire: &GoldenIntStruct) -> GoldenIntStruct
Converts the given reference to this type.
Sourceimpl Hash for GoldenIntStruct
impl Hash for GoldenIntStruct
Sourceimpl Ord for GoldenIntStruct
impl Ord for GoldenIntStruct
Sourcefn cmp(&self, other: &GoldenIntStruct) -> Ordering
fn cmp(&self, other: &GoldenIntStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenIntStruct
impl PartialEq for GoldenIntStruct
Sourceimpl PartialOrd for GoldenIntStruct
impl PartialOrd for GoldenIntStruct
impl Copy for GoldenIntStruct
impl Eq for GoldenIntStruct
impl StructuralPartialEq for GoldenIntStruct