pub struct GoldenNullableByteVectorStruct {
pub v: Option<Vec<u8>>,
}Fields
v: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for GoldenNullableByteVectorStruct
impl Clone for GoldenNullableByteVectorStruct
Sourcefn clone(&self) -> GoldenNullableByteVectorStruct
fn clone(&self) -> GoldenNullableByteVectorStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenNullableByteVectorStruct> for GoldenNullableByteVectorStruct
impl CompatFrom<GoldenNullableByteVectorStruct> for GoldenNullableByteVectorStruct
Sourcefn compat_from(
value: GoldenNullableByteVectorStruct,
) -> GoldenNullableByteVectorStruct
fn compat_from( value: GoldenNullableByteVectorStruct, ) -> GoldenNullableByteVectorStruct
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<GoldenNullableByteVectorStruct<'static>, ___E> for &'a GoldenNullableByteVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<GoldenNullableByteVectorStruct<'static>, ___E> for &'a GoldenNullableByteVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableByteVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableByteVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenNullableByteVectorStruct<'static>, ___E> for GoldenNullableByteVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<GoldenNullableByteVectorStruct<'static>, ___E> for GoldenNullableByteVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableByteVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableByteVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenNullableByteVectorStruct<'static>>, ___E> for &'a GoldenNullableByteVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableByteVectorStruct: Encode<GoldenNullableByteVectorStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenNullableByteVectorStruct<'static>>, ___E> for &'a GoldenNullableByteVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableByteVectorStruct: Encode<GoldenNullableByteVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a GoldenNullableByteVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableByteVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenNullableByteVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableByteVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenNullableByteVectorStruct<'static>>, ___E> for GoldenNullableByteVectorStructwhere
___E: Encoder + ?Sized,
GoldenNullableByteVectorStruct: Encode<GoldenNullableByteVectorStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, GoldenNullableByteVectorStruct<'static>>, ___E> for GoldenNullableByteVectorStructwhere
___E: Encoder + ?Sized,
GoldenNullableByteVectorStruct: Encode<GoldenNullableByteVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<GoldenNullableByteVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableByteVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenNullableByteVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableByteVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenNullableByteVectorStruct<'de>> for GoldenNullableByteVectorStruct
impl<'de> FromWire<GoldenNullableByteVectorStruct<'de>> for GoldenNullableByteVectorStruct
Sourcefn from_wire(
wire: GoldenNullableByteVectorStruct<'de>,
) -> GoldenNullableByteVectorStruct
fn from_wire( wire: GoldenNullableByteVectorStruct<'de>, ) -> GoldenNullableByteVectorStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenNullableByteVectorStruct<'de>> for GoldenNullableByteVectorStruct
impl<'de> FromWireRef<GoldenNullableByteVectorStruct<'de>> for GoldenNullableByteVectorStruct
Sourcefn from_wire_ref(
wire: &GoldenNullableByteVectorStruct<'de>,
) -> GoldenNullableByteVectorStruct
fn from_wire_ref( wire: &GoldenNullableByteVectorStruct<'de>, ) -> GoldenNullableByteVectorStruct
Converts the given reference to this type.
Sourceimpl Ord for GoldenNullableByteVectorStruct
impl Ord for GoldenNullableByteVectorStruct
Sourcefn cmp(&self, other: &GoldenNullableByteVectorStruct) -> Ordering
fn cmp(&self, other: &GoldenNullableByteVectorStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenNullableByteVectorStruct
impl PartialEq for GoldenNullableByteVectorStruct
Sourcefn eq(&self, other: &GoldenNullableByteVectorStruct) -> bool
fn eq(&self, other: &GoldenNullableByteVectorStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GoldenNullableByteVectorStruct
impl PartialOrd for GoldenNullableByteVectorStruct
impl Eq for GoldenNullableByteVectorStruct
impl StructuralPartialEq for GoldenNullableByteVectorStruct