pub struct GoldenNullableStruct {
pub v: Option<Box<GoldenBoolStruct>>,
}Fields
v: Option<Box<GoldenBoolStruct>>Trait Implementations
Sourceimpl Clone for GoldenNullableStruct
impl Clone for GoldenNullableStruct
Sourcefn clone(&self) -> GoldenNullableStruct
fn clone(&self) -> GoldenNullableStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenNullableStruct> for GoldenNullableStruct
impl CompatFrom<GoldenNullableStruct> for GoldenNullableStruct
Sourcefn compat_from(value: GoldenNullableStruct) -> GoldenNullableStruct
fn compat_from(value: GoldenNullableStruct) -> GoldenNullableStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenNullableStruct
impl Debug for GoldenNullableStruct
Sourceimpl<'a, ___E> Encode<GoldenNullableStruct<'static>, ___E> for &'a GoldenNullableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<GoldenNullableStruct<'static>, ___E> for &'a GoldenNullableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenNullableStruct<'static>, ___E> for GoldenNullableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<GoldenNullableStruct<'static>, ___E> for GoldenNullableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenNullableStruct<'static>>, ___E> for &'a GoldenNullableStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableStruct: Encode<GoldenNullableStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenNullableStruct<'static>>, ___E> for &'a GoldenNullableStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableStruct: Encode<GoldenNullableStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a GoldenNullableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenNullableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenNullableStruct<'static>>, ___E> for GoldenNullableStruct
impl<___E> EncodeOption<Box<'static, GoldenNullableStruct<'static>>, ___E> for GoldenNullableStruct
Sourcefn encode_option(
this: Option<GoldenNullableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenNullableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenNullableStruct<'de>> for GoldenNullableStruct
impl<'de> FromWire<GoldenNullableStruct<'de>> for GoldenNullableStruct
Sourcefn from_wire(wire: GoldenNullableStruct<'de>) -> GoldenNullableStruct
fn from_wire(wire: GoldenNullableStruct<'de>) -> GoldenNullableStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenNullableStruct<'de>> for GoldenNullableStruct
impl<'de> FromWireRef<GoldenNullableStruct<'de>> for GoldenNullableStruct
Sourcefn from_wire_ref(wire: &GoldenNullableStruct<'de>) -> GoldenNullableStruct
fn from_wire_ref(wire: &GoldenNullableStruct<'de>) -> GoldenNullableStruct
Converts the given reference to this type.
Sourceimpl Hash for GoldenNullableStruct
impl Hash for GoldenNullableStruct
Sourceimpl Ord for GoldenNullableStruct
impl Ord for GoldenNullableStruct
Sourcefn cmp(&self, other: &GoldenNullableStruct) -> Ordering
fn cmp(&self, other: &GoldenNullableStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenNullableStruct
impl PartialEq for GoldenNullableStruct
Sourceimpl PartialOrd for GoldenNullableStruct
impl PartialOrd for GoldenNullableStruct
impl Eq for GoldenNullableStruct
impl StructuralPartialEq for GoldenNullableStruct