pub struct GoldenStructVectorStruct {
pub v: Vec<GoldenIntStruct>,
}Fields
v: Vec<GoldenIntStruct>Trait Implementations
Sourceimpl Clone for GoldenStructVectorStruct
impl Clone for GoldenStructVectorStruct
Sourcefn clone(&self) -> GoldenStructVectorStruct
fn clone(&self) -> GoldenStructVectorStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenStructVectorStruct> for GoldenStructVectorStruct
impl CompatFrom<GoldenStructVectorStruct> for GoldenStructVectorStruct
Sourcefn compat_from(value: GoldenStructVectorStruct) -> GoldenStructVectorStruct
fn compat_from(value: GoldenStructVectorStruct) -> GoldenStructVectorStruct
Converts
value into a value of this type.Sourceimpl Debug for GoldenStructVectorStruct
impl Debug for GoldenStructVectorStruct
Sourceimpl<'a, ___E> Encode<GoldenStructVectorStruct<'static>, ___E> for &'a GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<GoldenStructVectorStruct<'static>, ___E> for &'a GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenStructVectorStruct<'static>>, ___E> for &'a GoldenStructVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenStructVectorStruct: Encode<GoldenStructVectorStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenStructVectorStruct<'static>>, ___E> for &'a GoldenStructVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenStructVectorStruct: Encode<GoldenStructVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a GoldenStructVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStructVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GoldenStructVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStructVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenStructVectorStruct<'static>>, ___E> for GoldenStructVectorStructwhere
___E: Encoder + ?Sized,
GoldenStructVectorStruct: Encode<GoldenStructVectorStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, GoldenStructVectorStruct<'static>>, ___E> for GoldenStructVectorStructwhere
___E: Encoder + ?Sized,
GoldenStructVectorStruct: Encode<GoldenStructVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<GoldenStructVectorStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStructVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GoldenStructVectorStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStructVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
impl<'de> FromWire<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
Sourcefn from_wire(wire: GoldenStructVectorStruct<'de>) -> GoldenStructVectorStruct
fn from_wire(wire: GoldenStructVectorStruct<'de>) -> GoldenStructVectorStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
impl<'de> FromWireRef<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
Sourcefn from_wire_ref(
wire: &GoldenStructVectorStruct<'de>,
) -> GoldenStructVectorStruct
fn from_wire_ref( wire: &GoldenStructVectorStruct<'de>, ) -> GoldenStructVectorStruct
Converts the given reference to this type.
Sourceimpl Hash for GoldenStructVectorStruct
impl Hash for GoldenStructVectorStruct
Sourceimpl Ord for GoldenStructVectorStruct
impl Ord for GoldenStructVectorStruct
Sourcefn cmp(&self, other: &GoldenStructVectorStruct) -> Ordering
fn cmp(&self, other: &GoldenStructVectorStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenStructVectorStruct
impl PartialEq for GoldenStructVectorStruct
Sourceimpl PartialOrd for GoldenStructVectorStruct
impl PartialOrd for GoldenStructVectorStruct
impl Eq for GoldenStructVectorStruct
impl StructuralPartialEq for GoldenStructVectorStruct