pub struct InterfaceConfig {
pub name: String,
pub ip_address_config: IpAddressConfig,
}Fields
name: Stringip_address_config: IpAddressConfigTrait Implementations
Sourceimpl Clone for InterfaceConfig
impl Clone for InterfaceConfig
Sourcefn clone(&self) -> InterfaceConfig
fn clone(&self) -> InterfaceConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<InterfaceConfig> for InterfaceConfig
impl CompatFrom<InterfaceConfig> for InterfaceConfig
Sourcefn compat_from(value: InterfaceConfig) -> InterfaceConfig
fn compat_from(value: InterfaceConfig) -> InterfaceConfig
Converts
value into a value of this type.Sourceimpl Debug for InterfaceConfig
impl Debug for InterfaceConfig
Sourceimpl<'a, ___E> Encode<InterfaceConfig<'static>, ___E> for &'a InterfaceConfigwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InterfaceConfig<'static>, ___E> for &'a InterfaceConfigwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterfaceConfig<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterfaceConfig<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InterfaceConfig<'static>, ___E> for InterfaceConfigwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InterfaceConfig<'static>, ___E> for InterfaceConfigwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterfaceConfig<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterfaceConfig<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InterfaceConfig<'static>>, ___E> for &'a InterfaceConfig
impl<'a, ___E> EncodeOption<Box<'static, InterfaceConfig<'static>>, ___E> for &'a InterfaceConfig
Sourcefn encode_option(
this: Option<&'a InterfaceConfig>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InterfaceConfig<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InterfaceConfig>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InterfaceConfig<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InterfaceConfig<'static>>, ___E> for InterfaceConfig
impl<___E> EncodeOption<Box<'static, InterfaceConfig<'static>>, ___E> for InterfaceConfig
Sourcefn encode_option(
this: Option<InterfaceConfig>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InterfaceConfig<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InterfaceConfig>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InterfaceConfig<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InterfaceConfig<'de>> for InterfaceConfig
impl<'de> FromWire<InterfaceConfig<'de>> for InterfaceConfig
Sourcefn from_wire(wire: InterfaceConfig<'de>) -> InterfaceConfig
fn from_wire(wire: InterfaceConfig<'de>) -> InterfaceConfig
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InterfaceConfig<'de>> for InterfaceConfig
impl<'de> FromWireRef<InterfaceConfig<'de>> for InterfaceConfig
Sourcefn from_wire_ref(wire: &InterfaceConfig<'de>) -> InterfaceConfig
fn from_wire_ref(wire: &InterfaceConfig<'de>) -> InterfaceConfig
Converts the given reference to this type.
Sourceimpl Hash for InterfaceConfig
impl Hash for InterfaceConfig
Sourceimpl Ord for InterfaceConfig
impl Ord for InterfaceConfig
Sourcefn cmp(&self, other: &InterfaceConfig) -> Ordering
fn cmp(&self, other: &InterfaceConfig) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InterfaceConfig
impl PartialEq for InterfaceConfig
Sourceimpl PartialOrd for InterfaceConfig
impl PartialOrd for InterfaceConfig
impl Eq for InterfaceConfig
impl StructuralPartialEq for InterfaceConfig