pub struct MultipleBoundedNonnullableVectorsOfUint32s {
pub vu0: Vec<u32>,
pub vu1: Vec<u32>,
}Fields
vu0: Vec<u32>vu1: Vec<u32>Trait Implementations
Sourceimpl Clone for MultipleBoundedNonnullableVectorsOfUint32s
impl Clone for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn clone(&self) -> MultipleBoundedNonnullableVectorsOfUint32s
fn clone(&self) -> MultipleBoundedNonnullableVectorsOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<MultipleBoundedNonnullableVectorsOfUint32s> for MultipleBoundedNonnullableVectorsOfUint32s
impl CompatFrom<MultipleBoundedNonnullableVectorsOfUint32s> for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn compat_from(
value: MultipleBoundedNonnullableVectorsOfUint32s,
) -> MultipleBoundedNonnullableVectorsOfUint32s
fn compat_from( value: MultipleBoundedNonnullableVectorsOfUint32s, ) -> MultipleBoundedNonnullableVectorsOfUint32s
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E> for &'a MultipleBoundedNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E> for &'a MultipleBoundedNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E> for MultipleBoundedNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E> for MultipleBoundedNonnullableVectorsOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNonnullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleBoundedNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleBoundedNonnullableVectorsOfUint32s: Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleBoundedNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleBoundedNonnullableVectorsOfUint32s: Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a MultipleBoundedNonnullableVectorsOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a MultipleBoundedNonnullableVectorsOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>, ___E> for MultipleBoundedNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleBoundedNonnullableVectorsOfUint32s: Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>, ___E> for MultipleBoundedNonnullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleBoundedNonnullableVectorsOfUint32s: Encode<MultipleBoundedNonnullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<MultipleBoundedNonnullableVectorsOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<MultipleBoundedNonnullableVectorsOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNonnullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MultipleBoundedNonnullableVectorsOfUint32s<'de>> for MultipleBoundedNonnullableVectorsOfUint32s
impl<'de> FromWire<MultipleBoundedNonnullableVectorsOfUint32s<'de>> for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn from_wire(
wire: MultipleBoundedNonnullableVectorsOfUint32s<'de>,
) -> MultipleBoundedNonnullableVectorsOfUint32s
fn from_wire( wire: MultipleBoundedNonnullableVectorsOfUint32s<'de>, ) -> MultipleBoundedNonnullableVectorsOfUint32s
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MultipleBoundedNonnullableVectorsOfUint32s<'de>> for MultipleBoundedNonnullableVectorsOfUint32s
impl<'de> FromWireRef<MultipleBoundedNonnullableVectorsOfUint32s<'de>> for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn from_wire_ref(
wire: &MultipleBoundedNonnullableVectorsOfUint32s<'de>,
) -> MultipleBoundedNonnullableVectorsOfUint32s
fn from_wire_ref( wire: &MultipleBoundedNonnullableVectorsOfUint32s<'de>, ) -> MultipleBoundedNonnullableVectorsOfUint32s
Converts the given reference to this type.
Sourceimpl Ord for MultipleBoundedNonnullableVectorsOfUint32s
impl Ord for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn cmp(&self, other: &MultipleBoundedNonnullableVectorsOfUint32s) -> Ordering
fn cmp(&self, other: &MultipleBoundedNonnullableVectorsOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MultipleBoundedNonnullableVectorsOfUint32s
impl PartialEq for MultipleBoundedNonnullableVectorsOfUint32s
Sourcefn eq(&self, other: &MultipleBoundedNonnullableVectorsOfUint32s) -> bool
fn eq(&self, other: &MultipleBoundedNonnullableVectorsOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MultipleBoundedNonnullableVectorsOfUint32s
impl PartialOrd for MultipleBoundedNonnullableVectorsOfUint32s
impl Eq for MultipleBoundedNonnullableVectorsOfUint32s
impl StructuralPartialEq for MultipleBoundedNonnullableVectorsOfUint32s