pub struct OptionalStringWrapper {
pub str: Option<String>,
}Fields
str: Option<String>Trait Implementations
Sourceimpl Clone for OptionalStringWrapper
impl Clone for OptionalStringWrapper
Sourcefn clone(&self) -> OptionalStringWrapper
fn clone(&self) -> OptionalStringWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OptionalStringWrapper> for OptionalStringWrapper
impl CompatFrom<OptionalStringWrapper> for OptionalStringWrapper
Sourcefn compat_from(value: OptionalStringWrapper) -> OptionalStringWrapper
fn compat_from(value: OptionalStringWrapper) -> OptionalStringWrapper
Converts
value into a value of this type.Sourceimpl Debug for OptionalStringWrapper
impl Debug for OptionalStringWrapper
Sourceimpl<'a, ___E> Encode<OptionalStringWrapper<'static>, ___E> for &'a OptionalStringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<OptionalStringWrapper<'static>, ___E> for &'a OptionalStringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OptionalStringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OptionalStringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OptionalStringWrapper<'static>, ___E> for OptionalStringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<OptionalStringWrapper<'static>, ___E> for OptionalStringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OptionalStringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OptionalStringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OptionalStringWrapper<'static>>, ___E> for &'a OptionalStringWrapperwhere
___E: Encoder + ?Sized,
&'a OptionalStringWrapper: Encode<OptionalStringWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OptionalStringWrapper<'static>>, ___E> for &'a OptionalStringWrapperwhere
___E: Encoder + ?Sized,
&'a OptionalStringWrapper: Encode<OptionalStringWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a OptionalStringWrapper>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OptionalStringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a OptionalStringWrapper>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OptionalStringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OptionalStringWrapper<'static>>, ___E> for OptionalStringWrapper
impl<___E> EncodeOption<Box<'static, OptionalStringWrapper<'static>>, ___E> for OptionalStringWrapper
Sourcefn encode_option(
this: Option<OptionalStringWrapper>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OptionalStringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<OptionalStringWrapper>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OptionalStringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<OptionalStringWrapper<'de>> for OptionalStringWrapper
impl<'de> FromWire<OptionalStringWrapper<'de>> for OptionalStringWrapper
Sourcefn from_wire(wire: OptionalStringWrapper<'de>) -> OptionalStringWrapper
fn from_wire(wire: OptionalStringWrapper<'de>) -> OptionalStringWrapper
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OptionalStringWrapper<'de>> for OptionalStringWrapper
impl<'de> FromWireRef<OptionalStringWrapper<'de>> for OptionalStringWrapper
Sourcefn from_wire_ref(wire: &OptionalStringWrapper<'de>) -> OptionalStringWrapper
fn from_wire_ref(wire: &OptionalStringWrapper<'de>) -> OptionalStringWrapper
Converts the given reference to this type.
Sourceimpl Hash for OptionalStringWrapper
impl Hash for OptionalStringWrapper
Sourceimpl Ord for OptionalStringWrapper
impl Ord for OptionalStringWrapper
Sourcefn cmp(&self, other: &OptionalStringWrapper) -> Ordering
fn cmp(&self, other: &OptionalStringWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OptionalStringWrapper
impl PartialEq for OptionalStringWrapper
Sourceimpl PartialOrd for OptionalStringWrapper
impl PartialOrd for OptionalStringWrapper
impl Eq for OptionalStringWrapper
impl StructuralPartialEq for OptionalStringWrapper