pub struct OutOfLineSandwich1 {
pub before: String,
pub v: Vec<Sandwich1>,
pub after: String,
}Fields
before: Stringv: Vec<Sandwich1>after: StringTrait Implementations
Sourceimpl Clone for OutOfLineSandwich1
impl Clone for OutOfLineSandwich1
Sourcefn clone(&self) -> OutOfLineSandwich1
fn clone(&self) -> OutOfLineSandwich1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OutOfLineSandwich1> for OutOfLineSandwich1
impl CompatFrom<OutOfLineSandwich1> for OutOfLineSandwich1
Sourcefn compat_from(value: OutOfLineSandwich1) -> OutOfLineSandwich1
fn compat_from(value: OutOfLineSandwich1) -> OutOfLineSandwich1
Converts
value into a value of this type.Sourceimpl Debug for OutOfLineSandwich1
impl Debug for OutOfLineSandwich1
Sourceimpl<'a, ___E> Encode<OutOfLineSandwich1<'static>, ___E> for &'a OutOfLineSandwich1where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<OutOfLineSandwich1<'static>, ___E> for &'a OutOfLineSandwich1where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OutOfLineSandwich1<'static>, ___E> for OutOfLineSandwich1where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<OutOfLineSandwich1<'static>, ___E> for OutOfLineSandwich1where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OutOfLineSandwich1<'static>>, ___E> for &'a OutOfLineSandwich1
impl<'a, ___E> EncodeOption<Box<'static, OutOfLineSandwich1<'static>>, ___E> for &'a OutOfLineSandwich1
Sourcefn encode_option(
this: Option<&'a OutOfLineSandwich1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a OutOfLineSandwich1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OutOfLineSandwich1<'static>>, ___E> for OutOfLineSandwich1
impl<___E> EncodeOption<Box<'static, OutOfLineSandwich1<'static>>, ___E> for OutOfLineSandwich1
Sourcefn encode_option(
this: Option<OutOfLineSandwich1>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<OutOfLineSandwich1>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<OutOfLineSandwich1<'de>> for OutOfLineSandwich1
impl<'de> FromWire<OutOfLineSandwich1<'de>> for OutOfLineSandwich1
Sourcefn from_wire(wire: OutOfLineSandwich1<'de>) -> OutOfLineSandwich1
fn from_wire(wire: OutOfLineSandwich1<'de>) -> OutOfLineSandwich1
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OutOfLineSandwich1<'de>> for OutOfLineSandwich1
impl<'de> FromWireRef<OutOfLineSandwich1<'de>> for OutOfLineSandwich1
Sourcefn from_wire_ref(wire: &OutOfLineSandwich1<'de>) -> OutOfLineSandwich1
fn from_wire_ref(wire: &OutOfLineSandwich1<'de>) -> OutOfLineSandwich1
Converts the given reference to this type.
Sourceimpl Hash for OutOfLineSandwich1
impl Hash for OutOfLineSandwich1
Sourceimpl Ord for OutOfLineSandwich1
impl Ord for OutOfLineSandwich1
Sourcefn cmp(&self, other: &OutOfLineSandwich1) -> Ordering
fn cmp(&self, other: &OutOfLineSandwich1) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OutOfLineSandwich1
impl PartialEq for OutOfLineSandwich1
Sourceimpl PartialOrd for OutOfLineSandwich1
impl PartialOrd for OutOfLineSandwich1
impl Eq for OutOfLineSandwich1
impl StructuralPartialEq for OutOfLineSandwich1