pub struct OutOfLineSandwich1WithOptUnion {
pub before: String,
pub v: Vec<Sandwich1WithOptUnion>,
pub after: String,
}Fields
before: Stringv: Vec<Sandwich1WithOptUnion>after: StringTrait Implementations
Sourceimpl Clone for OutOfLineSandwich1WithOptUnion
impl Clone for OutOfLineSandwich1WithOptUnion
Sourcefn clone(&self) -> OutOfLineSandwich1WithOptUnion
fn clone(&self) -> OutOfLineSandwich1WithOptUnion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OutOfLineSandwich1WithOptUnion> for OutOfLineSandwich1WithOptUnion
impl CompatFrom<OutOfLineSandwich1WithOptUnion> for OutOfLineSandwich1WithOptUnion
Sourcefn compat_from(
value: OutOfLineSandwich1WithOptUnion,
) -> OutOfLineSandwich1WithOptUnion
fn compat_from( value: OutOfLineSandwich1WithOptUnion, ) -> OutOfLineSandwich1WithOptUnion
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: Encoder + ?Sized,
&'a OutOfLineSandwich1WithOptUnion: Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: Encoder + ?Sized,
&'a OutOfLineSandwich1WithOptUnion: Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a OutOfLineSandwich1WithOptUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a OutOfLineSandwich1WithOptUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: Encoder + ?Sized,
OutOfLineSandwich1WithOptUnion: Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: Encoder + ?Sized,
OutOfLineSandwich1WithOptUnion: Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E>,
Sourcefn encode_option(
this: Option<OutOfLineSandwich1WithOptUnion>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<OutOfLineSandwich1WithOptUnion>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OutOfLineSandwich1WithOptUnion<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
impl<'de> FromWire<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
Sourcefn from_wire(
wire: OutOfLineSandwich1WithOptUnion<'de>,
) -> OutOfLineSandwich1WithOptUnion
fn from_wire( wire: OutOfLineSandwich1WithOptUnion<'de>, ) -> OutOfLineSandwich1WithOptUnion
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
impl<'de> FromWireRef<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
Sourcefn from_wire_ref(
wire: &OutOfLineSandwich1WithOptUnion<'de>,
) -> OutOfLineSandwich1WithOptUnion
fn from_wire_ref( wire: &OutOfLineSandwich1WithOptUnion<'de>, ) -> OutOfLineSandwich1WithOptUnion
Converts the given reference to this type.
Sourceimpl Ord for OutOfLineSandwich1WithOptUnion
impl Ord for OutOfLineSandwich1WithOptUnion
Sourcefn cmp(&self, other: &OutOfLineSandwich1WithOptUnion) -> Ordering
fn cmp(&self, other: &OutOfLineSandwich1WithOptUnion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OutOfLineSandwich1WithOptUnion
impl PartialEq for OutOfLineSandwich1WithOptUnion
Sourcefn eq(&self, other: &OutOfLineSandwich1WithOptUnion) -> bool
fn eq(&self, other: &OutOfLineSandwich1WithOptUnion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OutOfLineSandwich1WithOptUnion
impl PartialOrd for OutOfLineSandwich1WithOptUnion
impl Eq for OutOfLineSandwich1WithOptUnion
impl StructuralPartialEq for OutOfLineSandwich1WithOptUnion