pub struct PaddedTableStruct {
pub t: PaddedTable,
}Fields
t: PaddedTableTrait Implementations
Sourceimpl Clone for PaddedTableStruct
impl Clone for PaddedTableStruct
Sourcefn clone(&self) -> PaddedTableStruct
fn clone(&self) -> PaddedTableStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddedTableStruct> for PaddedTableStruct
impl CompatFrom<PaddedTableStruct> for PaddedTableStruct
Sourcefn compat_from(value: PaddedTableStruct) -> PaddedTableStruct
fn compat_from(value: PaddedTableStruct) -> PaddedTableStruct
Converts
value into a value of this type.Sourceimpl Debug for PaddedTableStruct
impl Debug for PaddedTableStruct
Sourceimpl<'a, ___E> Encode<PaddedTableStruct<'static>, ___E> for &'a PaddedTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PaddedTableStruct<'static>, ___E> for &'a PaddedTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddedTableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddedTableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddedTableStruct<'static>, ___E> for PaddedTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PaddedTableStruct<'static>, ___E> for PaddedTableStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddedTableStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddedTableStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddedTableStruct<'static>>, ___E> for &'a PaddedTableStruct
impl<'a, ___E> EncodeOption<Box<'static, PaddedTableStruct<'static>>, ___E> for &'a PaddedTableStruct
Sourcefn encode_option(
this: Option<&'a PaddedTableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddedTableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddedTableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddedTableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddedTableStruct<'static>>, ___E> for PaddedTableStruct
impl<___E> EncodeOption<Box<'static, PaddedTableStruct<'static>>, ___E> for PaddedTableStruct
Sourcefn encode_option(
this: Option<PaddedTableStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddedTableStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddedTableStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddedTableStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddedTableStruct<'de>> for PaddedTableStruct
impl<'de> FromWire<PaddedTableStruct<'de>> for PaddedTableStruct
Sourcefn from_wire(wire: PaddedTableStruct<'de>) -> PaddedTableStruct
fn from_wire(wire: PaddedTableStruct<'de>) -> PaddedTableStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddedTableStruct<'de>> for PaddedTableStruct
impl<'de> FromWireRef<PaddedTableStruct<'de>> for PaddedTableStruct
Sourcefn from_wire_ref(wire: &PaddedTableStruct<'de>) -> PaddedTableStruct
fn from_wire_ref(wire: &PaddedTableStruct<'de>) -> PaddedTableStruct
Converts the given reference to this type.
Sourceimpl Hash for PaddedTableStruct
impl Hash for PaddedTableStruct
Sourceimpl Ord for PaddedTableStruct
impl Ord for PaddedTableStruct
Sourcefn cmp(&self, other: &PaddedTableStruct) -> Ordering
fn cmp(&self, other: &PaddedTableStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddedTableStruct
impl PartialEq for PaddedTableStruct
Sourceimpl PartialOrd for PaddedTableStruct
impl PartialOrd for PaddedTableStruct
impl Copy for PaddedTableStruct
impl Eq for PaddedTableStruct
impl StructuralPartialEq for PaddedTableStruct