pub struct PaddingAlignment2MaskMayBe4Bytes {
pub a: u8,
pub b: u16,
pub c: u16,
}Fields
a: u8b: u16c: u16Trait Implementations
Sourceimpl Clone for PaddingAlignment2MaskMayBe4Bytes
impl Clone for PaddingAlignment2MaskMayBe4Bytes
Sourcefn clone(&self) -> PaddingAlignment2MaskMayBe4Bytes
fn clone(&self) -> PaddingAlignment2MaskMayBe4Bytes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
impl CompatFrom<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
Sourcefn compat_from(
value: PaddingAlignment2MaskMayBe4Bytes,
) -> PaddingAlignment2MaskMayBe4Bytes
fn compat_from( value: PaddingAlignment2MaskMayBe4Bytes, ) -> PaddingAlignment2MaskMayBe4Bytes
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4Bytes>, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: Encoder + ?Sized,
&'a PaddingAlignment2MaskMayBe4Bytes: Encode<PaddingAlignment2MaskMayBe4Bytes, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4Bytes>, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: Encoder + ?Sized,
&'a PaddingAlignment2MaskMayBe4Bytes: Encode<PaddingAlignment2MaskMayBe4Bytes, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingAlignment2MaskMayBe4Bytes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4Bytes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingAlignment2MaskMayBe4Bytes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4Bytes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4Bytes>, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: Encoder + ?Sized,
PaddingAlignment2MaskMayBe4Bytes: Encode<PaddingAlignment2MaskMayBe4Bytes, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4Bytes>, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: Encoder + ?Sized,
PaddingAlignment2MaskMayBe4Bytes: Encode<PaddingAlignment2MaskMayBe4Bytes, ___E>,
Sourcefn encode_option(
this: Option<PaddingAlignment2MaskMayBe4Bytes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4Bytes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingAlignment2MaskMayBe4Bytes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4Bytes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
impl FromWire<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
Sourcefn from_wire(
wire: PaddingAlignment2MaskMayBe4Bytes,
) -> PaddingAlignment2MaskMayBe4Bytes
fn from_wire( wire: PaddingAlignment2MaskMayBe4Bytes, ) -> PaddingAlignment2MaskMayBe4Bytes
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
impl FromWireRef<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
Sourcefn from_wire_ref(
wire: &PaddingAlignment2MaskMayBe4Bytes,
) -> PaddingAlignment2MaskMayBe4Bytes
fn from_wire_ref( wire: &PaddingAlignment2MaskMayBe4Bytes, ) -> PaddingAlignment2MaskMayBe4Bytes
Converts the given reference to this type.
Sourceimpl Ord for PaddingAlignment2MaskMayBe4Bytes
impl Ord for PaddingAlignment2MaskMayBe4Bytes
Sourcefn cmp(&self, other: &PaddingAlignment2MaskMayBe4Bytes) -> Ordering
fn cmp(&self, other: &PaddingAlignment2MaskMayBe4Bytes) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingAlignment2MaskMayBe4Bytes
impl PartialEq for PaddingAlignment2MaskMayBe4Bytes
Sourcefn eq(&self, other: &PaddingAlignment2MaskMayBe4Bytes) -> bool
fn eq(&self, other: &PaddingAlignment2MaskMayBe4Bytes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingAlignment2MaskMayBe4Bytes
impl PartialOrd for PaddingAlignment2MaskMayBe4Bytes
impl Copy for PaddingAlignment2MaskMayBe4Bytes
impl Eq for PaddingAlignment2MaskMayBe4Bytes
impl StructuralPartialEq for PaddingAlignment2MaskMayBe4Bytes