pub struct PaddingAlignment4MaskMayBe8BytesVector {
pub v: Vec<PaddingAlignment4MaskMayBe8Bytes>,
}Fields
v: Vec<PaddingAlignment4MaskMayBe8Bytes>Trait Implementations
Sourceimpl Clone for PaddingAlignment4MaskMayBe8BytesVector
impl Clone for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn clone(&self) -> PaddingAlignment4MaskMayBe8BytesVector
fn clone(&self) -> PaddingAlignment4MaskMayBe8BytesVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingAlignment4MaskMayBe8BytesVector> for PaddingAlignment4MaskMayBe8BytesVector
impl CompatFrom<PaddingAlignment4MaskMayBe8BytesVector> for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn compat_from(
value: PaddingAlignment4MaskMayBe8BytesVector,
) -> PaddingAlignment4MaskMayBe8BytesVector
fn compat_from( value: PaddingAlignment4MaskMayBe8BytesVector, ) -> PaddingAlignment4MaskMayBe8BytesVector
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E> for &'a PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E> for &'a PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8BytesVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8BytesVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E> for PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E> for PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8BytesVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8BytesVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>, ___E> for &'a PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: Encoder + ?Sized,
&'a PaddingAlignment4MaskMayBe8BytesVector: Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>, ___E> for &'a PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: Encoder + ?Sized,
&'a PaddingAlignment4MaskMayBe8BytesVector: Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingAlignment4MaskMayBe8BytesVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingAlignment4MaskMayBe8BytesVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>, ___E> for PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: Encoder + ?Sized,
PaddingAlignment4MaskMayBe8BytesVector: Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>, ___E> for PaddingAlignment4MaskMayBe8BytesVectorwhere
___E: Encoder + ?Sized,
PaddingAlignment4MaskMayBe8BytesVector: Encode<PaddingAlignment4MaskMayBe8BytesVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<PaddingAlignment4MaskMayBe8BytesVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingAlignment4MaskMayBe8BytesVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment4MaskMayBe8BytesVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingAlignment4MaskMayBe8BytesVector<'de>> for PaddingAlignment4MaskMayBe8BytesVector
impl<'de> FromWire<PaddingAlignment4MaskMayBe8BytesVector<'de>> for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn from_wire(
wire: PaddingAlignment4MaskMayBe8BytesVector<'de>,
) -> PaddingAlignment4MaskMayBe8BytesVector
fn from_wire( wire: PaddingAlignment4MaskMayBe8BytesVector<'de>, ) -> PaddingAlignment4MaskMayBe8BytesVector
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingAlignment4MaskMayBe8BytesVector<'de>> for PaddingAlignment4MaskMayBe8BytesVector
impl<'de> FromWireRef<PaddingAlignment4MaskMayBe8BytesVector<'de>> for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn from_wire_ref(
wire: &PaddingAlignment4MaskMayBe8BytesVector<'de>,
) -> PaddingAlignment4MaskMayBe8BytesVector
fn from_wire_ref( wire: &PaddingAlignment4MaskMayBe8BytesVector<'de>, ) -> PaddingAlignment4MaskMayBe8BytesVector
Converts the given reference to this type.
Sourceimpl Ord for PaddingAlignment4MaskMayBe8BytesVector
impl Ord for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn cmp(&self, other: &PaddingAlignment4MaskMayBe8BytesVector) -> Ordering
fn cmp(&self, other: &PaddingAlignment4MaskMayBe8BytesVector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingAlignment4MaskMayBe8BytesVector
impl PartialEq for PaddingAlignment4MaskMayBe8BytesVector
Sourcefn eq(&self, other: &PaddingAlignment4MaskMayBe8BytesVector) -> bool
fn eq(&self, other: &PaddingAlignment4MaskMayBe8BytesVector) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingAlignment4MaskMayBe8BytesVector
impl PartialOrd for PaddingAlignment4MaskMayBe8BytesVector
impl Eq for PaddingAlignment4MaskMayBe8BytesVector
impl StructuralPartialEq for PaddingAlignment4MaskMayBe8BytesVector