pub struct PaddingBetweenFieldsInt32Int64 {
pub a: i32,
pub b: i64,
}Fields
a: i32b: i64Trait Implementations
Sourceimpl Clone for PaddingBetweenFieldsInt32Int64
impl Clone for PaddingBetweenFieldsInt32Int64
Sourcefn clone(&self) -> PaddingBetweenFieldsInt32Int64
fn clone(&self) -> PaddingBetweenFieldsInt32Int64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
impl CompatFrom<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
Sourcefn compat_from(
value: PaddingBetweenFieldsInt32Int64,
) -> PaddingBetweenFieldsInt32Int64
fn compat_from( value: PaddingBetweenFieldsInt32Int64, ) -> PaddingBetweenFieldsInt32Int64
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt32Int64>, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt32Int64: Encode<PaddingBetweenFieldsInt32Int64, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt32Int64>, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt32Int64: Encode<PaddingBetweenFieldsInt32Int64, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingBetweenFieldsInt32Int64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt32Int64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingBetweenFieldsInt32Int64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt32Int64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt32Int64>, ___E> for PaddingBetweenFieldsInt32Int64where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt32Int64: Encode<PaddingBetweenFieldsInt32Int64, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt32Int64>, ___E> for PaddingBetweenFieldsInt32Int64where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt32Int64: Encode<PaddingBetweenFieldsInt32Int64, ___E>,
Sourcefn encode_option(
this: Option<PaddingBetweenFieldsInt32Int64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt32Int64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingBetweenFieldsInt32Int64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt32Int64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
impl FromWire<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
Sourcefn from_wire(
wire: PaddingBetweenFieldsInt32Int64,
) -> PaddingBetweenFieldsInt32Int64
fn from_wire( wire: PaddingBetweenFieldsInt32Int64, ) -> PaddingBetweenFieldsInt32Int64
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
impl FromWireRef<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
Sourcefn from_wire_ref(
wire: &PaddingBetweenFieldsInt32Int64,
) -> PaddingBetweenFieldsInt32Int64
fn from_wire_ref( wire: &PaddingBetweenFieldsInt32Int64, ) -> PaddingBetweenFieldsInt32Int64
Converts the given reference to this type.
Sourceimpl Ord for PaddingBetweenFieldsInt32Int64
impl Ord for PaddingBetweenFieldsInt32Int64
Sourcefn cmp(&self, other: &PaddingBetweenFieldsInt32Int64) -> Ordering
fn cmp(&self, other: &PaddingBetweenFieldsInt32Int64) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingBetweenFieldsInt32Int64
impl PartialEq for PaddingBetweenFieldsInt32Int64
Sourcefn eq(&self, other: &PaddingBetweenFieldsInt32Int64) -> bool
fn eq(&self, other: &PaddingBetweenFieldsInt32Int64) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingBetweenFieldsInt32Int64
impl PartialOrd for PaddingBetweenFieldsInt32Int64
impl Copy for PaddingBetweenFieldsInt32Int64
impl Eq for PaddingBetweenFieldsInt32Int64
impl StructuralPartialEq for PaddingBetweenFieldsInt32Int64