pub struct PaddingEndOfInlineObjectBeforeNextObject2Byte {
pub out_of_line: Option<Box<Struct8Byte>>,
pub in_line: Struct2Byte,
}Fields
out_of_line: Option<Box<Struct8Byte>>in_line: Struct2ByteTrait Implementations
Sourceimpl Clone for PaddingEndOfInlineObjectBeforeNextObject2Byte
impl Clone for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourcefn clone(&self) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
fn clone(&self) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E> for PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E> for PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E> for &'a PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E> for &'a PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, ___E> for PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfInlineObjectBeforeNextObject2Byte: Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, ___E> for PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfInlineObjectBeforeNextObject2Byte: Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<PaddingEndOfInlineObjectBeforeNextObject2Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingEndOfInlineObjectBeforeNextObject2Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, ___E> for &'a PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfInlineObjectBeforeNextObject2Byte: Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>, ___E> for &'a PaddingEndOfInlineObjectBeforeNextObject2Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfInlineObjectBeforeNextObject2Byte: Encode<PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingEndOfInlineObjectBeforeNextObject2Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingEndOfInlineObjectBeforeNextObject2Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfInlineObjectBeforeNextObject2Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourceimpl<'de> FromWire<PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>> for PaddingEndOfInlineObjectBeforeNextObject2Byte
impl<'de> FromWire<PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>> for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourcefn from_wire(
wire: PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>,
) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
fn from_wire( wire: PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>, ) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>> for PaddingEndOfInlineObjectBeforeNextObject2Byte
impl<'de> FromWireRef<PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>> for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourcefn from_wire_ref(
wire: &PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>,
) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
fn from_wire_ref( wire: &PaddingEndOfInlineObjectBeforeNextObject2Byte<'de>, ) -> PaddingEndOfInlineObjectBeforeNextObject2Byte
Converts the given reference to this type.
Sourceimpl Ord for PaddingEndOfInlineObjectBeforeNextObject2Byte
impl Ord for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourcefn cmp(&self, other: &PaddingEndOfInlineObjectBeforeNextObject2Byte) -> Ordering
fn cmp(&self, other: &PaddingEndOfInlineObjectBeforeNextObject2Byte) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for PaddingEndOfInlineObjectBeforeNextObject2Byte
impl PartialOrd for PaddingEndOfInlineObjectBeforeNextObject2Byte
Sourcefn partial_cmp(
&self,
other: &PaddingEndOfInlineObjectBeforeNextObject2Byte,
) -> Option<Ordering>
fn partial_cmp( &self, other: &PaddingEndOfInlineObjectBeforeNextObject2Byte, ) -> Option<Ordering>
impl StructuralPartialEq for PaddingEndOfInlineObjectBeforeNextObject2Byte