pub struct PaddingInBetweenOutOfLineObjects2Byte {
pub first: Option<Box<Struct2Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct2Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects2Byte
impl Clone for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects2Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects2Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects2Byte> for PaddingInBetweenOutOfLineObjects2Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects2Byte> for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn compat_from(
value: PaddingInBetweenOutOfLineObjects2Byte,
) -> PaddingInBetweenOutOfLineObjects2Byte
fn compat_from( value: PaddingInBetweenOutOfLineObjects2Byte, ) -> PaddingInBetweenOutOfLineObjects2Byte
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects2Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects2Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects2Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects2Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects2Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects2Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects2Byte: Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects2Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects2Byte: Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingInBetweenOutOfLineObjects2Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingInBetweenOutOfLineObjects2Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects2Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects2Byte: Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects2Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects2Byte: Encode<PaddingInBetweenOutOfLineObjects2Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<PaddingInBetweenOutOfLineObjects2Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingInBetweenOutOfLineObjects2Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects2Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects2Byte<'de>> for PaddingInBetweenOutOfLineObjects2Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects2Byte<'de>> for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn from_wire(
wire: PaddingInBetweenOutOfLineObjects2Byte<'de>,
) -> PaddingInBetweenOutOfLineObjects2Byte
fn from_wire( wire: PaddingInBetweenOutOfLineObjects2Byte<'de>, ) -> PaddingInBetweenOutOfLineObjects2Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects2Byte<'de>> for PaddingInBetweenOutOfLineObjects2Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects2Byte<'de>> for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn from_wire_ref(
wire: &PaddingInBetweenOutOfLineObjects2Byte<'de>,
) -> PaddingInBetweenOutOfLineObjects2Byte
fn from_wire_ref( wire: &PaddingInBetweenOutOfLineObjects2Byte<'de>, ) -> PaddingInBetweenOutOfLineObjects2Byte
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects2Byte
impl Ord for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects2Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects2Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects2Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects2Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects2Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects2Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects2Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects2Byte
impl Eq for PaddingInBetweenOutOfLineObjects2Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects2Byte