pub struct PaddingInBetweenOutOfLineObjects6Byte {
pub first: Option<Box<Struct6Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct6Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects6Byte
impl Clone for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects6Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects6Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects6Byte> for PaddingInBetweenOutOfLineObjects6Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects6Byte> for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn compat_from(
value: PaddingInBetweenOutOfLineObjects6Byte,
) -> PaddingInBetweenOutOfLineObjects6Byte
fn compat_from( value: PaddingInBetweenOutOfLineObjects6Byte, ) -> PaddingInBetweenOutOfLineObjects6Byte
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects6Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects6Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects6Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects6Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects6Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects6Bytewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects6Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects6Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects6Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects6Byte: Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects6Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects6Byte: Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a PaddingInBetweenOutOfLineObjects6Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PaddingInBetweenOutOfLineObjects6Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects6Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects6Byte: Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects6Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects6Byte: Encode<PaddingInBetweenOutOfLineObjects6Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<PaddingInBetweenOutOfLineObjects6Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PaddingInBetweenOutOfLineObjects6Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects6Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects6Byte<'de>> for PaddingInBetweenOutOfLineObjects6Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects6Byte<'de>> for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn from_wire(
wire: PaddingInBetweenOutOfLineObjects6Byte<'de>,
) -> PaddingInBetweenOutOfLineObjects6Byte
fn from_wire( wire: PaddingInBetweenOutOfLineObjects6Byte<'de>, ) -> PaddingInBetweenOutOfLineObjects6Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects6Byte<'de>> for PaddingInBetweenOutOfLineObjects6Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects6Byte<'de>> for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn from_wire_ref(
wire: &PaddingInBetweenOutOfLineObjects6Byte<'de>,
) -> PaddingInBetweenOutOfLineObjects6Byte
fn from_wire_ref( wire: &PaddingInBetweenOutOfLineObjects6Byte<'de>, ) -> PaddingInBetweenOutOfLineObjects6Byte
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects6Byte
impl Ord for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects6Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects6Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects6Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects6Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects6Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects6Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects6Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects6Byte
impl Eq for PaddingInBetweenOutOfLineObjects6Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects6Byte