pub struct Regression10V3 {
pub table: Regression10TableV3,
}Fields
table: Regression10TableV3Trait Implementations
Sourceimpl Clone for Regression10V3
impl Clone for Regression10V3
Sourcefn clone(&self) -> Regression10V3
fn clone(&self) -> Regression10V3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression10V3> for Regression10V3
impl CompatFrom<Regression10V3> for Regression10V3
Sourcefn compat_from(value: Regression10V3) -> Regression10V3
fn compat_from(value: Regression10V3) -> Regression10V3
Converts
value into a value of this type.Sourceimpl Debug for Regression10V3
impl Debug for Regression10V3
Sourceimpl<'a, ___E> Encode<Regression10V3<'static>, ___E> for &'a Regression10V3where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Regression10V3<'static>, ___E> for &'a Regression10V3where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V3<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V3<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression10V3<'static>, ___E> for Regression10V3where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Regression10V3<'static>, ___E> for Regression10V3where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V3<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V3<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression10V3<'static>>, ___E> for &'a Regression10V3
impl<'a, ___E> EncodeOption<Box<'static, Regression10V3<'static>>, ___E> for &'a Regression10V3
Sourcefn encode_option(
this: Option<&'a Regression10V3>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V3<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression10V3>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V3<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression10V3<'static>>, ___E> for Regression10V3
impl<___E> EncodeOption<Box<'static, Regression10V3<'static>>, ___E> for Regression10V3
Sourcefn encode_option(
this: Option<Regression10V3>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V3<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression10V3>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V3<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression10V3<'de>> for Regression10V3
impl<'de> FromWire<Regression10V3<'de>> for Regression10V3
Sourcefn from_wire(wire: Regression10V3<'de>) -> Regression10V3
fn from_wire(wire: Regression10V3<'de>) -> Regression10V3
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression10V3<'de>> for Regression10V3
impl<'de> FromWireRef<Regression10V3<'de>> for Regression10V3
Sourcefn from_wire_ref(wire: &Regression10V3<'de>) -> Regression10V3
fn from_wire_ref(wire: &Regression10V3<'de>) -> Regression10V3
Converts the given reference to this type.
Sourceimpl Hash for Regression10V3
impl Hash for Regression10V3
Sourceimpl Ord for Regression10V3
impl Ord for Regression10V3
Sourcefn cmp(&self, other: &Regression10V3) -> Ordering
fn cmp(&self, other: &Regression10V3) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression10V3
impl PartialEq for Regression10V3
Sourceimpl PartialOrd for Regression10V3
impl PartialOrd for Regression10V3
impl Copy for Regression10V3
impl Eq for Regression10V3
impl StructuralPartialEq for Regression10V3