pub struct Regression11 {
pub table_of_table: UnionWithRegression10Table,
}Fields
table_of_table: UnionWithRegression10TableTrait Implementations
Sourceimpl Clone for Regression11
impl Clone for Regression11
Sourcefn clone(&self) -> Regression11
fn clone(&self) -> Regression11
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression11> for Regression11
impl CompatFrom<Regression11> for Regression11
Sourcefn compat_from(value: Regression11) -> Regression11
fn compat_from(value: Regression11) -> Regression11
Converts
value into a value of this type.Sourceimpl Debug for Regression11
impl Debug for Regression11
Sourceimpl<'a, ___E> Encode<Regression11<'static>, ___E> for &'a Regression11where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Regression11<'static>, ___E> for &'a Regression11where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression11<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression11<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression11<'static>, ___E> for Regression11where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Regression11<'static>, ___E> for Regression11where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression11<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression11<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression11<'static>>, ___E> for &'a Regression11
impl<'a, ___E> EncodeOption<Box<'static, Regression11<'static>>, ___E> for &'a Regression11
Sourcefn encode_option(
this: Option<&'a Regression11>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression11<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression11>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression11<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression11<'static>>, ___E> for Regression11
impl<___E> EncodeOption<Box<'static, Regression11<'static>>, ___E> for Regression11
Sourcefn encode_option(
this: Option<Regression11>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression11<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression11>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression11<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression11<'de>> for Regression11
impl<'de> FromWire<Regression11<'de>> for Regression11
Sourcefn from_wire(wire: Regression11<'de>) -> Regression11
fn from_wire(wire: Regression11<'de>) -> Regression11
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression11<'de>> for Regression11
impl<'de> FromWireRef<Regression11<'de>> for Regression11
Sourcefn from_wire_ref(wire: &Regression11<'de>) -> Regression11
fn from_wire_ref(wire: &Regression11<'de>) -> Regression11
Converts the given reference to this type.
Sourceimpl Hash for Regression11
impl Hash for Regression11
Sourceimpl Ord for Regression11
impl Ord for Regression11
Sourcefn cmp(&self, other: &Regression11) -> Ordering
fn cmp(&self, other: &Regression11) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression11
impl PartialEq for Regression11
Sourceimpl PartialOrd for Regression11
impl PartialOrd for Regression11
impl Copy for Regression11
impl Eq for Regression11
impl StructuralPartialEq for Regression11