pub struct Regression3 {
pub opt_value: Option<Box<Regression2>>,
}Fields
opt_value: Option<Box<Regression2>>Trait Implementations
Sourceimpl Clone for Regression3
impl Clone for Regression3
Sourcefn clone(&self) -> Regression3
fn clone(&self) -> Regression3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression3> for Regression3
impl CompatFrom<Regression3> for Regression3
Sourcefn compat_from(value: Regression3) -> Regression3
fn compat_from(value: Regression3) -> Regression3
Converts
value into a value of this type.Sourceimpl Debug for Regression3
impl Debug for Regression3
Sourceimpl<'a, ___E> Encode<Regression3<'static>, ___E> for &'a Regression3where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Regression3<'static>, ___E> for &'a Regression3where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression3<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression3<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression3<'static>, ___E> for Regression3where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Regression3<'static>, ___E> for Regression3where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression3<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression3<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression3<'static>>, ___E> for &'a Regression3
impl<'a, ___E> EncodeOption<Box<'static, Regression3<'static>>, ___E> for &'a Regression3
Sourcefn encode_option(
this: Option<&'a Regression3>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression3<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression3>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression3<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression3<'static>>, ___E> for Regression3
impl<___E> EncodeOption<Box<'static, Regression3<'static>>, ___E> for Regression3
Sourcefn encode_option(
this: Option<Regression3>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression3<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression3>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression3<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression3<'de>> for Regression3
impl<'de> FromWire<Regression3<'de>> for Regression3
Sourcefn from_wire(wire: Regression3<'de>) -> Regression3
fn from_wire(wire: Regression3<'de>) -> Regression3
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression3<'de>> for Regression3
impl<'de> FromWireRef<Regression3<'de>> for Regression3
Sourcefn from_wire_ref(wire: &Regression3<'de>) -> Regression3
fn from_wire_ref(wire: &Regression3<'de>) -> Regression3
Converts the given reference to this type.
Sourceimpl Hash for Regression3
impl Hash for Regression3
Sourceimpl Ord for Regression3
impl Ord for Regression3
Sourcefn cmp(&self, other: &Regression3) -> Ordering
fn cmp(&self, other: &Regression3) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression3
impl PartialEq for Regression3
Sourceimpl PartialOrd for Regression3
impl PartialOrd for Regression3
impl Eq for Regression3
impl StructuralPartialEq for Regression3