pub struct Regression5 {
pub f1: u8,
pub f2: EnumUint32,
pub f3: EnumUint8,
pub f4: u16,
pub f5: u64,
pub f6: u8,
}Fields
f1: u8f2: EnumUint32f3: EnumUint8f4: u16f5: u64f6: u8Trait Implementations
Sourceimpl Clone for Regression5
impl Clone for Regression5
Sourcefn clone(&self) -> Regression5
fn clone(&self) -> Regression5
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression5> for Regression5
impl CompatFrom<Regression5> for Regression5
Sourcefn compat_from(value: Regression5) -> Regression5
fn compat_from(value: Regression5) -> Regression5
Converts
value into a value of this type.Sourceimpl Debug for Regression5
impl Debug for Regression5
Sourceimpl<'a, ___E> Encode<Regression5, ___E> for &'a Regression5where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Regression5, ___E> for &'a Regression5where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression5>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression5>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression5, ___E> for Regression5where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Regression5, ___E> for Regression5where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression5>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression5>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression5>, ___E> for &'a Regression5
impl<'a, ___E> EncodeOption<Box<'static, Regression5>, ___E> for &'a Regression5
Sourcefn encode_option(
this: Option<&'a Regression5>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression5>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Regression5>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression5>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression5>, ___E> for Regression5
impl<___E> EncodeOption<Box<'static, Regression5>, ___E> for Regression5
Sourcefn encode_option(
this: Option<Regression5>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression5>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Regression5>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression5>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Regression5> for Regression5
impl FromWire<Regression5> for Regression5
Sourcefn from_wire(wire: Regression5) -> Regression5
fn from_wire(wire: Regression5) -> Regression5
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Regression5> for Regression5
impl FromWireRef<Regression5> for Regression5
Sourcefn from_wire_ref(wire: &Regression5) -> Regression5
fn from_wire_ref(wire: &Regression5) -> Regression5
Converts the given reference to this type.
Sourceimpl Hash for Regression5
impl Hash for Regression5
Sourceimpl Ord for Regression5
impl Ord for Regression5
Sourcefn cmp(&self, other: &Regression5) -> Ordering
fn cmp(&self, other: &Regression5) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression5
impl PartialEq for Regression5
Sourceimpl PartialOrd for Regression5
impl PartialOrd for Regression5
impl Copy for Regression5
impl Eq for Regression5
impl StructuralPartialEq for Regression5