pub struct Sandwich4Message {
pub header: TransactionHeader,
pub body: Sandwich4,
}Fields
header: TransactionHeaderbody: Sandwich4Trait Implementations
Sourceimpl Clone for Sandwich4Message
impl Clone for Sandwich4Message
Sourcefn clone(&self) -> Sandwich4Message
fn clone(&self) -> Sandwich4Message
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Sandwich4Message> for Sandwich4Message
impl CompatFrom<Sandwich4Message> for Sandwich4Message
Sourcefn compat_from(value: Sandwich4Message) -> Sandwich4Message
fn compat_from(value: Sandwich4Message) -> Sandwich4Message
Converts
value into a value of this type.Sourceimpl Debug for Sandwich4Message
impl Debug for Sandwich4Message
Sourceimpl<'a, ___E> Encode<Sandwich4Message<'static>, ___E> for &'a Sandwich4Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Sandwich4Message<'static>, ___E> for &'a Sandwich4Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich4Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich4Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich4Message<'static>, ___E> for Sandwich4Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Sandwich4Message<'static>, ___E> for Sandwich4Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich4Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich4Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Sandwich4Message<'static>>, ___E> for &'a Sandwich4Message
impl<'a, ___E> EncodeOption<Box<'static, Sandwich4Message<'static>>, ___E> for &'a Sandwich4Message
Sourcefn encode_option(
this: Option<&'a Sandwich4Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich4Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Sandwich4Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich4Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Sandwich4Message<'static>>, ___E> for Sandwich4Message
impl<___E> EncodeOption<Box<'static, Sandwich4Message<'static>>, ___E> for Sandwich4Message
Sourcefn encode_option(
this: Option<Sandwich4Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich4Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Sandwich4Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich4Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Sandwich4Message<'de>> for Sandwich4Message
impl<'de> FromWire<Sandwich4Message<'de>> for Sandwich4Message
Sourcefn from_wire(wire: Sandwich4Message<'de>) -> Sandwich4Message
fn from_wire(wire: Sandwich4Message<'de>) -> Sandwich4Message
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Sandwich4Message<'de>> for Sandwich4Message
impl<'de> FromWireRef<Sandwich4Message<'de>> for Sandwich4Message
Sourcefn from_wire_ref(wire: &Sandwich4Message<'de>) -> Sandwich4Message
fn from_wire_ref(wire: &Sandwich4Message<'de>) -> Sandwich4Message
Converts the given reference to this type.
Sourceimpl Hash for Sandwich4Message
impl Hash for Sandwich4Message
Sourceimpl Ord for Sandwich4Message
impl Ord for Sandwich4Message
Sourcefn cmp(&self, other: &Sandwich4Message) -> Ordering
fn cmp(&self, other: &Sandwich4Message) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Sandwich4Message
impl PartialEq for Sandwich4Message
Sourceimpl PartialOrd for Sandwich4Message
impl PartialOrd for Sandwich4Message
impl Copy for Sandwich4Message
impl Eq for Sandwich4Message
impl StructuralPartialEq for Sandwich4Message