pub struct Sandwich5Message {
pub header: TransactionHeader,
pub body: Sandwich5,
}Fields
header: TransactionHeaderbody: Sandwich5Trait Implementations
Sourceimpl Clone for Sandwich5Message
impl Clone for Sandwich5Message
Sourcefn clone(&self) -> Sandwich5Message
fn clone(&self) -> Sandwich5Message
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Sandwich5Message> for Sandwich5Message
impl CompatFrom<Sandwich5Message> for Sandwich5Message
Sourcefn compat_from(value: Sandwich5Message) -> Sandwich5Message
fn compat_from(value: Sandwich5Message) -> Sandwich5Message
Converts
value into a value of this type.Sourceimpl Debug for Sandwich5Message
impl Debug for Sandwich5Message
Sourceimpl<'a, ___E> Encode<Sandwich5Message<'static>, ___E> for &'a Sandwich5Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Sandwich5Message<'static>, ___E> for &'a Sandwich5Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich5Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich5Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich5Message<'static>, ___E> for Sandwich5Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Sandwich5Message<'static>, ___E> for Sandwich5Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich5Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich5Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Sandwich5Message<'static>>, ___E> for &'a Sandwich5Message
impl<'a, ___E> EncodeOption<Box<'static, Sandwich5Message<'static>>, ___E> for &'a Sandwich5Message
Sourcefn encode_option(
this: Option<&'a Sandwich5Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich5Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Sandwich5Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich5Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Sandwich5Message<'static>>, ___E> for Sandwich5Message
impl<___E> EncodeOption<Box<'static, Sandwich5Message<'static>>, ___E> for Sandwich5Message
Sourcefn encode_option(
this: Option<Sandwich5Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich5Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Sandwich5Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich5Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Sandwich5Message<'de>> for Sandwich5Message
impl<'de> FromWire<Sandwich5Message<'de>> for Sandwich5Message
Sourcefn from_wire(wire: Sandwich5Message<'de>) -> Sandwich5Message
fn from_wire(wire: Sandwich5Message<'de>) -> Sandwich5Message
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Sandwich5Message<'de>> for Sandwich5Message
impl<'de> FromWireRef<Sandwich5Message<'de>> for Sandwich5Message
Sourcefn from_wire_ref(wire: &Sandwich5Message<'de>) -> Sandwich5Message
fn from_wire_ref(wire: &Sandwich5Message<'de>) -> Sandwich5Message
Converts the given reference to this type.
Sourceimpl Hash for Sandwich5Message
impl Hash for Sandwich5Message
Sourceimpl Ord for Sandwich5Message
impl Ord for Sandwich5Message
Sourcefn cmp(&self, other: &Sandwich5Message) -> Ordering
fn cmp(&self, other: &Sandwich5Message) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Sandwich5Message
impl PartialEq for Sandwich5Message
Sourceimpl PartialOrd for Sandwich5Message
impl PartialOrd for Sandwich5Message
impl Copy for Sandwich5Message
impl Eq for Sandwich5Message
impl StructuralPartialEq for Sandwich5Message