pub struct Sandwich7Message {
pub header: TransactionHeader,
pub body: Sandwich7,
}Fields
header: TransactionHeaderbody: Sandwich7Trait Implementations
Sourceimpl Clone for Sandwich7Message
impl Clone for Sandwich7Message
Sourcefn clone(&self) -> Sandwich7Message
fn clone(&self) -> Sandwich7Message
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Sandwich7Message> for Sandwich7Message
impl CompatFrom<Sandwich7Message> for Sandwich7Message
Sourcefn compat_from(value: Sandwich7Message) -> Sandwich7Message
fn compat_from(value: Sandwich7Message) -> Sandwich7Message
Converts
value into a value of this type.Sourceimpl Debug for Sandwich7Message
impl Debug for Sandwich7Message
Sourceimpl<'a, ___E> Encode<Sandwich7Message<'static>, ___E> for &'a Sandwich7Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Sandwich7Message<'static>, ___E> for &'a Sandwich7Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich7Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich7Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich7Message<'static>, ___E> for Sandwich7Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Sandwich7Message<'static>, ___E> for Sandwich7Messagewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich7Message<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich7Message<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Sandwich7Message<'static>>, ___E> for &'a Sandwich7Message
impl<'a, ___E> EncodeOption<Box<'static, Sandwich7Message<'static>>, ___E> for &'a Sandwich7Message
Sourcefn encode_option(
this: Option<&'a Sandwich7Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich7Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Sandwich7Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich7Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Sandwich7Message<'static>>, ___E> for Sandwich7Message
impl<___E> EncodeOption<Box<'static, Sandwich7Message<'static>>, ___E> for Sandwich7Message
Sourcefn encode_option(
this: Option<Sandwich7Message>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich7Message<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Sandwich7Message>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich7Message<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Sandwich7Message<'de>> for Sandwich7Message
impl<'de> FromWire<Sandwich7Message<'de>> for Sandwich7Message
Sourcefn from_wire(wire: Sandwich7Message<'de>) -> Sandwich7Message
fn from_wire(wire: Sandwich7Message<'de>) -> Sandwich7Message
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Sandwich7Message<'de>> for Sandwich7Message
impl<'de> FromWireRef<Sandwich7Message<'de>> for Sandwich7Message
Sourcefn from_wire_ref(wire: &Sandwich7Message<'de>) -> Sandwich7Message
fn from_wire_ref(wire: &Sandwich7Message<'de>) -> Sandwich7Message
Converts the given reference to this type.
Sourceimpl Hash for Sandwich7Message
impl Hash for Sandwich7Message
Sourceimpl Ord for Sandwich7Message
impl Ord for Sandwich7Message
Sourcefn cmp(&self, other: &Sandwich7Message) -> Ordering
fn cmp(&self, other: &Sandwich7Message) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Sandwich7Message
impl PartialEq for Sandwich7Message
Sourceimpl PartialOrd for Sandwich7Message
impl PartialOrd for Sandwich7Message
impl Eq for Sandwich7Message
impl StructuralPartialEq for Sandwich7Message