#[repr(C)]pub struct StrictEnumUint16Struct {
pub e: StrictEnumUint16,
}Fields
e: StrictEnumUint16Trait Implementations
Sourceimpl Clone for StrictEnumUint16Struct
impl Clone for StrictEnumUint16Struct
Sourcefn clone(&self) -> StrictEnumUint16Struct
fn clone(&self) -> StrictEnumUint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumUint16Struct> for StrictEnumUint16Struct
impl CompatFrom<StrictEnumUint16Struct> for StrictEnumUint16Struct
Sourcefn compat_from(value: StrictEnumUint16Struct) -> StrictEnumUint16Struct
fn compat_from(value: StrictEnumUint16Struct) -> StrictEnumUint16Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumUint16Struct
impl Debug for StrictEnumUint16Struct
Sourceimpl<'a, ___E> Encode<StrictEnumUint16Struct, ___E> for &'a StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint16Struct, ___E> for &'a StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint16Struct>, ___E> for &'a StrictEnumUint16Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint16Struct>, ___E> for &'a StrictEnumUint16Struct
Sourcefn encode_option(
this: Option<&'a StrictEnumUint16Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictEnumUint16Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumUint16Struct>, ___E> for StrictEnumUint16Struct
impl<___E> EncodeOption<Box<'static, StrictEnumUint16Struct>, ___E> for StrictEnumUint16Struct
Sourcefn encode_option(
this: Option<StrictEnumUint16Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictEnumUint16Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumUint16Struct> for StrictEnumUint16Struct
impl FromWire<StrictEnumUint16Struct> for StrictEnumUint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
Sourcefn from_wire(wire: StrictEnumUint16Struct) -> StrictEnumUint16Struct
fn from_wire(wire: StrictEnumUint16Struct) -> StrictEnumUint16Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint16Struct> for StrictEnumUint16Struct
impl FromWireRef<StrictEnumUint16Struct> for StrictEnumUint16Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint16Struct) -> StrictEnumUint16Struct
fn from_wire_ref(wire: &StrictEnumUint16Struct) -> StrictEnumUint16Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumUint16Struct
impl Hash for StrictEnumUint16Struct
Sourceimpl Ord for StrictEnumUint16Struct
impl Ord for StrictEnumUint16Struct
Sourcefn cmp(&self, other: &StrictEnumUint16Struct) -> Ordering
fn cmp(&self, other: &StrictEnumUint16Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumUint16Struct
impl PartialEq for StrictEnumUint16Struct
Sourceimpl PartialOrd for StrictEnumUint16Struct
impl PartialOrd for StrictEnumUint16Struct
impl Copy for StrictEnumUint16Struct
impl Eq for StrictEnumUint16Struct
impl StructuralPartialEq for StrictEnumUint16Struct