#[repr(C)]pub struct StrictEnumUint8Struct {
pub e: StrictEnumUint8,
}Fields
e: StrictEnumUint8Trait Implementations
Sourceimpl Clone for StrictEnumUint8Struct
impl Clone for StrictEnumUint8Struct
Sourcefn clone(&self) -> StrictEnumUint8Struct
fn clone(&self) -> StrictEnumUint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumUint8Struct> for StrictEnumUint8Struct
impl CompatFrom<StrictEnumUint8Struct> for StrictEnumUint8Struct
Sourcefn compat_from(value: StrictEnumUint8Struct) -> StrictEnumUint8Struct
fn compat_from(value: StrictEnumUint8Struct) -> StrictEnumUint8Struct
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumUint8Struct
impl Debug for StrictEnumUint8Struct
Sourceimpl<'a, ___E> Encode<StrictEnumUint8Struct, ___E> for &'a StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint8Struct, ___E> for &'a StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, StrictEnumUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, StrictEnumUint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint8Struct>, ___E> for &'a StrictEnumUint8Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumUint8Struct>, ___E> for &'a StrictEnumUint8Struct
Sourcefn encode_option(
this: Option<&'a StrictEnumUint8Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StrictEnumUint8Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumUint8Struct>, ___E> for StrictEnumUint8Struct
impl<___E> EncodeOption<Box<'static, StrictEnumUint8Struct>, ___E> for StrictEnumUint8Struct
Sourcefn encode_option(
this: Option<StrictEnumUint8Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumUint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StrictEnumUint8Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumUint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumUint8Struct> for StrictEnumUint8Struct
impl FromWire<StrictEnumUint8Struct> for StrictEnumUint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, StrictEnumUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, StrictEnumUint8Struct>
Sourcefn from_wire(wire: StrictEnumUint8Struct) -> StrictEnumUint8Struct
fn from_wire(wire: StrictEnumUint8Struct) -> StrictEnumUint8Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint8Struct> for StrictEnumUint8Struct
impl FromWireRef<StrictEnumUint8Struct> for StrictEnumUint8Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint8Struct) -> StrictEnumUint8Struct
fn from_wire_ref(wire: &StrictEnumUint8Struct) -> StrictEnumUint8Struct
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumUint8Struct
impl Hash for StrictEnumUint8Struct
Sourceimpl Ord for StrictEnumUint8Struct
impl Ord for StrictEnumUint8Struct
Sourcefn cmp(&self, other: &StrictEnumUint8Struct) -> Ordering
fn cmp(&self, other: &StrictEnumUint8Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumUint8Struct
impl PartialEq for StrictEnumUint8Struct
Sourceimpl PartialOrd for StrictEnumUint8Struct
impl PartialOrd for StrictEnumUint8Struct
impl Copy for StrictEnumUint8Struct
impl Eq for StrictEnumUint8Struct
impl StructuralPartialEq for StrictEnumUint8Struct