pub struct StringWrapper {
pub str: String,
}Fields
str: StringTrait Implementations
Sourceimpl Clone for StringWrapper
impl Clone for StringWrapper
Sourcefn clone(&self) -> StringWrapper
fn clone(&self) -> StringWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StringWrapper> for StringWrapper
impl CompatFrom<StringWrapper> for StringWrapper
Sourcefn compat_from(value: StringWrapper) -> StringWrapper
fn compat_from(value: StringWrapper) -> StringWrapper
Converts
value into a value of this type.Sourceimpl Debug for StringWrapper
impl Debug for StringWrapper
Sourceimpl<'a, ___E> Encode<StringWrapper<'static>, ___E> for &'a StringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StringWrapper<'static>, ___E> for &'a StringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StringWrapper<'static>, ___E> for StringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StringWrapper<'static>, ___E> for StringWrapperwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StringWrapper<'static>>, ___E> for &'a StringWrapper
impl<'a, ___E> EncodeOption<Box<'static, StringWrapper<'static>>, ___E> for &'a StringWrapper
Sourcefn encode_option(
this: Option<&'a StringWrapper>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StringWrapper>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StringWrapper<'static>>, ___E> for StringWrapper
impl<___E> EncodeOption<Box<'static, StringWrapper<'static>>, ___E> for StringWrapper
Sourcefn encode_option(
this: Option<StringWrapper>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StringWrapper>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StringWrapper<'de>> for StringWrapper
impl<'de> FromWire<StringWrapper<'de>> for StringWrapper
Sourcefn from_wire(wire: StringWrapper<'de>) -> StringWrapper
fn from_wire(wire: StringWrapper<'de>) -> StringWrapper
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StringWrapper<'de>> for StringWrapper
impl<'de> FromWireRef<StringWrapper<'de>> for StringWrapper
Sourcefn from_wire_ref(wire: &StringWrapper<'de>) -> StringWrapper
fn from_wire_ref(wire: &StringWrapper<'de>) -> StringWrapper
Converts the given reference to this type.
Sourceimpl Hash for StringWrapper
impl Hash for StringWrapper
Sourceimpl Ord for StringWrapper
impl Ord for StringWrapper
Sourcefn cmp(&self, other: &StringWrapper) -> Ordering
fn cmp(&self, other: &StringWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringWrapper
impl PartialEq for StringWrapper
Sourceimpl PartialOrd for StringWrapper
impl PartialOrd for StringWrapper
impl Eq for StringWrapper
impl StructuralPartialEq for StringWrapper