pub struct Struct5Byte {
pub a: i32,
pub b: i8,
}Fields
a: i32b: i8Trait Implementations
Sourceimpl Clone for Struct5Byte
impl Clone for Struct5Byte
Sourcefn clone(&self) -> Struct5Byte
fn clone(&self) -> Struct5Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct5Byte> for Struct5Byte
impl CompatFrom<Struct5Byte> for Struct5Byte
Sourcefn compat_from(value: Struct5Byte) -> Struct5Byte
fn compat_from(value: Struct5Byte) -> Struct5Byte
Converts
value into a value of this type.Sourceimpl Debug for Struct5Byte
impl Debug for Struct5Byte
Sourceimpl<'a, ___E> Encode<Struct5Byte, ___E> for &'a Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct5Byte, ___E> for &'a Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct5Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct5Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct5Byte, ___E> for Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct5Byte, ___E> for Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct5Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct5Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct5Byte>, ___E> for &'a Struct5Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct5Byte>, ___E> for &'a Struct5Byte
Sourcefn encode_option(
this: Option<&'a Struct5Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct5Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Struct5Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct5Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct5Byte>, ___E> for Struct5Byte
impl<___E> EncodeOption<Box<'static, Struct5Byte>, ___E> for Struct5Byte
Sourcefn encode_option(
this: Option<Struct5Byte>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct5Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Struct5Byte>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct5Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct5Byte> for Struct5Byte
impl FromWire<Struct5Byte> for Struct5Byte
Sourcefn from_wire(wire: Struct5Byte) -> Struct5Byte
fn from_wire(wire: Struct5Byte) -> Struct5Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct5Byte> for Struct5Byte
impl FromWireRef<Struct5Byte> for Struct5Byte
Sourcefn from_wire_ref(wire: &Struct5Byte) -> Struct5Byte
fn from_wire_ref(wire: &Struct5Byte) -> Struct5Byte
Converts the given reference to this type.
Sourceimpl Hash for Struct5Byte
impl Hash for Struct5Byte
Sourceimpl Ord for Struct5Byte
impl Ord for Struct5Byte
Sourcefn cmp(&self, other: &Struct5Byte) -> Ordering
fn cmp(&self, other: &Struct5Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct5Byte
impl PartialEq for Struct5Byte
Sourceimpl PartialOrd for Struct5Byte
impl PartialOrd for Struct5Byte
impl Copy for Struct5Byte
impl Eq for Struct5Byte
impl StructuralPartialEq for Struct5Byte