pub struct StructOfReverseOrdinalTable {
pub table: ReverseOrdinalTable,
}Fields
table: ReverseOrdinalTableTrait Implementations
Sourceimpl Clone for StructOfReverseOrdinalTable
impl Clone for StructOfReverseOrdinalTable
Sourcefn clone(&self) -> StructOfReverseOrdinalTable
fn clone(&self) -> StructOfReverseOrdinalTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfReverseOrdinalTable> for StructOfReverseOrdinalTable
impl CompatFrom<StructOfReverseOrdinalTable> for StructOfReverseOrdinalTable
Sourcefn compat_from(
value: StructOfReverseOrdinalTable,
) -> StructOfReverseOrdinalTable
fn compat_from( value: StructOfReverseOrdinalTable, ) -> StructOfReverseOrdinalTable
Converts
value into a value of this type.Sourceimpl Debug for StructOfReverseOrdinalTable
impl Debug for StructOfReverseOrdinalTable
Sourceimpl<'a, ___E> Encode<StructOfReverseOrdinalTable<'static>, ___E> for &'a StructOfReverseOrdinalTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructOfReverseOrdinalTable<'static>, ___E> for &'a StructOfReverseOrdinalTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfReverseOrdinalTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfReverseOrdinalTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfReverseOrdinalTable<'static>, ___E> for StructOfReverseOrdinalTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructOfReverseOrdinalTable<'static>, ___E> for StructOfReverseOrdinalTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfReverseOrdinalTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfReverseOrdinalTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfReverseOrdinalTable<'static>>, ___E> for &'a StructOfReverseOrdinalTablewhere
___E: Encoder + ?Sized,
&'a StructOfReverseOrdinalTable: Encode<StructOfReverseOrdinalTable<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StructOfReverseOrdinalTable<'static>>, ___E> for &'a StructOfReverseOrdinalTablewhere
___E: Encoder + ?Sized,
&'a StructOfReverseOrdinalTable: Encode<StructOfReverseOrdinalTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a StructOfReverseOrdinalTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfReverseOrdinalTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructOfReverseOrdinalTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfReverseOrdinalTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfReverseOrdinalTable<'static>>, ___E> for StructOfReverseOrdinalTablewhere
___E: Encoder + ?Sized,
StructOfReverseOrdinalTable: Encode<StructOfReverseOrdinalTable<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StructOfReverseOrdinalTable<'static>>, ___E> for StructOfReverseOrdinalTablewhere
___E: Encoder + ?Sized,
StructOfReverseOrdinalTable: Encode<StructOfReverseOrdinalTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<StructOfReverseOrdinalTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfReverseOrdinalTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructOfReverseOrdinalTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfReverseOrdinalTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfReverseOrdinalTable<'de>> for StructOfReverseOrdinalTable
impl<'de> FromWire<StructOfReverseOrdinalTable<'de>> for StructOfReverseOrdinalTable
Sourcefn from_wire(
wire: StructOfReverseOrdinalTable<'de>,
) -> StructOfReverseOrdinalTable
fn from_wire( wire: StructOfReverseOrdinalTable<'de>, ) -> StructOfReverseOrdinalTable
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfReverseOrdinalTable<'de>> for StructOfReverseOrdinalTable
impl<'de> FromWireRef<StructOfReverseOrdinalTable<'de>> for StructOfReverseOrdinalTable
Sourcefn from_wire_ref(
wire: &StructOfReverseOrdinalTable<'de>,
) -> StructOfReverseOrdinalTable
fn from_wire_ref( wire: &StructOfReverseOrdinalTable<'de>, ) -> StructOfReverseOrdinalTable
Converts the given reference to this type.
Sourceimpl Hash for StructOfReverseOrdinalTable
impl Hash for StructOfReverseOrdinalTable
Sourceimpl Ord for StructOfReverseOrdinalTable
impl Ord for StructOfReverseOrdinalTable
Sourcefn cmp(&self, other: &StructOfReverseOrdinalTable) -> Ordering
fn cmp(&self, other: &StructOfReverseOrdinalTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for StructOfReverseOrdinalTable
impl PartialOrd for StructOfReverseOrdinalTable
impl Copy for StructOfReverseOrdinalTable
impl Eq for StructOfReverseOrdinalTable
impl StructuralPartialEq for StructOfReverseOrdinalTable