pub struct StructOfTableWithStringAndVector {
pub table: TableWithStringAndVector,
}Fields
table: TableWithStringAndVectorTrait Implementations
Sourceimpl Clone for StructOfTableWithStringAndVector
impl Clone for StructOfTableWithStringAndVector
Sourcefn clone(&self) -> StructOfTableWithStringAndVector
fn clone(&self) -> StructOfTableWithStringAndVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfTableWithStringAndVector> for StructOfTableWithStringAndVector
impl CompatFrom<StructOfTableWithStringAndVector> for StructOfTableWithStringAndVector
Sourcefn compat_from(
value: StructOfTableWithStringAndVector,
) -> StructOfTableWithStringAndVector
fn compat_from( value: StructOfTableWithStringAndVector, ) -> StructOfTableWithStringAndVector
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<StructOfTableWithStringAndVector<'static>, ___E> for &'a StructOfTableWithStringAndVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructOfTableWithStringAndVector<'static>, ___E> for &'a StructOfTableWithStringAndVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithStringAndVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithStringAndVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfTableWithStringAndVector<'static>, ___E> for StructOfTableWithStringAndVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructOfTableWithStringAndVector<'static>, ___E> for StructOfTableWithStringAndVectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithStringAndVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithStringAndVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithStringAndVector<'static>>, ___E> for &'a StructOfTableWithStringAndVectorwhere
___E: Encoder + ?Sized,
&'a StructOfTableWithStringAndVector: Encode<StructOfTableWithStringAndVector<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithStringAndVector<'static>>, ___E> for &'a StructOfTableWithStringAndVectorwhere
___E: Encoder + ?Sized,
&'a StructOfTableWithStringAndVector: Encode<StructOfTableWithStringAndVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a StructOfTableWithStringAndVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithStringAndVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructOfTableWithStringAndVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithStringAndVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfTableWithStringAndVector<'static>>, ___E> for StructOfTableWithStringAndVectorwhere
___E: Encoder + ?Sized,
StructOfTableWithStringAndVector: Encode<StructOfTableWithStringAndVector<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StructOfTableWithStringAndVector<'static>>, ___E> for StructOfTableWithStringAndVectorwhere
___E: Encoder + ?Sized,
StructOfTableWithStringAndVector: Encode<StructOfTableWithStringAndVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<StructOfTableWithStringAndVector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithStringAndVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructOfTableWithStringAndVector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithStringAndVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfTableWithStringAndVector<'de>> for StructOfTableWithStringAndVector
impl<'de> FromWire<StructOfTableWithStringAndVector<'de>> for StructOfTableWithStringAndVector
Sourcefn from_wire(
wire: StructOfTableWithStringAndVector<'de>,
) -> StructOfTableWithStringAndVector
fn from_wire( wire: StructOfTableWithStringAndVector<'de>, ) -> StructOfTableWithStringAndVector
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfTableWithStringAndVector<'de>> for StructOfTableWithStringAndVector
impl<'de> FromWireRef<StructOfTableWithStringAndVector<'de>> for StructOfTableWithStringAndVector
Sourcefn from_wire_ref(
wire: &StructOfTableWithStringAndVector<'de>,
) -> StructOfTableWithStringAndVector
fn from_wire_ref( wire: &StructOfTableWithStringAndVector<'de>, ) -> StructOfTableWithStringAndVector
Converts the given reference to this type.
Sourceimpl Ord for StructOfTableWithStringAndVector
impl Ord for StructOfTableWithStringAndVector
Sourcefn cmp(&self, other: &StructOfTableWithStringAndVector) -> Ordering
fn cmp(&self, other: &StructOfTableWithStringAndVector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfTableWithStringAndVector
impl PartialEq for StructOfTableWithStringAndVector
Sourcefn eq(&self, other: &StructOfTableWithStringAndVector) -> bool
fn eq(&self, other: &StructOfTableWithStringAndVector) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for StructOfTableWithStringAndVector
impl PartialOrd for StructOfTableWithStringAndVector
impl Eq for StructOfTableWithStringAndVector
impl StructuralPartialEq for StructOfTableWithStringAndVector