pub struct StructTableNoFields {
pub t: TableNoFields,
}Fields
t: TableNoFieldsTrait Implementations
Sourceimpl Clone for StructTableNoFields
impl Clone for StructTableNoFields
Sourcefn clone(&self) -> StructTableNoFields
fn clone(&self) -> StructTableNoFields
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructTableNoFields> for StructTableNoFields
impl CompatFrom<StructTableNoFields> for StructTableNoFields
Sourcefn compat_from(value: StructTableNoFields) -> StructTableNoFields
fn compat_from(value: StructTableNoFields) -> StructTableNoFields
Converts
value into a value of this type.Sourceimpl Debug for StructTableNoFields
impl Debug for StructTableNoFields
Sourceimpl<'a, ___E> Encode<StructTableNoFields<'static>, ___E> for &'a StructTableNoFieldswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructTableNoFields<'static>, ___E> for &'a StructTableNoFieldswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructTableNoFields<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructTableNoFields<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructTableNoFields<'static>, ___E> for StructTableNoFieldswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructTableNoFields<'static>, ___E> for StructTableNoFieldswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructTableNoFields<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructTableNoFields<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructTableNoFields<'static>>, ___E> for &'a StructTableNoFields
impl<'a, ___E> EncodeOption<Box<'static, StructTableNoFields<'static>>, ___E> for &'a StructTableNoFields
Sourcefn encode_option(
this: Option<&'a StructTableNoFields>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructTableNoFields<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructTableNoFields>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructTableNoFields<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructTableNoFields<'static>>, ___E> for StructTableNoFields
impl<___E> EncodeOption<Box<'static, StructTableNoFields<'static>>, ___E> for StructTableNoFields
Sourcefn encode_option(
this: Option<StructTableNoFields>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructTableNoFields<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructTableNoFields>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructTableNoFields<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructTableNoFields<'de>> for StructTableNoFields
impl<'de> FromWire<StructTableNoFields<'de>> for StructTableNoFields
Sourcefn from_wire(wire: StructTableNoFields<'de>) -> StructTableNoFields
fn from_wire(wire: StructTableNoFields<'de>) -> StructTableNoFields
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructTableNoFields<'de>> for StructTableNoFields
impl<'de> FromWireRef<StructTableNoFields<'de>> for StructTableNoFields
Sourcefn from_wire_ref(wire: &StructTableNoFields<'de>) -> StructTableNoFields
fn from_wire_ref(wire: &StructTableNoFields<'de>) -> StructTableNoFields
Converts the given reference to this type.
Sourceimpl Hash for StructTableNoFields
impl Hash for StructTableNoFields
Sourceimpl Ord for StructTableNoFields
impl Ord for StructTableNoFields
Sourcefn cmp(&self, other: &StructTableNoFields) -> Ordering
fn cmp(&self, other: &StructTableNoFields) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructTableNoFields
impl PartialEq for StructTableNoFields
Sourceimpl PartialOrd for StructTableNoFields
impl PartialOrd for StructTableNoFields
impl Copy for StructTableNoFields
impl Eq for StructTableNoFields
impl StructuralPartialEq for StructTableNoFields