pub struct StructWithArrays {
pub arr_int: [i32; 2],
pub arr_string: [String; 2],
pub arr_nullable_string: [Option<String>; 2],
pub arr_struct: [StructWithInt; 2],
pub arr_nullable_struct: [Option<Box<StructWithInt>>; 2],
pub arr_arr_int: [[i32; 3]; 2],
}Fields
arr_int: [i32; 2]arr_string: [String; 2]arr_nullable_string: [Option<String>; 2]arr_struct: [StructWithInt; 2]arr_nullable_struct: [Option<Box<StructWithInt>>; 2]arr_arr_int: [[i32; 3]; 2]Trait Implementations
Sourceimpl Clone for StructWithArrays
impl Clone for StructWithArrays
Sourcefn clone(&self) -> StructWithArrays
fn clone(&self) -> StructWithArrays
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructWithArrays> for StructWithArrays
impl CompatFrom<StructWithArrays> for StructWithArrays
Sourcefn compat_from(value: StructWithArrays) -> StructWithArrays
fn compat_from(value: StructWithArrays) -> StructWithArrays
Converts
value into a value of this type.Sourceimpl Debug for StructWithArrays
impl Debug for StructWithArrays
Sourceimpl<'a, ___E> Encode<StructWithArrays<'static>, ___E> for &'a StructWithArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructWithArrays<'static>, ___E> for &'a StructWithArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithArrays<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithArrays<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithArrays<'static>, ___E> for StructWithArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructWithArrays<'static>, ___E> for StructWithArrayswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithArrays<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithArrays<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructWithArrays<'static>>, ___E> for &'a StructWithArrays
impl<'a, ___E> EncodeOption<Box<'static, StructWithArrays<'static>>, ___E> for &'a StructWithArrays
Sourcefn encode_option(
this: Option<&'a StructWithArrays>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithArrays<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a StructWithArrays>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithArrays<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructWithArrays<'static>>, ___E> for StructWithArrays
impl<___E> EncodeOption<Box<'static, StructWithArrays<'static>>, ___E> for StructWithArrays
Sourcefn encode_option(
this: Option<StructWithArrays>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithArrays<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<StructWithArrays>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithArrays<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructWithArrays<'de>> for StructWithArrays
impl<'de> FromWire<StructWithArrays<'de>> for StructWithArrays
Sourcefn from_wire(wire: StructWithArrays<'de>) -> StructWithArrays
fn from_wire(wire: StructWithArrays<'de>) -> StructWithArrays
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructWithArrays<'de>> for StructWithArrays
impl<'de> FromWireRef<StructWithArrays<'de>> for StructWithArrays
Sourcefn from_wire_ref(wire: &StructWithArrays<'de>) -> StructWithArrays
fn from_wire_ref(wire: &StructWithArrays<'de>) -> StructWithArrays
Converts the given reference to this type.
Sourceimpl Hash for StructWithArrays
impl Hash for StructWithArrays
Sourceimpl Ord for StructWithArrays
impl Ord for StructWithArrays
Sourcefn cmp(&self, other: &StructWithArrays) -> Ordering
fn cmp(&self, other: &StructWithArrays) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructWithArrays
impl PartialEq for StructWithArrays
Sourceimpl PartialOrd for StructWithArrays
impl PartialOrd for StructWithArrays
impl Eq for StructWithArrays
impl StructuralPartialEq for StructWithArrays