pub struct TableStructWithReservedSandwichStruct {
pub table: TableStructWithReservedSandwich,
}Fields
table: TableStructWithReservedSandwichTrait Implementations
Sourceimpl Clone for TableStructWithReservedSandwichStruct
impl Clone for TableStructWithReservedSandwichStruct
Sourcefn clone(&self) -> TableStructWithReservedSandwichStruct
fn clone(&self) -> TableStructWithReservedSandwichStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TableStructWithReservedSandwichStruct> for TableStructWithReservedSandwichStruct
impl CompatFrom<TableStructWithReservedSandwichStruct> for TableStructWithReservedSandwichStruct
Sourcefn compat_from(
value: TableStructWithReservedSandwichStruct,
) -> TableStructWithReservedSandwichStruct
fn compat_from( value: TableStructWithReservedSandwichStruct, ) -> TableStructWithReservedSandwichStruct
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TableStructWithReservedSandwichStruct<'static>, ___E> for &'a TableStructWithReservedSandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TableStructWithReservedSandwichStruct<'static>, ___E> for &'a TableStructWithReservedSandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithReservedSandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithReservedSandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableStructWithReservedSandwichStruct<'static>, ___E> for TableStructWithReservedSandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TableStructWithReservedSandwichStruct<'static>, ___E> for TableStructWithReservedSandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithReservedSandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithReservedSandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TableStructWithReservedSandwichStruct<'static>>, ___E> for &'a TableStructWithReservedSandwichStructwhere
___E: Encoder + ?Sized,
&'a TableStructWithReservedSandwichStruct: Encode<TableStructWithReservedSandwichStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TableStructWithReservedSandwichStruct<'static>>, ___E> for &'a TableStructWithReservedSandwichStructwhere
___E: Encoder + ?Sized,
&'a TableStructWithReservedSandwichStruct: Encode<TableStructWithReservedSandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TableStructWithReservedSandwichStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableStructWithReservedSandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TableStructWithReservedSandwichStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableStructWithReservedSandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TableStructWithReservedSandwichStruct<'static>>, ___E> for TableStructWithReservedSandwichStructwhere
___E: Encoder + ?Sized,
TableStructWithReservedSandwichStruct: Encode<TableStructWithReservedSandwichStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableStructWithReservedSandwichStruct<'static>>, ___E> for TableStructWithReservedSandwichStructwhere
___E: Encoder + ?Sized,
TableStructWithReservedSandwichStruct: Encode<TableStructWithReservedSandwichStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<TableStructWithReservedSandwichStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableStructWithReservedSandwichStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TableStructWithReservedSandwichStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableStructWithReservedSandwichStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableStructWithReservedSandwichStruct<'de>> for TableStructWithReservedSandwichStruct
impl<'de> FromWire<TableStructWithReservedSandwichStruct<'de>> for TableStructWithReservedSandwichStruct
Sourcefn from_wire(
wire: TableStructWithReservedSandwichStruct<'de>,
) -> TableStructWithReservedSandwichStruct
fn from_wire( wire: TableStructWithReservedSandwichStruct<'de>, ) -> TableStructWithReservedSandwichStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableStructWithReservedSandwichStruct<'de>> for TableStructWithReservedSandwichStruct
impl<'de> FromWireRef<TableStructWithReservedSandwichStruct<'de>> for TableStructWithReservedSandwichStruct
Sourcefn from_wire_ref(
wire: &TableStructWithReservedSandwichStruct<'de>,
) -> TableStructWithReservedSandwichStruct
fn from_wire_ref( wire: &TableStructWithReservedSandwichStruct<'de>, ) -> TableStructWithReservedSandwichStruct
Converts the given reference to this type.
Sourceimpl Ord for TableStructWithReservedSandwichStruct
impl Ord for TableStructWithReservedSandwichStruct
Sourcefn cmp(&self, other: &TableStructWithReservedSandwichStruct) -> Ordering
fn cmp(&self, other: &TableStructWithReservedSandwichStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TableStructWithReservedSandwichStruct
impl PartialEq for TableStructWithReservedSandwichStruct
Sourcefn eq(&self, other: &TableStructWithReservedSandwichStruct) -> bool
fn eq(&self, other: &TableStructWithReservedSandwichStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TableStructWithReservedSandwichStruct
impl PartialOrd for TableStructWithReservedSandwichStruct
impl Copy for TableStructWithReservedSandwichStruct
impl Eq for TableStructWithReservedSandwichStruct
impl StructuralPartialEq for TableStructWithReservedSandwichStruct