pub struct TestAddEthernetDeviceRequest {
pub topological_path: String,
pub config: InterfaceConfig,
pub this_should_be_a_handle: u32,
}Fields
topological_path: Stringconfig: InterfaceConfigthis_should_be_a_handle: u32Trait Implementations
Sourceimpl Clone for TestAddEthernetDeviceRequest
impl Clone for TestAddEthernetDeviceRequest
Sourcefn clone(&self) -> TestAddEthernetDeviceRequest
fn clone(&self) -> TestAddEthernetDeviceRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestAddEthernetDeviceRequest> for TestAddEthernetDeviceRequest
impl CompatFrom<TestAddEthernetDeviceRequest> for TestAddEthernetDeviceRequest
Sourcefn compat_from(
value: TestAddEthernetDeviceRequest,
) -> TestAddEthernetDeviceRequest
fn compat_from( value: TestAddEthernetDeviceRequest, ) -> TestAddEthernetDeviceRequest
Converts
value into a value of this type.Sourceimpl Debug for TestAddEthernetDeviceRequest
impl Debug for TestAddEthernetDeviceRequest
Sourceimpl<'a, ___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TestAddEthernetDeviceRequest<'static>>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: Encoder + ?Sized,
&'a TestAddEthernetDeviceRequest: Encode<TestAddEthernetDeviceRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TestAddEthernetDeviceRequest<'static>>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: Encoder + ?Sized,
&'a TestAddEthernetDeviceRequest: Encode<TestAddEthernetDeviceRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TestAddEthernetDeviceRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestAddEthernetDeviceRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TestAddEthernetDeviceRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestAddEthernetDeviceRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TestAddEthernetDeviceRequest<'static>>, ___E> for TestAddEthernetDeviceRequestwhere
___E: Encoder + ?Sized,
TestAddEthernetDeviceRequest: Encode<TestAddEthernetDeviceRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TestAddEthernetDeviceRequest<'static>>, ___E> for TestAddEthernetDeviceRequestwhere
___E: Encoder + ?Sized,
TestAddEthernetDeviceRequest: Encode<TestAddEthernetDeviceRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<TestAddEthernetDeviceRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestAddEthernetDeviceRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TestAddEthernetDeviceRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestAddEthernetDeviceRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
impl<'de> FromWire<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
Sourcefn from_wire(
wire: TestAddEthernetDeviceRequest<'de>,
) -> TestAddEthernetDeviceRequest
fn from_wire( wire: TestAddEthernetDeviceRequest<'de>, ) -> TestAddEthernetDeviceRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
impl<'de> FromWireRef<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
Sourcefn from_wire_ref(
wire: &TestAddEthernetDeviceRequest<'de>,
) -> TestAddEthernetDeviceRequest
fn from_wire_ref( wire: &TestAddEthernetDeviceRequest<'de>, ) -> TestAddEthernetDeviceRequest
Converts the given reference to this type.
Sourceimpl Hash for TestAddEthernetDeviceRequest
impl Hash for TestAddEthernetDeviceRequest
Sourceimpl Ord for TestAddEthernetDeviceRequest
impl Ord for TestAddEthernetDeviceRequest
Sourcefn cmp(&self, other: &TestAddEthernetDeviceRequest) -> Ordering
fn cmp(&self, other: &TestAddEthernetDeviceRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestAddEthernetDeviceRequest
impl PartialEq for TestAddEthernetDeviceRequest
Sourcefn eq(&self, other: &TestAddEthernetDeviceRequest) -> bool
fn eq(&self, other: &TestAddEthernetDeviceRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TestAddEthernetDeviceRequest
impl PartialOrd for TestAddEthernetDeviceRequest
impl Eq for TestAddEthernetDeviceRequest
impl StructuralPartialEq for TestAddEthernetDeviceRequest