pub struct TestOptionalStrictXUnionInStruct {
pub xu: Option<Box<SampleStrictXUnion>>,
}Fields
xu: Option<Box<SampleStrictXUnion>>Trait Implementations
Sourceimpl Clone for TestOptionalStrictXUnionInStruct
impl Clone for TestOptionalStrictXUnionInStruct
Sourcefn clone(&self) -> TestOptionalStrictXUnionInStruct
fn clone(&self) -> TestOptionalStrictXUnionInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestOptionalStrictXUnionInStruct> for TestOptionalStrictXUnionInStruct
impl CompatFrom<TestOptionalStrictXUnionInStruct> for TestOptionalStrictXUnionInStruct
Sourcefn compat_from(
value: TestOptionalStrictXUnionInStruct,
) -> TestOptionalStrictXUnionInStruct
fn compat_from( value: TestOptionalStrictXUnionInStruct, ) -> TestOptionalStrictXUnionInStruct
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TestOptionalStrictXUnionInStruct<'static>, ___E> for &'a TestOptionalStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TestOptionalStrictXUnionInStruct<'static>, ___E> for &'a TestOptionalStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestOptionalStrictXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestOptionalStrictXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestOptionalStrictXUnionInStruct<'static>, ___E> for TestOptionalStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TestOptionalStrictXUnionInStruct<'static>, ___E> for TestOptionalStrictXUnionInStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestOptionalStrictXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestOptionalStrictXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TestOptionalStrictXUnionInStruct<'static>>, ___E> for &'a TestOptionalStrictXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestOptionalStrictXUnionInStruct: Encode<TestOptionalStrictXUnionInStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TestOptionalStrictXUnionInStruct<'static>>, ___E> for &'a TestOptionalStrictXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestOptionalStrictXUnionInStruct: Encode<TestOptionalStrictXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TestOptionalStrictXUnionInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestOptionalStrictXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TestOptionalStrictXUnionInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestOptionalStrictXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TestOptionalStrictXUnionInStruct<'static>>, ___E> for TestOptionalStrictXUnionInStructwhere
___E: Encoder + ?Sized,
TestOptionalStrictXUnionInStruct: Encode<TestOptionalStrictXUnionInStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TestOptionalStrictXUnionInStruct<'static>>, ___E> for TestOptionalStrictXUnionInStructwhere
___E: Encoder + ?Sized,
TestOptionalStrictXUnionInStruct: Encode<TestOptionalStrictXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<TestOptionalStrictXUnionInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestOptionalStrictXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TestOptionalStrictXUnionInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestOptionalStrictXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestOptionalStrictXUnionInStruct<'de>> for TestOptionalStrictXUnionInStruct
impl<'de> FromWire<TestOptionalStrictXUnionInStruct<'de>> for TestOptionalStrictXUnionInStruct
Sourcefn from_wire(
wire: TestOptionalStrictXUnionInStruct<'de>,
) -> TestOptionalStrictXUnionInStruct
fn from_wire( wire: TestOptionalStrictXUnionInStruct<'de>, ) -> TestOptionalStrictXUnionInStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestOptionalStrictXUnionInStruct<'de>> for TestOptionalStrictXUnionInStruct
impl<'de> FromWireRef<TestOptionalStrictXUnionInStruct<'de>> for TestOptionalStrictXUnionInStruct
Sourcefn from_wire_ref(
wire: &TestOptionalStrictXUnionInStruct<'de>,
) -> TestOptionalStrictXUnionInStruct
fn from_wire_ref( wire: &TestOptionalStrictXUnionInStruct<'de>, ) -> TestOptionalStrictXUnionInStruct
Converts the given reference to this type.
Sourceimpl Ord for TestOptionalStrictXUnionInStruct
impl Ord for TestOptionalStrictXUnionInStruct
Sourcefn cmp(&self, other: &TestOptionalStrictXUnionInStruct) -> Ordering
fn cmp(&self, other: &TestOptionalStrictXUnionInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestOptionalStrictXUnionInStruct
impl PartialEq for TestOptionalStrictXUnionInStruct
Sourcefn eq(&self, other: &TestOptionalStrictXUnionInStruct) -> bool
fn eq(&self, other: &TestOptionalStrictXUnionInStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TestOptionalStrictXUnionInStruct
impl PartialOrd for TestOptionalStrictXUnionInStruct
impl Eq for TestOptionalStrictXUnionInStruct
impl StructuralPartialEq for TestOptionalStrictXUnionInStruct