pub struct TestXUnionInTable {
pub value: XUnionInTable,
}Fields
value: XUnionInTableTrait Implementations
Sourceimpl Clone for TestXUnionInTable
impl Clone for TestXUnionInTable
Sourcefn clone(&self) -> TestXUnionInTable
fn clone(&self) -> TestXUnionInTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestXUnionInTable> for TestXUnionInTable
impl CompatFrom<TestXUnionInTable> for TestXUnionInTable
Sourcefn compat_from(value: TestXUnionInTable) -> TestXUnionInTable
fn compat_from(value: TestXUnionInTable) -> TestXUnionInTable
Converts
value into a value of this type.Sourceimpl Debug for TestXUnionInTable
impl Debug for TestXUnionInTable
Sourceimpl<'a, ___E> Encode<TestXUnionInTable<'static>, ___E> for &'a TestXUnionInTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TestXUnionInTable<'static>, ___E> for &'a TestXUnionInTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestXUnionInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestXUnionInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestXUnionInTable<'static>, ___E> for TestXUnionInTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TestXUnionInTable<'static>, ___E> for TestXUnionInTablewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestXUnionInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestXUnionInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TestXUnionInTable<'static>>, ___E> for &'a TestXUnionInTable
impl<'a, ___E> EncodeOption<Box<'static, TestXUnionInTable<'static>>, ___E> for &'a TestXUnionInTable
Sourcefn encode_option(
this: Option<&'a TestXUnionInTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestXUnionInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TestXUnionInTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestXUnionInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TestXUnionInTable<'static>>, ___E> for TestXUnionInTable
impl<___E> EncodeOption<Box<'static, TestXUnionInTable<'static>>, ___E> for TestXUnionInTable
Sourcefn encode_option(
this: Option<TestXUnionInTable>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestXUnionInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TestXUnionInTable>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestXUnionInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestXUnionInTable<'de>> for TestXUnionInTable
impl<'de> FromWire<TestXUnionInTable<'de>> for TestXUnionInTable
Sourcefn from_wire(wire: TestXUnionInTable<'de>) -> TestXUnionInTable
fn from_wire(wire: TestXUnionInTable<'de>) -> TestXUnionInTable
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestXUnionInTable<'de>> for TestXUnionInTable
impl<'de> FromWireRef<TestXUnionInTable<'de>> for TestXUnionInTable
Sourcefn from_wire_ref(wire: &TestXUnionInTable<'de>) -> TestXUnionInTable
fn from_wire_ref(wire: &TestXUnionInTable<'de>) -> TestXUnionInTable
Converts the given reference to this type.
Sourceimpl Hash for TestXUnionInTable
impl Hash for TestXUnionInTable
Sourceimpl Ord for TestXUnionInTable
impl Ord for TestXUnionInTable
Sourcefn cmp(&self, other: &TestXUnionInTable) -> Ordering
fn cmp(&self, other: &TestXUnionInTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestXUnionInTable
impl PartialEq for TestXUnionInTable
Sourceimpl PartialOrd for TestXUnionInTable
impl PartialOrd for TestXUnionInTable
impl Eq for TestXUnionInTable
impl StructuralPartialEq for TestXUnionInTable