#[repr(C)]pub struct ThreeByteInArray {
pub elems: [ThreeByte; 3],
}Fields
elems: [ThreeByte; 3]Trait Implementations
Sourceimpl Clone for ThreeByteInArray
impl Clone for ThreeByteInArray
Sourcefn clone(&self) -> ThreeByteInArray
fn clone(&self) -> ThreeByteInArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ThreeByteInArray> for ThreeByteInArray
impl CompatFrom<ThreeByteInArray> for ThreeByteInArray
Sourcefn compat_from(value: ThreeByteInArray) -> ThreeByteInArray
fn compat_from(value: ThreeByteInArray) -> ThreeByteInArray
Converts
value into a value of this type.Sourceimpl Debug for ThreeByteInArray
impl Debug for ThreeByteInArray
Sourceimpl<'a, ___E> Encode<ThreeByteInArray, ___E> for &'a ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ThreeByteInArray, ___E> for &'a ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ThreeByteInArray, ___E> for ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ThreeByteInArray, ___E> for ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, ThreeByteInArray>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, ThreeByteInArray>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ThreeByteInArray>, ___E> for &'a ThreeByteInArray
impl<'a, ___E> EncodeOption<Box<'static, ThreeByteInArray>, ___E> for &'a ThreeByteInArray
Sourcefn encode_option(
this: Option<&'a ThreeByteInArray>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInArray>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ThreeByteInArray>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInArray>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ThreeByteInArray>, ___E> for ThreeByteInArray
impl<___E> EncodeOption<Box<'static, ThreeByteInArray>, ___E> for ThreeByteInArray
Sourcefn encode_option(
this: Option<ThreeByteInArray>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInArray>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ThreeByteInArray>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInArray>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ThreeByteInArray> for ThreeByteInArray
impl FromWire<ThreeByteInArray> for ThreeByteInArray
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, ThreeByteInArray>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, ThreeByteInArray>
Sourcefn from_wire(wire: ThreeByteInArray) -> ThreeByteInArray
fn from_wire(wire: ThreeByteInArray) -> ThreeByteInArray
Converts the given owned value to this type.
Sourceimpl FromWireRef<ThreeByteInArray> for ThreeByteInArray
impl FromWireRef<ThreeByteInArray> for ThreeByteInArray
Sourcefn from_wire_ref(wire: &ThreeByteInArray) -> ThreeByteInArray
fn from_wire_ref(wire: &ThreeByteInArray) -> ThreeByteInArray
Converts the given reference to this type.
Sourceimpl Hash for ThreeByteInArray
impl Hash for ThreeByteInArray
Sourceimpl Ord for ThreeByteInArray
impl Ord for ThreeByteInArray
Sourcefn cmp(&self, other: &ThreeByteInArray) -> Ordering
fn cmp(&self, other: &ThreeByteInArray) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ThreeByteInArray
impl PartialEq for ThreeByteInArray
Sourceimpl PartialOrd for ThreeByteInArray
impl PartialOrd for ThreeByteInArray
impl Copy for ThreeByteInArray
impl Eq for ThreeByteInArray
impl StructuralPartialEq for ThreeByteInArray