#[repr(C)]pub struct ThreeByteInStruct {
pub elem1: ThreeByte,
pub elem2: ThreeByte,
pub elem3: ThreeByte,
}Fields
elem1: ThreeByteelem2: ThreeByteelem3: ThreeByteTrait Implementations
Sourceimpl Clone for ThreeByteInStruct
impl Clone for ThreeByteInStruct
Sourcefn clone(&self) -> ThreeByteInStruct
fn clone(&self) -> ThreeByteInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ThreeByteInStruct> for ThreeByteInStruct
impl CompatFrom<ThreeByteInStruct> for ThreeByteInStruct
Sourcefn compat_from(value: ThreeByteInStruct) -> ThreeByteInStruct
fn compat_from(value: ThreeByteInStruct) -> ThreeByteInStruct
Converts
value into a value of this type.Sourceimpl Debug for ThreeByteInStruct
impl Debug for ThreeByteInStruct
Sourceimpl<'a, ___E> Encode<ThreeByteInStruct, ___E> for &'a ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ThreeByteInStruct, ___E> for &'a ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ThreeByteInStruct, ___E> for ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ThreeByteInStruct, ___E> for ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, ThreeByteInStruct>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, ThreeByteInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ThreeByteInStruct>, ___E> for &'a ThreeByteInStruct
impl<'a, ___E> EncodeOption<Box<'static, ThreeByteInStruct>, ___E> for &'a ThreeByteInStruct
Sourcefn encode_option(
this: Option<&'a ThreeByteInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ThreeByteInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ThreeByteInStruct>, ___E> for ThreeByteInStruct
impl<___E> EncodeOption<Box<'static, ThreeByteInStruct>, ___E> for ThreeByteInStruct
Sourcefn encode_option(
this: Option<ThreeByteInStruct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ThreeByteInStruct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ThreeByteInStruct> for ThreeByteInStruct
impl FromWire<ThreeByteInStruct> for ThreeByteInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, ThreeByteInStruct>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, ThreeByteInStruct>
Sourcefn from_wire(wire: ThreeByteInStruct) -> ThreeByteInStruct
fn from_wire(wire: ThreeByteInStruct) -> ThreeByteInStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<ThreeByteInStruct> for ThreeByteInStruct
impl FromWireRef<ThreeByteInStruct> for ThreeByteInStruct
Sourcefn from_wire_ref(wire: &ThreeByteInStruct) -> ThreeByteInStruct
fn from_wire_ref(wire: &ThreeByteInStruct) -> ThreeByteInStruct
Converts the given reference to this type.
Sourceimpl Hash for ThreeByteInStruct
impl Hash for ThreeByteInStruct
Sourceimpl Ord for ThreeByteInStruct
impl Ord for ThreeByteInStruct
Sourcefn cmp(&self, other: &ThreeByteInStruct) -> Ordering
fn cmp(&self, other: &ThreeByteInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ThreeByteInStruct
impl PartialEq for ThreeByteInStruct
Sourceimpl PartialOrd for ThreeByteInStruct
impl PartialOrd for ThreeByteInStruct
impl Copy for ThreeByteInStruct
impl Eq for ThreeByteInStruct
impl StructuralPartialEq for ThreeByteInStruct