#[repr(C)]pub struct TwoLayerStructNoPaddingAlign4 {
pub s: OneLayerStructNoPaddingAlign4,
pub a: u32,
}Fields
s: OneLayerStructNoPaddingAlign4a: u32Trait Implementations
Sourceimpl Clone for TwoLayerStructNoPaddingAlign4
impl Clone for TwoLayerStructNoPaddingAlign4
Sourcefn clone(&self) -> TwoLayerStructNoPaddingAlign4
fn clone(&self) -> TwoLayerStructNoPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
impl CompatFrom<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
Sourcefn compat_from(
value: TwoLayerStructNoPaddingAlign4,
) -> TwoLayerStructNoPaddingAlign4
fn compat_from( value: TwoLayerStructNoPaddingAlign4, ) -> TwoLayerStructNoPaddingAlign4
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign4>, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
&'a TwoLayerStructNoPaddingAlign4: Encode<TwoLayerStructNoPaddingAlign4, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign4>, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
&'a TwoLayerStructNoPaddingAlign4: Encode<TwoLayerStructNoPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<&'a TwoLayerStructNoPaddingAlign4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TwoLayerStructNoPaddingAlign4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign4>, ___E> for TwoLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
TwoLayerStructNoPaddingAlign4: Encode<TwoLayerStructNoPaddingAlign4, ___E>,
impl<___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign4>, ___E> for TwoLayerStructNoPaddingAlign4where
___E: Encoder + ?Sized,
TwoLayerStructNoPaddingAlign4: Encode<TwoLayerStructNoPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<TwoLayerStructNoPaddingAlign4>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TwoLayerStructNoPaddingAlign4>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
impl FromWire<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
Sourcefn from_wire(
wire: TwoLayerStructNoPaddingAlign4,
) -> TwoLayerStructNoPaddingAlign4
fn from_wire( wire: TwoLayerStructNoPaddingAlign4, ) -> TwoLayerStructNoPaddingAlign4
Converts the given owned value to this type.
Sourceimpl FromWireRef<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
impl FromWireRef<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
Sourcefn from_wire_ref(
wire: &TwoLayerStructNoPaddingAlign4,
) -> TwoLayerStructNoPaddingAlign4
fn from_wire_ref( wire: &TwoLayerStructNoPaddingAlign4, ) -> TwoLayerStructNoPaddingAlign4
Converts the given reference to this type.
Sourceimpl Hash for TwoLayerStructNoPaddingAlign4
impl Hash for TwoLayerStructNoPaddingAlign4
Sourceimpl Ord for TwoLayerStructNoPaddingAlign4
impl Ord for TwoLayerStructNoPaddingAlign4
Sourcefn cmp(&self, other: &TwoLayerStructNoPaddingAlign4) -> Ordering
fn cmp(&self, other: &TwoLayerStructNoPaddingAlign4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TwoLayerStructNoPaddingAlign4
impl PartialEq for TwoLayerStructNoPaddingAlign4
Sourcefn eq(&self, other: &TwoLayerStructNoPaddingAlign4) -> bool
fn eq(&self, other: &TwoLayerStructNoPaddingAlign4) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TwoLayerStructNoPaddingAlign4
impl PartialOrd for TwoLayerStructNoPaddingAlign4
impl Copy for TwoLayerStructNoPaddingAlign4
impl Eq for TwoLayerStructNoPaddingAlign4
impl StructuralPartialEq for TwoLayerStructNoPaddingAlign4