#[repr(C)]pub struct TwoLayerStructNoPaddingAlign8 {
pub s: OneLayerStructNoPaddingAlign8,
pub a: u64,
}Fields
s: OneLayerStructNoPaddingAlign8a: u64Trait Implementations
Sourceimpl Clone for TwoLayerStructNoPaddingAlign8
impl Clone for TwoLayerStructNoPaddingAlign8
Sourcefn clone(&self) -> TwoLayerStructNoPaddingAlign8
fn clone(&self) -> TwoLayerStructNoPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
impl CompatFrom<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
Sourcefn compat_from(
value: TwoLayerStructNoPaddingAlign8,
) -> TwoLayerStructNoPaddingAlign8
fn compat_from( value: TwoLayerStructNoPaddingAlign8, ) -> TwoLayerStructNoPaddingAlign8
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, TwoLayerStructNoPaddingAlign8>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, TwoLayerStructNoPaddingAlign8>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign8>, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
&'a TwoLayerStructNoPaddingAlign8: Encode<TwoLayerStructNoPaddingAlign8, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign8>, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
&'a TwoLayerStructNoPaddingAlign8: Encode<TwoLayerStructNoPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<&'a TwoLayerStructNoPaddingAlign8>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TwoLayerStructNoPaddingAlign8>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign8>, ___E> for TwoLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
TwoLayerStructNoPaddingAlign8: Encode<TwoLayerStructNoPaddingAlign8, ___E>,
impl<___E> EncodeOption<Box<'static, TwoLayerStructNoPaddingAlign8>, ___E> for TwoLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
TwoLayerStructNoPaddingAlign8: Encode<TwoLayerStructNoPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<TwoLayerStructNoPaddingAlign8>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TwoLayerStructNoPaddingAlign8>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructNoPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
impl FromWire<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, TwoLayerStructNoPaddingAlign8>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, TwoLayerStructNoPaddingAlign8>
Sourcefn from_wire(
wire: TwoLayerStructNoPaddingAlign8,
) -> TwoLayerStructNoPaddingAlign8
fn from_wire( wire: TwoLayerStructNoPaddingAlign8, ) -> TwoLayerStructNoPaddingAlign8
Converts the given owned value to this type.
Sourceimpl FromWireRef<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
impl FromWireRef<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
Sourcefn from_wire_ref(
wire: &TwoLayerStructNoPaddingAlign8,
) -> TwoLayerStructNoPaddingAlign8
fn from_wire_ref( wire: &TwoLayerStructNoPaddingAlign8, ) -> TwoLayerStructNoPaddingAlign8
Converts the given reference to this type.
Sourceimpl Hash for TwoLayerStructNoPaddingAlign8
impl Hash for TwoLayerStructNoPaddingAlign8
Sourceimpl Ord for TwoLayerStructNoPaddingAlign8
impl Ord for TwoLayerStructNoPaddingAlign8
Sourcefn cmp(&self, other: &TwoLayerStructNoPaddingAlign8) -> Ordering
fn cmp(&self, other: &TwoLayerStructNoPaddingAlign8) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TwoLayerStructNoPaddingAlign8
impl PartialEq for TwoLayerStructNoPaddingAlign8
Sourcefn eq(&self, other: &TwoLayerStructNoPaddingAlign8) -> bool
fn eq(&self, other: &TwoLayerStructNoPaddingAlign8) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TwoLayerStructNoPaddingAlign8
impl PartialOrd for TwoLayerStructNoPaddingAlign8
impl Copy for TwoLayerStructNoPaddingAlign8
impl Eq for TwoLayerStructNoPaddingAlign8
impl StructuralPartialEq for TwoLayerStructNoPaddingAlign8