#[repr(C)]pub struct Uint32Struct {
pub val: u32,
}Fields
val: u32Trait Implementations
Sourceimpl Clone for Uint32Struct
impl Clone for Uint32Struct
Sourcefn clone(&self) -> Uint32Struct
fn clone(&self) -> Uint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint32Struct> for Uint32Struct
impl CompatFrom<Uint32Struct> for Uint32Struct
Sourcefn compat_from(value: Uint32Struct) -> Uint32Struct
fn compat_from(value: Uint32Struct) -> Uint32Struct
Converts
value into a value of this type.Sourceimpl Debug for Uint32Struct
impl Debug for Uint32Struct
Sourceimpl<'a, ___E> Encode<Uint32Struct, ___E> for &'a Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint32Struct, ___E> for &'a Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint32Struct, ___E> for Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint32Struct, ___E> for Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint32Struct>, ___E> for &'a Uint32Struct
impl<'a, ___E> EncodeOption<Box<'static, Uint32Struct>, ___E> for &'a Uint32Struct
Sourcefn encode_option(
this: Option<&'a Uint32Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Uint32Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint32Struct>, ___E> for Uint32Struct
impl<___E> EncodeOption<Box<'static, Uint32Struct>, ___E> for Uint32Struct
Sourcefn encode_option(
this: Option<Uint32Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Uint32Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint32Struct> for Uint32Struct
impl FromWire<Uint32Struct> for Uint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
Sourcefn from_wire(wire: Uint32Struct) -> Uint32Struct
fn from_wire(wire: Uint32Struct) -> Uint32Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint32Struct> for Uint32Struct
impl FromWireRef<Uint32Struct> for Uint32Struct
Sourcefn from_wire_ref(wire: &Uint32Struct) -> Uint32Struct
fn from_wire_ref(wire: &Uint32Struct) -> Uint32Struct
Converts the given reference to this type.
Sourceimpl Hash for Uint32Struct
impl Hash for Uint32Struct
Sourceimpl Ord for Uint32Struct
impl Ord for Uint32Struct
Sourcefn cmp(&self, other: &Uint32Struct) -> Ordering
fn cmp(&self, other: &Uint32Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint32Struct
impl PartialEq for Uint32Struct
Sourceimpl PartialOrd for Uint32Struct
impl PartialOrd for Uint32Struct
impl Copy for Uint32Struct
impl Eq for Uint32Struct
impl StructuralPartialEq for Uint32Struct