#[repr(C)]pub struct Uint64Struct {
pub val: u64,
}Fields
val: u64Trait Implementations
Sourceimpl Clone for Uint64Struct
impl Clone for Uint64Struct
Sourcefn clone(&self) -> Uint64Struct
fn clone(&self) -> Uint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint64Struct> for Uint64Struct
impl CompatFrom<Uint64Struct> for Uint64Struct
Sourcefn compat_from(value: Uint64Struct) -> Uint64Struct
fn compat_from(value: Uint64Struct) -> Uint64Struct
Converts
value into a value of this type.Sourceimpl Debug for Uint64Struct
impl Debug for Uint64Struct
Sourceimpl<'a, ___E> Encode<Uint64Struct, ___E> for &'a Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint64Struct, ___E> for &'a Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint64Struct, ___E> for Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint64Struct, ___E> for Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint64Struct>, ___E> for &'a Uint64Struct
impl<'a, ___E> EncodeOption<Box<'static, Uint64Struct>, ___E> for &'a Uint64Struct
Sourcefn encode_option(
this: Option<&'a Uint64Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Uint64Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint64Struct>, ___E> for Uint64Struct
impl<___E> EncodeOption<Box<'static, Uint64Struct>, ___E> for Uint64Struct
Sourcefn encode_option(
this: Option<Uint64Struct>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Uint64Struct>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint64Struct> for Uint64Struct
impl FromWire<Uint64Struct> for Uint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
Sourcefn from_wire(wire: Uint64Struct) -> Uint64Struct
fn from_wire(wire: Uint64Struct) -> Uint64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint64Struct> for Uint64Struct
impl FromWireRef<Uint64Struct> for Uint64Struct
Sourcefn from_wire_ref(wire: &Uint64Struct) -> Uint64Struct
fn from_wire_ref(wire: &Uint64Struct) -> Uint64Struct
Converts the given reference to this type.
Sourceimpl Hash for Uint64Struct
impl Hash for Uint64Struct
Sourceimpl Ord for Uint64Struct
impl Ord for Uint64Struct
Sourcefn cmp(&self, other: &Uint64Struct) -> Ordering
fn cmp(&self, other: &Uint64Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint64Struct
impl PartialEq for Uint64Struct
Sourceimpl PartialOrd for Uint64Struct
impl PartialOrd for Uint64Struct
impl Copy for Uint64Struct
impl Eq for Uint64Struct
impl StructuralPartialEq for Uint64Struct