pub struct Uint8Uint16Uint32Uint64 {
pub f1: u8,
pub f2: u16,
pub f3: u32,
pub f4: u64,
}Fields
f1: u8f2: u16f3: u32f4: u64Trait Implementations
Sourceimpl Clone for Uint8Uint16Uint32Uint64
impl Clone for Uint8Uint16Uint32Uint64
Sourcefn clone(&self) -> Uint8Uint16Uint32Uint64
fn clone(&self) -> Uint8Uint16Uint32Uint64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
impl CompatFrom<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
Sourcefn compat_from(value: Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
fn compat_from(value: Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
Converts
value into a value of this type.Sourceimpl Debug for Uint8Uint16Uint32Uint64
impl Debug for Uint8Uint16Uint32Uint64
Sourceimpl<'a, ___E> Encode<Uint8Uint16Uint32Uint64, ___E> for &'a Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8Uint16Uint32Uint64, ___E> for &'a Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint8Uint16Uint32Uint64>, ___E> for &'a Uint8Uint16Uint32Uint64
impl<'a, ___E> EncodeOption<Box<'static, Uint8Uint16Uint32Uint64>, ___E> for &'a Uint8Uint16Uint32Uint64
Sourcefn encode_option(
this: Option<&'a Uint8Uint16Uint32Uint64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8Uint16Uint32Uint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Uint8Uint16Uint32Uint64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8Uint16Uint32Uint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint8Uint16Uint32Uint64>, ___E> for Uint8Uint16Uint32Uint64
impl<___E> EncodeOption<Box<'static, Uint8Uint16Uint32Uint64>, ___E> for Uint8Uint16Uint32Uint64
Sourcefn encode_option(
this: Option<Uint8Uint16Uint32Uint64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8Uint16Uint32Uint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Uint8Uint16Uint32Uint64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8Uint16Uint32Uint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
impl FromWire<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
Sourcefn from_wire(wire: Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
fn from_wire(wire: Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
impl FromWireRef<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
Sourcefn from_wire_ref(wire: &Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
fn from_wire_ref(wire: &Uint8Uint16Uint32Uint64) -> Uint8Uint16Uint32Uint64
Converts the given reference to this type.
Sourceimpl Hash for Uint8Uint16Uint32Uint64
impl Hash for Uint8Uint16Uint32Uint64
Sourceimpl Ord for Uint8Uint16Uint32Uint64
impl Ord for Uint8Uint16Uint32Uint64
Sourcefn cmp(&self, other: &Uint8Uint16Uint32Uint64) -> Ordering
fn cmp(&self, other: &Uint8Uint16Uint32Uint64) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint8Uint16Uint32Uint64
impl PartialEq for Uint8Uint16Uint32Uint64
Sourceimpl PartialOrd for Uint8Uint16Uint32Uint64
impl PartialOrd for Uint8Uint16Uint32Uint64
impl Copy for Uint8Uint16Uint32Uint64
impl Eq for Uint8Uint16Uint32Uint64
impl StructuralPartialEq for Uint8Uint16Uint32Uint64