pub struct UnboundedNullableVectorOfUint32s {
pub vu0: Option<Vec<u32>>,
}Fields
vu0: Option<Vec<u32>>Trait Implementations
Sourceimpl Clone for UnboundedNullableVectorOfUint32s
impl Clone for UnboundedNullableVectorOfUint32s
Sourcefn clone(&self) -> UnboundedNullableVectorOfUint32s
fn clone(&self) -> UnboundedNullableVectorOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<UnboundedNullableVectorOfUint32s> for UnboundedNullableVectorOfUint32s
impl CompatFrom<UnboundedNullableVectorOfUint32s> for UnboundedNullableVectorOfUint32s
Sourcefn compat_from(
value: UnboundedNullableVectorOfUint32s,
) -> UnboundedNullableVectorOfUint32s
fn compat_from( value: UnboundedNullableVectorOfUint32s, ) -> UnboundedNullableVectorOfUint32s
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<UnboundedNullableVectorOfUint32s<'static>, ___E> for &'a UnboundedNullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<UnboundedNullableVectorOfUint32s<'static>, ___E> for &'a UnboundedNullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UnboundedNullableVectorOfUint32s<'static>, ___E> for UnboundedNullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<UnboundedNullableVectorOfUint32s<'static>, ___E> for UnboundedNullableVectorOfUint32swhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnboundedNullableVectorOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnboundedNullableVectorOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UnboundedNullableVectorOfUint32s<'static>>, ___E> for &'a UnboundedNullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a UnboundedNullableVectorOfUint32s: Encode<UnboundedNullableVectorOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, UnboundedNullableVectorOfUint32s<'static>>, ___E> for &'a UnboundedNullableVectorOfUint32swhere
___E: Encoder + ?Sized,
&'a UnboundedNullableVectorOfUint32s: Encode<UnboundedNullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a UnboundedNullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a UnboundedNullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UnboundedNullableVectorOfUint32s<'static>>, ___E> for UnboundedNullableVectorOfUint32swhere
___E: Encoder + ?Sized,
UnboundedNullableVectorOfUint32s: Encode<UnboundedNullableVectorOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnboundedNullableVectorOfUint32s<'static>>, ___E> for UnboundedNullableVectorOfUint32swhere
___E: Encoder + ?Sized,
UnboundedNullableVectorOfUint32s: Encode<UnboundedNullableVectorOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<UnboundedNullableVectorOfUint32s>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<UnboundedNullableVectorOfUint32s>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnboundedNullableVectorOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnboundedNullableVectorOfUint32s<'de>> for UnboundedNullableVectorOfUint32s
impl<'de> FromWire<UnboundedNullableVectorOfUint32s<'de>> for UnboundedNullableVectorOfUint32s
Sourcefn from_wire(
wire: UnboundedNullableVectorOfUint32s<'de>,
) -> UnboundedNullableVectorOfUint32s
fn from_wire( wire: UnboundedNullableVectorOfUint32s<'de>, ) -> UnboundedNullableVectorOfUint32s
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<UnboundedNullableVectorOfUint32s<'de>> for UnboundedNullableVectorOfUint32s
impl<'de> FromWireRef<UnboundedNullableVectorOfUint32s<'de>> for UnboundedNullableVectorOfUint32s
Sourcefn from_wire_ref(
wire: &UnboundedNullableVectorOfUint32s<'de>,
) -> UnboundedNullableVectorOfUint32s
fn from_wire_ref( wire: &UnboundedNullableVectorOfUint32s<'de>, ) -> UnboundedNullableVectorOfUint32s
Converts the given reference to this type.
Sourceimpl Ord for UnboundedNullableVectorOfUint32s
impl Ord for UnboundedNullableVectorOfUint32s
Sourcefn cmp(&self, other: &UnboundedNullableVectorOfUint32s) -> Ordering
fn cmp(&self, other: &UnboundedNullableVectorOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UnboundedNullableVectorOfUint32s
impl PartialEq for UnboundedNullableVectorOfUint32s
Sourcefn eq(&self, other: &UnboundedNullableVectorOfUint32s) -> bool
fn eq(&self, other: &UnboundedNullableVectorOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UnboundedNullableVectorOfUint32s
impl PartialOrd for UnboundedNullableVectorOfUint32s
impl Eq for UnboundedNullableVectorOfUint32s
impl StructuralPartialEq for UnboundedNullableVectorOfUint32s