pub struct VectorOfUint64 {
pub v: Vec<u64>,
}Fields
v: Vec<u64>Trait Implementations
Sourceimpl Clone for VectorOfUint64
impl Clone for VectorOfUint64
Sourcefn clone(&self) -> VectorOfUint64
fn clone(&self) -> VectorOfUint64
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorOfUint64
impl Debug for VectorOfUint64
Sourceimpl<___E> Encode<VectorOfUint64<'static>, ___E> for VectorOfUint64where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<VectorOfUint64<'static>, ___E> for VectorOfUint64where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorOfUint64<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorOfUint64<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<VectorOfUint64<'static>, ___E> for &'a VectorOfUint64where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<VectorOfUint64<'static>, ___E> for &'a VectorOfUint64where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorOfUint64<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorOfUint64<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, VectorOfUint64<'static>>, ___E> for VectorOfUint64
impl<___E> EncodeOption<Box<'static, VectorOfUint64<'static>>, ___E> for VectorOfUint64
Sourcefn encode_option(
this: Option<VectorOfUint64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorOfUint64<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<VectorOfUint64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorOfUint64<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, VectorOfUint64<'static>>, ___E> for &'a VectorOfUint64
impl<'a, ___E> EncodeOption<Box<'static, VectorOfUint64<'static>>, ___E> for &'a VectorOfUint64
Sourcefn encode_option(
this: Option<&'a VectorOfUint64>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorOfUint64<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a VectorOfUint64>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorOfUint64<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for VectorOfUint64
Sourceimpl<'de> FromWire<VectorOfUint64<'de>> for VectorOfUint64
impl<'de> FromWire<VectorOfUint64<'de>> for VectorOfUint64
Sourcefn from_wire(wire: VectorOfUint64<'de>) -> VectorOfUint64
fn from_wire(wire: VectorOfUint64<'de>) -> VectorOfUint64
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<VectorOfUint64<'de>> for VectorOfUint64
impl<'de> FromWireRef<VectorOfUint64<'de>> for VectorOfUint64
Sourcefn from_wire_ref(wire: &VectorOfUint64<'de>) -> VectorOfUint64
fn from_wire_ref(wire: &VectorOfUint64<'de>) -> VectorOfUint64
Converts the given reference to this type.
Sourceimpl Hash for VectorOfUint64
impl Hash for VectorOfUint64
Sourceimpl Ord for VectorOfUint64
impl Ord for VectorOfUint64
Sourcefn cmp(&self, other: &VectorOfUint64) -> Ordering
fn cmp(&self, other: &VectorOfUint64) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VectorOfUint64
impl PartialEq for VectorOfUint64
Sourcefn eq(&self, other: &VectorOfUint64) -> bool
fn eq(&self, other: &VectorOfUint64) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VectorOfUint64
impl PartialOrd for VectorOfUint64
impl StructuralPartialEq for VectorOfUint64