#[repr(C)]pub struct AliasedBool {
pub value: bool,
}Expand description
The wire type corresponding to AliasedBool.
Fields
value: boolTrait Implementations
Sourceimpl Clone for AliasedBool
impl Clone for AliasedBool
Sourcefn clone(&self) -> AliasedBool
fn clone(&self) -> AliasedBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for AliasedBool
impl Constrained for AliasedBool
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, AliasedBool>,
_: <AliasedBool as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, AliasedBool>, _: <AliasedBool as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for AliasedBool
impl Debug for AliasedBool
Sourceimpl<___D> Decode<___D> for AliasedBoolwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for AliasedBoolwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<AliasedBool, ___E> for &'a AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedBool, ___E> for &'a AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedBool, ___E> for AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedBool, ___E> for AliasedBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
const COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<AliasedBool, ___E> for AliasedBool<T0>
impl<___E, T0> Encode<AliasedBool, ___E> for AliasedBool<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<AliasedBool> for AliasedBool
impl FromWire<AliasedBool> for AliasedBool
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
const COPY_OPTIMIZATION: CopyOptimization<AliasedBool, AliasedBool>
Sourcefn from_wire(wire: AliasedBool) -> AliasedBool
fn from_wire(wire: AliasedBool) -> AliasedBool
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedBool> for AliasedBool
impl FromWireRef<AliasedBool> for AliasedBool
Sourcefn from_wire_ref(wire: &AliasedBool) -> AliasedBool
fn from_wire_ref(wire: &AliasedBool) -> AliasedBool
Converts the given reference to this type.
Sourceimpl IntoNatural for AliasedBool
impl IntoNatural for AliasedBool
Sourcetype Natural = AliasedBool
type Natural = AliasedBool
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for AliasedBool
impl Wire for AliasedBool
Sourcetype Narrowed<'de> = AliasedBool
type Narrowed<'de> = AliasedBool
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<AliasedBool>)
fn zero_padding(out_: &mut MaybeUninit<AliasedBool>)
Writes zeroes to the padding for this type, if any.