#[repr(C)]pub struct AliasedStruct {
pub value: AnotherEmptyStruct,
}Expand description
The wire type corresponding to AliasedStruct.
Fields
value: AnotherEmptyStructTrait Implementations
Sourceimpl Clone for AliasedStruct
impl Clone for AliasedStruct
Sourcefn clone(&self) -> AliasedStruct
fn clone(&self) -> AliasedStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for AliasedStruct
impl Constrained for AliasedStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, AliasedStruct>,
_: <AliasedStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, AliasedStruct>, _: <AliasedStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for AliasedStruct
impl Debug for AliasedStruct
Sourceimpl<___D> Decode<___D> for AliasedStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for AliasedStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<AliasedStruct, ___E> for &'a AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedStruct, ___E> for &'a AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedStruct, ___E> for AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedStruct, ___E> for AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, AliasedStruct>
const COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, AliasedStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<AliasedStruct, ___E> for AliasedStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<AnotherEmptyStruct, ___E>,
impl<___E, T0> Encode<AliasedStruct, ___E> for AliasedStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<AnotherEmptyStruct, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<AliasedStruct> for AliasedStruct
impl FromWire<AliasedStruct> for AliasedStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, AliasedStruct>
const COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, AliasedStruct>
Sourcefn from_wire(wire: AliasedStruct) -> AliasedStruct
fn from_wire(wire: AliasedStruct) -> AliasedStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedStruct> for AliasedStruct
impl FromWireRef<AliasedStruct> for AliasedStruct
Sourcefn from_wire_ref(wire: &AliasedStruct) -> AliasedStruct
fn from_wire_ref(wire: &AliasedStruct) -> AliasedStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for AliasedStruct
impl IntoNatural for AliasedStruct
Sourcetype Natural = AliasedStruct
type Natural = AliasedStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for AliasedStruct
impl Wire for AliasedStruct
Sourcetype Narrowed<'de> = AliasedStruct
type Narrowed<'de> = AliasedStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<AliasedStruct>)
fn zero_padding(out_: &mut MaybeUninit<AliasedStruct>)
Writes zeroes to the padding for this type, if any.