#[repr(C)]pub struct AliasedUint64 {
pub value: Uint64,
}Expand description
The wire type corresponding to AliasedUint64.
Fields
value: Uint64Trait Implementations
Sourceimpl Clone for AliasedUint64
impl Clone for AliasedUint64
Sourcefn clone(&self) -> AliasedUint64
fn clone(&self) -> AliasedUint64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for AliasedUint64
impl Constrained for AliasedUint64
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, AliasedUint64>,
_: <AliasedUint64 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, AliasedUint64>, _: <AliasedUint64 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for AliasedUint64
impl Debug for AliasedUint64
Sourceimpl<___D> Decode<___D> for AliasedUint64where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for AliasedUint64where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<AliasedUint64, ___E> for &'a AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedUint64, ___E> for &'a AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedUint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedUint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedUint64, ___E> for AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedUint64, ___E> for AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, AliasedUint64>
const COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, AliasedUint64>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedUint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedUint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<AliasedUint64, ___E> for AliasedUint64<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<AliasedUint64, ___E> for AliasedUint64<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedUint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedUint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<AliasedUint64> for AliasedUint64
impl FromWire<AliasedUint64> for AliasedUint64
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, AliasedUint64>
const COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, AliasedUint64>
Sourcefn from_wire(wire: AliasedUint64) -> AliasedUint64
fn from_wire(wire: AliasedUint64) -> AliasedUint64
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedUint64> for AliasedUint64
impl FromWireRef<AliasedUint64> for AliasedUint64
Sourcefn from_wire_ref(wire: &AliasedUint64) -> AliasedUint64
fn from_wire_ref(wire: &AliasedUint64) -> AliasedUint64
Converts the given reference to this type.
Sourceimpl IntoNatural for AliasedUint64
impl IntoNatural for AliasedUint64
Sourcetype Natural = AliasedUint64
type Natural = AliasedUint64
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for AliasedUint64
impl Wire for AliasedUint64
Sourcetype Narrowed<'de> = AliasedUint64
type Narrowed<'de> = AliasedUint64
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<AliasedUint64>)
fn zero_padding(out_: &mut MaybeUninit<AliasedUint64>)
Writes zeroes to the padding for this type, if any.