#[repr(C)]pub struct ArrayOfArrayOfNonnullableHandles {
pub handles: [[NullableHandle; 3]; 4],
}Expand description
The wire type corresponding to ArrayOfArrayOfNonnullableHandles.
Fields
handles: [[NullableHandle; 3]; 4]Trait Implementations
Sourceimpl Constrained for ArrayOfArrayOfNonnullableHandles
impl Constrained for ArrayOfArrayOfNonnullableHandles
Sourceimpl<___D> Decode<___D> for ArrayOfArrayOfNonnullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ArrayOfArrayOfNonnullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ArrayOfArrayOfNonnullableHandles, ___E> for ArrayOfArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ArrayOfArrayOfNonnullableHandles, ___E> for ArrayOfArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfArrayOfNonnullableHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfArrayOfNonnullableHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfArrayOfNonnullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfArrayOfNonnullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ArrayOfArrayOfNonnullableHandles, ___E> for ArrayOfArrayOfNonnullableHandles<T0>
impl<___E, T0> Encode<ArrayOfArrayOfNonnullableHandles, ___E> for ArrayOfArrayOfNonnullableHandles<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfArrayOfNonnullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfArrayOfNonnullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayOfArrayOfNonnullableHandles> for ArrayOfArrayOfNonnullableHandles
impl FromWire<ArrayOfArrayOfNonnullableHandles> for ArrayOfArrayOfNonnullableHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArrayOfArrayOfNonnullableHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<ArrayOfArrayOfNonnullableHandles, Self>
Sourcefn from_wire(wire: ArrayOfArrayOfNonnullableHandles) -> Self
fn from_wire(wire: ArrayOfArrayOfNonnullableHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ArrayOfArrayOfNonnullableHandles
impl IntoNatural for ArrayOfArrayOfNonnullableHandles
Sourcetype Natural = ArrayOfArrayOfNonnullableHandles
type Natural = ArrayOfArrayOfNonnullableHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayOfArrayOfNonnullableHandles
impl Wire for ArrayOfArrayOfNonnullableHandles
Sourcetype Narrowed<'de> = ArrayOfArrayOfNonnullableHandles
type Narrowed<'de> = ArrayOfArrayOfNonnullableHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.