#[repr(C)]pub struct ArrayOfHandles {
pub a: [NullableHandle; 3],
}Expand description
The wire type corresponding to ArrayOfHandles.
Fields
a: [NullableHandle; 3]Trait Implementations
Sourceimpl Constrained for ArrayOfHandles
impl Constrained for ArrayOfHandles
Sourceimpl Debug for ArrayOfHandles
impl Debug for ArrayOfHandles
Sourceimpl<___D> Decode<___D> for ArrayOfHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ArrayOfHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ArrayOfHandles, ___E> for ArrayOfHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ArrayOfHandles, ___E> for ArrayOfHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ArrayOfHandles, ___E> for ArrayOfHandles<T0>
impl<___E, T0> Encode<ArrayOfHandles, ___E> for ArrayOfHandles<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayOfHandles> for ArrayOfHandles
impl FromWire<ArrayOfHandles> for ArrayOfHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArrayOfHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<ArrayOfHandles, Self>
Sourcefn from_wire(wire: ArrayOfHandles) -> Self
fn from_wire(wire: ArrayOfHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ArrayOfHandles
impl IntoNatural for ArrayOfHandles
Sourcetype Natural = ArrayOfHandles
type Natural = ArrayOfHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayOfHandles
impl Wire for ArrayOfHandles
Sourcetype Narrowed<'de> = ArrayOfHandles
type Narrowed<'de> = ArrayOfHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.