#[repr(C)]pub struct ArrayOfNonnullableHandles {
pub handles: [NullableHandle; 4],
}Expand description
The wire type corresponding to ArrayOfNonnullableHandles.
Fields
handles: [NullableHandle; 4]Trait Implementations
Sourceimpl Constrained for ArrayOfNonnullableHandles
impl Constrained for ArrayOfNonnullableHandles
Sourceimpl Debug for ArrayOfNonnullableHandles
impl Debug for ArrayOfNonnullableHandles
Sourceimpl<___D> Decode<___D> for ArrayOfNonnullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ArrayOfNonnullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ArrayOfNonnullableHandles, ___E> for ArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ArrayOfNonnullableHandles, ___E> for ArrayOfNonnullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfNonnullableHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfNonnullableHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfNonnullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfNonnullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ArrayOfNonnullableHandles, ___E> for ArrayOfNonnullableHandles<T0>
impl<___E, T0> Encode<ArrayOfNonnullableHandles, ___E> for ArrayOfNonnullableHandles<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfNonnullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfNonnullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayOfNonnullableHandles> for ArrayOfNonnullableHandles
impl FromWire<ArrayOfNonnullableHandles> for ArrayOfNonnullableHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArrayOfNonnullableHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<ArrayOfNonnullableHandles, Self>
Sourcefn from_wire(wire: ArrayOfNonnullableHandles) -> Self
fn from_wire(wire: ArrayOfNonnullableHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ArrayOfNonnullableHandles
impl IntoNatural for ArrayOfNonnullableHandles
Sourcetype Natural = ArrayOfNonnullableHandles
type Natural = ArrayOfNonnullableHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayOfNonnullableHandles
impl Wire for ArrayOfNonnullableHandles
Sourcetype Narrowed<'de> = ArrayOfNonnullableHandles
type Narrowed<'de> = ArrayOfNonnullableHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.