#[repr(C)]pub struct ArrayOfNullableHandles {
pub handles: [OptionalNullableHandle; 5],
}Expand description
The wire type corresponding to ArrayOfNullableHandles.
Fields
handles: [OptionalNullableHandle; 5]Trait Implementations
Sourceimpl Constrained for ArrayOfNullableHandles
impl Constrained for ArrayOfNullableHandles
Sourceimpl Debug for ArrayOfNullableHandles
impl Debug for ArrayOfNullableHandles
Sourceimpl<___D> Decode<___D> for ArrayOfNullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ArrayOfNullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ArrayOfNullableHandles, ___E> for ArrayOfNullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ArrayOfNullableHandles, ___E> for ArrayOfNullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfNullableHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfNullableHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfNullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfNullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ArrayOfNullableHandles, ___E> for ArrayOfNullableHandles<T0>
impl<___E, T0> Encode<ArrayOfNullableHandles, ___E> for ArrayOfNullableHandles<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfNullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfNullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayOfNullableHandles> for ArrayOfNullableHandles
impl FromWire<ArrayOfNullableHandles> for ArrayOfNullableHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArrayOfNullableHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<ArrayOfNullableHandles, Self>
Sourcefn from_wire(wire: ArrayOfNullableHandles) -> Self
fn from_wire(wire: ArrayOfNullableHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ArrayOfNullableHandles
impl IntoNatural for ArrayOfNullableHandles
Sourcetype Natural = ArrayOfNullableHandles
type Natural = ArrayOfNullableHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayOfNullableHandles
impl Wire for ArrayOfNullableHandles
Sourcetype Narrowed<'de> = ArrayOfNullableHandles
type Narrowed<'de> = ArrayOfNullableHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.