#[repr(C)]pub struct ArrayOfOptionalHandles {
pub a: [OptionalNullableHandle; 3],
}Expand description
The wire type corresponding to ArrayOfOptionalHandles.
Fields
a: [OptionalNullableHandle; 3]Trait Implementations
Sourceimpl Constrained for ArrayOfOptionalHandles
impl Constrained for ArrayOfOptionalHandles
Sourceimpl Debug for ArrayOfOptionalHandles
impl Debug for ArrayOfOptionalHandles
Sourceimpl<___D> Decode<___D> for ArrayOfOptionalHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ArrayOfOptionalHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ArrayOfOptionalHandles, ___E> for ArrayOfOptionalHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ArrayOfOptionalHandles, ___E> for ArrayOfOptionalHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfOptionalHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, ArrayOfOptionalHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfOptionalHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfOptionalHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ArrayOfOptionalHandles, ___E> for ArrayOfOptionalHandles<T0>
impl<___E, T0> Encode<ArrayOfOptionalHandles, ___E> for ArrayOfOptionalHandles<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayOfOptionalHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayOfOptionalHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayOfOptionalHandles> for ArrayOfOptionalHandles
impl FromWire<ArrayOfOptionalHandles> for ArrayOfOptionalHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArrayOfOptionalHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<ArrayOfOptionalHandles, Self>
Sourcefn from_wire(wire: ArrayOfOptionalHandles) -> Self
fn from_wire(wire: ArrayOfOptionalHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ArrayOfOptionalHandles
impl IntoNatural for ArrayOfOptionalHandles
Sourcetype Natural = ArrayOfOptionalHandles
type Natural = ArrayOfOptionalHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayOfOptionalHandles
impl Wire for ArrayOfOptionalHandles
Sourcetype Narrowed<'de> = ArrayOfOptionalHandles
type Narrowed<'de> = ArrayOfOptionalHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.