#[repr(C)]pub struct ArrayWithInternalPadding {
pub v: [OneLayerStructWithPaddingAlign4; 2],
}Expand description
The wire type corresponding to ArrayWithInternalPadding.
Fields
v: [OneLayerStructWithPaddingAlign4; 2]Trait Implementations
Sourceimpl Clone for ArrayWithInternalPadding
impl Clone for ArrayWithInternalPadding
Sourcefn clone(&self) -> ArrayWithInternalPadding
fn clone(&self) -> ArrayWithInternalPadding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ArrayWithInternalPadding
impl Constrained for ArrayWithInternalPadding
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ArrayWithInternalPadding>,
_: <ArrayWithInternalPadding as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ArrayWithInternalPadding>, _: <ArrayWithInternalPadding as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ArrayWithInternalPadding
impl Debug for ArrayWithInternalPadding
Sourceimpl<___D> Decode<___D> for ArrayWithInternalPaddingwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ArrayWithInternalPaddingwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ArrayWithInternalPadding, ___E> for &'a ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ArrayWithInternalPadding, ___E> for &'a ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayWithInternalPadding>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayWithInternalPadding>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayWithInternalPadding>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayWithInternalPadding>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPadding<T0>
impl<___E, T0> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPadding<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayWithInternalPadding>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayWithInternalPadding>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl FromWire<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn from_wire(wire: ArrayWithInternalPadding) -> ArrayWithInternalPadding
fn from_wire(wire: ArrayWithInternalPadding) -> ArrayWithInternalPadding
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl FromWireRef<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn from_wire_ref(wire: &ArrayWithInternalPadding) -> ArrayWithInternalPadding
fn from_wire_ref(wire: &ArrayWithInternalPadding) -> ArrayWithInternalPadding
Converts the given reference to this type.
Sourceimpl IntoNatural for ArrayWithInternalPadding
impl IntoNatural for ArrayWithInternalPadding
Sourcetype Natural = ArrayWithInternalPadding
type Natural = ArrayWithInternalPadding
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArrayWithInternalPadding
impl Wire for ArrayWithInternalPadding
Sourcetype Narrowed<'de> = ArrayWithInternalPadding
type Narrowed<'de> = ArrayWithInternalPadding
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ArrayWithInternalPadding>)
fn zero_padding(out_: &mut MaybeUninit<ArrayWithInternalPadding>)
Writes zeroes to the padding for this type, if any.