#[repr(C)]pub struct EmptyBitsStruct {
pub b: EmptyBits,
}Expand description
The wire type corresponding to EmptyBitsStruct.
Fields
b: EmptyBitsTrait Implementations
Sourceimpl Clone for EmptyBitsStruct
impl Clone for EmptyBitsStruct
Sourcefn clone(&self) -> EmptyBitsStruct
fn clone(&self) -> EmptyBitsStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EmptyBitsStruct
impl Constrained for EmptyBitsStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EmptyBitsStruct>,
_: <EmptyBitsStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EmptyBitsStruct>, _: <EmptyBitsStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for EmptyBitsStruct
impl Debug for EmptyBitsStruct
Sourceimpl<___D> Decode<___D> for EmptyBitsStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EmptyBitsStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EmptyBitsStruct, ___E> for &'a EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmptyBitsStruct, ___E> for &'a EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyBitsStruct, ___E> for EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmptyBitsStruct, ___E> for EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, EmptyBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, EmptyBitsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EmptyBitsStruct, ___E> for EmptyBitsStruct<T0>
impl<___E, T0> Encode<EmptyBitsStruct, ___E> for EmptyBitsStruct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EmptyBitsStruct> for EmptyBitsStruct
impl FromWire<EmptyBitsStruct> for EmptyBitsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, EmptyBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, EmptyBitsStruct>
Sourcefn from_wire(wire: EmptyBitsStruct) -> EmptyBitsStruct
fn from_wire(wire: EmptyBitsStruct) -> EmptyBitsStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmptyBitsStruct> for EmptyBitsStruct
impl FromWireRef<EmptyBitsStruct> for EmptyBitsStruct
Sourcefn from_wire_ref(wire: &EmptyBitsStruct) -> EmptyBitsStruct
fn from_wire_ref(wire: &EmptyBitsStruct) -> EmptyBitsStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for EmptyBitsStruct
impl IntoNatural for EmptyBitsStruct
Sourcetype Natural = EmptyBitsStruct
type Natural = EmptyBitsStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EmptyBitsStruct
impl Wire for EmptyBitsStruct
Sourcetype Narrowed<'de> = EmptyBitsStruct
type Narrowed<'de> = EmptyBitsStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EmptyBitsStruct>)
fn zero_padding(out_: &mut MaybeUninit<EmptyBitsStruct>)
Writes zeroes to the padding for this type, if any.