#[repr(C)]pub struct EmptyStructsInArrayInStruct {
pub v: [EmptyStruct; 4],
}Expand description
The wire type corresponding to EmptyStructsInArrayInStruct.
Fields
v: [EmptyStruct; 4]Trait Implementations
Sourceimpl Clone for EmptyStructsInArrayInStruct
impl Clone for EmptyStructsInArrayInStruct
Sourcefn clone(&self) -> EmptyStructsInArrayInStruct
fn clone(&self) -> EmptyStructsInArrayInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EmptyStructsInArrayInStruct
impl Constrained for EmptyStructsInArrayInStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EmptyStructsInArrayInStruct>,
_: <EmptyStructsInArrayInStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EmptyStructsInArrayInStruct>, _: <EmptyStructsInArrayInStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for EmptyStructsInArrayInStruct
impl Debug for EmptyStructsInArrayInStruct
Sourceimpl<___D> Decode<___D> for EmptyStructsInArrayInStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EmptyStructsInArrayInStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EmptyStructsInArrayInStruct, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmptyStructsInArrayInStruct, ___E> for &'a EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStruct<T0>
impl<___E, T0> Encode<EmptyStructsInArrayInStruct, ___E> for EmptyStructsInArrayInStruct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
impl FromWire<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
const COPY_OPTIMIZATION: CopyOptimization<EmptyStructsInArrayInStruct, EmptyStructsInArrayInStruct>
Sourcefn from_wire(wire: EmptyStructsInArrayInStruct) -> EmptyStructsInArrayInStruct
fn from_wire(wire: EmptyStructsInArrayInStruct) -> EmptyStructsInArrayInStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
impl FromWireRef<EmptyStructsInArrayInStruct> for EmptyStructsInArrayInStruct
Sourcefn from_wire_ref(
wire: &EmptyStructsInArrayInStruct,
) -> EmptyStructsInArrayInStruct
fn from_wire_ref( wire: &EmptyStructsInArrayInStruct, ) -> EmptyStructsInArrayInStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for EmptyStructsInArrayInStruct
impl IntoNatural for EmptyStructsInArrayInStruct
Sourcetype Natural = EmptyStructsInArrayInStruct
type Natural = EmptyStructsInArrayInStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EmptyStructsInArrayInStruct
impl Wire for EmptyStructsInArrayInStruct
Sourcetype Narrowed<'de> = EmptyStructsInArrayInStruct
type Narrowed<'de> = EmptyStructsInArrayInStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>)
fn zero_padding(out_: &mut MaybeUninit<EmptyStructsInArrayInStruct>)
Writes zeroes to the padding for this type, if any.