#[repr(C)]pub struct EventWithDefaultRights {
pub h: Event,
}Expand description
The wire type corresponding to EventWithDefaultRights.
Fields
h: EventTrait Implementations
Sourceimpl Constrained for EventWithDefaultRights
impl Constrained for EventWithDefaultRights
Sourceimpl Debug for EventWithDefaultRights
impl Debug for EventWithDefaultRights
Sourceimpl<___D> Decode<___D> for EventWithDefaultRightswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for EventWithDefaultRightswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<EventWithDefaultRights, ___E> for EventWithDefaultRightswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<EventWithDefaultRights, ___E> for EventWithDefaultRightswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EventWithDefaultRights>
const COPY_OPTIMIZATION: CopyOptimization<Self, EventWithDefaultRights>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventWithDefaultRights>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventWithDefaultRights>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EventWithDefaultRights, ___E> for EventWithDefaultRights<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<EventWithDefaultRights, ___E> for EventWithDefaultRights<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventWithDefaultRights>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventWithDefaultRights>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EventWithDefaultRights> for EventWithDefaultRights
impl FromWire<EventWithDefaultRights> for EventWithDefaultRights
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EventWithDefaultRights, Self>
const COPY_OPTIMIZATION: CopyOptimization<EventWithDefaultRights, Self>
Sourcefn from_wire(wire: EventWithDefaultRights) -> Self
fn from_wire(wire: EventWithDefaultRights) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for EventWithDefaultRights
impl IntoNatural for EventWithDefaultRights
Sourcetype Natural = EventWithDefaultRights
type Natural = EventWithDefaultRights
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EventWithDefaultRights
impl Wire for EventWithDefaultRights
Sourcetype Narrowed<'de> = EventWithDefaultRights
type Narrowed<'de> = EventWithDefaultRights
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.