#[repr(C)]pub struct EventWithReducedRights {
pub h: Event,
}Expand description
The wire type corresponding to EventWithReducedRights.
Fields
h: EventTrait Implementations
Sourceimpl Constrained for EventWithReducedRights
impl Constrained for EventWithReducedRights
Sourceimpl Debug for EventWithReducedRights
impl Debug for EventWithReducedRights
Sourceimpl<___D> Decode<___D> for EventWithReducedRightswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for EventWithReducedRightswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<EventWithReducedRights, ___E> for EventWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<EventWithReducedRights, ___E> for EventWithReducedRightswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EventWithReducedRights>
const COPY_OPTIMIZATION: CopyOptimization<Self, EventWithReducedRights>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventWithReducedRights>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventWithReducedRights>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EventWithReducedRights, ___E> for EventWithReducedRights<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<EventWithReducedRights, ___E> for EventWithReducedRights<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventWithReducedRights>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventWithReducedRights>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EventWithReducedRights> for EventWithReducedRights
impl FromWire<EventWithReducedRights> for EventWithReducedRights
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EventWithReducedRights, Self>
const COPY_OPTIMIZATION: CopyOptimization<EventWithReducedRights, Self>
Sourcefn from_wire(wire: EventWithReducedRights) -> Self
fn from_wire(wire: EventWithReducedRights) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for EventWithReducedRights
impl IntoNatural for EventWithReducedRights
Sourcetype Natural = EventWithReducedRights
type Natural = EventWithReducedRights
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EventWithReducedRights
impl Wire for EventWithReducedRights
Sourcetype Narrowed<'de> = EventWithReducedRights
type Narrowed<'de> = EventWithReducedRights
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.