#[repr(C)]pub struct FileGetAttrResponse {
pub s: Int32,
pub attributes: NodeAttributes,
}Expand description
The wire type corresponding to FileGetAttrResponse.
Fields
s: Int32attributes: NodeAttributesTrait Implementations
Sourceimpl Clone for FileGetAttrResponse
impl Clone for FileGetAttrResponse
Sourcefn clone(&self) -> FileGetAttrResponse
fn clone(&self) -> FileGetAttrResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FileGetAttrResponse
impl Constrained for FileGetAttrResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, FileGetAttrResponse>,
_: <FileGetAttrResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, FileGetAttrResponse>, _: <FileGetAttrResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for FileGetAttrResponse
impl Debug for FileGetAttrResponse
Sourceimpl<___D> Decode<___D> for FileGetAttrResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FileGetAttrResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<FileGetAttrResponse, ___E> for &'a FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FileGetAttrResponse, ___E> for &'a FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileGetAttrResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileGetAttrResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileGetAttrResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileGetAttrResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<NodeAttributes, ___E>,
impl<___E, T0, T1> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<NodeAttributes, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileGetAttrResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileGetAttrResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FileGetAttrResponse> for FileGetAttrResponse
impl FromWire<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn from_wire(wire: FileGetAttrResponse) -> FileGetAttrResponse
fn from_wire(wire: FileGetAttrResponse) -> FileGetAttrResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FileGetAttrResponse> for FileGetAttrResponse
impl FromWireRef<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn from_wire_ref(wire: &FileGetAttrResponse) -> FileGetAttrResponse
fn from_wire_ref(wire: &FileGetAttrResponse) -> FileGetAttrResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for FileGetAttrResponse
impl IntoNatural for FileGetAttrResponse
Sourcetype Natural = FileGetAttrResponse
type Natural = FileGetAttrResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FileGetAttrResponse
impl Wire for FileGetAttrResponse
Sourcetype Narrowed<'de> = FileGetAttrResponse
type Narrowed<'de> = FileGetAttrResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<FileGetAttrResponse>)
fn zero_padding(out_: &mut MaybeUninit<FileGetAttrResponse>)
Writes zeroes to the padding for this type, if any.