#[repr(C)]pub struct FiveByteInArray {
pub elems: [FiveByte; 3],
}Expand description
The wire type corresponding to FiveByteInArray.
Fields
elems: [FiveByte; 3]Trait Implementations
Sourceimpl Clone for FiveByteInArray
impl Clone for FiveByteInArray
Sourcefn clone(&self) -> FiveByteInArray
fn clone(&self) -> FiveByteInArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FiveByteInArray
impl Constrained for FiveByteInArray
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, FiveByteInArray>,
_: <FiveByteInArray as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, FiveByteInArray>, _: <FiveByteInArray as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for FiveByteInArray
impl Debug for FiveByteInArray
Sourceimpl<___D> Decode<___D> for FiveByteInArraywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FiveByteInArraywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<FiveByteInArray, ___E> for &'a FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FiveByteInArray, ___E> for &'a FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FiveByteInArray, ___E> for FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FiveByteInArray, ___E> for FiveByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<FiveByteInArray, ___E> for FiveByteInArray<T0>
impl<___E, T0> Encode<FiveByteInArray, ___E> for FiveByteInArray<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FiveByteInArray> for FiveByteInArray
impl FromWire<FiveByteInArray> for FiveByteInArray
Sourcefn from_wire(wire: FiveByteInArray) -> FiveByteInArray
fn from_wire(wire: FiveByteInArray) -> FiveByteInArray
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FiveByteInArray> for FiveByteInArray
impl FromWireRef<FiveByteInArray> for FiveByteInArray
Sourcefn from_wire_ref(wire: &FiveByteInArray) -> FiveByteInArray
fn from_wire_ref(wire: &FiveByteInArray) -> FiveByteInArray
Converts the given reference to this type.
Sourceimpl IntoNatural for FiveByteInArray
impl IntoNatural for FiveByteInArray
Sourcetype Natural = FiveByteInArray
type Natural = FiveByteInArray
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FiveByteInArray
impl Wire for FiveByteInArray
Sourcetype Narrowed<'de> = FiveByteInArray
type Narrowed<'de> = FiveByteInArray
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<FiveByteInArray>)
fn zero_padding(out_: &mut MaybeUninit<FiveByteInArray>)
Writes zeroes to the padding for this type, if any.