#[repr(C)]pub struct GoldenBoolStruct {
pub v: bool,
}Expand description
The wire type corresponding to GoldenBoolStruct.
Fields
v: boolTrait Implementations
Sourceimpl Clone for GoldenBoolStruct
impl Clone for GoldenBoolStruct
Sourcefn clone(&self) -> GoldenBoolStruct
fn clone(&self) -> GoldenBoolStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenBoolStruct
impl Constrained for GoldenBoolStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GoldenBoolStruct>,
_: <GoldenBoolStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GoldenBoolStruct>, _: <GoldenBoolStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for GoldenBoolStruct
impl Debug for GoldenBoolStruct
Sourceimpl<___D> Decode<___D> for GoldenBoolStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenBoolStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenBoolStruct, ___E> for &'a GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenBoolStruct, ___E> for &'a GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBoolStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBoolStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenBoolStruct, ___E> for GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenBoolStruct, ___E> for GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, GoldenBoolStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, GoldenBoolStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBoolStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBoolStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenBoolStruct, ___E> for GoldenBoolStruct<T0>
impl<___E, T0> Encode<GoldenBoolStruct, ___E> for GoldenBoolStruct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBoolStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBoolStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenBoolStruct> for GoldenBoolStruct
impl FromWire<GoldenBoolStruct> for GoldenBoolStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, GoldenBoolStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, GoldenBoolStruct>
Sourcefn from_wire(wire: GoldenBoolStruct) -> GoldenBoolStruct
fn from_wire(wire: GoldenBoolStruct) -> GoldenBoolStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenBoolStruct> for GoldenBoolStruct
impl FromWireRef<GoldenBoolStruct> for GoldenBoolStruct
Sourcefn from_wire_ref(wire: &GoldenBoolStruct) -> GoldenBoolStruct
fn from_wire_ref(wire: &GoldenBoolStruct) -> GoldenBoolStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenBoolStruct
impl IntoNatural for GoldenBoolStruct
Sourcetype Natural = GoldenBoolStruct
type Natural = GoldenBoolStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenBoolStruct
impl Wire for GoldenBoolStruct
Sourcetype Narrowed<'de> = GoldenBoolStruct
type Narrowed<'de> = GoldenBoolStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GoldenBoolStruct>)
fn zero_padding(out_: &mut MaybeUninit<GoldenBoolStruct>)
Writes zeroes to the padding for this type, if any.