#[repr(C)]pub struct GoldenEnumStruct {
pub v: GoldenEnum,
}Expand description
The wire type corresponding to GoldenEnumStruct.
Fields
v: GoldenEnumTrait Implementations
Sourceimpl Clone for GoldenEnumStruct
impl Clone for GoldenEnumStruct
Sourcefn clone(&self) -> GoldenEnumStruct
fn clone(&self) -> GoldenEnumStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenEnumStruct
impl Constrained for GoldenEnumStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GoldenEnumStruct>,
_: <GoldenEnumStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GoldenEnumStruct>, _: <GoldenEnumStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for GoldenEnumStruct
impl Debug for GoldenEnumStruct
Sourceimpl<___D> Decode<___D> for GoldenEnumStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenEnumStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenEnumStruct, ___E> for &'a GoldenEnumStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenEnumStruct, ___E> for &'a GoldenEnumStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenEnumStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenEnumStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenEnumStruct, ___E> for GoldenEnumStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenEnumStruct, ___E> for GoldenEnumStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenEnumStruct, GoldenEnumStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenEnumStruct, GoldenEnumStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenEnumStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenEnumStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenEnumStruct, ___E> for GoldenEnumStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenEnum, ___E>,
impl<___E, T0> Encode<GoldenEnumStruct, ___E> for GoldenEnumStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenEnum, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenEnumStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenEnumStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenEnumStruct> for GoldenEnumStruct
impl FromWire<GoldenEnumStruct> for GoldenEnumStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenEnumStruct, GoldenEnumStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenEnumStruct, GoldenEnumStruct>
Sourcefn from_wire(wire: GoldenEnumStruct) -> GoldenEnumStruct
fn from_wire(wire: GoldenEnumStruct) -> GoldenEnumStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenEnumStruct> for GoldenEnumStruct
impl FromWireRef<GoldenEnumStruct> for GoldenEnumStruct
Sourcefn from_wire_ref(wire: &GoldenEnumStruct) -> GoldenEnumStruct
fn from_wire_ref(wire: &GoldenEnumStruct) -> GoldenEnumStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenEnumStruct
impl IntoNatural for GoldenEnumStruct
Sourcetype Natural = GoldenEnumStruct
type Natural = GoldenEnumStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenEnumStruct
impl Wire for GoldenEnumStruct
Sourcetype Narrowed<'de> = GoldenEnumStruct
type Narrowed<'de> = GoldenEnumStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GoldenEnumStruct>)
fn zero_padding(out_: &mut MaybeUninit<GoldenEnumStruct>)
Writes zeroes to the padding for this type, if any.