#[repr(C)]pub struct GoldenHandleBasicRightsStruct {
pub v: Event,
}Expand description
The wire type corresponding to GoldenHandleBasicRightsStruct.
Fields
v: EventTrait Implementations
Sourceimpl Constrained for GoldenHandleBasicRightsStruct
impl Constrained for GoldenHandleBasicRightsStruct
Sourceimpl<___D> Decode<___D> for GoldenHandleBasicRightsStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for GoldenHandleBasicRightsStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenHandleBasicRightsStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenHandleBasicRightsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
impl FromWire<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenHandleBasicRightsStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenHandleBasicRightsStruct, Self>
Sourcefn from_wire(wire: GoldenHandleBasicRightsStruct) -> Self
fn from_wire(wire: GoldenHandleBasicRightsStruct) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for GoldenHandleBasicRightsStruct
impl IntoNatural for GoldenHandleBasicRightsStruct
Sourcetype Natural = GoldenHandleBasicRightsStruct
type Natural = GoldenHandleBasicRightsStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenHandleBasicRightsStruct
impl Wire for GoldenHandleBasicRightsStruct
Sourcetype Narrowed<'de> = GoldenHandleBasicRightsStruct
type Narrowed<'de> = GoldenHandleBasicRightsStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.