#[repr(C)]pub struct GoldenNullableHandleStruct {
pub v: OptionalNullableHandle,
}Expand description
The wire type corresponding to GoldenNullableHandleStruct.
Fields
v: OptionalNullableHandleTrait Implementations
Sourceimpl Constrained for GoldenNullableHandleStruct
impl Constrained for GoldenNullableHandleStruct
Sourceimpl Debug for GoldenNullableHandleStruct
impl Debug for GoldenNullableHandleStruct
Sourceimpl<___D> Decode<___D> for GoldenNullableHandleStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for GoldenNullableHandleStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<GoldenNullableHandleStruct, ___E> for GoldenNullableHandleStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<GoldenNullableHandleStruct, ___E> for GoldenNullableHandleStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenNullableHandleStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenNullableHandleStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableHandleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableHandleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenNullableHandleStruct, ___E> for GoldenNullableHandleStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
impl<___E, T0> Encode<GoldenNullableHandleStruct, ___E> for GoldenNullableHandleStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableHandleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableHandleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenNullableHandleStruct> for GoldenNullableHandleStruct
impl FromWire<GoldenNullableHandleStruct> for GoldenNullableHandleStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenNullableHandleStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenNullableHandleStruct, Self>
Sourcefn from_wire(wire: GoldenNullableHandleStruct) -> Self
fn from_wire(wire: GoldenNullableHandleStruct) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for GoldenNullableHandleStruct
impl IntoNatural for GoldenNullableHandleStruct
Sourcetype Natural = GoldenNullableHandleStruct
type Natural = GoldenNullableHandleStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenNullableHandleStruct
impl Wire for GoldenNullableHandleStruct
Sourcetype Narrowed<'de> = GoldenNullableHandleStruct
type Narrowed<'de> = GoldenNullableHandleStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.