#[repr(C)]pub struct GoldenStructArrayStruct {
pub v: [GoldenIntStruct; 2],
}Expand description
The wire type corresponding to GoldenStructArrayStruct.
Fields
v: [GoldenIntStruct; 2]Trait Implementations
Sourceimpl Clone for GoldenStructArrayStruct
impl Clone for GoldenStructArrayStruct
Sourcefn clone(&self) -> GoldenStructArrayStruct
fn clone(&self) -> GoldenStructArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenStructArrayStruct
impl Constrained for GoldenStructArrayStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GoldenStructArrayStruct>,
_: <GoldenStructArrayStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GoldenStructArrayStruct>, _: <GoldenStructArrayStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for GoldenStructArrayStruct
impl Debug for GoldenStructArrayStruct
Sourceimpl<___D> Decode<___D> for GoldenStructArrayStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenStructArrayStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenStructArrayStruct, ___E> for &'a GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenStructArrayStruct, ___E> for &'a GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, GoldenStructArrayStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, GoldenStructArrayStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStruct<T0>
impl<___E, T0> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStruct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl FromWire<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, GoldenStructArrayStruct>
const COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, GoldenStructArrayStruct>
Sourcefn from_wire(wire: GoldenStructArrayStruct) -> GoldenStructArrayStruct
fn from_wire(wire: GoldenStructArrayStruct) -> GoldenStructArrayStruct
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl FromWireRef<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourcefn from_wire_ref(wire: &GoldenStructArrayStruct) -> GoldenStructArrayStruct
fn from_wire_ref(wire: &GoldenStructArrayStruct) -> GoldenStructArrayStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenStructArrayStruct
impl IntoNatural for GoldenStructArrayStruct
Sourcetype Natural = GoldenStructArrayStruct
type Natural = GoldenStructArrayStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenStructArrayStruct
impl Wire for GoldenStructArrayStruct
Sourcetype Narrowed<'de> = GoldenStructArrayStruct
type Narrowed<'de> = GoldenStructArrayStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GoldenStructArrayStruct>)
fn zero_padding(out_: &mut MaybeUninit<GoldenStructArrayStruct>)
Writes zeroes to the padding for this type, if any.