#[repr(C)]pub struct GoldenStructVectorStruct<'de> {
pub v: Vector<'de, GoldenIntStruct>,
}Expand description
The wire type corresponding to GoldenStructVectorStruct.
Fields
v: Vector<'de, GoldenIntStruct>Trait Implementations
Sourceimpl Constrained for GoldenStructVectorStruct<'_>
impl Constrained for GoldenStructVectorStruct<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GoldenStructVectorStruct<'_>>,
_: <GoldenStructVectorStruct<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GoldenStructVectorStruct<'_>>, _: <GoldenStructVectorStruct<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for GoldenStructVectorStruct<'de>
impl<'de> Debug for GoldenStructVectorStruct<'de>
Sourceimpl<'de, ___D> Decode<___D> for GoldenStructVectorStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for GoldenStructVectorStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenStructVectorStruct<'static>, ___E> for &'a GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<GoldenStructVectorStruct<'static>, ___E> for &'a GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, GoldenIntStruct>, ___E>,
impl<___E, T0> Encode<GoldenStructVectorStruct<'static>, ___E> for GoldenStructVectorStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, GoldenIntStruct>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
impl<'de> FromWire<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
Sourcefn from_wire(wire: GoldenStructVectorStruct<'de>) -> GoldenStructVectorStruct
fn from_wire(wire: GoldenStructVectorStruct<'de>) -> GoldenStructVectorStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
impl<'de> FromWireRef<GoldenStructVectorStruct<'de>> for GoldenStructVectorStruct
Sourcefn from_wire_ref(
wire: &GoldenStructVectorStruct<'de>,
) -> GoldenStructVectorStruct
fn from_wire_ref( wire: &GoldenStructVectorStruct<'de>, ) -> GoldenStructVectorStruct
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for GoldenStructVectorStruct<'de>
impl<'de> IntoNatural for GoldenStructVectorStruct<'de>
Sourcetype Natural = GoldenStructVectorStruct
type Natural = GoldenStructVectorStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenStructVectorStruct<'static>
impl Wire for GoldenStructVectorStruct<'static>
Sourcetype Narrowed<'de> = GoldenStructVectorStruct<'de>
type Narrowed<'de> = GoldenStructVectorStruct<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>)
fn zero_padding(out_: &mut MaybeUninit<GoldenStructVectorStruct<'static>>)
Writes zeroes to the padding for this type, if any.