#[repr(C)]pub struct GoldenUnionStruct {
pub v: GoldenUnion,
}Expand description
The wire type corresponding to GoldenUnionStruct.
Fields
v: GoldenUnionTrait Implementations
Sourceimpl Clone for GoldenUnionStruct
impl Clone for GoldenUnionStruct
Sourcefn clone(&self) -> GoldenUnionStruct
fn clone(&self) -> GoldenUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenUnionStruct
impl Constrained for GoldenUnionStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GoldenUnionStruct>,
_: <GoldenUnionStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GoldenUnionStruct>, _: <GoldenUnionStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for GoldenUnionStruct
impl Debug for GoldenUnionStruct
Sourceimpl<___D> Decode<___D> for GoldenUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenUnionStruct, ___E> for &'a GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenUnionStruct, ___E> for &'a GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenUnionStruct, ___E> for GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenUnionStruct, ___E> for GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<GoldenUnionStruct, ___E> for GoldenUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenUnion, ___E>,
impl<___E, T0> Encode<GoldenUnionStruct, ___E> for GoldenUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenUnion, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenUnionStruct> for GoldenUnionStruct
impl FromWire<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn from_wire(wire: GoldenUnionStruct) -> GoldenUnionStruct
fn from_wire(wire: GoldenUnionStruct) -> GoldenUnionStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<GoldenUnionStruct> for GoldenUnionStruct
impl FromWireRef<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn from_wire_ref(wire: &GoldenUnionStruct) -> GoldenUnionStruct
fn from_wire_ref(wire: &GoldenUnionStruct) -> GoldenUnionStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenUnionStruct
impl IntoNatural for GoldenUnionStruct
Sourcetype Natural = GoldenUnionStruct
type Natural = GoldenUnionStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenUnionStruct
impl Wire for GoldenUnionStruct
Sourcetype Narrowed<'de> = GoldenUnionStruct
type Narrowed<'de> = GoldenUnionStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GoldenUnionStruct>)
fn zero_padding(out_: &mut MaybeUninit<GoldenUnionStruct>)
Writes zeroes to the padding for this type, if any.