#[repr(C)]pub struct Int64Struct {
pub x: Int64,
}Expand description
The wire type corresponding to Int64Struct.
Fields
x: Int64Trait Implementations
Sourceimpl Clone for Int64Struct
impl Clone for Int64Struct
Sourcefn clone(&self) -> Int64Struct
fn clone(&self) -> Int64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Int64Struct
impl Constrained for Int64Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Int64Struct>,
_: <Int64Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Int64Struct>, _: <Int64Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Int64Struct
impl Debug for Int64Struct
Sourceimpl<___D> Decode<___D> for Int64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Int64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Int64Struct, ___E> for &'a Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Int64Struct, ___E> for &'a Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Int64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Int64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Int64Struct, ___E> for Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Int64Struct, ___E> for Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Int64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Int64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Int64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Int64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Int64Struct, ___E> for Int64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
impl<___E, T0> Encode<Int64Struct, ___E> for Int64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Int64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Int64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Int64Struct> for Int64Struct
impl FromWire<Int64Struct> for Int64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Int64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Int64Struct>
Sourcefn from_wire(wire: Int64Struct) -> Int64Struct
fn from_wire(wire: Int64Struct) -> Int64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Int64Struct> for Int64Struct
impl FromWireRef<Int64Struct> for Int64Struct
Sourcefn from_wire_ref(wire: &Int64Struct) -> Int64Struct
fn from_wire_ref(wire: &Int64Struct) -> Int64Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for Int64Struct
impl IntoNatural for Int64Struct
Sourcetype Natural = Int64Struct
type Natural = Int64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Int64Struct
impl Wire for Int64Struct
Sourcetype Narrowed<'de> = Int64Struct
type Narrowed<'de> = Int64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Int64Struct>)
fn zero_padding(out_: &mut MaybeUninit<Int64Struct>)
Writes zeroes to the padding for this type, if any.