#[repr(C)]pub struct LotsOfVectors<'de> {
pub v1: Vector<'de, Uint16>,
pub v2: Vector<'de, Uint32>,
pub v3: Vector<'de, Uint64>,
pub v4: Vector<'de, String<'de>>,
pub v5: Vector<'de, i8>,
pub v6: Vector<'de, Int16>,
pub v7: Vector<'de, Int32>,
pub v8: Vector<'de, Int64>,
pub v9: Vector<'de, bool>,
}Expand description
The wire type corresponding to LotsOfVectors.
Fields
v1: Vector<'de, Uint16>v2: Vector<'de, Uint32>v3: Vector<'de, Uint64>v4: Vector<'de, String<'de>>v5: Vector<'de, i8>v6: Vector<'de, Int16>v7: Vector<'de, Int32>v8: Vector<'de, Int64>v9: Vector<'de, bool>Trait Implementations
Sourceimpl Constrained for LotsOfVectors<'_>
impl Constrained for LotsOfVectors<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, LotsOfVectors<'_>>,
_: <LotsOfVectors<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, LotsOfVectors<'_>>, _: <LotsOfVectors<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for LotsOfVectors<'de>
impl<'de> Debug for LotsOfVectors<'de>
Sourceimpl<'de, ___D> Decode<___D> for LotsOfVectors<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for LotsOfVectors<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<LotsOfVectors<'static>, ___E> for &'a LotsOfVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<LotsOfVectors<'static>, ___E> for &'a LotsOfVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LotsOfVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LotsOfVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LotsOfVectors<'static>, ___E> for LotsOfVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<LotsOfVectors<'static>, ___E> for LotsOfVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LotsOfVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LotsOfVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8> Encode<LotsOfVectors<'static>, ___E> for LotsOfVectors<T0, T1, T2, T3, T4, T5, T6, T7, T8>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, Uint16>, ___E>,
T1: Encode<Vector<'static, Uint32>, ___E>,
T2: Encode<Vector<'static, Uint64>, ___E>,
T3: Encode<Vector<'static, String<'static>>, ___E>,
T4: Encode<Vector<'static, i8>, ___E>,
T5: Encode<Vector<'static, Int16>, ___E>,
T6: Encode<Vector<'static, Int32>, ___E>,
T7: Encode<Vector<'static, Int64>, ___E>,
T8: Encode<Vector<'static, bool>, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8> Encode<LotsOfVectors<'static>, ___E> for LotsOfVectors<T0, T1, T2, T3, T4, T5, T6, T7, T8>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, Uint16>, ___E>,
T1: Encode<Vector<'static, Uint32>, ___E>,
T2: Encode<Vector<'static, Uint64>, ___E>,
T3: Encode<Vector<'static, String<'static>>, ___E>,
T4: Encode<Vector<'static, i8>, ___E>,
T5: Encode<Vector<'static, Int16>, ___E>,
T6: Encode<Vector<'static, Int32>, ___E>,
T7: Encode<Vector<'static, Int64>, ___E>,
T8: Encode<Vector<'static, bool>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LotsOfVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LotsOfVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<LotsOfVectors<'de>> for LotsOfVectors
impl<'de> FromWire<LotsOfVectors<'de>> for LotsOfVectors
Sourcefn from_wire(wire: LotsOfVectors<'de>) -> LotsOfVectors
fn from_wire(wire: LotsOfVectors<'de>) -> LotsOfVectors
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<LotsOfVectors<'de>> for LotsOfVectors
impl<'de> FromWireRef<LotsOfVectors<'de>> for LotsOfVectors
Sourcefn from_wire_ref(wire: &LotsOfVectors<'de>) -> LotsOfVectors
fn from_wire_ref(wire: &LotsOfVectors<'de>) -> LotsOfVectors
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for LotsOfVectors<'de>
impl<'de> IntoNatural for LotsOfVectors<'de>
Sourcetype Natural = LotsOfVectors
type Natural = LotsOfVectors
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for LotsOfVectors<'static>
impl Wire for LotsOfVectors<'static>
Sourcetype Narrowed<'de> = LotsOfVectors<'de>
type Narrowed<'de> = LotsOfVectors<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<LotsOfVectors<'static>>)
fn zero_padding(out_: &mut MaybeUninit<LotsOfVectors<'static>>)
Writes zeroes to the padding for this type, if any.