#[repr(C)]pub struct MixedFieldsMessage {
pub header: TransactionHeader,
pub body: MixedFieldsBody,
}Expand description
The wire type corresponding to MixedFieldsMessage.
Fields
header: TransactionHeaderbody: MixedFieldsBodyTrait Implementations
Sourceimpl Clone for MixedFieldsMessage
impl Clone for MixedFieldsMessage
Sourcefn clone(&self) -> MixedFieldsMessage
fn clone(&self) -> MixedFieldsMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for MixedFieldsMessage
impl Constrained for MixedFieldsMessage
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, MixedFieldsMessage>,
_: <MixedFieldsMessage as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, MixedFieldsMessage>, _: <MixedFieldsMessage as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for MixedFieldsMessage
impl Debug for MixedFieldsMessage
Sourceimpl<___D> Decode<___D> for MixedFieldsMessagewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for MixedFieldsMessagewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<MixedFieldsMessage, ___E> for &'a MixedFieldsMessagewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MixedFieldsMessage, ___E> for &'a MixedFieldsMessagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsMessage>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsMessage>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MixedFieldsMessage, ___E> for MixedFieldsMessagewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MixedFieldsMessage, ___E> for MixedFieldsMessagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsMessage>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsMessage>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<MixedFieldsMessage, ___E> for MixedFieldsMessage<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TransactionHeader, ___E>,
T1: Encode<MixedFieldsBody, ___E>,
impl<___E, T0, T1> Encode<MixedFieldsMessage, ___E> for MixedFieldsMessage<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TransactionHeader, ___E>,
T1: Encode<MixedFieldsBody, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsMessage>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsMessage>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<MixedFieldsMessage> for MixedFieldsMessage
impl FromWire<MixedFieldsMessage> for MixedFieldsMessage
Sourcefn from_wire(wire: MixedFieldsMessage) -> MixedFieldsMessage
fn from_wire(wire: MixedFieldsMessage) -> MixedFieldsMessage
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<MixedFieldsMessage> for MixedFieldsMessage
impl FromWireRef<MixedFieldsMessage> for MixedFieldsMessage
Sourcefn from_wire_ref(wire: &MixedFieldsMessage) -> MixedFieldsMessage
fn from_wire_ref(wire: &MixedFieldsMessage) -> MixedFieldsMessage
Converts the given reference to this type.
Sourceimpl IntoNatural for MixedFieldsMessage
impl IntoNatural for MixedFieldsMessage
Sourcetype Natural = MixedFieldsMessage
type Natural = MixedFieldsMessage
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for MixedFieldsMessage
impl Wire for MixedFieldsMessage
Sourcetype Narrowed<'de> = MixedFieldsMessage
type Narrowed<'de> = MixedFieldsMessage
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<MixedFieldsMessage>)
fn zero_padding(out_: &mut MaybeUninit<MixedFieldsMessage>)
Writes zeroes to the padding for this type, if any.