#[repr(C)]pub struct MultipleNullableHandles {
pub data0: Uint32,
pub handle0: OptionalNullableHandle,
pub data1: Uint64,
pub handle1: OptionalChannel,
pub handle2: OptionalEvent,
pub data2: Uint64,
}Expand description
The wire type corresponding to MultipleNullableHandles.
Fields
data0: Uint32handle0: OptionalNullableHandledata1: Uint64handle1: OptionalChannelhandle2: OptionalEventdata2: Uint64Trait Implementations
Sourceimpl Constrained for MultipleNullableHandles
impl Constrained for MultipleNullableHandles
Sourceimpl Debug for MultipleNullableHandles
impl Debug for MultipleNullableHandles
Sourceimpl<___D> Decode<___D> for MultipleNullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for MultipleNullableHandleswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<MultipleNullableHandles, ___E> for MultipleNullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<MultipleNullableHandles, ___E> for MultipleNullableHandleswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MultipleNullableHandles>
const COPY_OPTIMIZATION: CopyOptimization<Self, MultipleNullableHandles>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleNullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleNullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<MultipleNullableHandles, ___E> for MultipleNullableHandles<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<OptionalNullableHandle, ___E>,
T2: Encode<Uint64, ___E>,
T3: Encode<OptionalChannel, ___E>,
T4: Encode<OptionalEvent, ___E>,
T5: Encode<Uint64, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5> Encode<MultipleNullableHandles, ___E> for MultipleNullableHandles<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<OptionalNullableHandle, ___E>,
T2: Encode<Uint64, ___E>,
T3: Encode<OptionalChannel, ___E>,
T4: Encode<OptionalEvent, ___E>,
T5: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleNullableHandles>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleNullableHandles>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<MultipleNullableHandles> for MultipleNullableHandles
impl FromWire<MultipleNullableHandles> for MultipleNullableHandles
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MultipleNullableHandles, Self>
const COPY_OPTIMIZATION: CopyOptimization<MultipleNullableHandles, Self>
Sourcefn from_wire(wire: MultipleNullableHandles) -> Self
fn from_wire(wire: MultipleNullableHandles) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for MultipleNullableHandles
impl IntoNatural for MultipleNullableHandles
Sourcetype Natural = MultipleNullableHandles
type Natural = MultipleNullableHandles
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for MultipleNullableHandles
impl Wire for MultipleNullableHandles
Sourcetype Narrowed<'de> = MultipleNullableHandles
type Narrowed<'de> = MultipleNullableHandles
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.