#[repr(C)]pub struct NonnullableHandle {
pub h: NullableHandle,
}Expand description
The wire type corresponding to NonnullableHandle.
Fields
h: NullableHandleTrait Implementations
Sourceimpl Constrained for NonnullableHandle
impl Constrained for NonnullableHandle
Sourceimpl Debug for NonnullableHandle
impl Debug for NonnullableHandle
Sourceimpl<___D> Decode<___D> for NonnullableHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for NonnullableHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<NonnullableHandle, ___E> for NonnullableHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<NonnullableHandle, ___E> for NonnullableHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, NonnullableHandle>
const COPY_OPTIMIZATION: CopyOptimization<Self, NonnullableHandle>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NonnullableHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NonnullableHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<NonnullableHandle, ___E> for NonnullableHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<NullableHandle, ___E>,
impl<___E, T0> Encode<NonnullableHandle, ___E> for NonnullableHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<NullableHandle, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NonnullableHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NonnullableHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<NonnullableHandle> for NonnullableHandle
impl FromWire<NonnullableHandle> for NonnullableHandle
Sourceconst COPY_OPTIMIZATION: CopyOptimization<NonnullableHandle, Self>
const COPY_OPTIMIZATION: CopyOptimization<NonnullableHandle, Self>
Sourcefn from_wire(wire: NonnullableHandle) -> Self
fn from_wire(wire: NonnullableHandle) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for NonnullableHandle
impl IntoNatural for NonnullableHandle
Sourcetype Natural = NonnullableHandle
type Natural = NonnullableHandle
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for NonnullableHandle
impl Wire for NonnullableHandle
Sourcetype Narrowed<'de> = NonnullableHandle
type Narrowed<'de> = NonnullableHandle
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.