#[repr(C)]pub struct NonnullableHandleArray {
pub handles: [NullableHandle; 4],
}Expand description
The wire type corresponding to NonnullableHandleArray.
Fields
handles: [NullableHandle; 4]Trait Implementations
Sourceimpl Constrained for NonnullableHandleArray
impl Constrained for NonnullableHandleArray
Sourceimpl Debug for NonnullableHandleArray
impl Debug for NonnullableHandleArray
Sourceimpl<___D> Decode<___D> for NonnullableHandleArraywhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for NonnullableHandleArraywhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<NonnullableHandleArray, ___E> for NonnullableHandleArraywhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<NonnullableHandleArray, ___E> for NonnullableHandleArraywhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, NonnullableHandleArray>
const COPY_OPTIMIZATION: CopyOptimization<Self, NonnullableHandleArray>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NonnullableHandleArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NonnullableHandleArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<NonnullableHandleArray, ___E> for NonnullableHandleArray<T0>
impl<___E, T0> Encode<NonnullableHandleArray, ___E> for NonnullableHandleArray<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NonnullableHandleArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NonnullableHandleArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<NonnullableHandleArray> for NonnullableHandleArray
impl FromWire<NonnullableHandleArray> for NonnullableHandleArray
Sourceconst COPY_OPTIMIZATION: CopyOptimization<NonnullableHandleArray, Self>
const COPY_OPTIMIZATION: CopyOptimization<NonnullableHandleArray, Self>
Sourcefn from_wire(wire: NonnullableHandleArray) -> Self
fn from_wire(wire: NonnullableHandleArray) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for NonnullableHandleArray
impl IntoNatural for NonnullableHandleArray
Sourcetype Natural = NonnullableHandleArray
type Natural = NonnullableHandleArray
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for NonnullableHandleArray
impl Wire for NonnullableHandleArray
Sourcetype Narrowed<'de> = NonnullableHandleArray
type Narrowed<'de> = NonnullableHandleArray
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.