#[repr(C)]pub struct NullableHandle {
pub h: OptionalNullableHandle,
}Expand description
The wire type corresponding to NullableHandle.
Fields
h: OptionalNullableHandleTrait Implementations
Sourceimpl Constrained for NullableHandle
impl Constrained for NullableHandle
Sourceimpl Debug for NullableHandle
impl Debug for NullableHandle
Sourceimpl<___D> Decode<___D> for NullableHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for NullableHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<NullableHandle, ___E> for NullableHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<NullableHandle, ___E> for NullableHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, NullableHandle>
const COPY_OPTIMIZATION: CopyOptimization<Self, NullableHandle>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NullableHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NullableHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<NullableHandle, ___E> for NullableHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
impl<___E, T0> Encode<NullableHandle, ___E> for NullableHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NullableHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NullableHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<NullableHandle> for NullableHandle
impl FromWire<NullableHandle> for NullableHandle
Sourceconst COPY_OPTIMIZATION: CopyOptimization<NullableHandle, Self>
const COPY_OPTIMIZATION: CopyOptimization<NullableHandle, Self>
Sourcefn from_wire(wire: NullableHandle) -> Self
fn from_wire(wire: NullableHandle) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for NullableHandle
impl IntoNatural for NullableHandle
Sourcetype Natural = NullableHandle
type Natural = NullableHandle
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for NullableHandle
impl Wire for NullableHandle
Sourcetype Narrowed<'de> = NullableHandle
type Narrowed<'de> = NullableHandle
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.