#[repr(C)]pub struct OneLayerStructNoPaddingAlign4 {
pub a: Uint16,
pub b: u8,
pub c: u8,
pub d: Uint32,
}Expand description
The wire type corresponding to OneLayerStructNoPaddingAlign4.
Fields
a: Uint16b: u8c: u8d: Uint32Trait Implementations
Sourceimpl Clone for OneLayerStructNoPaddingAlign4
impl Clone for OneLayerStructNoPaddingAlign4
Sourcefn clone(&self) -> OneLayerStructNoPaddingAlign4
fn clone(&self) -> OneLayerStructNoPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for OneLayerStructNoPaddingAlign4
impl Constrained for OneLayerStructNoPaddingAlign4
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, OneLayerStructNoPaddingAlign4>,
_: <OneLayerStructNoPaddingAlign4 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, OneLayerStructNoPaddingAlign4>, _: <OneLayerStructNoPaddingAlign4 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for OneLayerStructNoPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for OneLayerStructNoPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for &'a OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<OneLayerStructNoPaddingAlign4, ___E> for OneLayerStructNoPaddingAlign4<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
impl FromWire<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign4, OneLayerStructNoPaddingAlign4>
Sourcefn from_wire(
wire: OneLayerStructNoPaddingAlign4,
) -> OneLayerStructNoPaddingAlign4
fn from_wire( wire: OneLayerStructNoPaddingAlign4, ) -> OneLayerStructNoPaddingAlign4
Converts the given owned value to this type.
Sourceimpl FromWireRef<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
impl FromWireRef<OneLayerStructNoPaddingAlign4> for OneLayerStructNoPaddingAlign4
Sourcefn from_wire_ref(
wire: &OneLayerStructNoPaddingAlign4,
) -> OneLayerStructNoPaddingAlign4
fn from_wire_ref( wire: &OneLayerStructNoPaddingAlign4, ) -> OneLayerStructNoPaddingAlign4
Converts the given reference to this type.
Sourceimpl IntoNatural for OneLayerStructNoPaddingAlign4
impl IntoNatural for OneLayerStructNoPaddingAlign4
Sourcetype Natural = OneLayerStructNoPaddingAlign4
type Natural = OneLayerStructNoPaddingAlign4
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for OneLayerStructNoPaddingAlign4
impl Wire for OneLayerStructNoPaddingAlign4
Sourcetype Narrowed<'de> = OneLayerStructNoPaddingAlign4
type Narrowed<'de> = OneLayerStructNoPaddingAlign4
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>)
fn zero_padding(out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign4>)
Writes zeroes to the padding for this type, if any.