#[repr(C)]pub struct OneLayerStructWithBool {
pub a: bool,
pub b: u8,
pub c: Uint16,
pub d: Uint32,
}Expand description
The wire type corresponding to OneLayerStructWithBool.
Fields
a: boolb: u8c: Uint16d: Uint32Trait Implementations
Sourceimpl Clone for OneLayerStructWithBool
impl Clone for OneLayerStructWithBool
Sourcefn clone(&self) -> OneLayerStructWithBool
fn clone(&self) -> OneLayerStructWithBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for OneLayerStructWithBool
impl Constrained for OneLayerStructWithBool
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, OneLayerStructWithBool>,
_: <OneLayerStructWithBool as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, OneLayerStructWithBool>, _: <OneLayerStructWithBool as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for OneLayerStructWithBool
impl Debug for OneLayerStructWithBool
Sourceimpl<___D> Decode<___D> for OneLayerStructWithBoolwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for OneLayerStructWithBoolwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<OneLayerStructWithBool, ___E> for &'a OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithBool, ___E> for &'a OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBool<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<OneLayerStructWithBool, ___E> for OneLayerStructWithBool<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<OneLayerStructWithBool> for OneLayerStructWithBool
impl FromWire<OneLayerStructWithBool> for OneLayerStructWithBool
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructWithBool, OneLayerStructWithBool>
Sourcefn from_wire(wire: OneLayerStructWithBool) -> OneLayerStructWithBool
fn from_wire(wire: OneLayerStructWithBool) -> OneLayerStructWithBool
Converts the given owned value to this type.
Sourceimpl FromWireRef<OneLayerStructWithBool> for OneLayerStructWithBool
impl FromWireRef<OneLayerStructWithBool> for OneLayerStructWithBool
Sourcefn from_wire_ref(wire: &OneLayerStructWithBool) -> OneLayerStructWithBool
fn from_wire_ref(wire: &OneLayerStructWithBool) -> OneLayerStructWithBool
Converts the given reference to this type.
Sourceimpl IntoNatural for OneLayerStructWithBool
impl IntoNatural for OneLayerStructWithBool
Sourcetype Natural = OneLayerStructWithBool
type Natural = OneLayerStructWithBool
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for OneLayerStructWithBool
impl Wire for OneLayerStructWithBool
Sourcetype Narrowed<'de> = OneLayerStructWithBool
type Narrowed<'de> = OneLayerStructWithBool
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<OneLayerStructWithBool>)
fn zero_padding(out_: &mut MaybeUninit<OneLayerStructWithBool>)
Writes zeroes to the padding for this type, if any.