#[repr(C)]pub struct OneLayerStructWithPaddingAlign4 {
pub a: Uint16,
pub b: u8,
pub c: Uint32,
}Expand description
The wire type corresponding to OneLayerStructWithPaddingAlign4.
Fields
a: Uint16b: u8c: Uint32Trait Implementations
Sourceimpl Clone for OneLayerStructWithPaddingAlign4
impl Clone for OneLayerStructWithPaddingAlign4
Sourcefn clone(&self) -> OneLayerStructWithPaddingAlign4
fn clone(&self) -> OneLayerStructWithPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for OneLayerStructWithPaddingAlign4
impl Constrained for OneLayerStructWithPaddingAlign4
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, OneLayerStructWithPaddingAlign4>,
_: <OneLayerStructWithPaddingAlign4 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, OneLayerStructWithPaddingAlign4>, _: <OneLayerStructWithPaddingAlign4 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for OneLayerStructWithPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for OneLayerStructWithPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl FromWire<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn from_wire(
wire: OneLayerStructWithPaddingAlign4,
) -> OneLayerStructWithPaddingAlign4
fn from_wire( wire: OneLayerStructWithPaddingAlign4, ) -> OneLayerStructWithPaddingAlign4
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl FromWireRef<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn from_wire_ref(
wire: &OneLayerStructWithPaddingAlign4,
) -> OneLayerStructWithPaddingAlign4
fn from_wire_ref( wire: &OneLayerStructWithPaddingAlign4, ) -> OneLayerStructWithPaddingAlign4
Converts the given reference to this type.
Sourceimpl IntoNatural for OneLayerStructWithPaddingAlign4
impl IntoNatural for OneLayerStructWithPaddingAlign4
Sourcetype Natural = OneLayerStructWithPaddingAlign4
type Natural = OneLayerStructWithPaddingAlign4
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for OneLayerStructWithPaddingAlign4
impl Wire for OneLayerStructWithPaddingAlign4
Sourcetype Narrowed<'de> = OneLayerStructWithPaddingAlign4
type Narrowed<'de> = OneLayerStructWithPaddingAlign4
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>)
fn zero_padding(out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>)
Writes zeroes to the padding for this type, if any.