#[repr(C)]pub struct OutOfLineSandwich1WithOptUnion<'de> {
pub before: String<'de>,
pub v: Vector<'de, Sandwich1WithOptUnion>,
pub after: String<'de>,
}Expand description
The wire type corresponding to OutOfLineSandwich1WithOptUnion.
Fields
before: String<'de>v: Vector<'de, Sandwich1WithOptUnion>after: String<'de>Trait Implementations
Sourceimpl Constrained for OutOfLineSandwich1WithOptUnion<'_>
impl Constrained for OutOfLineSandwich1WithOptUnion<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, OutOfLineSandwich1WithOptUnion<'_>>,
_: <OutOfLineSandwich1WithOptUnion<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, OutOfLineSandwich1WithOptUnion<'_>>, _: <OutOfLineSandwich1WithOptUnion<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for OutOfLineSandwich1WithOptUnion<'de>
impl<'de> Debug for OutOfLineSandwich1WithOptUnion<'de>
Sourceimpl<'de, ___D> Decode<___D> for OutOfLineSandwich1WithOptUnion<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for OutOfLineSandwich1WithOptUnion<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for &'a OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnionwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnion<T0, T1, T2>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
T1: Encode<Vector<'static, Sandwich1WithOptUnion>, ___E>,
T2: Encode<String<'static>, ___E>,
impl<___E, T0, T1, T2> Encode<OutOfLineSandwich1WithOptUnion<'static>, ___E> for OutOfLineSandwich1WithOptUnion<T0, T1, T2>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
T1: Encode<Vector<'static, Sandwich1WithOptUnion>, ___E>,
T2: Encode<String<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
impl<'de> FromWire<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
Sourcefn from_wire(
wire: OutOfLineSandwich1WithOptUnion<'de>,
) -> OutOfLineSandwich1WithOptUnion
fn from_wire( wire: OutOfLineSandwich1WithOptUnion<'de>, ) -> OutOfLineSandwich1WithOptUnion
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
impl<'de> FromWireRef<OutOfLineSandwich1WithOptUnion<'de>> for OutOfLineSandwich1WithOptUnion
Sourcefn from_wire_ref(
wire: &OutOfLineSandwich1WithOptUnion<'de>,
) -> OutOfLineSandwich1WithOptUnion
fn from_wire_ref( wire: &OutOfLineSandwich1WithOptUnion<'de>, ) -> OutOfLineSandwich1WithOptUnion
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for OutOfLineSandwich1WithOptUnion<'de>
impl<'de> IntoNatural for OutOfLineSandwich1WithOptUnion<'de>
Sourcetype Natural = OutOfLineSandwich1WithOptUnion
type Natural = OutOfLineSandwich1WithOptUnion
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for OutOfLineSandwich1WithOptUnion<'static>
impl Wire for OutOfLineSandwich1WithOptUnion<'static>
Sourcetype Narrowed<'de> = OutOfLineSandwich1WithOptUnion<'de>
type Narrowed<'de> = OutOfLineSandwich1WithOptUnion<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>)
fn zero_padding(out_: &mut MaybeUninit<OutOfLineSandwich1WithOptUnion<'static>>)
Writes zeroes to the padding for this type, if any.