#[repr(C)]pub struct RecursiveOptionalStructWithString<'de> {
pub inner: Box<'de, RecursiveOptionalStructWithString<'de>>,
pub str: OptionalString<'de>,
}Expand description
The wire type corresponding to RecursiveOptionalStructWithString.
Fields
inner: Box<'de, RecursiveOptionalStructWithString<'de>>str: OptionalString<'de>Trait Implementations
Sourceimpl Constrained for RecursiveOptionalStructWithString<'_>
impl Constrained for RecursiveOptionalStructWithString<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, RecursiveOptionalStructWithString<'_>>,
_: <RecursiveOptionalStructWithString<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, RecursiveOptionalStructWithString<'_>>, _: <RecursiveOptionalStructWithString<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for RecursiveOptionalStructWithString<'de>
impl<'de> Debug for RecursiveOptionalStructWithString<'de>
Sourceimpl<'de, ___D> Decode<___D> for RecursiveOptionalStructWithString<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for RecursiveOptionalStructWithString<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithString<T0, T1>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E>,
T1: Encode<OptionalString<'static>, ___E>,
impl<___E, T0, T1> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithString<T0, T1>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E>,
T1: Encode<OptionalString<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
impl<'de> FromWire<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
Sourcefn from_wire(
wire: RecursiveOptionalStructWithString<'de>,
) -> RecursiveOptionalStructWithString
fn from_wire( wire: RecursiveOptionalStructWithString<'de>, ) -> RecursiveOptionalStructWithString
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
impl<'de> FromWireRef<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
Sourcefn from_wire_ref(
wire: &RecursiveOptionalStructWithString<'de>,
) -> RecursiveOptionalStructWithString
fn from_wire_ref( wire: &RecursiveOptionalStructWithString<'de>, ) -> RecursiveOptionalStructWithString
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for RecursiveOptionalStructWithString<'de>
impl<'de> IntoNatural for RecursiveOptionalStructWithString<'de>
Sourcetype Natural = RecursiveOptionalStructWithString
type Natural = RecursiveOptionalStructWithString
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for RecursiveOptionalStructWithString<'static>
impl Wire for RecursiveOptionalStructWithString<'static>
Sourcetype Narrowed<'de> = RecursiveOptionalStructWithString<'de>
type Narrowed<'de> = RecursiveOptionalStructWithString<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
)
fn zero_padding( out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, )
Writes zeroes to the padding for this type, if any.