#[repr(C)]pub struct Regression10V2<'de> {
pub table: Regression10TableV2<'de>,
}Expand description
The wire type corresponding to Regression10V2.
Fields
table: Regression10TableV2<'de>Trait Implementations
Sourceimpl Constrained for Regression10V2<'_>
impl Constrained for Regression10V2<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Regression10V2<'_>>,
_: <Regression10V2<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Regression10V2<'_>>, _: <Regression10V2<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for Regression10V2<'de>
impl<'de> Debug for Regression10V2<'de>
Sourceimpl<'de, ___D> Decode<___D> for Regression10V2<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for Regression10V2<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<Regression10V2<'static>, ___E> for &'a Regression10V2where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Regression10V2<'static>, ___E> for &'a Regression10V2where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression10V2<'static>, ___E> for Regression10V2where
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Regression10V2<'static>, ___E> for Regression10V2where
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<Regression10V2<'static>, ___E> for Regression10V2<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Regression10TableV2<'static>, ___E>,
impl<___E, T0> Encode<Regression10V2<'static>, ___E> for Regression10V2<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Regression10TableV2<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<Regression10V2<'de>> for Regression10V2
impl<'de> FromWire<Regression10V2<'de>> for Regression10V2
Sourcefn from_wire(wire: Regression10V2<'de>) -> Regression10V2
fn from_wire(wire: Regression10V2<'de>) -> Regression10V2
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression10V2<'de>> for Regression10V2
impl<'de> FromWireRef<Regression10V2<'de>> for Regression10V2
Sourcefn from_wire_ref(wire: &Regression10V2<'de>) -> Regression10V2
fn from_wire_ref(wire: &Regression10V2<'de>) -> Regression10V2
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for Regression10V2<'de>
impl<'de> IntoNatural for Regression10V2<'de>
Sourcetype Natural = Regression10V2
type Natural = Regression10V2
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Regression10V2<'static>
impl Wire for Regression10V2<'static>
Sourcetype Narrowed<'de> = Regression10V2<'de>
type Narrowed<'de> = Regression10V2<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Regression10V2<'static>>)
fn zero_padding(out_: &mut MaybeUninit<Regression10V2<'static>>)
Writes zeroes to the padding for this type, if any.