#[repr(C)]pub struct Sandwich1Message {
pub header: TransactionHeader,
pub body: Sandwich1,
}Expand description
The wire type corresponding to Sandwich1Message.
Fields
header: TransactionHeaderbody: Sandwich1Trait Implementations
Sourceimpl Clone for Sandwich1Message
impl Clone for Sandwich1Message
Sourcefn clone(&self) -> Sandwich1Message
fn clone(&self) -> Sandwich1Message
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Sandwich1Message
impl Constrained for Sandwich1Message
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Sandwich1Message>,
_: <Sandwich1Message as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Sandwich1Message>, _: <Sandwich1Message as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Sandwich1Message
impl Debug for Sandwich1Message
Sourceimpl<___D> Decode<___D> for Sandwich1Messagewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Sandwich1Messagewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Sandwich1Message, ___E> for &'a Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Sandwich1Message, ___E> for &'a Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1Message>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1Message>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich1Message, ___E> for Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Sandwich1Message, ___E> for Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1Message>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1Message>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<Sandwich1Message, ___E> for Sandwich1Message<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TransactionHeader, ___E>,
T1: Encode<Sandwich1, ___E>,
impl<___E, T0, T1> Encode<Sandwich1Message, ___E> for Sandwich1Message<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TransactionHeader, ___E>,
T1: Encode<Sandwich1, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1Message>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1Message>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Sandwich1Message> for Sandwich1Message
impl FromWire<Sandwich1Message> for Sandwich1Message
Sourcefn from_wire(wire: Sandwich1Message) -> Sandwich1Message
fn from_wire(wire: Sandwich1Message) -> Sandwich1Message
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Sandwich1Message> for Sandwich1Message
impl FromWireRef<Sandwich1Message> for Sandwich1Message
Sourcefn from_wire_ref(wire: &Sandwich1Message) -> Sandwich1Message
fn from_wire_ref(wire: &Sandwich1Message) -> Sandwich1Message
Converts the given reference to this type.
Sourceimpl IntoNatural for Sandwich1Message
impl IntoNatural for Sandwich1Message
Sourcetype Natural = Sandwich1Message
type Natural = Sandwich1Message
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Sandwich1Message
impl Wire for Sandwich1Message
Sourcetype Narrowed<'de> = Sandwich1Message
type Narrowed<'de> = Sandwich1Message
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Sandwich1Message>)
fn zero_padding(out_: &mut MaybeUninit<Sandwich1Message>)
Writes zeroes to the padding for this type, if any.