#[repr(C)]pub struct SingleHandle {
pub h: NullableHandle,
}Expand description
The wire type corresponding to SingleHandle.
Fields
h: NullableHandleTrait Implementations
Sourceimpl Constrained for SingleHandle
impl Constrained for SingleHandle
Sourceimpl Debug for SingleHandle
impl Debug for SingleHandle
Sourceimpl<___D> Decode<___D> for SingleHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SingleHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SingleHandle, ___E> for SingleHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SingleHandle, ___E> for SingleHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SingleHandle>
const COPY_OPTIMIZATION: CopyOptimization<Self, SingleHandle>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SingleHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SingleHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SingleHandle, ___E> for SingleHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<NullableHandle, ___E>,
impl<___E, T0> Encode<SingleHandle, ___E> for SingleHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<NullableHandle, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SingleHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SingleHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SingleHandle> for SingleHandle
impl FromWire<SingleHandle> for SingleHandle
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SingleHandle, Self>
const COPY_OPTIMIZATION: CopyOptimization<SingleHandle, Self>
Sourcefn from_wire(wire: SingleHandle) -> Self
fn from_wire(wire: SingleHandle) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for SingleHandle
impl IntoNatural for SingleHandle
Sourcetype Natural = SingleHandle
type Natural = SingleHandle
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SingleHandle
impl Wire for SingleHandle
Sourcetype Narrowed<'de> = SingleHandle
type Narrowed<'de> = SingleHandle
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.