#[repr(C)]pub struct SingleOptionalHandle {
pub h: OptionalNullableHandle,
}Expand description
The wire type corresponding to SingleOptionalHandle.
Fields
h: OptionalNullableHandleTrait Implementations
Sourceimpl Constrained for SingleOptionalHandle
impl Constrained for SingleOptionalHandle
Sourceimpl Debug for SingleOptionalHandle
impl Debug for SingleOptionalHandle
Sourceimpl<___D> Decode<___D> for SingleOptionalHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SingleOptionalHandlewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SingleOptionalHandle, ___E> for SingleOptionalHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SingleOptionalHandle, ___E> for SingleOptionalHandlewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SingleOptionalHandle>
const COPY_OPTIMIZATION: CopyOptimization<Self, SingleOptionalHandle>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SingleOptionalHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SingleOptionalHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SingleOptionalHandle, ___E> for SingleOptionalHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
impl<___E, T0> Encode<SingleOptionalHandle, ___E> for SingleOptionalHandle<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalNullableHandle, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SingleOptionalHandle>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SingleOptionalHandle>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SingleOptionalHandle> for SingleOptionalHandle
impl FromWire<SingleOptionalHandle> for SingleOptionalHandle
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SingleOptionalHandle, Self>
const COPY_OPTIMIZATION: CopyOptimization<SingleOptionalHandle, Self>
Sourcefn from_wire(wire: SingleOptionalHandle) -> Self
fn from_wire(wire: SingleOptionalHandle) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for SingleOptionalHandle
impl IntoNatural for SingleOptionalHandle
Sourcetype Natural = SingleOptionalHandle
type Natural = SingleOptionalHandle
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SingleOptionalHandle
impl Wire for SingleOptionalHandle
Sourcetype Narrowed<'de> = SingleOptionalHandle
type Narrowed<'de> = SingleOptionalHandle
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.