#[repr(C)]pub struct Size5Alignment1 {
pub data: [u8; 5],
}Expand description
The wire type corresponding to Size5Alignment1.
Fields
data: [u8; 5]Trait Implementations
Sourceimpl Clone for Size5Alignment1
impl Clone for Size5Alignment1
Sourcefn clone(&self) -> Size5Alignment1
fn clone(&self) -> Size5Alignment1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Size5Alignment1
impl Constrained for Size5Alignment1
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Size5Alignment1>,
_: <Size5Alignment1 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Size5Alignment1>, _: <Size5Alignment1 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Size5Alignment1
impl Debug for Size5Alignment1
Sourceimpl<___D> Decode<___D> for Size5Alignment1where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Size5Alignment1where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Size5Alignment1, ___E> for &'a Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment1, ___E> for &'a Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment1, ___E> for Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment1, ___E> for Size5Alignment1where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Size5Alignment1, ___E> for Size5Alignment1<T0>
impl<___E, T0> Encode<Size5Alignment1, ___E> for Size5Alignment1<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Size5Alignment1> for Size5Alignment1
impl FromWire<Size5Alignment1> for Size5Alignment1
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1, Size5Alignment1>
Sourcefn from_wire(wire: Size5Alignment1) -> Size5Alignment1
fn from_wire(wire: Size5Alignment1) -> Size5Alignment1
Converts the given owned value to this type.
Sourceimpl FromWireRef<Size5Alignment1> for Size5Alignment1
impl FromWireRef<Size5Alignment1> for Size5Alignment1
Sourcefn from_wire_ref(wire: &Size5Alignment1) -> Size5Alignment1
fn from_wire_ref(wire: &Size5Alignment1) -> Size5Alignment1
Converts the given reference to this type.
Sourceimpl IntoNatural for Size5Alignment1
impl IntoNatural for Size5Alignment1
Sourcetype Natural = Size5Alignment1
type Natural = Size5Alignment1
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Size5Alignment1
impl Wire for Size5Alignment1
Sourcetype Narrowed<'de> = Size5Alignment1
type Narrowed<'de> = Size5Alignment1
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Size5Alignment1>)
fn zero_padding(out_: &mut MaybeUninit<Size5Alignment1>)
Writes zeroes to the padding for this type, if any.