#[repr(C)]pub struct Size5Alignment1Array {
pub a: [Size5Alignment1; 3],
}Expand description
The wire type corresponding to Size5Alignment1Array.
Fields
a: [Size5Alignment1; 3]Trait Implementations
Sourceimpl Clone for Size5Alignment1Array
impl Clone for Size5Alignment1Array
Sourcefn clone(&self) -> Size5Alignment1Array
fn clone(&self) -> Size5Alignment1Array
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Size5Alignment1Array
impl Constrained for Size5Alignment1Array
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Size5Alignment1Array>,
_: <Size5Alignment1Array as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Size5Alignment1Array>, _: <Size5Alignment1Array as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Size5Alignment1Array
impl Debug for Size5Alignment1Array
Sourceimpl<___D> Decode<___D> for Size5Alignment1Arraywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Size5Alignment1Arraywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Size5Alignment1Array, ___E> for &'a Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment1Array, ___E> for &'a Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1Array>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1Array>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Size5Alignment1Array>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Size5Alignment1Array>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1Array>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1Array>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Array<T0>
impl<___E, T0> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Array<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1Array>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1Array>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Size5Alignment1Array> for Size5Alignment1Array
impl FromWire<Size5Alignment1Array> for Size5Alignment1Array
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Size5Alignment1Array>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Size5Alignment1Array>
Sourcefn from_wire(wire: Size5Alignment1Array) -> Size5Alignment1Array
fn from_wire(wire: Size5Alignment1Array) -> Size5Alignment1Array
Converts the given owned value to this type.
Sourceimpl FromWireRef<Size5Alignment1Array> for Size5Alignment1Array
impl FromWireRef<Size5Alignment1Array> for Size5Alignment1Array
Sourcefn from_wire_ref(wire: &Size5Alignment1Array) -> Size5Alignment1Array
fn from_wire_ref(wire: &Size5Alignment1Array) -> Size5Alignment1Array
Converts the given reference to this type.
Sourceimpl IntoNatural for Size5Alignment1Array
impl IntoNatural for Size5Alignment1Array
Sourcetype Natural = Size5Alignment1Array
type Natural = Size5Alignment1Array
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Size5Alignment1Array
impl Wire for Size5Alignment1Array
Sourcetype Narrowed<'de> = Size5Alignment1Array
type Narrowed<'de> = Size5Alignment1Array
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Size5Alignment1Array>)
fn zero_padding(out_: &mut MaybeUninit<Size5Alignment1Array>)
Writes zeroes to the padding for this type, if any.