#[repr(C)]pub struct Size5Alignment4 {
pub four: Uint32,
pub one: u8,
}Expand description
The wire type corresponding to Size5Alignment4.
Fields
four: Uint32one: u8Trait Implementations
Sourceimpl Clone for Size5Alignment4
impl Clone for Size5Alignment4
Sourcefn clone(&self) -> Size5Alignment4
fn clone(&self) -> Size5Alignment4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Size5Alignment4
impl Constrained for Size5Alignment4
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Size5Alignment4>,
_: <Size5Alignment4 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Size5Alignment4>, _: <Size5Alignment4 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Size5Alignment4
impl Debug for Size5Alignment4
Sourceimpl<___D> Decode<___D> for Size5Alignment4where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Size5Alignment4where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Size5Alignment4, ___E> for &'a Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment4, ___E> for &'a Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment4, ___E> for Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment4, ___E> for Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<Size5Alignment4, ___E> for Size5Alignment4<T0, T1>
impl<___E, T0, T1> Encode<Size5Alignment4, ___E> for Size5Alignment4<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Size5Alignment4> for Size5Alignment4
impl FromWire<Size5Alignment4> for Size5Alignment4
Sourcefn from_wire(wire: Size5Alignment4) -> Size5Alignment4
fn from_wire(wire: Size5Alignment4) -> Size5Alignment4
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Size5Alignment4> for Size5Alignment4
impl FromWireRef<Size5Alignment4> for Size5Alignment4
Sourcefn from_wire_ref(wire: &Size5Alignment4) -> Size5Alignment4
fn from_wire_ref(wire: &Size5Alignment4) -> Size5Alignment4
Converts the given reference to this type.
Sourceimpl IntoNatural for Size5Alignment4
impl IntoNatural for Size5Alignment4
Sourcetype Natural = Size5Alignment4
type Natural = Size5Alignment4
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Size5Alignment4
impl Wire for Size5Alignment4
Sourcetype Narrowed<'de> = Size5Alignment4
type Narrowed<'de> = Size5Alignment4
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Size5Alignment4>)
fn zero_padding(out_: &mut MaybeUninit<Size5Alignment4>)
Writes zeroes to the padding for this type, if any.