#[repr(C)]pub struct StrictBitsUint64Struct {
pub b: StrictBitsUint64,
}Expand description
The wire type corresponding to StrictBitsUint64Struct.
Fields
b: StrictBitsUint64Trait Implementations
Sourceimpl Clone for StrictBitsUint64Struct
impl Clone for StrictBitsUint64Struct
Sourcefn clone(&self) -> StrictBitsUint64Struct
fn clone(&self) -> StrictBitsUint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictBitsUint64Struct
impl Constrained for StrictBitsUint64Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StrictBitsUint64Struct>,
_: <StrictBitsUint64Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StrictBitsUint64Struct>, _: <StrictBitsUint64Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StrictBitsUint64Struct
impl Debug for StrictBitsUint64Struct
Sourceimpl<___D> Decode<___D> for StrictBitsUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictBitsUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictBitsUint64Struct, ___E> for &'a StrictBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint64Struct, ___E> for &'a StrictBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint64Struct, ___E> for StrictBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint64Struct, ___E> for StrictBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint64Struct, StrictBitsUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint64Struct, StrictBitsUint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictBitsUint64Struct, ___E> for StrictBitsUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint64, ___E>,
impl<___E, T0> Encode<StrictBitsUint64Struct, ___E> for StrictBitsUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictBitsUint64Struct> for StrictBitsUint64Struct
impl FromWire<StrictBitsUint64Struct> for StrictBitsUint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint64Struct, StrictBitsUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint64Struct, StrictBitsUint64Struct>
Sourcefn from_wire(wire: StrictBitsUint64Struct) -> StrictBitsUint64Struct
fn from_wire(wire: StrictBitsUint64Struct) -> StrictBitsUint64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint64Struct> for StrictBitsUint64Struct
impl FromWireRef<StrictBitsUint64Struct> for StrictBitsUint64Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint64Struct) -> StrictBitsUint64Struct
fn from_wire_ref(wire: &StrictBitsUint64Struct) -> StrictBitsUint64Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictBitsUint64Struct
impl IntoNatural for StrictBitsUint64Struct
Sourcetype Natural = StrictBitsUint64Struct
type Natural = StrictBitsUint64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictBitsUint64Struct
impl Wire for StrictBitsUint64Struct
Sourcetype Narrowed<'de> = StrictBitsUint64Struct
type Narrowed<'de> = StrictBitsUint64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StrictBitsUint64Struct>)
fn zero_padding(out_: &mut MaybeUninit<StrictBitsUint64Struct>)
Writes zeroes to the padding for this type, if any.