#[repr(C)]pub struct StrictBitsUint8Struct {
pub b: StrictBitsUint8,
}Expand description
The wire type corresponding to StrictBitsUint8Struct.
Fields
b: StrictBitsUint8Trait Implementations
Sourceimpl Clone for StrictBitsUint8Struct
impl Clone for StrictBitsUint8Struct
Sourcefn clone(&self) -> StrictBitsUint8Struct
fn clone(&self) -> StrictBitsUint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictBitsUint8Struct
impl Constrained for StrictBitsUint8Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StrictBitsUint8Struct>,
_: <StrictBitsUint8Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StrictBitsUint8Struct>, _: <StrictBitsUint8Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StrictBitsUint8Struct
impl Debug for StrictBitsUint8Struct
Sourceimpl<___D> Decode<___D> for StrictBitsUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictBitsUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictBitsUint8Struct, ___E> for &'a StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint8Struct, ___E> for &'a StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint8, ___E>,
impl<___E, T0> Encode<StrictBitsUint8Struct, ___E> for StrictBitsUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint8, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictBitsUint8Struct> for StrictBitsUint8Struct
impl FromWire<StrictBitsUint8Struct> for StrictBitsUint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint8Struct, StrictBitsUint8Struct>
Sourcefn from_wire(wire: StrictBitsUint8Struct) -> StrictBitsUint8Struct
fn from_wire(wire: StrictBitsUint8Struct) -> StrictBitsUint8Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint8Struct> for StrictBitsUint8Struct
impl FromWireRef<StrictBitsUint8Struct> for StrictBitsUint8Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint8Struct) -> StrictBitsUint8Struct
fn from_wire_ref(wire: &StrictBitsUint8Struct) -> StrictBitsUint8Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictBitsUint8Struct
impl IntoNatural for StrictBitsUint8Struct
Sourcetype Natural = StrictBitsUint8Struct
type Natural = StrictBitsUint8Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictBitsUint8Struct
impl Wire for StrictBitsUint8Struct
Sourcetype Narrowed<'de> = StrictBitsUint8Struct
type Narrowed<'de> = StrictBitsUint8Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StrictBitsUint8Struct>)
fn zero_padding(out_: &mut MaybeUninit<StrictBitsUint8Struct>)
Writes zeroes to the padding for this type, if any.