#[repr(C)]pub struct StrictEnumInt8Struct {
pub e: StrictEnumInt8,
}Expand description
The wire type corresponding to StrictEnumInt8Struct.
Fields
e: StrictEnumInt8Trait Implementations
Sourceimpl Clone for StrictEnumInt8Struct
impl Clone for StrictEnumInt8Struct
Sourcefn clone(&self) -> StrictEnumInt8Struct
fn clone(&self) -> StrictEnumInt8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumInt8Struct
impl Constrained for StrictEnumInt8Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StrictEnumInt8Struct>,
_: <StrictEnumInt8Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StrictEnumInt8Struct>, _: <StrictEnumInt8Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StrictEnumInt8Struct
impl Debug for StrictEnumInt8Struct
Sourceimpl<___D> Decode<___D> for StrictEnumInt8Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumInt8Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumInt8Struct, ___E> for &'a StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt8Struct, ___E> for &'a StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, StrictEnumInt8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, StrictEnumInt8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt8, ___E>,
impl<___E, T0> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt8, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl FromWire<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, StrictEnumInt8Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, StrictEnumInt8Struct>
Sourcefn from_wire(wire: StrictEnumInt8Struct) -> StrictEnumInt8Struct
fn from_wire(wire: StrictEnumInt8Struct) -> StrictEnumInt8Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl FromWireRef<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt8Struct) -> StrictEnumInt8Struct
fn from_wire_ref(wire: &StrictEnumInt8Struct) -> StrictEnumInt8Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumInt8Struct
impl IntoNatural for StrictEnumInt8Struct
Sourcetype Natural = StrictEnumInt8Struct
type Natural = StrictEnumInt8Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumInt8Struct
impl Wire for StrictEnumInt8Struct
Sourcetype Narrowed<'de> = StrictEnumInt8Struct
type Narrowed<'de> = StrictEnumInt8Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StrictEnumInt8Struct>)
fn zero_padding(out_: &mut MaybeUninit<StrictEnumInt8Struct>)
Writes zeroes to the padding for this type, if any.