#[repr(C)]pub struct StrictEnumUint16Struct {
pub e: StrictEnumUint16,
}Expand description
The wire type corresponding to StrictEnumUint16Struct.
Fields
e: StrictEnumUint16Trait Implementations
Sourceimpl Clone for StrictEnumUint16Struct
impl Clone for StrictEnumUint16Struct
Sourcefn clone(&self) -> StrictEnumUint16Struct
fn clone(&self) -> StrictEnumUint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumUint16Struct
impl Constrained for StrictEnumUint16Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StrictEnumUint16Struct>,
_: <StrictEnumUint16Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StrictEnumUint16Struct>, _: <StrictEnumUint16Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StrictEnumUint16Struct
impl Debug for StrictEnumUint16Struct
Sourceimpl<___D> Decode<___D> for StrictEnumUint16Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumUint16Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumUint16Struct, ___E> for &'a StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint16Struct, ___E> for &'a StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint16, ___E>,
impl<___E, T0> Encode<StrictEnumUint16Struct, ___E> for StrictEnumUint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumUint16Struct> for StrictEnumUint16Struct
impl FromWire<StrictEnumUint16Struct> for StrictEnumUint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint16Struct, StrictEnumUint16Struct>
Sourcefn from_wire(wire: StrictEnumUint16Struct) -> StrictEnumUint16Struct
fn from_wire(wire: StrictEnumUint16Struct) -> StrictEnumUint16Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint16Struct> for StrictEnumUint16Struct
impl FromWireRef<StrictEnumUint16Struct> for StrictEnumUint16Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint16Struct) -> StrictEnumUint16Struct
fn from_wire_ref(wire: &StrictEnumUint16Struct) -> StrictEnumUint16Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumUint16Struct
impl IntoNatural for StrictEnumUint16Struct
Sourcetype Natural = StrictEnumUint16Struct
type Natural = StrictEnumUint16Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumUint16Struct
impl Wire for StrictEnumUint16Struct
Sourcetype Narrowed<'de> = StrictEnumUint16Struct
type Narrowed<'de> = StrictEnumUint16Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StrictEnumUint16Struct>)
fn zero_padding(out_: &mut MaybeUninit<StrictEnumUint16Struct>)
Writes zeroes to the padding for this type, if any.