#[repr(C)]pub struct StrictEnumUint64Struct {
pub e: StrictEnumUint64,
}Expand description
The wire type corresponding to StrictEnumUint64Struct.
Fields
e: StrictEnumUint64Trait Implementations
Sourceimpl Clone for StrictEnumUint64Struct
impl Clone for StrictEnumUint64Struct
Sourcefn clone(&self) -> StrictEnumUint64Struct
fn clone(&self) -> StrictEnumUint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumUint64Struct
impl Constrained for StrictEnumUint64Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StrictEnumUint64Struct>,
_: <StrictEnumUint64Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StrictEnumUint64Struct>, _: <StrictEnumUint64Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StrictEnumUint64Struct
impl Debug for StrictEnumUint64Struct
Sourceimpl<___D> Decode<___D> for StrictEnumUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumUint64Struct, ___E> for &'a StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint64Struct, ___E> for &'a StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint64, ___E>,
impl<___E, T0> Encode<StrictEnumUint64Struct, ___E> for StrictEnumUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumUint64Struct> for StrictEnumUint64Struct
impl FromWire<StrictEnumUint64Struct> for StrictEnumUint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint64Struct, StrictEnumUint64Struct>
Sourcefn from_wire(wire: StrictEnumUint64Struct) -> StrictEnumUint64Struct
fn from_wire(wire: StrictEnumUint64Struct) -> StrictEnumUint64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint64Struct> for StrictEnumUint64Struct
impl FromWireRef<StrictEnumUint64Struct> for StrictEnumUint64Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint64Struct) -> StrictEnumUint64Struct
fn from_wire_ref(wire: &StrictEnumUint64Struct) -> StrictEnumUint64Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumUint64Struct
impl IntoNatural for StrictEnumUint64Struct
Sourcetype Natural = StrictEnumUint64Struct
type Natural = StrictEnumUint64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumUint64Struct
impl Wire for StrictEnumUint64Struct
Sourcetype Narrowed<'de> = StrictEnumUint64Struct
type Narrowed<'de> = StrictEnumUint64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StrictEnumUint64Struct>)
fn zero_padding(out_: &mut MaybeUninit<StrictEnumUint64Struct>)
Writes zeroes to the padding for this type, if any.