#[repr(C)]pub struct Struct1Byte {
pub a: i8,
}Expand description
The wire type corresponding to Struct1Byte.
Fields
a: i8Trait Implementations
Sourceimpl Clone for Struct1Byte
impl Clone for Struct1Byte
Sourcefn clone(&self) -> Struct1Byte
fn clone(&self) -> Struct1Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct1Byte
impl Constrained for Struct1Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct1Byte>,
_: <Struct1Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct1Byte>, _: <Struct1Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct1Byte
impl Debug for Struct1Byte
Sourceimpl<___D> Decode<___D> for Struct1Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct1Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct1Byte, ___E> for &'a Struct1Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct1Byte, ___E> for &'a Struct1Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct1Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct1Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct1Byte, ___E> for Struct1Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct1Byte, ___E> for Struct1Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct1Byte, Struct1Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct1Byte, Struct1Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct1Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct1Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Struct1Byte, ___E> for Struct1Byte<T0>
impl<___E, T0> Encode<Struct1Byte, ___E> for Struct1Byte<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct1Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct1Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct1Byte> for Struct1Byte
impl FromWire<Struct1Byte> for Struct1Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct1Byte, Struct1Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct1Byte, Struct1Byte>
Sourcefn from_wire(wire: Struct1Byte) -> Struct1Byte
fn from_wire(wire: Struct1Byte) -> Struct1Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct1Byte> for Struct1Byte
impl FromWireRef<Struct1Byte> for Struct1Byte
Sourcefn from_wire_ref(wire: &Struct1Byte) -> Struct1Byte
fn from_wire_ref(wire: &Struct1Byte) -> Struct1Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct1Byte
impl IntoNatural for Struct1Byte
Sourcetype Natural = Struct1Byte
type Natural = Struct1Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct1Byte
impl Wire for Struct1Byte
Sourcetype Narrowed<'de> = Struct1Byte
type Narrowed<'de> = Struct1Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct1Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct1Byte>)
Writes zeroes to the padding for this type, if any.