#[repr(C)]pub struct Struct2Byte {
pub a: Int16,
}Expand description
The wire type corresponding to Struct2Byte.
Fields
a: Int16Trait Implementations
Sourceimpl Clone for Struct2Byte
impl Clone for Struct2Byte
Sourcefn clone(&self) -> Struct2Byte
fn clone(&self) -> Struct2Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct2Byte
impl Constrained for Struct2Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct2Byte>,
_: <Struct2Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct2Byte>, _: <Struct2Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct2Byte
impl Debug for Struct2Byte
Sourceimpl<___D> Decode<___D> for Struct2Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct2Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct2Byte, ___E> for &'a Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct2Byte, ___E> for &'a Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct2Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct2Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct2Byte, ___E> for Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct2Byte, ___E> for Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Struct2Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Struct2Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct2Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct2Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Struct2Byte, ___E> for Struct2Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int16, ___E>,
impl<___E, T0> Encode<Struct2Byte, ___E> for Struct2Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct2Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct2Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct2Byte> for Struct2Byte
impl FromWire<Struct2Byte> for Struct2Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Struct2Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Struct2Byte>
Sourcefn from_wire(wire: Struct2Byte) -> Struct2Byte
fn from_wire(wire: Struct2Byte) -> Struct2Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct2Byte> for Struct2Byte
impl FromWireRef<Struct2Byte> for Struct2Byte
Sourcefn from_wire_ref(wire: &Struct2Byte) -> Struct2Byte
fn from_wire_ref(wire: &Struct2Byte) -> Struct2Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct2Byte
impl IntoNatural for Struct2Byte
Sourcetype Natural = Struct2Byte
type Natural = Struct2Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct2Byte
impl Wire for Struct2Byte
Sourcetype Narrowed<'de> = Struct2Byte
type Narrowed<'de> = Struct2Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct2Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct2Byte>)
Writes zeroes to the padding for this type, if any.