#[repr(C)]pub struct Struct3Byte {
pub a: Int16,
pub b: i8,
}Expand description
The wire type corresponding to Struct3Byte.
Fields
a: Int16b: i8Trait Implementations
Sourceimpl Clone for Struct3Byte
impl Clone for Struct3Byte
Sourcefn clone(&self) -> Struct3Byte
fn clone(&self) -> Struct3Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct3Byte
impl Constrained for Struct3Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct3Byte>,
_: <Struct3Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct3Byte>, _: <Struct3Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct3Byte
impl Debug for Struct3Byte
Sourceimpl<___D> Decode<___D> for Struct3Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct3Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct3Byte, ___E> for &'a Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct3Byte, ___E> for &'a Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct3Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct3Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct3Byte, ___E> for Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct3Byte, ___E> for Struct3Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct3Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct3Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<Struct3Byte, ___E> for Struct3Byte<T0, T1>
impl<___E, T0, T1> Encode<Struct3Byte, ___E> for Struct3Byte<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct3Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct3Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct3Byte> for Struct3Byte
impl FromWire<Struct3Byte> for Struct3Byte
Sourcefn from_wire(wire: Struct3Byte) -> Struct3Byte
fn from_wire(wire: Struct3Byte) -> Struct3Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct3Byte> for Struct3Byte
impl FromWireRef<Struct3Byte> for Struct3Byte
Sourcefn from_wire_ref(wire: &Struct3Byte) -> Struct3Byte
fn from_wire_ref(wire: &Struct3Byte) -> Struct3Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct3Byte
impl IntoNatural for Struct3Byte
Sourcetype Natural = Struct3Byte
type Natural = Struct3Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct3Byte
impl Wire for Struct3Byte
Sourcetype Narrowed<'de> = Struct3Byte
type Narrowed<'de> = Struct3Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct3Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct3Byte>)
Writes zeroes to the padding for this type, if any.