#[repr(C)]pub struct Struct4Byte {
pub a: Int32,
}Expand description
The wire type corresponding to Struct4Byte.
Fields
a: Int32Trait Implementations
Sourceimpl Clone for Struct4Byte
impl Clone for Struct4Byte
Sourcefn clone(&self) -> Struct4Byte
fn clone(&self) -> Struct4Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct4Byte
impl Constrained for Struct4Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct4Byte>,
_: <Struct4Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct4Byte>, _: <Struct4Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct4Byte
impl Debug for Struct4Byte
Sourceimpl<___D> Decode<___D> for Struct4Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct4Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct4Byte, ___E> for &'a Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct4Byte, ___E> for &'a Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct4Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct4Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct4Byte, ___E> for Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct4Byte, ___E> for Struct4Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct4Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct4Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Struct4Byte, ___E> for Struct4Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
impl<___E, T0> Encode<Struct4Byte, ___E> for Struct4Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct4Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct4Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct4Byte> for Struct4Byte
impl FromWire<Struct4Byte> for Struct4Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct4Byte, Struct4Byte>
Sourcefn from_wire(wire: Struct4Byte) -> Struct4Byte
fn from_wire(wire: Struct4Byte) -> Struct4Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct4Byte> for Struct4Byte
impl FromWireRef<Struct4Byte> for Struct4Byte
Sourcefn from_wire_ref(wire: &Struct4Byte) -> Struct4Byte
fn from_wire_ref(wire: &Struct4Byte) -> Struct4Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct4Byte
impl IntoNatural for Struct4Byte
Sourcetype Natural = Struct4Byte
type Natural = Struct4Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct4Byte
impl Wire for Struct4Byte
Sourcetype Narrowed<'de> = Struct4Byte
type Narrowed<'de> = Struct4Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct4Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct4Byte>)
Writes zeroes to the padding for this type, if any.