#[repr(C)]pub struct Struct5Byte {
pub a: Int32,
pub b: i8,
}Expand description
The wire type corresponding to Struct5Byte.
Fields
a: Int32b: i8Trait Implementations
Sourceimpl Clone for Struct5Byte
impl Clone for Struct5Byte
Sourcefn clone(&self) -> Struct5Byte
fn clone(&self) -> Struct5Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct5Byte
impl Constrained for Struct5Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct5Byte>,
_: <Struct5Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct5Byte>, _: <Struct5Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct5Byte
impl Debug for Struct5Byte
Sourceimpl<___D> Decode<___D> for Struct5Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct5Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct5Byte, ___E> for &'a Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct5Byte, ___E> for &'a Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct5Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct5Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct5Byte, ___E> for Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct5Byte, ___E> for Struct5Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct5Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct5Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<Struct5Byte, ___E> for Struct5Byte<T0, T1>
impl<___E, T0, T1> Encode<Struct5Byte, ___E> for Struct5Byte<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct5Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct5Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct5Byte> for Struct5Byte
impl FromWire<Struct5Byte> for Struct5Byte
Sourcefn from_wire(wire: Struct5Byte) -> Struct5Byte
fn from_wire(wire: Struct5Byte) -> Struct5Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct5Byte> for Struct5Byte
impl FromWireRef<Struct5Byte> for Struct5Byte
Sourcefn from_wire_ref(wire: &Struct5Byte) -> Struct5Byte
fn from_wire_ref(wire: &Struct5Byte) -> Struct5Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct5Byte
impl IntoNatural for Struct5Byte
Sourcetype Natural = Struct5Byte
type Natural = Struct5Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct5Byte
impl Wire for Struct5Byte
Sourcetype Narrowed<'de> = Struct5Byte
type Narrowed<'de> = Struct5Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct5Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct5Byte>)
Writes zeroes to the padding for this type, if any.