#[repr(C)]pub struct Struct6Byte {
pub a: Int32,
pub b: Int16,
}Expand description
The wire type corresponding to Struct6Byte.
Fields
a: Int32b: Int16Trait Implementations
Sourceimpl Clone for Struct6Byte
impl Clone for Struct6Byte
Sourcefn clone(&self) -> Struct6Byte
fn clone(&self) -> Struct6Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct6Byte
impl Constrained for Struct6Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct6Byte>,
_: <Struct6Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct6Byte>, _: <Struct6Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct6Byte
impl Debug for Struct6Byte
Sourceimpl<___D> Decode<___D> for Struct6Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct6Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct6Byte, ___E> for &'a Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct6Byte, ___E> for &'a Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct6Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct6Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct6Byte, ___E> for Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct6Byte, ___E> for Struct6Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct6Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct6Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<Struct6Byte, ___E> for Struct6Byte<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int16, ___E>,
impl<___E, T0, T1> Encode<Struct6Byte, ___E> for Struct6Byte<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct6Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct6Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct6Byte> for Struct6Byte
impl FromWire<Struct6Byte> for Struct6Byte
Sourcefn from_wire(wire: Struct6Byte) -> Struct6Byte
fn from_wire(wire: Struct6Byte) -> Struct6Byte
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct6Byte> for Struct6Byte
impl FromWireRef<Struct6Byte> for Struct6Byte
Sourcefn from_wire_ref(wire: &Struct6Byte) -> Struct6Byte
fn from_wire_ref(wire: &Struct6Byte) -> Struct6Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct6Byte
impl IntoNatural for Struct6Byte
Sourcetype Natural = Struct6Byte
type Natural = Struct6Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct6Byte
impl Wire for Struct6Byte
Sourcetype Narrowed<'de> = Struct6Byte
type Narrowed<'de> = Struct6Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct6Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct6Byte>)
Writes zeroes to the padding for this type, if any.