#[repr(C)]pub struct Struct8Byte {
pub a: Int64,
}Expand description
The wire type corresponding to Struct8Byte.
Fields
a: Int64Trait Implementations
Sourceimpl Clone for Struct8Byte
impl Clone for Struct8Byte
Sourcefn clone(&self) -> Struct8Byte
fn clone(&self) -> Struct8Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct8Byte
impl Constrained for Struct8Byte
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Struct8Byte>,
_: <Struct8Byte as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Struct8Byte>, _: <Struct8Byte as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Struct8Byte
impl Debug for Struct8Byte
Sourceimpl<___D> Decode<___D> for Struct8Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct8Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct8Byte, ___E> for &'a Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct8Byte, ___E> for &'a Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct8Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct8Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct8Byte, ___E> for Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct8Byte, ___E> for Struct8Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct8Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct8Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Struct8Byte, ___E> for Struct8Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
impl<___E, T0> Encode<Struct8Byte, ___E> for Struct8Byte<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct8Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct8Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct8Byte> for Struct8Byte
impl FromWire<Struct8Byte> for Struct8Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
const COPY_OPTIMIZATION: CopyOptimization<Struct8Byte, Struct8Byte>
Sourcefn from_wire(wire: Struct8Byte) -> Struct8Byte
fn from_wire(wire: Struct8Byte) -> Struct8Byte
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct8Byte> for Struct8Byte
impl FromWireRef<Struct8Byte> for Struct8Byte
Sourcefn from_wire_ref(wire: &Struct8Byte) -> Struct8Byte
fn from_wire_ref(wire: &Struct8Byte) -> Struct8Byte
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct8Byte
impl IntoNatural for Struct8Byte
Sourcetype Natural = Struct8Byte
type Natural = Struct8Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct8Byte
impl Wire for Struct8Byte
Sourcetype Narrowed<'de> = Struct8Byte
type Narrowed<'de> = Struct8Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Struct8Byte>)
fn zero_padding(out_: &mut MaybeUninit<Struct8Byte>)
Writes zeroes to the padding for this type, if any.