#[repr(C)]pub struct StructOfEndpoints {
pub client_end: ClientEnd<Protocol, Channel>,
pub optional_client_end: ClientEnd<Protocol, OptionalChannel>,
pub server_end: ServerEnd<Protocol, Channel>,
pub optional_server_end: ServerEnd<Protocol, OptionalChannel>,
}Expand description
The wire type corresponding to StructOfEndpoints.
Fields
client_end: ClientEnd<Protocol, Channel>optional_client_end: ClientEnd<Protocol, OptionalChannel>server_end: ServerEnd<Protocol, Channel>optional_server_end: ServerEnd<Protocol, OptionalChannel>Trait Implementations
Sourceimpl Constrained for StructOfEndpoints
impl Constrained for StructOfEndpoints
Sourceimpl Debug for StructOfEndpoints
impl Debug for StructOfEndpoints
Sourceimpl<___D> Decode<___D> for StructOfEndpointswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for StructOfEndpointswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<StructOfEndpoints, ___E> for StructOfEndpointswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<StructOfEndpoints, ___E> for StructOfEndpointswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StructOfEndpoints>
const COPY_OPTIMIZATION: CopyOptimization<Self, StructOfEndpoints>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfEndpoints>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfEndpoints>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3> Encode<StructOfEndpoints, ___E> for StructOfEndpoints<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<StructOfEndpoints, ___E> for StructOfEndpoints<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfEndpoints>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfEndpoints>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StructOfEndpoints> for StructOfEndpoints
impl FromWire<StructOfEndpoints> for StructOfEndpoints
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StructOfEndpoints, Self>
const COPY_OPTIMIZATION: CopyOptimization<StructOfEndpoints, Self>
Sourcefn from_wire(wire: StructOfEndpoints) -> Self
fn from_wire(wire: StructOfEndpoints) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for StructOfEndpoints
impl IntoNatural for StructOfEndpoints
Sourcetype Natural = StructOfEndpoints
type Natural = StructOfEndpoints
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StructOfEndpoints
impl Wire for StructOfEndpoints
Sourcetype Narrowed<'de> = StructOfEndpoints
type Narrowed<'de> = StructOfEndpoints
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.