#[repr(C)]pub struct StructWithInt {
pub x: Int32,
}Expand description
The wire type corresponding to StructWithInt.
Fields
x: Int32Trait Implementations
Sourceimpl Clone for StructWithInt
impl Clone for StructWithInt
Sourcefn clone(&self) -> StructWithInt
fn clone(&self) -> StructWithInt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StructWithInt
impl Constrained for StructWithInt
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StructWithInt>,
_: <StructWithInt as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StructWithInt>, _: <StructWithInt as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StructWithInt
impl Debug for StructWithInt
Sourceimpl<___D> Decode<___D> for StructWithIntwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StructWithIntwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StructWithInt, ___E> for &'a StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StructWithInt, ___E> for &'a StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithInt>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithInt>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithInt, ___E> for StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StructWithInt, ___E> for StructWithIntwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
const COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithInt>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithInt>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StructWithInt, ___E> for StructWithInt<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
impl<___E, T0> Encode<StructWithInt, ___E> for StructWithInt<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithInt>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithInt>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StructWithInt> for StructWithInt
impl FromWire<StructWithInt> for StructWithInt
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
const COPY_OPTIMIZATION: CopyOptimization<StructWithInt, StructWithInt>
Sourcefn from_wire(wire: StructWithInt) -> StructWithInt
fn from_wire(wire: StructWithInt) -> StructWithInt
Converts the given owned value to this type.
Sourceimpl FromWireRef<StructWithInt> for StructWithInt
impl FromWireRef<StructWithInt> for StructWithInt
Sourcefn from_wire_ref(wire: &StructWithInt) -> StructWithInt
fn from_wire_ref(wire: &StructWithInt) -> StructWithInt
Converts the given reference to this type.
Sourceimpl IntoNatural for StructWithInt
impl IntoNatural for StructWithInt
Sourcetype Natural = StructWithInt
type Natural = StructWithInt
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StructWithInt
impl Wire for StructWithInt
Sourcetype Narrowed<'de> = StructWithInt
type Narrowed<'de> = StructWithInt
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StructWithInt>)
fn zero_padding(out_: &mut MaybeUninit<StructWithInt>)
Writes zeroes to the padding for this type, if any.