#[repr(C)]pub struct StructWithVectors<'de> {
pub vec_empty: Vector<'de, Int32>,
pub vec_int: Vector<'de, Int32>,
pub vec_string: Vector<'de, String<'de>>,
pub vec_nullable_string: Vector<'de, OptionalString<'de>>,
pub vec_struct: Vector<'de, StructWithInt>,
pub vec_nullable_struct: Vector<'de, Box<'de, StructWithInt>>,
pub vec_vec_int: Vector<'de, Vector<'de, Int32>>,
}Expand description
The wire type corresponding to StructWithVectors.
Fields
vec_empty: Vector<'de, Int32>vec_int: Vector<'de, Int32>vec_string: Vector<'de, String<'de>>vec_nullable_string: Vector<'de, OptionalString<'de>>vec_struct: Vector<'de, StructWithInt>vec_nullable_struct: Vector<'de, Box<'de, StructWithInt>>vec_vec_int: Vector<'de, Vector<'de, Int32>>Trait Implementations
Sourceimpl Constrained for StructWithVectors<'_>
impl Constrained for StructWithVectors<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StructWithVectors<'_>>,
_: <StructWithVectors<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StructWithVectors<'_>>, _: <StructWithVectors<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for StructWithVectors<'de>
impl<'de> Debug for StructWithVectors<'de>
Sourceimpl<'de, ___D> Decode<___D> for StructWithVectors<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for StructWithVectors<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<StructWithVectors<'static>, ___E> for &'a StructWithVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<StructWithVectors<'static>, ___E> for &'a StructWithVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithVectors<'static>, ___E> for StructWithVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<StructWithVectors<'static>, ___E> for StructWithVectorswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StructWithVectors<'static>, ___E> for StructWithVectors<T0, T1, T2, T3, T4, T5, T6>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, Int32>, ___E>,
T1: Encode<Vector<'static, Int32>, ___E>,
T2: Encode<Vector<'static, String<'static>>, ___E>,
T3: Encode<Vector<'static, OptionalString<'static>>, ___E>,
T4: Encode<Vector<'static, StructWithInt>, ___E>,
T5: Encode<Vector<'static, Box<'static, StructWithInt>>, ___E>,
T6: Encode<Vector<'static, Vector<'static, Int32>>, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StructWithVectors<'static>, ___E> for StructWithVectors<T0, T1, T2, T3, T4, T5, T6>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, Int32>, ___E>,
T1: Encode<Vector<'static, Int32>, ___E>,
T2: Encode<Vector<'static, String<'static>>, ___E>,
T3: Encode<Vector<'static, OptionalString<'static>>, ___E>,
T4: Encode<Vector<'static, StructWithInt>, ___E>,
T5: Encode<Vector<'static, Box<'static, StructWithInt>>, ___E>,
T6: Encode<Vector<'static, Vector<'static, Int32>>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<StructWithVectors<'de>> for StructWithVectors
impl<'de> FromWire<StructWithVectors<'de>> for StructWithVectors
Sourcefn from_wire(wire: StructWithVectors<'de>) -> StructWithVectors
fn from_wire(wire: StructWithVectors<'de>) -> StructWithVectors
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructWithVectors<'de>> for StructWithVectors
impl<'de> FromWireRef<StructWithVectors<'de>> for StructWithVectors
Sourcefn from_wire_ref(wire: &StructWithVectors<'de>) -> StructWithVectors
fn from_wire_ref(wire: &StructWithVectors<'de>) -> StructWithVectors
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for StructWithVectors<'de>
impl<'de> IntoNatural for StructWithVectors<'de>
Sourcetype Natural = StructWithVectors
type Natural = StructWithVectors
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StructWithVectors<'static>
impl Wire for StructWithVectors<'static>
Sourcetype Narrowed<'de> = StructWithVectors<'de>
type Narrowed<'de> = StructWithVectors<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StructWithVectors<'static>>)
fn zero_padding(out_: &mut MaybeUninit<StructWithVectors<'static>>)
Writes zeroes to the padding for this type, if any.