#[repr(C)]pub struct TableStructWithUint32SandwichStruct<'de> {
pub table: TableStructWithUint32Sandwich<'de>,
}Expand description
The wire type corresponding to TableStructWithUint32SandwichStruct.
Fields
table: TableStructWithUint32Sandwich<'de>Trait Implementations
Sourceimpl Constrained for TableStructWithUint32SandwichStruct<'_>
impl Constrained for TableStructWithUint32SandwichStruct<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TableStructWithUint32SandwichStruct<'_>>,
_: <TableStructWithUint32SandwichStruct<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TableStructWithUint32SandwichStruct<'_>>, _: <TableStructWithUint32SandwichStruct<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for TableStructWithUint32SandwichStruct<'de>
impl<'de> Debug for TableStructWithUint32SandwichStruct<'de>
Sourceimpl<'de, ___D> Decode<___D> for TableStructWithUint32SandwichStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for TableStructWithUint32SandwichStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for &'a TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<TableStructWithUint32Sandwich<'static>, ___E>,
impl<___E, T0> Encode<TableStructWithUint32SandwichStruct<'static>, ___E> for TableStructWithUint32SandwichStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<TableStructWithUint32Sandwich<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
impl<'de> FromWire<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
Sourcefn from_wire(
wire: TableStructWithUint32SandwichStruct<'de>,
) -> TableStructWithUint32SandwichStruct
fn from_wire( wire: TableStructWithUint32SandwichStruct<'de>, ) -> TableStructWithUint32SandwichStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
impl<'de> FromWireRef<TableStructWithUint32SandwichStruct<'de>> for TableStructWithUint32SandwichStruct
Sourcefn from_wire_ref(
wire: &TableStructWithUint32SandwichStruct<'de>,
) -> TableStructWithUint32SandwichStruct
fn from_wire_ref( wire: &TableStructWithUint32SandwichStruct<'de>, ) -> TableStructWithUint32SandwichStruct
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for TableStructWithUint32SandwichStruct<'de>
impl<'de> IntoNatural for TableStructWithUint32SandwichStruct<'de>
Sourcetype Natural = TableStructWithUint32SandwichStruct
type Natural = TableStructWithUint32SandwichStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TableStructWithUint32SandwichStruct<'static>
impl Wire for TableStructWithUint32SandwichStruct<'static>
Sourcetype Narrowed<'de> = TableStructWithUint32SandwichStruct<'de>
type Narrowed<'de> = TableStructWithUint32SandwichStruct<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(
out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>,
)
fn zero_padding( out_: &mut MaybeUninit<TableStructWithUint32SandwichStruct<'static>>, )
Writes zeroes to the padding for this type, if any.