#[repr(C)]pub struct TableWithReservedFieldThenUnionStruct<'de> {
pub t: TableWithReservedFieldThenUnion<'de>,
}Expand description
The wire type corresponding to TableWithReservedFieldThenUnionStruct.
Fields
t: TableWithReservedFieldThenUnion<'de>Trait Implementations
Sourceimpl Constrained for TableWithReservedFieldThenUnionStruct<'_>
impl Constrained for TableWithReservedFieldThenUnionStruct<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TableWithReservedFieldThenUnionStruct<'_>>,
_: <TableWithReservedFieldThenUnionStruct<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TableWithReservedFieldThenUnionStruct<'_>>, _: <TableWithReservedFieldThenUnionStruct<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for TableWithReservedFieldThenUnionStruct<'de>
impl<'de> Debug for TableWithReservedFieldThenUnionStruct<'de>
Sourceimpl<'de, ___D> Decode<___D> for TableWithReservedFieldThenUnionStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for TableWithReservedFieldThenUnionStruct<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<TableWithReservedFieldThenUnion<'static>, ___E>,
impl<___E, T0> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStruct<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<TableWithReservedFieldThenUnion<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
impl<'de> FromWire<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
Sourcefn from_wire(
wire: TableWithReservedFieldThenUnionStruct<'de>,
) -> TableWithReservedFieldThenUnionStruct
fn from_wire( wire: TableWithReservedFieldThenUnionStruct<'de>, ) -> TableWithReservedFieldThenUnionStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
impl<'de> FromWireRef<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
Sourcefn from_wire_ref(
wire: &TableWithReservedFieldThenUnionStruct<'de>,
) -> TableWithReservedFieldThenUnionStruct
fn from_wire_ref( wire: &TableWithReservedFieldThenUnionStruct<'de>, ) -> TableWithReservedFieldThenUnionStruct
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for TableWithReservedFieldThenUnionStruct<'de>
impl<'de> IntoNatural for TableWithReservedFieldThenUnionStruct<'de>
Sourcetype Natural = TableWithReservedFieldThenUnionStruct
type Natural = TableWithReservedFieldThenUnionStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TableWithReservedFieldThenUnionStruct<'static>
impl Wire for TableWithReservedFieldThenUnionStruct<'static>
Sourcetype Narrowed<'de> = TableWithReservedFieldThenUnionStruct<'de>
type Narrowed<'de> = TableWithReservedFieldThenUnionStruct<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
)
fn zero_padding( out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, )
Writes zeroes to the padding for this type, if any.