#[repr(C)]pub struct TestAddEthernetDeviceRequest<'de> {
pub topological_path: String<'de>,
pub config: InterfaceConfig<'de>,
pub this_should_be_a_handle: Uint32,
}Expand description
The wire type corresponding to TestAddEthernetDeviceRequest.
Fields
topological_path: String<'de>config: InterfaceConfig<'de>this_should_be_a_handle: Uint32Trait Implementations
Sourceimpl Constrained for TestAddEthernetDeviceRequest<'_>
impl Constrained for TestAddEthernetDeviceRequest<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TestAddEthernetDeviceRequest<'_>>,
_: <TestAddEthernetDeviceRequest<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TestAddEthernetDeviceRequest<'_>>, _: <TestAddEthernetDeviceRequest<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for TestAddEthernetDeviceRequest<'de>
impl<'de> Debug for TestAddEthernetDeviceRequest<'de>
Sourceimpl<'de, ___D> Decode<___D> for TestAddEthernetDeviceRequest<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for TestAddEthernetDeviceRequest<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for &'a TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequest<T0, T1, T2>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
T1: Encode<InterfaceConfig<'static>, ___E>,
T2: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2> Encode<TestAddEthernetDeviceRequest<'static>, ___E> for TestAddEthernetDeviceRequest<T0, T1, T2>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
T1: Encode<InterfaceConfig<'static>, ___E>,
T2: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
impl<'de> FromWire<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
Sourcefn from_wire(
wire: TestAddEthernetDeviceRequest<'de>,
) -> TestAddEthernetDeviceRequest
fn from_wire( wire: TestAddEthernetDeviceRequest<'de>, ) -> TestAddEthernetDeviceRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
impl<'de> FromWireRef<TestAddEthernetDeviceRequest<'de>> for TestAddEthernetDeviceRequest
Sourcefn from_wire_ref(
wire: &TestAddEthernetDeviceRequest<'de>,
) -> TestAddEthernetDeviceRequest
fn from_wire_ref( wire: &TestAddEthernetDeviceRequest<'de>, ) -> TestAddEthernetDeviceRequest
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for TestAddEthernetDeviceRequest<'de>
impl<'de> IntoNatural for TestAddEthernetDeviceRequest<'de>
Sourcetype Natural = TestAddEthernetDeviceRequest
type Natural = TestAddEthernetDeviceRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TestAddEthernetDeviceRequest<'static>
impl Wire for TestAddEthernetDeviceRequest<'static>
Sourcetype Narrowed<'de> = TestAddEthernetDeviceRequest<'de>
type Narrowed<'de> = TestAddEthernetDeviceRequest<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>)
fn zero_padding(out_: &mut MaybeUninit<TestAddEthernetDeviceRequest<'static>>)
Writes zeroes to the padding for this type, if any.