#[repr(C)]pub struct TwoLayerStructInnerBool {
pub s: OneLayerStructWithBool,
pub a: Uint64,
}Expand description
The wire type corresponding to TwoLayerStructInnerBool.
Fields
s: OneLayerStructWithBoola: Uint64Trait Implementations
Sourceimpl Clone for TwoLayerStructInnerBool
impl Clone for TwoLayerStructInnerBool
Sourcefn clone(&self) -> TwoLayerStructInnerBool
fn clone(&self) -> TwoLayerStructInnerBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TwoLayerStructInnerBool
impl Constrained for TwoLayerStructInnerBool
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TwoLayerStructInnerBool>,
_: <TwoLayerStructInnerBool as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TwoLayerStructInnerBool>, _: <TwoLayerStructInnerBool as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for TwoLayerStructInnerBool
impl Debug for TwoLayerStructInnerBool
Sourceimpl<___D> Decode<___D> for TwoLayerStructInnerBoolwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TwoLayerStructInnerBoolwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TwoLayerStructInnerBool, ___E> for &'a TwoLayerStructInnerBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructInnerBool, ___E> for &'a TwoLayerStructInnerBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructInnerBool, ___E> for TwoLayerStructInnerBoolwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructInnerBool, ___E> for TwoLayerStructInnerBoolwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructInnerBool, TwoLayerStructInnerBool>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructInnerBool, TwoLayerStructInnerBool>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<TwoLayerStructInnerBool, ___E> for TwoLayerStructInnerBool<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithBool, ___E>,
T1: Encode<Uint64, ___E>,
impl<___E, T0, T1> Encode<TwoLayerStructInnerBool, ___E> for TwoLayerStructInnerBool<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithBool, ___E>,
T1: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerBool>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerBool>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TwoLayerStructInnerBool> for TwoLayerStructInnerBool
impl FromWire<TwoLayerStructInnerBool> for TwoLayerStructInnerBool
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructInnerBool, TwoLayerStructInnerBool>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructInnerBool, TwoLayerStructInnerBool>
Sourcefn from_wire(wire: TwoLayerStructInnerBool) -> TwoLayerStructInnerBool
fn from_wire(wire: TwoLayerStructInnerBool) -> TwoLayerStructInnerBool
Converts the given owned value to this type.
Sourceimpl FromWireRef<TwoLayerStructInnerBool> for TwoLayerStructInnerBool
impl FromWireRef<TwoLayerStructInnerBool> for TwoLayerStructInnerBool
Sourcefn from_wire_ref(wire: &TwoLayerStructInnerBool) -> TwoLayerStructInnerBool
fn from_wire_ref(wire: &TwoLayerStructInnerBool) -> TwoLayerStructInnerBool
Converts the given reference to this type.
Sourceimpl IntoNatural for TwoLayerStructInnerBool
impl IntoNatural for TwoLayerStructInnerBool
Sourcetype Natural = TwoLayerStructInnerBool
type Natural = TwoLayerStructInnerBool
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TwoLayerStructInnerBool
impl Wire for TwoLayerStructInnerBool
Sourcetype Narrowed<'de> = TwoLayerStructInnerBool
type Narrowed<'de> = TwoLayerStructInnerBool
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TwoLayerStructInnerBool>)
fn zero_padding(out_: &mut MaybeUninit<TwoLayerStructInnerBool>)
Writes zeroes to the padding for this type, if any.