#[repr(C)]pub struct TwoLayerStructNoPaddingAlign4 {
pub s: OneLayerStructNoPaddingAlign4,
pub a: Uint32,
}Expand description
The wire type corresponding to TwoLayerStructNoPaddingAlign4.
Fields
s: OneLayerStructNoPaddingAlign4a: Uint32Trait Implementations
Sourceimpl Clone for TwoLayerStructNoPaddingAlign4
impl Clone for TwoLayerStructNoPaddingAlign4
Sourcefn clone(&self) -> TwoLayerStructNoPaddingAlign4
fn clone(&self) -> TwoLayerStructNoPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TwoLayerStructNoPaddingAlign4
impl Constrained for TwoLayerStructNoPaddingAlign4
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TwoLayerStructNoPaddingAlign4>,
_: <TwoLayerStructNoPaddingAlign4 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TwoLayerStructNoPaddingAlign4>, _: <TwoLayerStructNoPaddingAlign4 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for TwoLayerStructNoPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TwoLayerStructNoPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for &'a TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructNoPaddingAlign4, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<TwoLayerStructNoPaddingAlign4, ___E> for TwoLayerStructNoPaddingAlign4<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructNoPaddingAlign4, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
impl FromWire<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign4, TwoLayerStructNoPaddingAlign4>
Sourcefn from_wire(
wire: TwoLayerStructNoPaddingAlign4,
) -> TwoLayerStructNoPaddingAlign4
fn from_wire( wire: TwoLayerStructNoPaddingAlign4, ) -> TwoLayerStructNoPaddingAlign4
Converts the given owned value to this type.
Sourceimpl FromWireRef<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
impl FromWireRef<TwoLayerStructNoPaddingAlign4> for TwoLayerStructNoPaddingAlign4
Sourcefn from_wire_ref(
wire: &TwoLayerStructNoPaddingAlign4,
) -> TwoLayerStructNoPaddingAlign4
fn from_wire_ref( wire: &TwoLayerStructNoPaddingAlign4, ) -> TwoLayerStructNoPaddingAlign4
Converts the given reference to this type.
Sourceimpl IntoNatural for TwoLayerStructNoPaddingAlign4
impl IntoNatural for TwoLayerStructNoPaddingAlign4
Sourcetype Natural = TwoLayerStructNoPaddingAlign4
type Natural = TwoLayerStructNoPaddingAlign4
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TwoLayerStructNoPaddingAlign4
impl Wire for TwoLayerStructNoPaddingAlign4
Sourcetype Narrowed<'de> = TwoLayerStructNoPaddingAlign4
type Narrowed<'de> = TwoLayerStructNoPaddingAlign4
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>)
fn zero_padding(out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign4>)
Writes zeroes to the padding for this type, if any.