#[repr(C)]pub struct Uint16Struct {
pub val: Uint16,
}Expand description
The wire type corresponding to Uint16Struct.
Fields
val: Uint16Trait Implementations
Sourceimpl Clone for Uint16Struct
impl Clone for Uint16Struct
Sourcefn clone(&self) -> Uint16Struct
fn clone(&self) -> Uint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint16Struct
impl Constrained for Uint16Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint16Struct>,
_: <Uint16Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint16Struct>, _: <Uint16Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint16Struct
impl Debug for Uint16Struct
Sourceimpl<___D> Decode<___D> for Uint16Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint16Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint16Struct, ___E> for &'a Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint16Struct, ___E> for &'a Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint16Struct, ___E> for Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint16Struct, ___E> for Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Uint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Uint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Uint16Struct, ___E> for Uint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<Uint16Struct, ___E> for Uint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint16Struct> for Uint16Struct
impl FromWire<Uint16Struct> for Uint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Uint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Uint16Struct>
Sourcefn from_wire(wire: Uint16Struct) -> Uint16Struct
fn from_wire(wire: Uint16Struct) -> Uint16Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint16Struct> for Uint16Struct
impl FromWireRef<Uint16Struct> for Uint16Struct
Sourcefn from_wire_ref(wire: &Uint16Struct) -> Uint16Struct
fn from_wire_ref(wire: &Uint16Struct) -> Uint16Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint16Struct
impl IntoNatural for Uint16Struct
Sourcetype Natural = Uint16Struct
type Natural = Uint16Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint16Struct
impl Wire for Uint16Struct
Sourcetype Narrowed<'de> = Uint16Struct
type Narrowed<'de> = Uint16Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint16Struct>)
fn zero_padding(out_: &mut MaybeUninit<Uint16Struct>)
Writes zeroes to the padding for this type, if any.