#[repr(C)]pub struct Uint32Struct {
pub val: Uint32,
}Expand description
The wire type corresponding to Uint32Struct.
Fields
val: Uint32Trait Implementations
Sourceimpl Clone for Uint32Struct
impl Clone for Uint32Struct
Sourcefn clone(&self) -> Uint32Struct
fn clone(&self) -> Uint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint32Struct
impl Constrained for Uint32Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint32Struct>,
_: <Uint32Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint32Struct>, _: <Uint32Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint32Struct
impl Debug for Uint32Struct
Sourceimpl<___D> Decode<___D> for Uint32Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint32Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint32Struct, ___E> for &'a Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint32Struct, ___E> for &'a Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint32Struct, ___E> for Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint32Struct, ___E> for Uint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Uint32Struct, ___E> for Uint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<Uint32Struct, ___E> for Uint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint32Struct> for Uint32Struct
impl FromWire<Uint32Struct> for Uint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint32Struct, Uint32Struct>
Sourcefn from_wire(wire: Uint32Struct) -> Uint32Struct
fn from_wire(wire: Uint32Struct) -> Uint32Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint32Struct> for Uint32Struct
impl FromWireRef<Uint32Struct> for Uint32Struct
Sourcefn from_wire_ref(wire: &Uint32Struct) -> Uint32Struct
fn from_wire_ref(wire: &Uint32Struct) -> Uint32Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint32Struct
impl IntoNatural for Uint32Struct
Sourcetype Natural = Uint32Struct
type Natural = Uint32Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint32Struct
impl Wire for Uint32Struct
Sourcetype Narrowed<'de> = Uint32Struct
type Narrowed<'de> = Uint32Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint32Struct>)
fn zero_padding(out_: &mut MaybeUninit<Uint32Struct>)
Writes zeroes to the padding for this type, if any.