#[repr(C)]pub struct Uint64Struct {
pub val: Uint64,
}Expand description
The wire type corresponding to Uint64Struct.
Fields
val: Uint64Trait Implementations
Sourceimpl Clone for Uint64Struct
impl Clone for Uint64Struct
Sourcefn clone(&self) -> Uint64Struct
fn clone(&self) -> Uint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint64Struct
impl Constrained for Uint64Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint64Struct>,
_: <Uint64Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint64Struct>, _: <Uint64Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint64Struct
impl Debug for Uint64Struct
Sourceimpl<___D> Decode<___D> for Uint64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint64Struct, ___E> for &'a Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint64Struct, ___E> for &'a Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint64Struct, ___E> for Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint64Struct, ___E> for Uint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Uint64Struct, ___E> for Uint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<Uint64Struct, ___E> for Uint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint64Struct> for Uint64Struct
impl FromWire<Uint64Struct> for Uint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint64Struct, Uint64Struct>
Sourcefn from_wire(wire: Uint64Struct) -> Uint64Struct
fn from_wire(wire: Uint64Struct) -> Uint64Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint64Struct> for Uint64Struct
impl FromWireRef<Uint64Struct> for Uint64Struct
Sourcefn from_wire_ref(wire: &Uint64Struct) -> Uint64Struct
fn from_wire_ref(wire: &Uint64Struct) -> Uint64Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint64Struct
impl IntoNatural for Uint64Struct
Sourcetype Natural = Uint64Struct
type Natural = Uint64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint64Struct
impl Wire for Uint64Struct
Sourcetype Narrowed<'de> = Uint64Struct
type Narrowed<'de> = Uint64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint64Struct>)
fn zero_padding(out_: &mut MaybeUninit<Uint64Struct>)
Writes zeroes to the padding for this type, if any.