#[repr(C)]pub struct Uint64Uint32Uint16Uint8 {
pub f1: Uint64,
pub f2: Uint32,
pub f3: Uint16,
pub f4: u8,
}Expand description
The wire type corresponding to Uint64Uint32Uint16Uint8.
Fields
f1: Uint64f2: Uint32f3: Uint16f4: u8Trait Implementations
Sourceimpl Clone for Uint64Uint32Uint16Uint8
impl Clone for Uint64Uint32Uint16Uint8
Sourcefn clone(&self) -> Uint64Uint32Uint16Uint8
fn clone(&self) -> Uint64Uint32Uint16Uint8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint64Uint32Uint16Uint8
impl Constrained for Uint64Uint32Uint16Uint8
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint64Uint32Uint16Uint8>,
_: <Uint64Uint32Uint16Uint8 as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint64Uint32Uint16Uint8>, _: <Uint64Uint32Uint16Uint8 as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint64Uint32Uint16Uint8
impl Debug for Uint64Uint32Uint16Uint8
Sourceimpl<___D> Decode<___D> for Uint64Uint32Uint16Uint8where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint64Uint32Uint16Uint8where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint64Uint32Uint16Uint8, ___E> for &'a Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint64Uint32Uint16Uint8, ___E> for &'a Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl FromWire<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn from_wire(wire: Uint64Uint32Uint16Uint8) -> Uint64Uint32Uint16Uint8
fn from_wire(wire: Uint64Uint32Uint16Uint8) -> Uint64Uint32Uint16Uint8
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl FromWireRef<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn from_wire_ref(wire: &Uint64Uint32Uint16Uint8) -> Uint64Uint32Uint16Uint8
fn from_wire_ref(wire: &Uint64Uint32Uint16Uint8) -> Uint64Uint32Uint16Uint8
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint64Uint32Uint16Uint8
impl IntoNatural for Uint64Uint32Uint16Uint8
Sourcetype Natural = Uint64Uint32Uint16Uint8
type Natural = Uint64Uint32Uint16Uint8
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint64Uint32Uint16Uint8
impl Wire for Uint64Uint32Uint16Uint8
Sourcetype Narrowed<'de> = Uint64Uint32Uint16Uint8
type Narrowed<'de> = Uint64Uint32Uint16Uint8
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>)
fn zero_padding(out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>)
Writes zeroes to the padding for this type, if any.