#[repr(C)]pub struct Uint8Struct {
pub val: u8,
}Expand description
The wire type corresponding to Uint8Struct.
Fields
val: u8Trait Implementations
Sourceimpl Clone for Uint8Struct
impl Clone for Uint8Struct
Sourcefn clone(&self) -> Uint8Struct
fn clone(&self) -> Uint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint8Struct
impl Constrained for Uint8Struct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint8Struct>,
_: <Uint8Struct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint8Struct>, _: <Uint8Struct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint8Struct
impl Debug for Uint8Struct
Sourceimpl<___D> Decode<___D> for Uint8Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint8Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint8Struct, ___E> for &'a Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8Struct, ___E> for &'a Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8Struct, ___E> for Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8Struct, ___E> for Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Uint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Uint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Uint8Struct, ___E> for Uint8Struct<T0>
impl<___E, T0> Encode<Uint8Struct, ___E> for Uint8Struct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint8Struct> for Uint8Struct
impl FromWire<Uint8Struct> for Uint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Uint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Uint8Struct>
Sourcefn from_wire(wire: Uint8Struct) -> Uint8Struct
fn from_wire(wire: Uint8Struct) -> Uint8Struct
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint8Struct> for Uint8Struct
impl FromWireRef<Uint8Struct> for Uint8Struct
Sourcefn from_wire_ref(wire: &Uint8Struct) -> Uint8Struct
fn from_wire_ref(wire: &Uint8Struct) -> Uint8Struct
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint8Struct
impl IntoNatural for Uint8Struct
Sourcetype Natural = Uint8Struct
type Natural = Uint8Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint8Struct
impl Wire for Uint8Struct
Sourcetype Narrowed<'de> = Uint8Struct
type Narrowed<'de> = Uint8Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint8Struct>)
fn zero_padding(out_: &mut MaybeUninit<Uint8Struct>)
Writes zeroes to the padding for this type, if any.