#[repr(C)]pub struct Uint8UnionStruct {
pub u: Uint8Union,
}Expand description
The wire type corresponding to Uint8UnionStruct.
Fields
u: Uint8UnionTrait Implementations
Sourceimpl Clone for Uint8UnionStruct
impl Clone for Uint8UnionStruct
Sourcefn clone(&self) -> Uint8UnionStruct
fn clone(&self) -> Uint8UnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint8UnionStruct
impl Constrained for Uint8UnionStruct
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, Uint8UnionStruct>,
_: <Uint8UnionStruct as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, Uint8UnionStruct>, _: <Uint8UnionStruct as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for Uint8UnionStruct
impl Debug for Uint8UnionStruct
Sourceimpl<___D> Decode<___D> for Uint8UnionStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint8UnionStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint8UnionStruct, ___E> for &'a Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8UnionStruct, ___E> for &'a Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8UnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8UnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8UnionStruct, ___E> for Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8UnionStruct, ___E> for Uint8UnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8UnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8UnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<Uint8UnionStruct, ___E> for Uint8UnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint8Union, ___E>,
impl<___E, T0> Encode<Uint8UnionStruct, ___E> for Uint8UnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint8Union, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8UnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8UnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint8UnionStruct> for Uint8UnionStruct
impl FromWire<Uint8UnionStruct> for Uint8UnionStruct
Sourcefn from_wire(wire: Uint8UnionStruct) -> Uint8UnionStruct
fn from_wire(wire: Uint8UnionStruct) -> Uint8UnionStruct
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint8UnionStruct> for Uint8UnionStruct
impl FromWireRef<Uint8UnionStruct> for Uint8UnionStruct
Sourcefn from_wire_ref(wire: &Uint8UnionStruct) -> Uint8UnionStruct
fn from_wire_ref(wire: &Uint8UnionStruct) -> Uint8UnionStruct
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint8UnionStruct
impl IntoNatural for Uint8UnionStruct
Sourcetype Natural = Uint8UnionStruct
type Natural = Uint8UnionStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint8UnionStruct
impl Wire for Uint8UnionStruct
Sourcetype Narrowed<'de> = Uint8UnionStruct
type Narrowed<'de> = Uint8UnionStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Uint8UnionStruct>)
fn zero_padding(out_: &mut MaybeUninit<Uint8UnionStruct>)
Writes zeroes to the padding for this type, if any.