#[repr(C)]pub struct UpdatePolicy {
pub fetch_if_absent: bool,
pub allow_old_versions: bool,
}Expand description
The wire type corresponding to UpdatePolicy.
Fields
fetch_if_absent: boolallow_old_versions: boolTrait Implementations
Sourceimpl Clone for UpdatePolicy
impl Clone for UpdatePolicy
Sourcefn clone(&self) -> UpdatePolicy
fn clone(&self) -> UpdatePolicy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for UpdatePolicy
impl Constrained for UpdatePolicy
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, UpdatePolicy>,
_: <UpdatePolicy as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, UpdatePolicy>, _: <UpdatePolicy as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for UpdatePolicy
impl Debug for UpdatePolicy
Sourceimpl<___D> Decode<___D> for UpdatePolicywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for UpdatePolicywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<UpdatePolicy, ___E> for &'a UpdatePolicywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<UpdatePolicy, ___E> for &'a UpdatePolicywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UpdatePolicy>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UpdatePolicy>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UpdatePolicy, ___E> for UpdatePolicywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<UpdatePolicy, ___E> for UpdatePolicywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UpdatePolicy, UpdatePolicy>
const COPY_OPTIMIZATION: CopyOptimization<UpdatePolicy, UpdatePolicy>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UpdatePolicy>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UpdatePolicy>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<UpdatePolicy, ___E> for UpdatePolicy<T0, T1>
impl<___E, T0, T1> Encode<UpdatePolicy, ___E> for UpdatePolicy<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UpdatePolicy>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UpdatePolicy>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<UpdatePolicy> for UpdatePolicy
impl FromWire<UpdatePolicy> for UpdatePolicy
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UpdatePolicy, UpdatePolicy>
const COPY_OPTIMIZATION: CopyOptimization<UpdatePolicy, UpdatePolicy>
Sourcefn from_wire(wire: UpdatePolicy) -> UpdatePolicy
fn from_wire(wire: UpdatePolicy) -> UpdatePolicy
Converts the given owned value to this type.
Sourceimpl FromWireRef<UpdatePolicy> for UpdatePolicy
impl FromWireRef<UpdatePolicy> for UpdatePolicy
Sourcefn from_wire_ref(wire: &UpdatePolicy) -> UpdatePolicy
fn from_wire_ref(wire: &UpdatePolicy) -> UpdatePolicy
Converts the given reference to this type.
Sourceimpl IntoNatural for UpdatePolicy
impl IntoNatural for UpdatePolicy
Sourcetype Natural = UpdatePolicy
type Natural = UpdatePolicy
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for UpdatePolicy
impl Wire for UpdatePolicy
Sourcetype Narrowed<'de> = UpdatePolicy
type Narrowed<'de> = UpdatePolicy
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<UpdatePolicy>)
fn zero_padding(out_: &mut MaybeUninit<UpdatePolicy>)
Writes zeroes to the padding for this type, if any.