#[repr(C)]pub struct GoldenHandleBasicRightsStruct {
pub v: Event,
}Fields
v: EventTrait Implementations
Sourceimpl CompatFrom<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
impl CompatFrom<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
Sourcefn compat_from(value: GoldenHandleBasicRightsStruct) -> Self
fn compat_from(value: GoldenHandleBasicRightsStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
impl CompatFrom<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
Sourcefn compat_from(value: GoldenHandleBasicRightsStruct) -> Self
fn compat_from(value: GoldenHandleBasicRightsStruct) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<GoldenHandleBasicRightsStruct, ___E> for GoldenHandleBasicRightsStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenHandleBasicRightsStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenHandleBasicRightsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenHandleBasicRightsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenHandleBasicRightsStruct>, ___E> for GoldenHandleBasicRightsStructwhere
___E: Encoder + ?Sized,
GoldenHandleBasicRightsStruct: Encode<GoldenHandleBasicRightsStruct, ___E>,
impl<___E> EncodeOption<Box<'static, GoldenHandleBasicRightsStruct>, ___E> for GoldenHandleBasicRightsStructwhere
___E: Encoder + ?Sized,
GoldenHandleBasicRightsStruct: Encode<GoldenHandleBasicRightsStruct, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenHandleBasicRightsStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenHandleBasicRightsStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
impl FromWire<GoldenHandleBasicRightsStruct> for GoldenHandleBasicRightsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenHandleBasicRightsStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenHandleBasicRightsStruct, Self>
Sourcefn from_wire(wire: GoldenHandleBasicRightsStruct) -> Self
fn from_wire(wire: GoldenHandleBasicRightsStruct) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for GoldenHandleBasicRightsStruct
impl PartialEq for GoldenHandleBasicRightsStruct
Sourcefn eq(&self, other: &GoldenHandleBasicRightsStruct) -> bool
fn eq(&self, other: &GoldenHandleBasicRightsStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GoldenHandleBasicRightsStruct